// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtxml_python.h"

// main header
#include "qdomnode_wrapper.h"

// Argument includes
#include <QString>
#include <QtXml/qdom.h>
#include <qtextstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomNode_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDomNode >()))
        return -1;

    ::QDomNode *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDomNode", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDomNode::QDomNode()
    // 1: QDomNode::QDomNode(QDomNode)
    if (numArgs == 0) {
        overloadId = 0; // QDomNode()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDomNode(QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDomNode()
        {

            // QDomNode()
            cptr = new ::QDomNode();
            break;
        }
        case 1: // QDomNode(const QDomNode &node)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDomNode cppArg0_local;
            ::QDomNode *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomNode(QDomNode)
                cptr = new ::QDomNode(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDomNode >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDomNodeFunc_appendChild(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomNode::appendChild(QDomNode)->QDomNode
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArg)))) {
        overloadId = 0; // appendChild(QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "appendChild", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDomNode cppArg0_local;
        ::QDomNode *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // appendChild(QDomNode)
            QDomNode cppResult = cppSelf->appendChild(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_attributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // attributes()const
        QDomNamedNodeMap cppResult = const_cast<const ::QDomNode *>(cppSelf)->attributes();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNamedNodeMap_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_childNodes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // childNodes()const
        QDomNodeList cppResult = const_cast<const ::QDomNode *>(cppSelf)->childNodes();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDomNodeFunc_cloneNode(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "cloneNode", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    if (PyArg_ParseTuple(args, "|O:cloneNode", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomNode::cloneNode(bool=)const->QDomNode
    if (numArgs == 0) {
        overloadId = 0; // cloneNode(bool)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // cloneNode(bool)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "cloneNode", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_deep = Shiboken::String::createStaticString("deep");
            if (PyDict_Contains(kwds, key_deep) != 0) {
                value = PyDict_GetItem(kwds, key_deep);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_deep);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "cloneNode", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "cloneNode", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_deep);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "cloneNode", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // cloneNode(bool)const
            QDomNode cppResult = const_cast<const ::QDomNode *>(cppSelf)->cloneNode(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_columnNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // columnNumber()const
        int cppResult = const_cast<const ::QDomNode *>(cppSelf)->columnNumber();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_firstChild(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // firstChild()const
        QDomNode cppResult = const_cast<const ::QDomNode *>(cppSelf)->firstChild();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_firstChildElement(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "firstChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    if (PyArg_ParseTuple(args, "|OO:firstChildElement", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomNode::firstChildElement(const QString&=,const QString&=)const->QDomElement
    if (numArgs == 0) {
        overloadId = 0; // firstChildElement(QString,QString)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // firstChildElement(QString,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // firstChildElement(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "firstChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_tagName = Shiboken::String::createStaticString("tagName");
            if (PyDict_Contains(kwds, key_tagName) != 0) {
                value = PyDict_GetItem(kwds, key_tagName);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_tagName);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "firstChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "firstChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_tagName);
            }
            static PyObject *const key_namespaceURI = Shiboken::String::createStaticString("namespaceURI");
            if (PyDict_Contains(kwds, key_namespaceURI) != 0) {
                value = PyDict_GetItem(kwds, key_namespaceURI);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_namespaceURI);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "firstChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "firstChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_namespaceURI);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "firstChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // firstChildElement(QString,QString)const
            QDomElement cppResult = const_cast<const ::QDomNode *>(cppSelf)->firstChildElement(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomElement_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_hasAttributes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasAttributes()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->hasAttributes();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_hasChildNodes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasChildNodes()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->hasChildNodes();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_insertAfter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertAfter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomNode::insertAfter(QDomNode,QDomNode)->QDomNode
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insertAfter(QDomNode,QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertAfter", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDomNode cppArg0_local;
        ::QDomNode *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDomNode cppArg1_local;
        ::QDomNode *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // insertAfter(QDomNode,QDomNode)
            QDomNode cppResult = cppSelf->insertAfter(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_insertBefore(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertBefore", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomNode::insertBefore(QDomNode,QDomNode)->QDomNode
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArgs[1])))) {
        overloadId = 0; // insertBefore(QDomNode,QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertBefore", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDomNode cppArg0_local;
        ::QDomNode *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDomNode cppArg1_local;
        ::QDomNode *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // insertBefore(QDomNode,QDomNode)
            QDomNode cppResult = cppSelf->insertBefore(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isAttr(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isAttr()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isAttr();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isCDATASection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isCDATASection()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isCDATASection();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isCharacterData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isCharacterData()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isCharacterData();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isComment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isComment()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isComment();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isDocument(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDocument()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isDocument();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isDocumentFragment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDocumentFragment()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isDocumentFragment();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isDocumentType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isDocumentType()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isDocumentType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isElement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isElement()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isElement();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isEntity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEntity()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isEntity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isEntityReference(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEntityReference()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isEntityReference();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isNotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNotation()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isNotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isNull(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isNull()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isNull();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isProcessingInstruction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isProcessingInstruction()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isProcessingInstruction();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isSupported(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "isSupported", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomNode::isSupported(QString,QString)const->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // isSupported(QString,QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "isSupported", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isSupported(QString,QString)const
            bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isSupported(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_isText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isText()const
        bool cppResult = const_cast<const ::QDomNode *>(cppSelf)->isText();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_lastChild(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastChild()const
        QDomNode cppResult = const_cast<const ::QDomNode *>(cppSelf)->lastChild();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_lastChildElement(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "lastChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    if (PyArg_ParseTuple(args, "|OO:lastChildElement", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomNode::lastChildElement(const QString&=,const QString&=)const->QDomElement
    if (numArgs == 0) {
        overloadId = 0; // lastChildElement(QString,QString)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // lastChildElement(QString,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // lastChildElement(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "lastChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_tagName = Shiboken::String::createStaticString("tagName");
            if (PyDict_Contains(kwds, key_tagName) != 0) {
                value = PyDict_GetItem(kwds, key_tagName);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_tagName);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "lastChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "lastChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_tagName);
            }
            static PyObject *const key_namespaceURI = Shiboken::String::createStaticString("namespaceURI");
            if (PyDict_Contains(kwds, key_namespaceURI) != 0) {
                value = PyDict_GetItem(kwds, key_namespaceURI);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_namespaceURI);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "lastChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "lastChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_namespaceURI);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "lastChildElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // lastChildElement(QString,QString)const
            QDomElement cppResult = const_cast<const ::QDomNode *>(cppSelf)->lastChildElement(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomElement_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_lineNumber(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lineNumber()const
        int cppResult = const_cast<const ::QDomNode *>(cppSelf)->lineNumber();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_localName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localName()const
        QString cppResult = const_cast<const ::QDomNode *>(cppSelf)->localName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_namedItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomNode::namedItem(QString)const->QDomNode
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // namedItem(QString)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "namedItem", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // namedItem(QString)const
            QDomNode cppResult = const_cast<const ::QDomNode *>(cppSelf)->namedItem(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_namespaceURI(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // namespaceURI()const
        QString cppResult = const_cast<const ::QDomNode *>(cppSelf)->namespaceURI();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_nextSibling(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nextSibling()const
        QDomNode cppResult = const_cast<const ::QDomNode *>(cppSelf)->nextSibling();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_nextSiblingElement(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "nextSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    if (PyArg_ParseTuple(args, "|OO:nextSiblingElement", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomNode::nextSiblingElement(const QString&=,const QString&=)const->QDomElement
    if (numArgs == 0) {
        overloadId = 0; // nextSiblingElement(QString,QString)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // nextSiblingElement(QString,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // nextSiblingElement(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "nextSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_taName = Shiboken::String::createStaticString("taName");
            if (PyDict_Contains(kwds, key_taName) != 0) {
                value = PyDict_GetItem(kwds, key_taName);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_taName);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "nextSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "nextSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_taName);
            }
            static PyObject *const key_namespaceURI = Shiboken::String::createStaticString("namespaceURI");
            if (PyDict_Contains(kwds, key_namespaceURI) != 0) {
                value = PyDict_GetItem(kwds, key_namespaceURI);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_namespaceURI);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "nextSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "nextSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_namespaceURI);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "nextSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // nextSiblingElement(QString,QString)const
            QDomElement cppResult = const_cast<const ::QDomNode *>(cppSelf)->nextSiblingElement(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomElement_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_nodeName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nodeName()const
        QString cppResult = const_cast<const ::QDomNode *>(cppSelf)->nodeName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_nodeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nodeType()const
        QDomNode::NodeType cppResult = const_cast<const ::QDomNode *>(cppSelf)->nodeType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_NodeType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_nodeValue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nodeValue()const
        QString cppResult = const_cast<const ::QDomNode *>(cppSelf)->nodeValue();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_normalize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // normalize()
        cppSelf->normalize();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDomNodeFunc_ownerDocument(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ownerDocument()const
        QDomDocument cppResult = const_cast<const ::QDomNode *>(cppSelf)->ownerDocument();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_parentNode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parentNode()const
        QDomNode cppResult = const_cast<const ::QDomNode *>(cppSelf)->parentNode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_prefix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // prefix()const
        QString cppResult = const_cast<const ::QDomNode *>(cppSelf)->prefix();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_previousSibling(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // previousSibling()const
        QDomNode cppResult = const_cast<const ::QDomNode *>(cppSelf)->previousSibling();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_previousSiblingElement(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "previousSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    if (PyArg_ParseTuple(args, "|OO:previousSiblingElement", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomNode::previousSiblingElement(const QString&=,const QString&=)const->QDomElement
    if (numArgs == 0) {
        overloadId = 0; // previousSiblingElement(QString,QString)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // previousSiblingElement(QString,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // previousSiblingElement(QString,QString)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "previousSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_tagName = Shiboken::String::createStaticString("tagName");
            if (PyDict_Contains(kwds, key_tagName) != 0) {
                value = PyDict_GetItem(kwds, key_tagName);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_tagName);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "previousSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "previousSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_tagName);
            }
            static PyObject *const key_namespaceURI = Shiboken::String::createStaticString("namespaceURI");
            if (PyDict_Contains(kwds, key_namespaceURI) != 0) {
                value = PyDict_GetItem(kwds, key_namespaceURI);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_namespaceURI);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "previousSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "previousSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_namespaceURI);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "previousSiblingElement", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
            }
        }
        ::QString cppArg0 = QString();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // previousSiblingElement(QString,QString)const
            QDomElement cppResult = const_cast<const ::QDomNode *>(cppSelf)->previousSiblingElement(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomElement_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_removeChild(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomNode::removeChild(QDomNode)->QDomNode
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArg)))) {
        overloadId = 0; // removeChild(QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeChild", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDomNode cppArg0_local;
        ::QDomNode *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // removeChild(QDomNode)
            QDomNode cppResult = cppSelf->removeChild(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_replaceChild(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "replaceChild", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomNode::replaceChild(QDomNode,QDomNode)->QDomNode
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArgs[1])))) {
        overloadId = 0; // replaceChild(QDomNode,QDomNode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "replaceChild", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDomNode cppArg0_local;
        ::QDomNode *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QDomNode cppArg1_local;
        ::QDomNode *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // replaceChild(QDomNode,QDomNode)
            QDomNode cppResult = cppSelf->replaceChild(*cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_save(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "save", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:save", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QDomNode::save(QTextStream&,int,QDomNode::EncodingPolicy=)const
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // save(QTextStream&,int,QDomNode::EncodingPolicy)const
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_EncodingPolicy_IDX])))->converter, (pyArgs[2])))) {
            overloadId = 0; // save(QTextStream&,int,QDomNode::EncodingPolicy)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "save", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_arg__3 = Shiboken::String::createStaticString("arg__3");
            if (PyDict_Contains(kwds, key_arg__3) != 0) {
                value = PyDict_GetItem(kwds, key_arg__3);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_arg__3);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "save", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_EncodingPolicy_IDX])))->converter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "save", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_arg__3);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "save", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTextStream *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QDomNode::EncodingPolicy cppArg2(QDomNode::EncodingFromDocument);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // save(QTextStream&,int,QDomNode::EncodingPolicy)const
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const_cast<const ::QDomNode *>(cppSelf)->save(*cppArg0, cppArg1, cppArg2);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDomNodeFunc_setNodeValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomNode::setNodeValue(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setNodeValue(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNodeValue", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNodeValue(QString)
            cppSelf->setNodeValue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDomNodeFunc_setPrefix(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomNode::setPrefix(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPrefix(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPrefix", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPrefix(QString)
            cppSelf->setPrefix(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDomNodeFunc_toAttr(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toAttr()const
        QDomAttr cppResult = const_cast<const ::QDomNode *>(cppSelf)->toAttr();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomAttr_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_toCDATASection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toCDATASection()const
        QDomCDATASection cppResult = const_cast<const ::QDomNode *>(cppSelf)->toCDATASection();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCDATASection_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_toCharacterData(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toCharacterData()const
        QDomCharacterData cppResult = const_cast<const ::QDomNode *>(cppSelf)->toCharacterData();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomCharacterData_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_toComment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toComment()const
        QDomComment cppResult = const_cast<const ::QDomNode *>(cppSelf)->toComment();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomComment_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_toDocument(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toDocument()const
        QDomDocument cppResult = const_cast<const ::QDomNode *>(cppSelf)->toDocument();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocument_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_toDocumentFragment(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toDocumentFragment()const
        QDomDocumentFragment cppResult = const_cast<const ::QDomNode *>(cppSelf)->toDocumentFragment();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentFragment_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_toDocumentType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toDocumentType()const
        QDomDocumentType cppResult = const_cast<const ::QDomNode *>(cppSelf)->toDocumentType();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomDocumentType_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_toElement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toElement()const
        QDomElement cppResult = const_cast<const ::QDomNode *>(cppSelf)->toElement();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomElement_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_toEntity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toEntity()const
        QDomEntity cppResult = const_cast<const ::QDomNode *>(cppSelf)->toEntity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntity_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_toEntityReference(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toEntityReference()const
        QDomEntityReference cppResult = const_cast<const ::QDomNode *>(cppSelf)->toEntityReference();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomEntityReference_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_toNotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toNotation()const
        QDomNotation cppResult = const_cast<const ::QDomNode *>(cppSelf)->toNotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNotation_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_toProcessingInstruction(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toProcessingInstruction()const
        QDomProcessingInstruction cppResult = const_cast<const ::QDomNode *>(cppSelf)->toProcessingInstruction();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeFunc_toText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toText()const
        QDomText cppResult = const_cast<const ::QDomNode *>(cppSelf)->toText();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomText_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNode__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDomNode_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QDomNode_EnumFlagInfo[] = {
    "EncodingPolicy:Enum",
    "NodeType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDomNode_methods[] = {
    {"appendChild", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_appendChild), METH_O, nullptr},
    {"attributes", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_attributes), METH_NOARGS, nullptr},
    {"childNodes", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_childNodes), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_clear), METH_NOARGS, nullptr},
    {"cloneNode", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_cloneNode), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"columnNumber", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_columnNumber), METH_NOARGS, nullptr},
    {"firstChild", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_firstChild), METH_NOARGS, nullptr},
    {"firstChildElement", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_firstChildElement), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"hasAttributes", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_hasAttributes), METH_NOARGS, nullptr},
    {"hasChildNodes", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_hasChildNodes), METH_NOARGS, nullptr},
    {"insertAfter", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_insertAfter), METH_VARARGS, nullptr},
    {"insertBefore", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_insertBefore), METH_VARARGS, nullptr},
    {"isAttr", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isAttr), METH_NOARGS, nullptr},
    {"isCDATASection", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isCDATASection), METH_NOARGS, nullptr},
    {"isCharacterData", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isCharacterData), METH_NOARGS, nullptr},
    {"isComment", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isComment), METH_NOARGS, nullptr},
    {"isDocument", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isDocument), METH_NOARGS, nullptr},
    {"isDocumentFragment", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isDocumentFragment), METH_NOARGS, nullptr},
    {"isDocumentType", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isDocumentType), METH_NOARGS, nullptr},
    {"isElement", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isElement), METH_NOARGS, nullptr},
    {"isEntity", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isEntity), METH_NOARGS, nullptr},
    {"isEntityReference", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isEntityReference), METH_NOARGS, nullptr},
    {"isNotation", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isNotation), METH_NOARGS, nullptr},
    {"isNull", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isNull), METH_NOARGS, nullptr},
    {"isProcessingInstruction", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isProcessingInstruction), METH_NOARGS, nullptr},
    {"isSupported", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isSupported), METH_VARARGS, nullptr},
    {"isText", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_isText), METH_NOARGS, nullptr},
    {"lastChild", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_lastChild), METH_NOARGS, nullptr},
    {"lastChildElement", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_lastChildElement), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"lineNumber", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_lineNumber), METH_NOARGS, nullptr},
    {"localName", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_localName), METH_NOARGS, nullptr},
    {"namedItem", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_namedItem), METH_O, nullptr},
    {"namespaceURI", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_namespaceURI), METH_NOARGS, nullptr},
    {"nextSibling", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_nextSibling), METH_NOARGS, nullptr},
    {"nextSiblingElement", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_nextSiblingElement), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"nodeName", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_nodeName), METH_NOARGS, nullptr},
    {"nodeType", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_nodeType), METH_NOARGS, nullptr},
    {"nodeValue", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_nodeValue), METH_NOARGS, nullptr},
    {"normalize", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_normalize), METH_NOARGS, nullptr},
    {"ownerDocument", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_ownerDocument), METH_NOARGS, nullptr},
    {"parentNode", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_parentNode), METH_NOARGS, nullptr},
    {"prefix", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_prefix), METH_NOARGS, nullptr},
    {"previousSibling", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_previousSibling), METH_NOARGS, nullptr},
    {"previousSiblingElement", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_previousSiblingElement), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"removeChild", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_removeChild), METH_O, nullptr},
    {"replaceChild", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_replaceChild), METH_VARARGS, nullptr},
    {"save", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_save), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setNodeValue", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_setNodeValue), METH_O, nullptr},
    {"setPrefix", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_setPrefix), METH_O, nullptr},
    {"toAttr", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_toAttr), METH_NOARGS, nullptr},
    {"toCDATASection", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_toCDATASection), METH_NOARGS, nullptr},
    {"toCharacterData", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_toCharacterData), METH_NOARGS, nullptr},
    {"toComment", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_toComment), METH_NOARGS, nullptr},
    {"toDocument", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_toDocument), METH_NOARGS, nullptr},
    {"toDocumentFragment", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_toDocumentFragment), METH_NOARGS, nullptr},
    {"toDocumentType", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_toDocumentType), METH_NOARGS, nullptr},
    {"toElement", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_toElement), METH_NOARGS, nullptr},
    {"toEntity", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_toEntity), METH_NOARGS, nullptr},
    {"toEntityReference", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_toEntityReference), METH_NOARGS, nullptr},
    {"toNotation", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_toNotation), METH_NOARGS, nullptr},
    {"toProcessingInstruction", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_toProcessingInstruction), METH_NOARGS, nullptr},
    {"toText", reinterpret_cast<PyCFunction>(Sbk_QDomNodeFunc_toText), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDomNode__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDomNode___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

static PyObject *Sbk_QDomNodeFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QDomNode::operator<<(QTextStream&)->QTextStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QTextStream&,QDomNode)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QTextStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QTextStream&,QDomNode) [reverse operator]
                QTextStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTextStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QDomNode_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArg)))) {
                // operator!=(const QDomNode &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDomNode cppArg0_local;
                ::QDomNode *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), (pyArg)))) {
                // operator==(const QDomNode &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDomNode cppArg0_local;
                ::QDomNode *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QDomNode_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDomNode_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDomNode_Type = nullptr;
static PyTypeObject *Sbk_QDomNode_TypeF(void)
{
    return _Sbk_QDomNode_Type;
}

static PyType_Slot Sbk_QDomNode_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDomNode_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDomNode_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QDomNode_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDomNode_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDomNode_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QDomNode___nb_bool)},
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QDomNodeFunc___lshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDomNode_spec = {
    "2:PySide6.QtXml.QDomNode",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDomNode_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QDomNode_NodeType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDomNode::NodeType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDomNode::NodeType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDomNode_NodeType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_NodeType_IDX])))
        return Enum_PythonToCpp_QDomNode_NodeType;
    return {};
}

static PyObject *QDomNode_NodeType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDomNode::NodeType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDomNode::NodeType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_NodeType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QDomNode_EncodingPolicy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QDomNode::EncodingPolicy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QDomNode::EncodingPolicy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QDomNode_EncodingPolicy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_EncodingPolicy_IDX])))
        return Enum_PythonToCpp_QDomNode_EncodingPolicy;
    return {};
}

static PyObject *QDomNode_EncodingPolicy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QDomNode::EncodingPolicy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QDomNode::EncodingPolicy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_EncodingPolicy_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDomNode_PythonToCpp_QDomNode_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDomNode_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDomNode_PythonToCpp_QDomNode_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDomNode_TypeF()))
        return QDomNode_PythonToCpp_QDomNode_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDomNode_PTR_CppToPython_QDomNode(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDomNode_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDomNode_COPY_CppToPython_QDomNode(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDomNode *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDomNode_TypeF(), new ::QDomNode(*source), true, true);
}

// Python to C++ copy conversion.
static void QDomNode_PythonToCpp_QDomNode_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDomNode *>(cppOut) = *reinterpret_cast< ::QDomNode *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDomNode_PythonToCpp_QDomNode_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDomNode_TypeF()))
        return QDomNode_PythonToCpp_QDomNode_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDomNode_SignatureStrings[] = {
    "1:PySide6.QtXml.QDomNode(self)",
    "0:PySide6.QtXml.QDomNode(self,node:PySide6.QtXml.QDomNode)",
    "PySide6.QtXml.QDomNode.appendChild(self,newChild:PySide6.QtXml.QDomNode)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNode.attributes(self)->PySide6.QtXml.QDomNamedNodeMap",
    "PySide6.QtXml.QDomNode.childNodes(self)->PySide6.QtXml.QDomNodeList",
    "PySide6.QtXml.QDomNode.clear(self)",
    "PySide6.QtXml.QDomNode.cloneNode(self,deep:bool=true)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNode.columnNumber(self)->int",
    "PySide6.QtXml.QDomNode.firstChild(self)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNode.firstChildElement(self,tagName:QString=QString(),namespaceURI:QString=QString())->PySide6.QtXml.QDomElement",
    "PySide6.QtXml.QDomNode.hasAttributes(self)->bool",
    "PySide6.QtXml.QDomNode.hasChildNodes(self)->bool",
    "PySide6.QtXml.QDomNode.insertAfter(self,newChild:PySide6.QtXml.QDomNode,refChild:PySide6.QtXml.QDomNode)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNode.insertBefore(self,newChild:PySide6.QtXml.QDomNode,refChild:PySide6.QtXml.QDomNode)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNode.isAttr(self)->bool",
    "PySide6.QtXml.QDomNode.isCDATASection(self)->bool",
    "PySide6.QtXml.QDomNode.isCharacterData(self)->bool",
    "PySide6.QtXml.QDomNode.isComment(self)->bool",
    "PySide6.QtXml.QDomNode.isDocument(self)->bool",
    "PySide6.QtXml.QDomNode.isDocumentFragment(self)->bool",
    "PySide6.QtXml.QDomNode.isDocumentType(self)->bool",
    "PySide6.QtXml.QDomNode.isElement(self)->bool",
    "PySide6.QtXml.QDomNode.isEntity(self)->bool",
    "PySide6.QtXml.QDomNode.isEntityReference(self)->bool",
    "PySide6.QtXml.QDomNode.isNotation(self)->bool",
    "PySide6.QtXml.QDomNode.isNull(self)->bool",
    "PySide6.QtXml.QDomNode.isProcessingInstruction(self)->bool",
    "PySide6.QtXml.QDomNode.isSupported(self,feature:QString,version:QString)->bool",
    "PySide6.QtXml.QDomNode.isText(self)->bool",
    "PySide6.QtXml.QDomNode.lastChild(self)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNode.lastChildElement(self,tagName:QString=QString(),namespaceURI:QString=QString())->PySide6.QtXml.QDomElement",
    "PySide6.QtXml.QDomNode.lineNumber(self)->int",
    "PySide6.QtXml.QDomNode.localName(self)->QString",
    "PySide6.QtXml.QDomNode.namedItem(self,name:QString)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNode.namespaceURI(self)->QString",
    "PySide6.QtXml.QDomNode.nextSibling(self)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNode.nextSiblingElement(self,taName:QString=QString(),namespaceURI:QString=QString())->PySide6.QtXml.QDomElement",
    "PySide6.QtXml.QDomNode.nodeName(self)->QString",
    "PySide6.QtXml.QDomNode.nodeType(self)->PySide6.QtXml.QDomNode.NodeType",
    "PySide6.QtXml.QDomNode.nodeValue(self)->QString",
    "PySide6.QtXml.QDomNode.normalize(self)",
    "PySide6.QtXml.QDomNode.ownerDocument(self)->PySide6.QtXml.QDomDocument",
    "PySide6.QtXml.QDomNode.parentNode(self)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNode.prefix(self)->QString",
    "PySide6.QtXml.QDomNode.previousSibling(self)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNode.previousSiblingElement(self,tagName:QString=QString(),namespaceURI:QString=QString())->PySide6.QtXml.QDomElement",
    "PySide6.QtXml.QDomNode.removeChild(self,oldChild:PySide6.QtXml.QDomNode)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNode.replaceChild(self,newChild:PySide6.QtXml.QDomNode,oldChild:PySide6.QtXml.QDomNode)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNode.save(self,arg__1:PySide6.QtCore.QTextStream,arg__2:int,arg__3:PySide6.QtXml.QDomNode.EncodingPolicy=QDomNode.EncodingFromDocument)",
    "PySide6.QtXml.QDomNode.setNodeValue(self,value:QString)",
    "PySide6.QtXml.QDomNode.setPrefix(self,pre:QString)",
    "PySide6.QtXml.QDomNode.toAttr(self)->PySide6.QtXml.QDomAttr",
    "PySide6.QtXml.QDomNode.toCDATASection(self)->PySide6.QtXml.QDomCDATASection",
    "PySide6.QtXml.QDomNode.toCharacterData(self)->PySide6.QtXml.QDomCharacterData",
    "PySide6.QtXml.QDomNode.toComment(self)->PySide6.QtXml.QDomComment",
    "PySide6.QtXml.QDomNode.toDocument(self)->PySide6.QtXml.QDomDocument",
    "PySide6.QtXml.QDomNode.toDocumentFragment(self)->PySide6.QtXml.QDomDocumentFragment",
    "PySide6.QtXml.QDomNode.toDocumentType(self)->PySide6.QtXml.QDomDocumentType",
    "PySide6.QtXml.QDomNode.toElement(self)->PySide6.QtXml.QDomElement",
    "PySide6.QtXml.QDomNode.toEntity(self)->PySide6.QtXml.QDomEntity",
    "PySide6.QtXml.QDomNode.toEntityReference(self)->PySide6.QtXml.QDomEntityReference",
    "PySide6.QtXml.QDomNode.toNotation(self)->PySide6.QtXml.QDomNotation",
    "PySide6.QtXml.QDomNode.toProcessingInstruction(self)->PySide6.QtXml.QDomProcessingInstruction",
    "PySide6.QtXml.QDomNode.toText(self)->PySide6.QtXml.QDomText",
    "PySide6.QtXml.QDomNode.__copy__(self)->typing.Self",
    "PySide6.QtXml.QDomNode.__lshift__(self,stream:PySide6.QtCore.QTextStream)->PySide6.QtCore.QTextStream",
    "PySide6.QtXml.QDomNode.__ne__(self,other:PySide6.QtXml.QDomNode)->bool",
    "PySide6.QtXml.QDomNode.__eq__(self,other:PySide6.QtXml.QDomNode)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QDomNode_SignatureByteSize = 769;
static constexpr uint8_t QDomNode_SignatureBytes[769] = {
    0x78, 0xda, 0xc5, 0x56, 0x51, 0x6f, 0xda, 0x30, 0x10, 0x7e, 0xef, 0x2f, 0x69, 0xa5, 0x0c, 0xad,
    0x9b, 0xb4, 0x07, 0x24, 0x26, 0x31, 0x68, 0xa5, 0x4a, 0x1b, 0x82, 0xd2, 0x4d, 0x7d, 0x8b, 0x4c,
    0x72, 0x01, 0x4b, 0x8e, 0xed, 0xd9, 0x0e, 0x2d, 0xfb, 0xf5, 0xb3, 0x49, 0x42, 0x42, 0x12, 0x3b,
    0xce, 0xa8, 0xd6, 0x17, 0x48, 0xe2, 0xef, 0xbe, 0x3b, 0xdf, 0x9d, 0xcf, 0xdf, 0xed, 0x78, 0x79,
    0x58, 0xe3, 0x18, 0xbe, 0x8c, 0x56, 0xea, 0x39, 0x25, 0xa3, 0xd5, 0x9c, 0xa5, 0x0b, 0x16, 0xc3,
    0xb5, 0x04, 0x92, 0xdc, 0x5c, 0x7d, 0x74, 0x2d, 0x07, 0x54, 0x3f, 0x59, 0x00, 0x37, 0x57, 0xdd,
    0xdf, 0x47, 0x88, 0x73, 0xa0, 0xf1, 0x6c, 0x87, 0x49, 0x5c, 0x90, 0xc0, 0xcb, 0xf1, 0xcd, 0x46,
    0xf4, 0xe1, 0x6b, 0xf7, 0x82, 0xd5, 0x81, 0x52, 0x02, 0x6f, 0x32, 0x05, 0x32, 0xdf, 0x43, 0xa7,
    0x3d, 0x4a, 0x21, 0x36, 0xe8, 0x1f, 0x88, 0xdb, 0x78, 0x22, 0x13, 0x94, 0x79, 0x72, 0xf1, 0xe8,
    0xe5, 0xef, 0x58, 0x2a, 0x2b, 0x07, 0x01, 0x24, 0x8a, 0x54, 0x5a, 0x21, 0x8c, 0x42, 0x95, 0xd2,
    0x18, 0x80, 0x8f, 0x37, 0x8c, 0x91, 0x89, 0x12, 0xd9, 0xf0, 0xcd, 0x47, 0x8c, 0x64, 0x29, 0x5d,
    0x64, 0xe9, 0x06, 0x44, 0x19, 0x36, 0xa6, 0xd6, 0xf8, 0x12, 0x2c, 0xa4, 0xaa, 0x6a, 0x31, 0xd8,
    0x5d, 0x65, 0x7f, 0x47, 0x20, 0x05, 0xaa, 0xf2, 0x4d, 0x28, 0xb4, 0x35, 0x19, 0x1e, 0xaf, 0xd6,
    0xba, 0x14, 0x74, 0x3b, 0x29, 0xfe, 0xaf, 0x6f, 0x02, 0xaa, 0x3f, 0x4b, 0x8e, 0x22, 0xf8, 0xf9,
    0xf8, 0xd0, 0x5e, 0xee, 0xf4, 0x5f, 0x30, 0xdb, 0x42, 0xd8, 0x21, 0x39, 0x6d, 0x55, 0xdc, 0x24,
    0xd0, 0x61, 0x30, 0x6b, 0x95, 0xd6, 0x65, 0x80, 0xa9, 0x04, 0xa1, 0xa6, 0x89, 0x2a, 0x52, 0xda,
    0xd7, 0xb1, 0x81, 0x80, 0xe4, 0x4d, 0x3b, 0x3a, 0x0f, 0xe0, 0x1b, 0x24, 0x4c, 0xc0, 0x3b, 0x45,
    0x70, 0xcc, 0xb1, 0x57, 0xb2, 0xe4, 0x6c, 0x3e, 0x7d, 0x9a, 0xae, 0x21, 0x52, 0x98, 0x51, 0x4f,
    0x8b, 0x1d, 0x12, 0x28, 0xd2, 0xe9, 0x9d, 0x23, 0x85, 0x3c, 0x4d, 0x58, 0x7a, 0x6a, 0xb7, 0x5e,
    0xf0, 0x9c, 0x45, 0xd9, 0x70, 0xf4, 0xbd, 0x40, 0xdb, 0xe1, 0x56, 0x4f, 0x07, 0x0e, 0x7e, 0x16,
    0xf5, 0x13, 0xd3, 0x0f, 0xa6, 0x0a, 0xab, 0xc3, 0x10, 0xec, 0x23, 0x24, 0x20, 0x80, 0x46, 0x9e,
    0xd1, 0x2c, 0x98, 0x42, 0xfe, 0x15, 0x5b, 0x64, 0x84, 0xf8, 0x21, 0x97, 0x82, 0x45, 0x20, 0xa5,
    0x3e, 0xde, 0x0f, 0x54, 0xea, 0x91, 0x36, 0xa0, 0x2d, 0xd6, 0x19, 0xe7, 0x4c, 0x28, 0x28, 0xee,
    0x89, 0x04, 0x90, 0xca, 0xc4, 0x69, 0xa8, 0x04, 0x7b, 0x10, 0x52, 0x73, 0x95, 0xef, 0xbd, 0x74,
    0x4f, 0xf0, 0xea, 0x95, 0x6c, 0x82, 0x2e, 0x1a, 0x89, 0x27, 0xf3, 0x77, 0x9b, 0x88, 0x04, 0xeb,
    0x0b, 0xc5, 0xf7, 0x06, 0x20, 0x2c, 0x42, 0xc4, 0x84, 0x56, 0x62, 0x0b, 0xd7, 0x36, 0xbc, 0x09,
    0x37, 0x7e, 0x50, 0x90, 0x16, 0x83, 0xa8, 0xb6, 0xa9, 0xc1, 0xa9, 0xaa, 0x6f, 0xdd, 0xd7, 0xbd,
    0x2e, 0xe2, 0x1a, 0x6f, 0x88, 0x49, 0xce, 0x3f, 0x95, 0xa7, 0x46, 0xd0, 0x28, 0xd0, 0x7f, 0xab,
    0x8f, 0x51, 0x4d, 0x43, 0x32, 0xae, 0x7f, 0xea, 0x53, 0xc5, 0x02, 0x5b, 0x14, 0x30, 0x17, 0xcd,
    0x2f, 0x44, 0x32, 0x7f, 0xb7, 0x22, 0x45, 0x04, 0xff, 0x01, 0xb7, 0x7c, 0x61, 0x2f, 0x54, 0xcf,
    0xed, 0xc6, 0x80, 0x6d, 0x63, 0x4b, 0x84, 0x8d, 0x86, 0x23, 0x3d, 0xab, 0x54, 0x25, 0x3c, 0x87,
    0x96, 0x95, 0xeb, 0x1b, 0x0f, 0xbf, 0x7a, 0x6e, 0x4d, 0x83, 0xf7, 0x98, 0x65, 0xf2, 0xa2, 0x46,
    0x6a, 0x90, 0xbc, 0xdb, 0x69, 0x17, 0x90, 0xb2, 0x3d, 0xd4, 0xf4, 0x34, 0x23, 0xf1, 0x9b, 0xde,
    0xfd, 0x02, 0x38, 0xd1, 0x01, 0xfb, 0x2b, 0xf6, 0x37, 0x8f, 0x40, 0xa2, 0x7d, 0xa1, 0x7b, 0x90,
    0xd8, 0x86, 0xe1, 0x6d, 0x8d, 0x77, 0xa6, 0x25, 0xd1, 0x68, 0x65, 0x46, 0xbb, 0xce, 0x21, 0xa0,
    0x34, 0x47, 0x7c, 0x1a, 0xeb, 0x89, 0x97, 0x3f, 0x7e, 0xb6, 0x04, 0x31, 0xba, 0xa3, 0x11, 0x8b,
    0x75, 0xd6, 0x97, 0x8c, 0xe0, 0xe8, 0x30, 0x69, 0x7d, 0xbf, 0x17, 0x55, 0xd7, 0x5a, 0xbb, 0x5f,
    0xc2, 0xb1, 0x67, 0xab, 0x73, 0x15, 0xec, 0xcd, 0xe3, 0x69, 0x22, 0x3a, 0xec, 0x96, 0x55, 0xc7,
    0x06, 0x5c, 0xf4, 0x9b, 0x28, 0x56, 0x97, 0x60, 0x6d, 0x90, 0x59, 0xb5, 0xdb, 0x76, 0x89, 0xb2,
    0x36, 0xb8, 0x8e, 0x72, 0x70, 0x75, 0xc9, 0xb5, 0x0e, 0xb2, 0x3a, 0xcc, 0xc1, 0x76, 0xae, 0xe4,
    0x3a, 0x78, 0x72, 0x80, 0x9d, 0xe1, 0xf2, 0xe9, 0x53, 0x71, 0x34, 0x45, 0x9f, 0x9d, 0xab, 0x44,
    0xf6, 0x73, 0xba, 0x87, 0x77, 0x1d, 0x65, 0xe7, 0x6a, 0x88, 0xc5, 0xc1, 0x53, 0x42, 0x33, 0x9c,
    0x29, 0xc8, 0x0e, 0x82, 0xe3, 0x7a, 0x9f, 0x7d, 0x4b, 0x55, 0xda, 0x88, 0x4e, 0x40, 0x3b, 0x63,
    0x53, 0x72, 0x76, 0x01, 0x73, 0x84, 0x9d, 0xc3, 0x29, 0x2f, 0xdb, 0x56, 0x9d, 0x70, 0x3b, 0x7b,
    0x5d, 0x32, 0xb6, 0x41, 0x66, 0xd5, 0x66, 0x1b, 0x86, 0x11, 0xe3, 0x87, 0x30, 0x2c, 0xad, 0xd5,
    0x81, 0x6b, 0xa7, 0xa3, 0xb5, 0x7e, 0xb3, 0x9b, 0x10, 0xb9, 0xc3, 0x89, 0x2a, 0x8c, 0x02, 0x79,
    0x1c, 0x68, 0x8e, 0x59, 0x77, 0x16, 0x54, 0x73, 0xd1, 0xee, 0x85, 0x42, 0xe9, 0x81, 0xa9, 0x1d,
    0x08, 0xfb, 0x90, 0x76, 0x89, 0xe4, 0x30, 0x84, 0xdf, 0x43, 0x68, 0xfe, 0x02, 0x7c, 0xf7, 0x81,
    0x82
};
#endif

PyTypeObject *init_QDomNode(PyObject *module)
{
    if (SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX].type != nullptr)
        return SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX].type;

    Shiboken::AutoDecRef Sbk_QDomNode_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDomNode_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDomNode",
        "QDomNode",
        &Sbk_QDomNode_spec,
        &Shiboken::callCppDestructor< ::QDomNode >,
        Sbk_QDomNode_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDomNode_TypeF(); // references _Sbk_QDomNode_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDomNode_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDomNode_SignatureBytes, QDomNode_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDomNode_PropertyStrings);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDomNode_PythonToCpp_QDomNode_PTR,
        is_QDomNode_PythonToCpp_QDomNode_PTR_Convertible,
        QDomNode_PTR_CppToPython_QDomNode,
        QDomNode_COPY_CppToPython_QDomNode);

    Shiboken::Conversions::registerConverterName(converter, "QDomNode");
    Shiboken::Conversions::registerConverterName(converter, "QDomNode*");
    Shiboken::Conversions::registerConverterName(converter, "QDomNode&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDomNode).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDomNode_PythonToCpp_QDomNode_COPY,
        is_QDomNode_PythonToCpp_QDomNode_COPY_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QDomNode_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'NodeType'.
    const char *NodeType_Initializer[] = {
        "ElementNode",
        "AttributeNode",
        "TextNode",
        "CDATASectionNode",
        "EntityReferenceNode",
        "EntityNode",
        "ProcessingInstructionNode",
        "CommentNode",
        "DocumentNode",
        "DocumentTypeNode",
        "DocumentFragmentNode",
        "NotationNode",
        "BaseNode",
        "CharacterDataNode",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t NodeType_InitializerValues[] = {
        uint8_t(QDomNode::NodeType::ElementNode),               //  0x01  1
        uint8_t(QDomNode::NodeType::AttributeNode),             //  0x02  2
        uint8_t(QDomNode::NodeType::TextNode),                  //  0x03  3
        uint8_t(QDomNode::NodeType::CDATASectionNode),          //  0x04  4
        uint8_t(QDomNode::NodeType::EntityReferenceNode),       //  0x05  5
        uint8_t(QDomNode::NodeType::EntityNode),                //  0x06  6
        uint8_t(QDomNode::NodeType::ProcessingInstructionNode), //  0x07  7
        uint8_t(QDomNode::NodeType::CommentNode),               //  0x08  8
        uint8_t(QDomNode::NodeType::DocumentNode),              //  0x09  9
        uint8_t(QDomNode::NodeType::DocumentTypeNode),          //  0x0a  10
        uint8_t(QDomNode::NodeType::DocumentFragmentNode),      //  0x0b  11
        uint8_t(QDomNode::NodeType::NotationNode),              //  0x0c  12
        uint8_t(QDomNode::NodeType::BaseNode),                  //  0x15  21
        uint8_t(QDomNode::NodeType::CharacterDataNode)          //  0x16  22
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDomNode_TypeF(),
        "2:PySide6.QtXml.QDomNode.NodeType",
        NodeType_Initializer, NodeType_InitializerValues);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_NodeType_IDX].type = EType;
    // Register converter for enum 'QDomNode::NodeType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDomNode_NodeType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDomNode_NodeType,
            is_Enum_PythonToCpp_QDomNode_NodeType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDomNode::NodeType");
        Shiboken::Conversions::registerConverterAlias(converter, "NodeType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'NodeType' enum.

    // Initialization of enum 'EncodingPolicy'.
    const char *EncodingPolicy_Initializer[] = {
        "EncodingFromDocument",
        "EncodingFromTextStream",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t EncodingPolicy_InitializerValues[] = {
        uint8_t(QDomNode::EncodingPolicy::EncodingFromDocument),  //  0x01  1
        uint8_t(QDomNode::EncodingPolicy::EncodingFromTextStream) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QDomNode_TypeF(),
        "2:PySide6.QtXml.QDomNode.EncodingPolicy",
        EncodingPolicy_Initializer, EncodingPolicy_InitializerValues);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_EncodingPolicy_IDX].type = EType;
    // Register converter for enum 'QDomNode::EncodingPolicy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QDomNode_EncodingPolicy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QDomNode_EncodingPolicy,
            is_Enum_PythonToCpp_QDomNode_EncodingPolicy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QDomNode::EncodingPolicy");
        Shiboken::Conversions::registerConverterAlias(converter, "EncodingPolicy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'EncodingPolicy' enum.

    qRegisterMetaType< ::QDomNode >("QDomNode");
    qRegisterMetaType< ::QDomNode::NodeType >("QDomNode::NodeType");
    qRegisterMetaType< ::QDomNode::EncodingPolicy >("QDomNode::EncodingPolicy");

    return pyType;
}
