// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtxml_python.h"

// main header
#include "qdomnodelist_wrapper.h"

// Argument includes
#include <QtXml/qdom.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomNodeList_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDomNodeList >()))
        return -1;

    ::QDomNodeList *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDomNodeList", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDomNodeList::QDomNodeList()
    // 1: QDomNodeList::QDomNodeList(QDomNodeList)
    if (numArgs == 0) {
        overloadId = 0; // QDomNodeList()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDomNodeList(QDomNodeList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDomNodeList()
        {

            // QDomNodeList()
            cptr = new ::QDomNodeList();
            break;
        }
        case 1: // QDomNodeList(const QDomNodeList &nodeList)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDomNodeList cppArg0_local;
            ::QDomNodeList *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomNodeList(QDomNodeList)
                cptr = new ::QDomNodeList(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDomNodeList >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDomNodeListFunc_at(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNodeList *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomNodeList::at(int)const->QDomNode
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // at(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "at", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // at(int)const
            QDomNode cppResult = const_cast<const ::QDomNodeList *>(cppSelf)->at(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeListFunc_count(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNodeList *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // count()const
        int cppResult = const_cast<const ::QDomNodeList *>(cppSelf)->count();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeListFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNodeList *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QDomNodeList *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeListFunc_item(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNodeList *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomNodeList::item(int)const->QDomNode
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // item(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "item", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // item(int)const
            QDomNode cppResult = const_cast<const ::QDomNodeList *>(cppSelf)->item(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeListFunc_length(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNodeList *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // length()const
        int cppResult = const_cast<const ::QDomNodeList *>(cppSelf)->length();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeListFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomNodeList *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        int cppResult = const_cast<const ::QDomNodeList *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomNodeList__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomNodeList *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDomNodeList_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDomNodeList_methods[] = {
    {"at", reinterpret_cast<PyCFunction>(Sbk_QDomNodeListFunc_at), METH_O, nullptr},
    {"count", reinterpret_cast<PyCFunction>(Sbk_QDomNodeListFunc_count), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QDomNodeListFunc_isEmpty), METH_NOARGS, nullptr},
    {"item", reinterpret_cast<PyCFunction>(Sbk_QDomNodeListFunc_item), METH_O, nullptr},
    {"length", reinterpret_cast<PyCFunction>(Sbk_QDomNodeListFunc_length), METH_NOARGS, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QDomNodeListFunc_size), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDomNodeList__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Rich comparison
static PyObject * Sbk_QDomNodeList_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomNodeList *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), (pyArg)))) {
                // operator!=(const QDomNodeList &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDomNodeList cppArg0_local;
                ::QDomNodeList *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), (pyArg)))) {
                // operator==(const QDomNodeList &other) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QDomNodeList cppArg0_local;
                ::QDomNodeList *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QDomNodeList_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDomNodeList_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDomNodeList_Type = nullptr;
static PyTypeObject *Sbk_QDomNodeList_TypeF(void)
{
    return _Sbk_QDomNodeList_Type;
}

static PyType_Slot Sbk_QDomNodeList_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDomNodeList_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDomNodeList_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QDomNodeList_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDomNodeList_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDomNodeList_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDomNodeList_spec = {
    "2:PySide6.QtXml.QDomNodeList",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDomNodeList_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDomNodeList_PythonToCpp_QDomNodeList_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDomNodeList_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDomNodeList_PythonToCpp_QDomNodeList_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDomNodeList_TypeF()))
        return QDomNodeList_PythonToCpp_QDomNodeList_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDomNodeList_PTR_CppToPython_QDomNodeList(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDomNodeList_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDomNodeList_COPY_CppToPython_QDomNodeList(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDomNodeList *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDomNodeList_TypeF(), new ::QDomNodeList(*source), true, true);
}

// Python to C++ copy conversion.
static void QDomNodeList_PythonToCpp_QDomNodeList_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDomNodeList *>(cppOut) = *reinterpret_cast< ::QDomNodeList *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDomNodeList_PythonToCpp_QDomNodeList_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDomNodeList_TypeF()))
        return QDomNodeList_PythonToCpp_QDomNodeList_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDomNodeList_SignatureStrings[] = {
    "1:PySide6.QtXml.QDomNodeList(self)",
    "0:PySide6.QtXml.QDomNodeList(self,nodeList:PySide6.QtXml.QDomNodeList)",
    "PySide6.QtXml.QDomNodeList.at(self,index:int)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNodeList.count(self)->int",
    "PySide6.QtXml.QDomNodeList.isEmpty(self)->bool",
    "PySide6.QtXml.QDomNodeList.item(self,index:int)->PySide6.QtXml.QDomNode",
    "PySide6.QtXml.QDomNodeList.length(self)->int",
    "PySide6.QtXml.QDomNodeList.size(self)->int",
    "PySide6.QtXml.QDomNodeList.__copy__(self)->typing.Self",
    "PySide6.QtXml.QDomNodeList.__ne__(self,other:PySide6.QtXml.QDomNodeList)->bool",
    "PySide6.QtXml.QDomNodeList.__eq__(self,other:PySide6.QtXml.QDomNodeList)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QDomNodeList_SignatureByteSize = 166;
static constexpr uint8_t QDomNodeList_SignatureBytes[166] = {
    0x78, 0xda, 0xad, 0x91, 0xb1, 0x0e, 0x82, 0x40, 0x0c, 0x86, 0x77, 0x9f, 0x44, 0x12, 0xb8, 0xe8,
    0xe2, 0xc0, 0xc0, 0xa4, 0x9b, 0x31, 0x12, 0x16, 0xb7, 0x8b, 0x42, 0x85, 0x26, 0x77, 0x2d, 0x7a,
    0x35, 0xf1, 0x7c, 0x7a, 0x19, 0x8e, 0x4d, 0x0f, 0x4c, 0x1c, 0x9b, 0x7e, 0xff, 0x97, 0x3f, 0xed,
    0x3a, 0x3f, 0xfa, 0x0a, 0x1b, 0xd8, 0xa8, 0x52, 0x4e, 0xd6, 0xa8, 0x72, 0xcb, 0xf6, 0xc0, 0x0d,
    0xec, 0xd1, 0xc9, 0xd2, 0x81, 0xb9, 0x26, 0x8b, 0xd5, 0x14, 0x92, 0x52, 0x98, 0x22, 0x60, 0xb2,
    0xf8, 0xbe, 0x53, 0xe7, 0xe0, 0x41, 0x6a, 0xe0, 0x99, 0x23, 0x49, 0x92, 0x15, 0x9f, 0xf1, 0x98,
    0xa5, 0xe6, 0x07, 0x85, 0xce, 0x59, 0x31, 0x48, 0x62, 0x2c, 0xba, 0x9d, 0xed, 0xc5, 0x8f, 0xf4,
    0x85, 0xd9, 0x44, 0x71, 0x01, 0xfb, 0x8f, 0x8a, 0x06, 0xa8, 0x95, 0x6e, 0x66, 0x47, 0x87, 0x2f,
    0x98, 0x89, 0x6a, 0x5d, 0x73, 0xef, 0xb5, 0x1e, 0x71, 0xf1, 0x3d, 0x52, 0xab, 0xaa, 0x61, 0x8a,
    0xc7, 0x08, 0x42, 0x28, 0x65, 0xe9, 0xe0, 0x1e, 0x7b, 0xe0, 0xf4, 0x95, 0xb4, 0x86, 0xdb, 0xaf,
    0xba, 0x37, 0xe4, 0x19, 0xe0, 0xf5
};
#endif

PyTypeObject *init_QDomNodeList(PyObject *module)
{
    if (SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX].type != nullptr)
        return SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX].type;

    Shiboken::AutoDecRef Sbk_QDomNodeList_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QDomNodeList_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDomNodeList",
        "QDomNodeList",
        &Sbk_QDomNodeList_spec,
        &Shiboken::callCppDestructor< ::QDomNodeList >,
        Sbk_QDomNodeList_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDomNodeList_TypeF(); // references _Sbk_QDomNodeList_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDomNodeList_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDomNodeList_SignatureBytes, QDomNodeList_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDomNodeList_PropertyStrings);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomNodeList_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDomNodeList_PythonToCpp_QDomNodeList_PTR,
        is_QDomNodeList_PythonToCpp_QDomNodeList_PTR_Convertible,
        QDomNodeList_PTR_CppToPython_QDomNodeList,
        QDomNodeList_COPY_CppToPython_QDomNodeList);

    Shiboken::Conversions::registerConverterName(converter, "QDomNodeList");
    Shiboken::Conversions::registerConverterName(converter, "QDomNodeList*");
    Shiboken::Conversions::registerConverterName(converter, "QDomNodeList&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDomNodeList).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDomNodeList_PythonToCpp_QDomNodeList_COPY,
        is_QDomNodeList_PythonToCpp_QDomNodeList_COPY_Convertible);

    qRegisterMetaType< ::QDomNodeList >("QDomNodeList");

    return pyType;
}
