// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtxml_python.h"

// main header
#include "qdomprocessinginstruction_wrapper.h"

// Argument includes
#include <QString>
#include <QtXml/qdom.h>
#include <qtextstream.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QDomProcessingInstruction_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QDomProcessingInstruction >()))
        return -1;

    ::QDomProcessingInstruction *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QDomProcessingInstruction", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QDomProcessingInstruction::QDomProcessingInstruction()
    // 1: QDomProcessingInstruction::QDomProcessingInstruction(QDomProcessingInstruction)
    if (numArgs == 0) {
        overloadId = 0; // QDomProcessingInstruction()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]), (pyArgs[0])))) {
        overloadId = 1; // QDomProcessingInstruction(QDomProcessingInstruction)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QDomProcessingInstruction()
        {

            // QDomProcessingInstruction()
            cptr = new ::QDomProcessingInstruction();
            break;
        }
        case 1: // QDomProcessingInstruction(const QDomProcessingInstruction &processingInstruction)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QDomProcessingInstruction cppArg0_local;
            ::QDomProcessingInstruction *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QDomProcessingInstruction(QDomProcessingInstruction)
                cptr = new ::QDomProcessingInstruction(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QDomProcessingInstruction >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QDomProcessingInstructionFunc_data(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomProcessingInstruction *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // data()const
        QString cppResult = const_cast<const ::QDomProcessingInstruction *>(cppSelf)->data();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomProcessingInstructionFunc_nodeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomProcessingInstruction *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nodeType()const
        QDomNode::NodeType cppResult = const_cast<const ::QDomProcessingInstruction *>(cppSelf)->nodeType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_NodeType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomProcessingInstructionFunc_setData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomProcessingInstruction *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDomProcessingInstruction::setData(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setData(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setData", errInfo, SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setData(QString)
            cppSelf->setData(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QDomProcessingInstructionFunc_target(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QDomProcessingInstruction *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // target()const
        QString cppResult = const_cast<const ::QDomProcessingInstruction *>(cppSelf)->target();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QDomProcessingInstruction__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QDomProcessingInstruction *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QDomProcessingInstruction_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QDomProcessingInstruction_methods[] = {
    {"data", reinterpret_cast<PyCFunction>(Sbk_QDomProcessingInstructionFunc_data), METH_NOARGS, nullptr},
    {"nodeType", reinterpret_cast<PyCFunction>(Sbk_QDomProcessingInstructionFunc_nodeType), METH_NOARGS, nullptr},
    {"setData", reinterpret_cast<PyCFunction>(Sbk_QDomProcessingInstructionFunc_setData), METH_O, nullptr},
    {"target", reinterpret_cast<PyCFunction>(Sbk_QDomProcessingInstructionFunc_target), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QDomProcessingInstruction__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QDomProcessingInstruction___nb_bool(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return -1;
    auto *cppSelf = reinterpret_cast< ::QDomProcessingInstruction *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return !cppSelf->isNull() ? 1 : 0;
}

} // extern "C"

static int Sbk_QDomProcessingInstruction_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QDomProcessingInstruction_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QDomProcessingInstruction_Type = nullptr;
static PyTypeObject *Sbk_QDomProcessingInstruction_TypeF(void)
{
    return _Sbk_QDomProcessingInstruction_Type;
}

static PyType_Slot Sbk_QDomProcessingInstruction_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QDomProcessingInstruction_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QDomProcessingInstruction_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QDomProcessingInstruction_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QDomProcessingInstruction_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_bool,        reinterpret_cast<void *>(Sbk_QDomProcessingInstruction___nb_bool)},
    {0, nullptr}
};
static PyType_Spec Sbk_QDomProcessingInstruction_spec = {
    "2:PySide6.QtXml.QDomProcessingInstruction",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QDomProcessingInstruction_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QDomProcessingInstruction_PythonToCpp_QDomProcessingInstruction_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QDomProcessingInstruction_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QDomProcessingInstruction_PythonToCpp_QDomProcessingInstruction_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QDomProcessingInstruction_TypeF()))
        return QDomProcessingInstruction_PythonToCpp_QDomProcessingInstruction_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QDomProcessingInstruction_PTR_CppToPython_QDomProcessingInstruction(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QDomProcessingInstruction_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QDomProcessingInstruction_COPY_CppToPython_QDomProcessingInstruction(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QDomProcessingInstruction *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QDomProcessingInstruction_TypeF(), new ::QDomProcessingInstruction(*source), true, true);
}

// Python to C++ copy conversion.
static void QDomProcessingInstruction_PythonToCpp_QDomProcessingInstruction_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QDomProcessingInstruction *>(cppOut) = *reinterpret_cast< ::QDomProcessingInstruction *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QDomProcessingInstruction_PythonToCpp_QDomProcessingInstruction_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QDomProcessingInstruction_TypeF()))
        return QDomProcessingInstruction_PythonToCpp_QDomProcessingInstruction_COPY;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QDomProcessingInstruction_SignatureStrings[] = {
    "1:PySide6.QtXml.QDomProcessingInstruction(self)",
    "0:PySide6.QtXml.QDomProcessingInstruction(self,processingInstruction:PySide6.QtXml.QDomProcessingInstruction)",
    "PySide6.QtXml.QDomProcessingInstruction.data(self)->QString",
    "PySide6.QtXml.QDomProcessingInstruction.nodeType(self)->PySide6.QtXml.QDomNode.NodeType",
    "PySide6.QtXml.QDomProcessingInstruction.setData(self,data:QString)",
    "PySide6.QtXml.QDomProcessingInstruction.target(self)->QString",
    "PySide6.QtXml.QDomProcessingInstruction.__copy__(self)->typing.Self",
    nullptr}; // Sentinel
#else
static constexpr size_t QDomProcessingInstruction_SignatureByteSize = 153;
static constexpr uint8_t QDomProcessingInstruction_SignatureBytes[153] = {
    0x78, 0xda, 0x33, 0xb4, 0x0a, 0xa8, 0x0c, 0xce, 0x4c, 0x49, 0x35, 0xd3, 0x0b, 0x2c, 0x89, 0xc8,
    0xcd, 0xd1, 0x0b, 0x74, 0xc9, 0xcf, 0x0d, 0x28, 0xca, 0x4f, 0x4e, 0x2d, 0x2e, 0xce, 0xcc, 0x4b,
    0xf7, 0xcc, 0x2b, 0x2e, 0x29, 0x2a, 0x4d, 0x2e, 0xc9, 0xcc, 0xcf, 0xd3, 0x28, 0x4e, 0xcd, 0x49,
    0xd3, 0xe4, 0x32, 0x20, 0x49, 0xbd, 0x4e, 0x01, 0x36, 0x29, 0x62, 0x8d, 0xd0, 0xe4, 0x22, 0x52,
    0xa1, 0x5e, 0x4a, 0x62, 0x49, 0x22, 0xc4, 0x81, 0xba, 0x76, 0x81, 0xc1, 0x25, 0x45, 0x40, 0x69,
    0xa2, 0xf5, 0xe6, 0xe5, 0xa7, 0xa4, 0x86, 0x54, 0x16, 0xa4, 0xc2, 0xf4, 0x63, 0xea, 0xf3, 0x03,
    0xaa, 0xd0, 0xf3, 0x83, 0x2a, 0x23, 0xda, 0xdc, 0xe2, 0xd4, 0x12, 0x17, 0x98, 0xb3, 0x74, 0x40,
    0x0e, 0xb4, 0x82, 0xba, 0x8c, 0x78, 0x6f, 0x95, 0x24, 0x16, 0xa5, 0xa7, 0x96, 0x90, 0xeb, 0xb1,
    0xf8, 0xf8, 0xe4, 0xfc, 0x82, 0xca, 0xf8, 0x78, 0x98, 0xfe, 0x92, 0xca, 0x02, 0xa0, 0x0a, 0xbd,
    0x60, 0x20, 0x8f, 0x0b, 0x00, 0xc2, 0xb8, 0xba, 0x34
};
#endif

PyTypeObject *init_QDomProcessingInstruction(PyObject *module)
{
    if (SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX].type != nullptr)
        return SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX].type;

    Shiboken::AutoDecRef Sbk_QDomProcessingInstruction_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtXmlTypeStructs[SBK_QDomNode_IDX]))));

    _Sbk_QDomProcessingInstruction_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QDomProcessingInstruction",
        "QDomProcessingInstruction",
        &Sbk_QDomProcessingInstruction_spec,
        &Shiboken::callCppDestructor< ::QDomProcessingInstruction >,
        Sbk_QDomProcessingInstruction_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QDomProcessingInstruction_TypeF(); // references _Sbk_QDomProcessingInstruction_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QDomProcessingInstruction_SignatureStrings);
#else
    InitSignatureBytes(pyType, QDomProcessingInstruction_SignatureBytes, QDomProcessingInstruction_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QDomProcessingInstruction_PropertyStrings);
    SbkPySide6_QtXmlTypeStructs[SBK_QDomProcessingInstruction_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QDomProcessingInstruction_PythonToCpp_QDomProcessingInstruction_PTR,
        is_QDomProcessingInstruction_PythonToCpp_QDomProcessingInstruction_PTR_Convertible,
        QDomProcessingInstruction_PTR_CppToPython_QDomProcessingInstruction,
        QDomProcessingInstruction_COPY_CppToPython_QDomProcessingInstruction);

    Shiboken::Conversions::registerConverterName(converter, "QDomProcessingInstruction");
    Shiboken::Conversions::registerConverterName(converter, "QDomProcessingInstruction*");
    Shiboken::Conversions::registerConverterName(converter, "QDomProcessingInstruction&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QDomProcessingInstruction).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QDomProcessingInstruction_PythonToCpp_QDomProcessingInstruction_COPY,
        is_QDomProcessingInstruction_PythonToCpp_QDomProcessingInstruction_COPY_Convertible);

    qRegisterMetaType< ::QDomProcessingInstruction >("QDomProcessingInstruction");

    return pyType;
}
