// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgraphswidgets_python.h"

// main header
#include "q3dgraphswidgetitem_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGraphs/q3dscene.h>
#include <QtGraphs/qabstract3daxis.h>
#include <QtGraphs/qabstract3dseries.h>
#include <QtGraphs/qcustom3ditem.h>
#include <QtGraphs/qgraphs3dnamespace.h>
#include <QtGraphs/qgraphstheme.h>
#include <QtGui/qcolor.h>
#include <QtGui/qevent.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qvectornd.h>
#include <QtQuick/qquickitemgrabresult.h>
#include <QtQuickWidgets/qquickwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qlocale.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsharedpointer.h>
#include <qsize.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void Q3DGraphsWidgetItemWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

void Q3DGraphsWidgetItemWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DGraphsWidgetItem", funcName);
        return;
    }
}

void Q3DGraphsWidgetItemWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DGraphsWidgetItem", funcName);
        return;
    }
}

void Q3DGraphsWidgetItemWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DGraphsWidgetItem", funcName);
        return;
    }
}

void Q3DGraphsWidgetItemWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DGraphsWidgetItem", funcName);
        return;
    }
}

bool Q3DGraphsWidgetItemWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[4])
        return this->::Q3DGraphsWidgetItem::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::Q3DGraphsWidgetItem::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DGraphsWidgetItem", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("Q3DGraphsWidgetItem", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool Q3DGraphsWidgetItemWrapper::eventFilter(::QObject * obj, ::QEvent * event)
{
    if (m_PyMethodCache[5])
        return this->::Q3DGraphsWidgetItem::eventFilter(obj, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::Q3DGraphsWidgetItem::eventFilter(obj, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), obj),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), obj),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DGraphsWidgetItem", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("Q3DGraphsWidgetItem", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void Q3DGraphsWidgetItemWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("Q3DGraphsWidgetItem", funcName);
        return;
    }
}

const QMetaObject *Q3DGraphsWidgetItemWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return Q3DGraphsWidgetItem::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int Q3DGraphsWidgetItemWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = Q3DGraphsWidgetItem::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *Q3DGraphsWidgetItemWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< Q3DGraphsWidgetItemWrapper *>(this));
    return Q3DGraphsWidgetItem::qt_metacast(_clname);
}

Q3DGraphsWidgetItemWrapper::~Q3DGraphsWidgetItemWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_Q3DGraphsWidgetItemFunc_activeTheme(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activeTheme()const
        QGraphsTheme * cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->activeTheme();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_addCustomItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::addCustomItem(QCustom3DItem*)->qsizetype
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QCustom3DItem_IDX]), (pyArg)))) {
        overloadId = 0; // addCustomItem(QCustom3DItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addCustomItem", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCustom3DItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addCustomItem(QCustom3DItem*)
            qsizetype cppResult = cppSelf->addCustomItem(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_addTheme(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::addTheme(QGraphsTheme*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), (pyArg)))) {
        overloadId = 0; // addTheme(QGraphsTheme*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addTheme", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphsTheme *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addTheme(QGraphsTheme*)
            cppSelf->addTheme(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_ambientLightStrength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ambientLightStrength()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->ambientLightStrength();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_aspectRatio(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // aspectRatio()const
        qreal cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->aspectRatio();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_cameraPreset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cameraPreset()const
        QtGraphs3D::CameraPreset cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->cameraPreset();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_CameraPreset_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_cameraTargetPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cameraTargetPosition()const
        QVector3D cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->cameraTargetPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_cameraXRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cameraXRotation()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->cameraXRotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_cameraYRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cameraYRotation()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->cameraYRotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_cameraZoomLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cameraZoomLevel()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->cameraZoomLevel();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_clearSelection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearSelection()
        cppSelf->clearSelection();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_currentFps(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentFps()const
        int cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->currentFps();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_customItems(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // customItems()const
        QList<QCustom3DItem*> cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->customItems();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsWidgetsTypeConverters[SBK_QtGraphsWidgets_QList_QCustom3DItemPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_doPicking(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::doPicking(QPoint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // doPicking(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "doPicking", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // doPicking(QPoint)
            cppSelf->doPicking(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Q3DGraphsWidgetItem::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_eventFilter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::eventFilter(QObject*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "eventFilter", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // eventFilter(QObject*,QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::Q3DGraphsWidgetItem::eventFilter(cppArg0, cppArg1)
                : cppSelf->eventFilter(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_gridLineType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // gridLineType()const
        QtGraphs3D::GridLineType cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->gridLineType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_GridLineType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_hasSeries(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::hasSeries(QAbstract3DSeries*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DSeries_IDX]), (pyArg)))) {
        overloadId = 0; // hasSeries(QAbstract3DSeries*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hasSeries", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstract3DSeries *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hasSeries(QAbstract3DSeries*)const
            bool cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->hasSeries(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_horizontalAspectRatio(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // horizontalAspectRatio()const
        qreal cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->horizontalAspectRatio();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_isOrthoProjection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isOrthoProjection()const
        bool cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->isOrthoProjection();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_isPolar(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isPolar()const
        bool cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->isPolar();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_isRotationEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRotationEnabled()const
        bool cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->isRotationEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_isSelectionEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSelectionEnabled()const
        bool cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->isSelectionEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_isZoomAtTargetEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isZoomAtTargetEnabled()const
        bool cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->isZoomAtTargetEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_isZoomEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isZoomEnabled()const
        bool cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->isZoomEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_labelMargin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // labelMargin()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->labelMargin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_lightColor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lightColor()const
        QColor cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->lightColor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_lightStrength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lightStrength()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->lightStrength();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_locale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // locale()const
        QLocale cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->locale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_margin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // margin()const
        qreal cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->margin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_maxCameraXRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxCameraXRotation()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->maxCameraXRotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_maxCameraYRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxCameraYRotation()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->maxCameraYRotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_maxCameraZoomLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maxCameraZoomLevel()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->maxCameraZoomLevel();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_measureFps(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // measureFps()const
        bool cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->measureFps();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_minCameraXRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minCameraXRotation()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->minCameraXRotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_minCameraYRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minCameraYRotation()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->minCameraYRotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_minCameraZoomLevel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minCameraZoomLevel()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->minCameraZoomLevel();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_msaaSamples(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // msaaSamples()const
        int cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->msaaSamples();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_optimizationHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // optimizationHint()const
        QtGraphs3D::OptimizationHint cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->optimizationHint();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_OptimizationHint_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_queriedGraphPosition(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // queriedGraphPosition()const
        QVector3D cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->queriedGraphPosition();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_radialLabelOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // radialLabelOffset()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->radialLabelOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_releaseCustomItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::releaseCustomItem(QCustom3DItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QCustom3DItem_IDX]), (pyArg)))) {
        overloadId = 0; // releaseCustomItem(QCustom3DItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "releaseCustomItem", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCustom3DItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // releaseCustomItem(QCustom3DItem*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            Shiboken::Object::releaseOwnership(pyArg);
            // END of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            // ========================================================================
            // End of code injection

            cppSelf->releaseCustomItem(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "releaseCustomItem(QCustom3DItem*)1", pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_releaseTheme(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::releaseTheme(QGraphsTheme*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), (pyArg)))) {
        overloadId = 0; // releaseTheme(QGraphsTheme*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "releaseTheme", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphsTheme *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // releaseTheme(QGraphsTheme*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            Shiboken::Object::releaseOwnership(pyArg);
            // END of custom code block [file: ../glue/qtdatavisualization.cpp (releaseownership)]
            // ========================================================================
            // End of code injection

            cppSelf->releaseTheme(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "releaseTheme(QGraphsTheme*)1", pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_removeCustomItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::removeCustomItem(QCustom3DItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QCustom3DItem_IDX]), (pyArg)))) {
        overloadId = 0; // removeCustomItem(QCustom3DItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeCustomItem", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCustom3DItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeCustomItem(QCustom3DItem*)
            cppSelf->removeCustomItem(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_removeCustomItemAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::removeCustomItemAt(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // removeCustomItemAt(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeCustomItemAt", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeCustomItemAt(QVector3D)
            cppSelf->removeCustomItemAt(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_removeCustomItems(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // removeCustomItems()
        cppSelf->removeCustomItems();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_renderToImage(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "renderToImage", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    if (PyArg_ParseTuple(args, "|O:renderToImage", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::renderToImage(QSize=)const->QSharedPointer<QQuickItemGrabResult>
    if (numArgs == 0) {
        overloadId = 0; // renderToImage(QSize)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0])))) {
        overloadId = 0; // renderToImage(QSize)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "renderToImage", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_imageSize = Shiboken::String::createStaticString("imageSize");
            if (PyDict_Contains(kwds, key_imageSize) != 0) {
                value = PyDict_GetItem(kwds, key_imageSize);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_imageSize);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "renderToImage", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "renderToImage", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_imageSize);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "renderToImage", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSize cppArg0 = QSize();
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // renderToImage(QSize)const
            QSharedPointer<QQuickItemGrabResult> cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->renderToImage(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSharedPointer_QQuickItemGrabResult_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_scene(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scene()const
        Q3DScene * cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->scene();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_Q3DScene_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_selectedAxis(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedAxis()const
        QAbstract3DAxis * cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->selectedAxis();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QAbstract3DAxis_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_selectedCustomItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedCustomItem()const
        QCustom3DItem * cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->selectedCustomItem();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QCustom3DItem_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_selectedCustomItemIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedCustomItemIndex()const
        qsizetype cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->selectedCustomItemIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_selectedElement(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedElement()const
        QtGraphs3D::ElementType cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->selectedElement();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_ElementType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_selectedLabelIndex(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedLabelIndex()const
        int cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->selectedLabelIndex();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_selectionMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectionMode()const
        QFlags<QtGraphs3D::SelectionFlag> cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->selectionMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QFlags_QtGraphs3D_SelectionFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setActiveTheme(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setActiveTheme(QGraphsTheme*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QGraphsTheme_IDX]), (pyArg)))) {
        overloadId = 0; // setActiveTheme(QGraphsTheme*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActiveTheme", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphsTheme *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActiveTheme(QGraphsTheme*)
            cppSelf->setActiveTheme(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setAmbientLightStrength(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setAmbientLightStrength(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setAmbientLightStrength(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAmbientLightStrength", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAmbientLightStrength(float)
            cppSelf->setAmbientLightStrength(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setAspectRatio(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setAspectRatio(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setAspectRatio(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAspectRatio", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAspectRatio(qreal)
            cppSelf->setAspectRatio(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setCameraPosition(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setCameraPosition", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setCameraPosition", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setCameraPosition(float,float,float=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // setCameraPosition(float,float,float)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
            overloadId = 0; // setCameraPosition(float,float,float)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCameraPosition", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_zoom = Shiboken::String::createStaticString("zoom");
            if (PyDict_Contains(kwds, key_zoom) != 0) {
                value = PyDict_GetItem(kwds, key_zoom);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_zoom);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setCameraPosition", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "setCameraPosition", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_zoom);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setCameraPosition", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);
            }
        }
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2 = 100.0f;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraPosition(float,float,float)
            cppSelf->setCameraPosition(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setCameraPreset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setCameraPreset(QtGraphs3D::CameraPreset)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_CameraPreset_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setCameraPreset(QtGraphs3D::CameraPreset)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCameraPreset", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        ::QtGraphs3D::CameraPreset cppArg0{QtGraphs3D::CameraPreset::NoPreset};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraPreset(QtGraphs3D::CameraPreset)
            cppSelf->setCameraPreset(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setCameraTargetPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setCameraTargetPosition(QVector3D)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QVector3D_IDX]), (pyArg)))) {
        overloadId = 0; // setCameraTargetPosition(QVector3D)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCameraTargetPosition", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QVector3D cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraTargetPosition(QVector3D)
            cppSelf->setCameraTargetPosition(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setCameraXRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setCameraXRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setCameraXRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCameraXRotation", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraXRotation(float)
            cppSelf->setCameraXRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setCameraYRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setCameraYRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setCameraYRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCameraYRotation", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraYRotation(float)
            cppSelf->setCameraYRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setCameraZoomLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setCameraZoomLevel(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setCameraZoomLevel(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCameraZoomLevel", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCameraZoomLevel(float)
            cppSelf->setCameraZoomLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setDefaultInputHandler(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // setDefaultInputHandler()
        cppSelf->setDefaultInputHandler();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setDragButton(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setDragButton(QFlags<Qt::MouseButton>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MouseButton_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setDragButton(QFlags<Qt::MouseButton>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDragButton", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        ::QFlags<Qt::MouseButton> cppArg0 = QFlags<Qt::MouseButton>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDragButton(QFlags<Qt::MouseButton>)
            cppSelf->setDragButton(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setGridLineType(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setGridLineType(QtGraphs3D::GridLineType)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_GridLineType_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setGridLineType(QtGraphs3D::GridLineType)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGridLineType", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        ::QtGraphs3D::GridLineType cppArg0{QtGraphs3D::GridLineType::Shader};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGridLineType(QtGraphs3D::GridLineType)
            cppSelf->setGridLineType(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setHorizontalAspectRatio(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setHorizontalAspectRatio(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setHorizontalAspectRatio(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHorizontalAspectRatio", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHorizontalAspectRatio(qreal)
            cppSelf->setHorizontalAspectRatio(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setLabelMargin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setLabelMargin(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setLabelMargin(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLabelMargin", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelMargin(float)
            cppSelf->setLabelMargin(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setLightColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setLightColor(QColor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 0; // setLightColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLightColor", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QColor cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLightColor(QColor)
            cppSelf->setLightColor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setLightStrength(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setLightStrength(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setLightStrength(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLightStrength", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLightStrength(float)
            cppSelf->setLightStrength(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setLocale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setLocale(QLocale)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLocale_IDX]), (pyArg)))) {
        overloadId = 0; // setLocale(QLocale)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocale", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QLocale cppArg0_local;
        ::QLocale *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocale(QLocale)
            cppSelf->setLocale(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setMargin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setMargin(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMargin", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMargin(qreal)
            cppSelf->setMargin(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setMaxCameraXRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setMaxCameraXRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaxCameraXRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxCameraXRotation", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxCameraXRotation(float)
            cppSelf->setMaxCameraXRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setMaxCameraYRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setMaxCameraYRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaxCameraYRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxCameraYRotation", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxCameraYRotation(float)
            cppSelf->setMaxCameraYRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setMaxCameraZoomLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setMaxCameraZoomLevel(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMaxCameraZoomLevel(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaxCameraZoomLevel", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaxCameraZoomLevel(float)
            cppSelf->setMaxCameraZoomLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setMeasureFps(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setMeasureFps(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setMeasureFps(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMeasureFps", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMeasureFps(bool)
            cppSelf->setMeasureFps(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setMinCameraXRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setMinCameraXRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMinCameraXRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinCameraXRotation", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinCameraXRotation(float)
            cppSelf->setMinCameraXRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setMinCameraYRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setMinCameraYRotation(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMinCameraYRotation(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinCameraYRotation", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinCameraYRotation(float)
            cppSelf->setMinCameraYRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setMinCameraZoomLevel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setMinCameraZoomLevel(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setMinCameraZoomLevel(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinCameraZoomLevel", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinCameraZoomLevel(float)
            cppSelf->setMinCameraZoomLevel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setMsaaSamples(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setMsaaSamples(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMsaaSamples(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMsaaSamples", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMsaaSamples(int)
            cppSelf->setMsaaSamples(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setOptimizationHint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setOptimizationHint(QtGraphs3D::OptimizationHint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_OptimizationHint_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setOptimizationHint(QtGraphs3D::OptimizationHint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOptimizationHint", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        ::QtGraphs3D::OptimizationHint cppArg0{QtGraphs3D::OptimizationHint::Default};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOptimizationHint(QtGraphs3D::OptimizationHint)
            cppSelf->setOptimizationHint(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setOrthoProjection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setOrthoProjection(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setOrthoProjection(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOrthoProjection", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOrthoProjection(bool)
            cppSelf->setOrthoProjection(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setPolar(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setPolar(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setPolar(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPolar", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPolar(bool)
            cppSelf->setPolar(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setRadialLabelOffset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setRadialLabelOffset(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setRadialLabelOffset(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRadialLabelOffset", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRadialLabelOffset(float)
            cppSelf->setRadialLabelOffset(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setRotationEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setRotationEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setRotationEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRotationEnabled", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotationEnabled(bool)
            cppSelf->setRotationEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setSelectionEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setSelectionEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSelectionEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelectionEnabled", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectionEnabled(bool)
            cppSelf->setSelectionEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setSelectionMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setSelectionMode(QFlags<QtGraphs3D::SelectionFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QFlags_QtGraphs3D_SelectionFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setSelectionMode(QFlags<QtGraphs3D::SelectionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSelectionMode", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        ::QFlags<QtGraphs3D::SelectionFlag> cppArg0 = QFlags<QtGraphs3D::SelectionFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSelectionMode(QFlags<QtGraphs3D::SelectionFlag>)
            cppSelf->setSelectionMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setShadowQuality(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setShadowQuality(QtGraphs3D::ShadowQuality)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_ShadowQuality_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setShadowQuality(QtGraphs3D::ShadowQuality)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShadowQuality", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        ::QtGraphs3D::ShadowQuality cppArg0{QtGraphs3D::ShadowQuality::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShadowQuality(QtGraphs3D::ShadowQuality)
            cppSelf->setShadowQuality(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setShadowStrength(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setShadowStrength(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setShadowStrength(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShadowStrength", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShadowStrength(float)
            cppSelf->setShadowStrength(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setWidget(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setWidget(QQuickWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickWidgetsTypeStructs[SBK_QQuickWidget_IDX]), (pyArg)))) {
        overloadId = 0; // setWidget(QQuickWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWidget", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuickWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWidget(QQuickWidget*)
            cppSelf->setWidget(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setWrapCameraXRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setWrapCameraXRotation(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setWrapCameraXRotation(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWrapCameraXRotation", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWrapCameraXRotation(bool)
            cppSelf->setWrapCameraXRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setWrapCameraYRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setWrapCameraYRotation(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setWrapCameraYRotation(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWrapCameraYRotation", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWrapCameraYRotation(bool)
            cppSelf->setWrapCameraYRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setZoomAtTargetEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setZoomAtTargetEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setZoomAtTargetEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZoomAtTargetEnabled", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZoomAtTargetEnabled(bool)
            cppSelf->setZoomAtTargetEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_setZoomEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: Q3DGraphsWidgetItem::setZoomEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setZoomEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZoomEnabled", errInfo, SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZoomEnabled(bool)
            cppSelf->setZoomEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_shadowQuality(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shadowQuality()const
        QtGraphs3D::ShadowQuality cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->shadowQuality();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGraphsTypeStructs[SBK_QtGraphs3D_ShadowQuality_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_shadowStrength(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shadowStrength()const
        float cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->shadowStrength();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_themes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // themes()const
        QList<QGraphsTheme*> cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->themes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGraphsWidgetsTypeConverters[SBK_QtGraphsWidgets_QList_QGraphsThemePTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_unsetDefaultDragHandler(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unsetDefaultDragHandler()
        cppSelf->unsetDefaultDragHandler();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_unsetDefaultInputHandler(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unsetDefaultInputHandler()
        cppSelf->unsetDefaultInputHandler();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_unsetDefaultPinchHandler(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unsetDefaultPinchHandler()
        cppSelf->unsetDefaultPinchHandler();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_unsetDefaultTapHandler(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unsetDefaultTapHandler()
        cppSelf->unsetDefaultTapHandler();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_unsetDefaultWheelHandler(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unsetDefaultWheelHandler()
        cppSelf->unsetDefaultWheelHandler();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_widget(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // widget()const
        QQuickWidget * cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->widget();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickWidgetsTypeStructs[SBK_QQuickWidget_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_wrapCameraXRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wrapCameraXRotation()const
        bool cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->wrapCameraXRotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_Q3DGraphsWidgetItemFunc_wrapCameraYRotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wrapCameraYRotation()const
        bool cppResult = const_cast<const ::Q3DGraphsWidgetItem *>(cppSelf)->wrapCameraYRotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_Q3DGraphsWidgetItem_PropertyStrings[] = {
    "activeTheme::",
    "ambientLightStrength::",
    "aspectRatio::",
    "cameraPreset::",
    "cameraTargetPosition::",
    "cameraXRotation::",
    "cameraYRotation::",
    "cameraZoomLevel::",
    "currentFps:",
    "gridLineType::",
    "horizontalAspectRatio::",
    "labelMargin::",
    "lightColor::",
    "lightStrength::",
    "locale::",
    "margin::",
    "maxCameraXRotation::",
    "maxCameraYRotation::",
    "maxCameraZoomLevel::",
    "measureFps::",
    "minCameraXRotation::",
    "minCameraYRotation::",
    "minCameraZoomLevel::",
    "msaaSamples::",
    "optimizationHint::",
    "orthoProjection:isOrthoProjection:",
    "polar:isPolar:",
    "queriedGraphPosition:",
    "radialLabelOffset::",
    "rotationEnabled:isRotationEnabled:",
    "scene:",
    "selectedElement:",
    "selectionEnabled:isSelectionEnabled:",
    "selectionMode::",
    "shadowQuality::",
    "shadowStrength::",
    "wrapCameraXRotation::",
    "wrapCameraYRotation::",
    "zoomAtTargetEnabled:isZoomAtTargetEnabled:",
    "zoomEnabled:isZoomEnabled:",
    nullptr // Sentinel
};

static PyMethodDef Sbk_Q3DGraphsWidgetItem_methods[] = {
    {"activeTheme", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_activeTheme), METH_NOARGS, nullptr},
    {"addCustomItem", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_addCustomItem), METH_O, nullptr},
    {"addTheme", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_addTheme), METH_O, nullptr},
    {"ambientLightStrength", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_ambientLightStrength), METH_NOARGS, nullptr},
    {"aspectRatio", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_aspectRatio), METH_NOARGS, nullptr},
    {"cameraPreset", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_cameraPreset), METH_NOARGS, nullptr},
    {"cameraTargetPosition", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_cameraTargetPosition), METH_NOARGS, nullptr},
    {"cameraXRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_cameraXRotation), METH_NOARGS, nullptr},
    {"cameraYRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_cameraYRotation), METH_NOARGS, nullptr},
    {"cameraZoomLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_cameraZoomLevel), METH_NOARGS, nullptr},
    {"clearSelection", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_clearSelection), METH_NOARGS, nullptr},
    {"currentFps", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_currentFps), METH_NOARGS, nullptr},
    {"customItems", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_customItems), METH_NOARGS, nullptr},
    {"doPicking", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_doPicking), METH_O, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_event), METH_O, nullptr},
    {"eventFilter", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_eventFilter), METH_VARARGS, nullptr},
    {"gridLineType", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_gridLineType), METH_NOARGS, nullptr},
    {"hasSeries", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_hasSeries), METH_O, nullptr},
    {"horizontalAspectRatio", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_horizontalAspectRatio), METH_NOARGS, nullptr},
    {"isOrthoProjection", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_isOrthoProjection), METH_NOARGS, nullptr},
    {"isPolar", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_isPolar), METH_NOARGS, nullptr},
    {"isRotationEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_isRotationEnabled), METH_NOARGS, nullptr},
    {"isSelectionEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_isSelectionEnabled), METH_NOARGS, nullptr},
    {"isZoomAtTargetEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_isZoomAtTargetEnabled), METH_NOARGS, nullptr},
    {"isZoomEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_isZoomEnabled), METH_NOARGS, nullptr},
    {"labelMargin", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_labelMargin), METH_NOARGS, nullptr},
    {"lightColor", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_lightColor), METH_NOARGS, nullptr},
    {"lightStrength", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_lightStrength), METH_NOARGS, nullptr},
    {"locale", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_locale), METH_NOARGS, nullptr},
    {"margin", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_margin), METH_NOARGS, nullptr},
    {"maxCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_maxCameraXRotation), METH_NOARGS, nullptr},
    {"maxCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_maxCameraYRotation), METH_NOARGS, nullptr},
    {"maxCameraZoomLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_maxCameraZoomLevel), METH_NOARGS, nullptr},
    {"measureFps", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_measureFps), METH_NOARGS, nullptr},
    {"minCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_minCameraXRotation), METH_NOARGS, nullptr},
    {"minCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_minCameraYRotation), METH_NOARGS, nullptr},
    {"minCameraZoomLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_minCameraZoomLevel), METH_NOARGS, nullptr},
    {"msaaSamples", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_msaaSamples), METH_NOARGS, nullptr},
    {"optimizationHint", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_optimizationHint), METH_NOARGS, nullptr},
    {"queriedGraphPosition", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_queriedGraphPosition), METH_NOARGS, nullptr},
    {"radialLabelOffset", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_radialLabelOffset), METH_NOARGS, nullptr},
    {"releaseCustomItem", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_releaseCustomItem), METH_O, nullptr},
    {"releaseTheme", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_releaseTheme), METH_O, nullptr},
    {"removeCustomItem", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_removeCustomItem), METH_O, nullptr},
    {"removeCustomItemAt", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_removeCustomItemAt), METH_O, nullptr},
    {"removeCustomItems", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_removeCustomItems), METH_NOARGS, nullptr},
    {"renderToImage", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_renderToImage), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"scene", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_scene), METH_NOARGS, nullptr},
    {"selectedAxis", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_selectedAxis), METH_NOARGS, nullptr},
    {"selectedCustomItem", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_selectedCustomItem), METH_NOARGS, nullptr},
    {"selectedCustomItemIndex", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_selectedCustomItemIndex), METH_NOARGS, nullptr},
    {"selectedElement", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_selectedElement), METH_NOARGS, nullptr},
    {"selectedLabelIndex", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_selectedLabelIndex), METH_NOARGS, nullptr},
    {"selectionMode", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_selectionMode), METH_NOARGS, nullptr},
    {"setActiveTheme", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setActiveTheme), METH_O, nullptr},
    {"setAmbientLightStrength", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setAmbientLightStrength), METH_O, nullptr},
    {"setAspectRatio", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setAspectRatio), METH_O, nullptr},
    {"setCameraPosition", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setCameraPosition), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setCameraPreset", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setCameraPreset), METH_O, nullptr},
    {"setCameraTargetPosition", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setCameraTargetPosition), METH_O, nullptr},
    {"setCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setCameraXRotation), METH_O, nullptr},
    {"setCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setCameraYRotation), METH_O, nullptr},
    {"setCameraZoomLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setCameraZoomLevel), METH_O, nullptr},
    {"setDefaultInputHandler", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setDefaultInputHandler), METH_NOARGS, nullptr},
    {"setDragButton", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setDragButton), METH_O, nullptr},
    {"setGridLineType", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setGridLineType), METH_O, nullptr},
    {"setHorizontalAspectRatio", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setHorizontalAspectRatio), METH_O, nullptr},
    {"setLabelMargin", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setLabelMargin), METH_O, nullptr},
    {"setLightColor", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setLightColor), METH_O, nullptr},
    {"setLightStrength", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setLightStrength), METH_O, nullptr},
    {"setLocale", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setLocale), METH_O, nullptr},
    {"setMargin", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setMargin), METH_O, nullptr},
    {"setMaxCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setMaxCameraXRotation), METH_O, nullptr},
    {"setMaxCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setMaxCameraYRotation), METH_O, nullptr},
    {"setMaxCameraZoomLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setMaxCameraZoomLevel), METH_O, nullptr},
    {"setMeasureFps", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setMeasureFps), METH_O, nullptr},
    {"setMinCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setMinCameraXRotation), METH_O, nullptr},
    {"setMinCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setMinCameraYRotation), METH_O, nullptr},
    {"setMinCameraZoomLevel", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setMinCameraZoomLevel), METH_O, nullptr},
    {"setMsaaSamples", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setMsaaSamples), METH_O, nullptr},
    {"setOptimizationHint", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setOptimizationHint), METH_O, nullptr},
    {"setOrthoProjection", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setOrthoProjection), METH_O, nullptr},
    {"setPolar", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setPolar), METH_O, nullptr},
    {"setRadialLabelOffset", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setRadialLabelOffset), METH_O, nullptr},
    {"setRotationEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setRotationEnabled), METH_O, nullptr},
    {"setSelectionEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setSelectionEnabled), METH_O, nullptr},
    {"setSelectionMode", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setSelectionMode), METH_O, nullptr},
    {"setShadowQuality", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setShadowQuality), METH_O, nullptr},
    {"setShadowStrength", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setShadowStrength), METH_O, nullptr},
    {"setWidget", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setWidget), METH_O, nullptr},
    {"setWrapCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setWrapCameraXRotation), METH_O, nullptr},
    {"setWrapCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setWrapCameraYRotation), METH_O, nullptr},
    {"setZoomAtTargetEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setZoomAtTargetEnabled), METH_O, nullptr},
    {"setZoomEnabled", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_setZoomEnabled), METH_O, nullptr},
    {"shadowQuality", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_shadowQuality), METH_NOARGS, nullptr},
    {"shadowStrength", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_shadowStrength), METH_NOARGS, nullptr},
    {"themes", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_themes), METH_NOARGS, nullptr},
    {"unsetDefaultDragHandler", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_unsetDefaultDragHandler), METH_NOARGS, nullptr},
    {"unsetDefaultInputHandler", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_unsetDefaultInputHandler), METH_NOARGS, nullptr},
    {"unsetDefaultPinchHandler", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_unsetDefaultPinchHandler), METH_NOARGS, nullptr},
    {"unsetDefaultTapHandler", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_unsetDefaultTapHandler), METH_NOARGS, nullptr},
    {"unsetDefaultWheelHandler", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_unsetDefaultWheelHandler), METH_NOARGS, nullptr},
    {"widget", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_widget), METH_NOARGS, nullptr},
    {"wrapCameraXRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_wrapCameraXRotation), METH_NOARGS, nullptr},
    {"wrapCameraYRotation", reinterpret_cast<PyCFunction>(Sbk_Q3DGraphsWidgetItemFunc_wrapCameraYRotation), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_Q3DGraphsWidgetItem_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::Q3DGraphsWidgetItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<Q3DGraphsWidgetItemWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_Q3DGraphsWidgetItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_Q3DGraphsWidgetItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_Q3DGraphsWidgetItem_Type = nullptr;
static PyTypeObject *Sbk_Q3DGraphsWidgetItem_TypeF(void)
{
    return _Sbk_Q3DGraphsWidgetItem_Type;
}

static PyType_Slot Sbk_Q3DGraphsWidgetItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_Q3DGraphsWidgetItem_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_Q3DGraphsWidgetItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_Q3DGraphsWidgetItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_Q3DGraphsWidgetItem_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_Q3DGraphsWidgetItem_spec = {
    "2:PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_Q3DGraphsWidgetItem_slots
};

} //extern "C"

static void *Sbk_Q3DGraphsWidgetItem_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::Q3DGraphsWidgetItem *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void Q3DGraphsWidgetItem_PythonToCpp_Q3DGraphsWidgetItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_Q3DGraphsWidgetItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_Q3DGraphsWidgetItem_PythonToCpp_Q3DGraphsWidgetItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_Q3DGraphsWidgetItem_TypeF()))
        return Q3DGraphsWidgetItem_PythonToCpp_Q3DGraphsWidgetItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *Q3DGraphsWidgetItem_PTR_CppToPython_Q3DGraphsWidgetItem(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::Q3DGraphsWidgetItem *>(const_cast<void *>(cppIn)), Sbk_Q3DGraphsWidgetItem_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *Q3DGraphsWidgetItem_SignatureStrings[] = {
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.activeTheme(self)->PySide6.QtGraphs.QGraphsTheme",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.addCustomItem(self,item:PySide6.QtGraphs.QCustom3DItem)->qsizetype",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.addTheme(self,theme:PySide6.QtGraphs.QGraphsTheme)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.ambientLightStrength(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.aspectRatio(self)->qreal",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.cameraPreset(self)->PySide6.QtGraphs.QtGraphs3D.CameraPreset",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.cameraTargetPosition(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.cameraXRotation(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.cameraYRotation(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.cameraZoomLevel(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.clearSelection(self)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.currentFps(self)->int",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.customItems(self)->QList[PySide6.QtGraphs.QCustom3DItem]",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.doPicking(self,point:PySide6.QtCore.QPoint)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.eventFilter(self,obj:PySide6.QtCore.QObject,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.gridLineType(self)->PySide6.QtGraphs.QtGraphs3D.GridLineType",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.hasSeries(self,series:PySide6.QtGraphs.QAbstract3DSeries)->bool",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.horizontalAspectRatio(self)->qreal",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.isOrthoProjection(self)->bool",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.isPolar(self)->bool",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.isRotationEnabled(self)->bool",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.isSelectionEnabled(self)->bool",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.isZoomAtTargetEnabled(self)->bool",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.isZoomEnabled(self)->bool",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.labelMargin(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.lightColor(self)->PySide6.QtGui.QColor",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.lightStrength(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.locale(self)->PySide6.QtCore.QLocale",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.margin(self)->qreal",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.maxCameraXRotation(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.maxCameraYRotation(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.maxCameraZoomLevel(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.measureFps(self)->bool",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.minCameraXRotation(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.minCameraYRotation(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.minCameraZoomLevel(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.msaaSamples(self)->int",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.optimizationHint(self)->PySide6.QtGraphs.QtGraphs3D.OptimizationHint",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.queriedGraphPosition(self)->PySide6.QtGui.QVector3D",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.radialLabelOffset(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.releaseCustomItem(self,item:PySide6.QtGraphs.QCustom3DItem)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.releaseTheme(self,theme:PySide6.QtGraphs.QGraphsTheme)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.removeCustomItem(self,item:PySide6.QtGraphs.QCustom3DItem)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.removeCustomItemAt(self,position:PySide6.QtGui.QVector3D)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.removeCustomItems(self)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.renderToImage(self,imageSize:PySide6.QtCore.QSize=QSize())->QSharedPointer[PySide6.QtQuick.QQuickItemGrabResult]",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.scene(self)->PySide6.QtGraphs.Q3DScene",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.selectedAxis(self)->PySide6.QtGraphs.QAbstract3DAxis",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.selectedCustomItem(self)->PySide6.QtGraphs.QCustom3DItem",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.selectedCustomItemIndex(self)->qsizetype",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.selectedElement(self)->PySide6.QtGraphs.QtGraphs3D.ElementType",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.selectedLabelIndex(self)->int",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.selectionMode(self)->PySide6.QtGraphs.QtGraphs3D.SelectionFlag",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setActiveTheme(self,activeTheme:PySide6.QtGraphs.QGraphsTheme)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setAmbientLightStrength(self,newAmbientLightStrength:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setAspectRatio(self,ratio:qreal)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setCameraPosition(self,horizontal:float,vertical:float,zoom:float=100.0f)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setCameraPreset(self,preset:PySide6.QtGraphs.QtGraphs3D.CameraPreset)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setCameraTargetPosition(self,target:PySide6.QtGui.QVector3D)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setCameraXRotation(self,rotation:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setCameraYRotation(self,rotation:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setCameraZoomLevel(self,level:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setDefaultInputHandler(self)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setDragButton(self,button:PySide6.QtCore.Qt.MouseButton)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setGridLineType(self,gridLineType:PySide6.QtGraphs.QtGraphs3D.GridLineType)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setHorizontalAspectRatio(self,ratio:qreal)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setLabelMargin(self,margin:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setLightColor(self,newLightColor:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setLightStrength(self,newLightStrength:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setLocale(self,locale:typing.Union[PySide6.QtCore.QLocale, PySide6.QtCore.QLocale.Language])",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setMargin(self,margin:qreal)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setMaxCameraXRotation(self,rotation:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setMaxCameraYRotation(self,rotation:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setMaxCameraZoomLevel(self,level:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setMeasureFps(self,enable:bool)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setMinCameraXRotation(self,rotation:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setMinCameraYRotation(self,rotation:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setMinCameraZoomLevel(self,level:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setMsaaSamples(self,samples:int)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setOptimizationHint(self,hint:PySide6.QtGraphs.QtGraphs3D.OptimizationHint)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setOrthoProjection(self,enable:bool)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setPolar(self,enable:bool)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setRadialLabelOffset(self,offset:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setRotationEnabled(self,enable:bool)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setSelectionEnabled(self,enable:bool)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setSelectionMode(self,selectionMode:PySide6.QtGraphs.QtGraphs3D.SelectionFlag)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setShadowQuality(self,shadowQuality:PySide6.QtGraphs.QtGraphs3D.ShadowQuality)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setShadowStrength(self,newShadowStrength:float)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setWidget(self,widget:PySide6.QtQuickWidgets.QQuickWidget)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setWrapCameraXRotation(self,wrap:bool)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setWrapCameraYRotation(self,wrap:bool)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setZoomAtTargetEnabled(self,enable:bool)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.setZoomEnabled(self,enable:bool)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.shadowQuality(self)->PySide6.QtGraphs.QtGraphs3D.ShadowQuality",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.shadowStrength(self)->float",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.themes(self)->QList[PySide6.QtGraphs.QGraphsTheme]",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.unsetDefaultDragHandler(self)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.unsetDefaultInputHandler(self)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.unsetDefaultPinchHandler(self)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.unsetDefaultTapHandler(self)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.unsetDefaultWheelHandler(self)",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.widget(self)->PySide6.QtQuickWidgets.QQuickWidget",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.wrapCameraXRotation(self)->bool",
    "PySide6.QtGraphsWidgets.Q3DGraphsWidgetItem.wrapCameraYRotation(self)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t Q3DGraphsWidgetItem_SignatureByteSize = 1297;
static constexpr uint8_t Q3DGraphsWidgetItem_SignatureBytes[1297] = {
    0x78, 0xda, 0xbd, 0x59, 0x4d, 0x6f, 0xdb, 0x38, 0x10, 0xbd, 0xef, 0xaf, 0xc8, 0xb1, 0x01, 0xb8,
    0x42, 0x8a, 0x2c, 0x7a, 0x10, 0xd0, 0x05, 0xbc, 0x71, 0xbe, 0x00, 0x19, 0xb1, 0x63, 0x6f, 0xbb,
    0xd9, 0xa2, 0x07, 0xda, 0x1a, 0x4b, 0xcc, 0x52, 0xa4, 0x4b, 0x52, 0x71, 0x92, 0x5f, 0x5f, 0x4a,
    0xb2, 0x64, 0x49, 0x96, 0x12, 0x93, 0x62, 0xf7, 0x92, 0x50, 0xf4, 0xe8, 0x3d, 0x7e, 0xce, 0xcc,
    0x1b, 0x4d, 0x5f, 0xe6, 0x24, 0x84, 0x4f, 0xde, 0x4c, 0x5d, 0x0b, 0xbc, 0x89, 0xe5, 0x57, 0x12,
    0x46, 0xa0, 0xa4, 0x37, 0x3b, 0x1f, 0xd7, 0x3b, 0x6e, 0x15, 0x24, 0x1e, 0x5e, 0x29, 0xf2, 0x04,
    0x8b, 0x18, 0x12, 0xf8, 0x20, 0x81, 0xae, 0x4f, 0x7f, 0xff, 0x73, 0xda, 0x7a, 0xdd, 0x9b, 0x15,
    0xff, 0x73, 0xa3, 0xdf, 0xa6, 0x26, 0xe0, 0x61, 0x78, 0x91, 0x4a, 0xc5, 0x93, 0xec, 0x29, 0x87,
    0x47, 0x44, 0xb7, 0xfc, 0x43, 0x86, 0xc2, 0xec, 0x7c, 0x9c, 0x19, 0xea, 0x21, 0xfc, 0x90, 0xe4,
    0x15, 0xd4, 0xcb, 0xc6, 0x98, 0x6e, 0x3f, 0x11, 0xa4, 0xb2, 0xa6, 0xff, 0xe6, 0x64, 0x4e, 0xcd,
    0xe0, 0x93, 0x25, 0x01, 0xa6, 0x02, 0x12, 0xc5, 0x6a, 0xae, 0x04, 0xb0, 0x48, 0xc5, 0xe5, 0x9a,
    0xad, 0x29, 0xc7, 0xca, 0x0c, 0x4d, 0x6e, 0x60, 0xa5, 0xee, 0xb1, 0x22, 0xbc, 0x04, 0xf9, 0x21,
    0x00, 0x53, 0x23, 0x90, 0x15, 0x4e, 0x40, 0xe0, 0xa9, 0x00, 0x09, 0xaa, 0x7f, 0xfb, 0x76, 0x8d,
    0xf3, 0xb1, 0x77, 0x51, 0xb3, 0xb7, 0x20, 0x5a, 0x60, 0xa1, 0x3b, 0xa6, 0x5c, 0x12, 0x3d, 0x6a,
    0xd6, 0x41, 0x98, 0x12, 0x6f, 0xf6, 0x45, 0x4f, 0x8b, 0x8b, 0xf3, 0xb1, 0x05, 0xfe, 0x3f, 0xf7,
    0x5c, 0xe1, 0x3a, 0xb4, 0xf9, 0xb2, 0x16, 0x40, 0x0f, 0xae, 0x80, 0xfe, 0xe5, 0x3c, 0x09, 0xe0,
    0x09, 0xe8, 0x00, 0x20, 0x0a, 0x58, 0xcc, 0x81, 0xea, 0x65, 0xa9, 0x06, 0x64, 0x06, 0x90, 0x0a,
    0x7d, 0xd8, 0xd4, 0xd5, 0x46, 0x96, 0x83, 0x20, 0xcc, 0x70, 0x08, 0xd5, 0x25, 0xac, 0x20, 0x66,
    0x01, 0x91, 0xea, 0xdb, 0xdb, 0x17, 0xf1, 0xbb, 0x11, 0x49, 0xc8, 0xa7, 0x64, 0xf5, 0x1f, 0x61,
    0x51, 0x71, 0xfd, 0x36, 0x5c, 0x8f, 0xb2, 0x76, 0xfd, 0x2e, 0xb8, 0x00, 0x6f, 0x36, 0xcd, 0x7a,
    0xcd, 0xa6, 0xaf, 0x57, 0x9f, 0x15, 0x87, 0x1b, 0xe5, 0xcd, 0x03, 0xcc, 0xcb, 0xac, 0x57, 0x4f,
    0x69, 0xc9, 0x39, 0x35, 0x47, 0xbe, 0x22, 0x54, 0x81, 0x28, 0xf0, 0xf9, 0xf2, 0xf1, 0x00, 0xfd,
    0x6e, 0xf9, 0xa8, 0x77, 0xce, 0x35, 0x75, 0x24, 0x48, 0x18, 0x10, 0x06, 0x0b, 0xed, 0xe3, 0x8e,
    0xb9, 0xb8, 0xd7, 0x35, 0x7b, 0x23, 0xa2, 0x18, 0xcb, 0x39, 0x08, 0x02, 0xc5, 0xc6, 0x23, 0x99,
    0xb7, 0x3b, 0xbc, 0xe2, 0x68, 0x29, 0x95, 0xd0, 0xc1, 0xe0, 0x7c, 0x5c, 0x98, 0xdb, 0x4c, 0x2a,
    0xe6, 0x82, 0xbc, 0x72, 0xa6, 0x30, 0x1d, 0xb9, 0x70, 0x6e, 0x44, 0xde, 0x09, 0x15, 0xf3, 0xa9,
    0xe0, 0x8f, 0xf5, 0xbb, 0x63, 0x31, 0x30, 0x22, 0xa7, 0x9c, 0x62, 0x31, 0xe0, 0xfd, 0xd2, 0x9f,
    0x5c, 0x32, 0xbc, 0xa4, 0x10, 0x0e, 0x40, 0xaa, 0x3c, 0xc1, 0x70, 0xa8, 0xcc, 0x39, 0x8d, 0x54,
    0xe1, 0x94, 0xdd, 0xa0, 0x0d, 0x45, 0xa1, 0x78, 0x09, 0x74, 0xa2, 0x07, 0x44, 0x06, 0x78, 0x5e,
    0x9a, 0x05, 0xd8, 0x0b, 0x4e, 0xb9, 0xe8, 0x89, 0x30, 0xf9, 0x6f, 0xe6, 0x90, 0xc3, 0x63, 0x36,
    0xe5, 0x2b, 0x4c, 0x3b, 0xee, 0x6b, 0xe1, 0x0c, 0x82, 0xfc, 0x57, 0x23, 0xc0, 0xa4, 0xb1, 0x54,
    0xe6, 0x57, 0x24, 0xc1, 0xcf, 0x17, 0xae, 0x22, 0x67, 0x85, 0xf5, 0xe0, 0x10, 0xcb, 0x41, 0xfc,
    0x4c, 0x00, 0xcb, 0x54, 0x40, 0x2d, 0xfc, 0x19, 0x1f, 0xcb, 0x84, 0x30, 0x77, 0xcb, 0x54, 0x62,
    0x3d, 0x38, 0xc4, 0x72, 0xb1, 0x4c, 0x12, 0xe3, 0x39, 0x4e, 0x36, 0x14, 0xac, 0xd3, 0x04, 0xbe,
    0x51, 0x24, 0x21, 0xaf, 0xf9, 0xa4, 0x6e, 0x08, 0x3b, 0x2a, 0xa3, 0xbc, 0x6b, 0xbd, 0x63, 0x44,
    0xf8, 0x23, 0xcd, 0x62, 0x4d, 0x98, 0xf7, 0xff, 0x8a, 0xac, 0x52, 0xe0, 0x90, 0x60, 0x1a, 0x64,
    0x4e, 0xe9, 0x6e, 0xbd, 0xae, 0xe5, 0xc8, 0xe6, 0xcb, 0x2b, 0xb4, 0xdb, 0xc6, 0x12, 0x6c, 0xe4,
    0x8c, 0x0d, 0xcf, 0xaf, 0xd4, 0x31, 0x02, 0x12, 0xfe, 0xf4, 0x7f, 0xcc, 0xa4, 0x49, 0x33, 0x52,
    0x65, 0x62, 0x58, 0x6c, 0xb4, 0xdf, 0xb3, 0xc3, 0xc3, 0x58, 0xa4, 0x45, 0x82, 0xad, 0xc3, 0x42,
    0x08, 0x62, 0xc1, 0x6f, 0x13, 0x1c, 0xed, 0x16, 0x9d, 0x64, 0xcd, 0xb9, 0x16, 0xa1, 0x07, 0x29,
    0x5f, 0xd6, 0xf9, 0x39, 0xff, 0xfb, 0xe1, 0x34, 0xcb, 0xa3, 0xe7, 0x31, 0x16, 0x10, 0xe6, 0x79,
    0x2d, 0x88, 0x5a, 0x42, 0x3d, 0x4b, 0x75, 0x36, 0xec, 0xcd, 0xf2, 0x7f, 0x19, 0x8b, 0x66, 0x5d,
    0xde, 0x83, 0x4c, 0xa9, 0x32, 0x4b, 0xab, 0xe5, 0x0a, 0xd8, 0x1b, 0x29, 0xa2, 0xce, 0xd7, 0x32,
    0x03, 0x33, 0xc8, 0x3c, 0x05, 0x81, 0x70, 0xf4, 0x4c, 0x64, 0x3f, 0xf2, 0x3e, 0x23, 0xcc, 0xec,
    0xac, 0x08, 0x5a, 0x67, 0xac, 0x93, 0xa6, 0x7e, 0xc0, 0x06, 0x92, 0xdc, 0xea, 0x6d, 0x7c, 0xae,
    0x82, 0xa9, 0x55, 0x09, 0xa1, 0x04, 0xbd, 0xa4, 0xfa, 0x5a, 0x1d, 0xe7, 0x01, 0x77, 0xa6, 0x0b,
    0x5b, 0xaa, 0xdc, 0x3d, 0x35, 0x86, 0x6e, 0xea, 0x46, 0x65, 0x99, 0x52, 0x4e, 0x78, 0x78, 0x94,
    0x9a, 0xa8, 0x72, 0xd0, 0x2b, 0x8a, 0x23, 0x43, 0x2a, 0x35, 0x6a, 0x55, 0x8c, 0x50, 0xad, 0x84,
    0xe4, 0xd2, 0x4d, 0x65, 0x54, 0x7d, 0x15, 0x17, 0xc4, 0x60, 0xdb, 0xf5, 0xa3, 0x9f, 0x3b, 0x76,
    0x73, 0x9e, 0x96, 0x5c, 0x41, 0x22, 0x6b, 0xfa, 0x79, 0x3e, 0x66, 0x0c, 0xb6, 0xab, 0xb1, 0xd4,
    0xc3, 0x19, 0xda, 0x2b, 0xa3, 0x62, 0x84, 0xe8, 0x09, 0x84, 0x22, 0xab, 0xea, 0xf1, 0x55, 0xc7,
    0xff, 0xa2, 0xf9, 0xf9, 0xe3, 0xd9, 0x99, 0x77, 0xb6, 0xb6, 0x65, 0xdd, 0x57, 0x82, 0xd0, 0x26,
    0x6f, 0xfb, 0xc7, 0x96, 0x83, 0x2c, 0x19, 0x3b, 0x4a, 0x42, 0x48, 0xe5, 0x7d, 0x6e, 0xfc, 0x7b,
    0x45, 0xd4, 0x4c, 0xdd, 0x90, 0xd8, 0x3d, 0x59, 0xee, 0x78, 0x57, 0x0a, 0xe7, 0x06, 0xb3, 0x99,
    0xca, 0x21, 0x9a, 0x35, 0x2d, 0x01, 0xc7, 0xb0, 0xc6, 0x3a, 0x5e, 0xdc, 0xb2, 0x4d, 0xaa, 0x6e,
    0x30, 0x0b, 0xe9, 0xae, 0x4e, 0x61, 0x0e, 0x24, 0x70, 0xf4, 0x57, 0xaa, 0x54, 0x39, 0xd1, 0x65,
    0xde, 0x3e, 0x08, 0x6d, 0xca, 0x9b, 0xf0, 0x54, 0x42, 0x61, 0x69, 0x4c, 0x72, 0xdd, 0x2e, 0x69,
    0xa0, 0x7a, 0x91, 0xc3, 0x3f, 0xb6, 0xba, 0x61, 0xcc, 0x7b, 0xd3, 0x5b, 0x75, 0x18, 0x74, 0x8d,
    0x83, 0x96, 0x94, 0x45, 0x85, 0x56, 0xb3, 0xdc, 0xca, 0xa0, 0xa9, 0x69, 0x33, 0xff, 0xb5, 0xef,
    0xf2, 0x75, 0x98, 0x22, 0x2c, 0xf2, 0xfe, 0x66, 0xfa, 0xf0, 0x7d, 0xeb, 0x12, 0xbb, 0xe8, 0x64,
    0x16, 0xe8, 0xb9, 0xb0, 0x8f, 0xda, 0xd1, 0x69, 0x4b, 0x74, 0xd2, 0x32, 0xba, 0x8f, 0x96, 0xf8,
    0xd3, 0x1f, 0xda, 0xea, 0x0b, 0x16, 0x04, 0x33, 0x55, 0x37, 0x28, 0xf7, 0xf6, 0x9a, 0xf2, 0x25,
    0xa6, 0x25, 0x5c, 0x09, 0x94, 0x32, 0x49, 0x22, 0x06, 0xe1, 0x89, 0x0e, 0x3a, 0xdf, 0xed, 0xa6,
    0x75, 0xe0, 0x99, 0x5d, 0xb8, 0xe4, 0x60, 0x2f, 0xb5, 0x51, 0x21, 0xbb, 0xfb, 0x56, 0xa9, 0x2e,
    0xbe, 0x0f, 0xe7, 0x5d, 0xf4, 0x7b, 0x01, 0x66, 0x51, 0xaa, 0x53, 0x3a, 0xf3, 0x29, 0x76, 0x1c,
    0x01, 0xbb, 0x03, 0x35, 0xe9, 0xd6, 0xea, 0x43, 0xbd, 0xce, 0xa4, 0x5b, 0xb6, 0x3b, 0x83, 0x75,
    0xe8, 0xcf, 0x26, 0x4d, 0x25, 0x8f, 0x20, 0xaf, 0x36, 0xf9, 0x99, 0x9c, 0x37, 0xc7, 0xea, 0x96,
    0xf4, 0x83, 0xa7, 0xdd, 0xad, 0xee, 0x9d, 0xc1, 0xba, 0x5c, 0xcd, 0x96, 0xe0, 0x47, 0xb2, 0x78,
    0xf0, 0x8d, 0x2b, 0xec, 0x1a, 0xec, 0xae, 0x4b, 0xfa, 0xa3, 0xb8, 0x59, 0xc2, 0x7f, 0x5f, 0xfd,
    0x9b, 0xf3, 0x76, 0x54, 0x78, 0x07, 0x9d, 0x8b, 0x7d, 0xa1, 0x77, 0x10, 0xcc, 0x7d, 0x67, 0xe5,
    0x00, 0xf1, 0xbc, 0x6d, 0xb9, 0x61, 0x5d, 0x35, 0xe4, 0x41, 0x83, 0xec, 0x2c, 0x25, 0xbb, 0x41,
    0xac, 0x94, 0x04, 0x6a, 0x88, 0x0b, 0xff, 0x68, 0x55, 0x61, 0x4e, 0x1d, 0xe3, 0x90, 0x6f, 0x67,
    0x29, 0xa6, 0x44, 0xbd, 0xec, 0xa8, 0xeb, 0x5d, 0x6f, 0x53, 0xd7, 0x2d, 0x2d, 0xa9, 0x0f, 0xc2,
    0x58, 0xb3, 0xdb, 0x72, 0xd3, 0x8b, 0xa7, 0x02, 0x73, 0x9b, 0xb7, 0xfd, 0x56, 0x8d, 0xa0, 0x02,
    0xa8, 0x3d, 0x99, 0xd3, 0xe8, 0xbe, 0x4e, 0x7f, 0xb8, 0xd5, 0x3f, 0xd8, 0x9d, 0x85, 0x3d, 0xe4,
    0x83, 0x2b, 0xc8, 0xbe, 0x0f, 0x16, 0x83, 0xce, 0x6c, 0xfb, 0xbb, 0xc5, 0x00, 0xb0, 0x83, 0x23,
    0xf8, 0x9e, 0x8e, 0xae, 0xbf, 0x60, 0x41, 0x35, 0xfc, 0x8b, 0x44, 0x5e, 0x1c, 0x7c, 0xf7, 0xa3,
    0x6e, 0x4d, 0x83, 0x9b, 0x15, 0x9f, 0x74, 0x76, 0x58, 0xc9, 0x90, 0x4c, 0x44, 0xd8, 0xab, 0x90,
    0x3a, 0xd2, 0x40, 0x41, 0x53, 0x87, 0x9a, 0x12, 0xb6, 0x8a, 0xdd, 0x40, 0x2d, 0xf0, 0xc6, 0x0d,
    0xd0, 0xd7, 0x18, 0x80, 0xda, 0x43, 0x6d, 0xf7, 0x1e, 0xa3, 0x71, 0xfc, 0x7a, 0x9d, 0x85, 0x19,
    0x7a, 0x8f, 0xa3, 0xb0, 0xf9, 0xac, 0xb2, 0xed, 0xf1, 0x10, 0x25, 0xd6, 0x4f, 0xef, 0xc5, 0x69,
    0x86
};
#endif

PyTypeObject *init_Q3DGraphsWidgetItem(PyObject *module)
{
    if (SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX].type != nullptr)
        return SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX].type;

    Shiboken::AutoDecRef Sbk_Q3DGraphsWidgetItem_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_Q3DGraphsWidgetItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "Q3DGraphsWidgetItem",
        "Q3DGraphsWidgetItem*",
        &Sbk_Q3DGraphsWidgetItem_spec,
        &Shiboken::callCppDestructor< Q3DGraphsWidgetItem >,
        Sbk_Q3DGraphsWidgetItem_Type_bases.object(),
        0);
    auto *pyType = Sbk_Q3DGraphsWidgetItem_TypeF(); // references _Sbk_Q3DGraphsWidgetItem_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, Q3DGraphsWidgetItem_SignatureStrings);
#else
    InitSignatureBytes(pyType, Q3DGraphsWidgetItem_SignatureBytes, Q3DGraphsWidgetItem_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_Q3DGraphsWidgetItem_PropertyStrings);
    SbkPySide6_QtGraphsWidgetsTypeStructs[SBK_Q3DGraphsWidgetItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        Q3DGraphsWidgetItem_PythonToCpp_Q3DGraphsWidgetItem_PTR,
        is_Q3DGraphsWidgetItem_PythonToCpp_Q3DGraphsWidgetItem_PTR_Convertible,
        Q3DGraphsWidgetItem_PTR_CppToPython_Q3DGraphsWidgetItem);

    Shiboken::Conversions::registerConverterName(converter, "Q3DGraphsWidgetItem");
    Shiboken::Conversions::registerConverterName(converter, "Q3DGraphsWidgetItem*");
    Shiboken::Conversions::registerConverterName(converter, "Q3DGraphsWidgetItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::Q3DGraphsWidgetItem).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(Q3DGraphsWidgetItemWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_Q3DGraphsWidgetItem_TypeF(), &Sbk_Q3DGraphsWidgetItem_typeDiscovery);

    PySide::Signal::registerSignals(pyType, &::Q3DGraphsWidgetItem::staticMetaObject);
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::Q3DGraphsWidgetItem::staticMetaObject, sizeof(Q3DGraphsWidgetItemWrapper));

    return pyType;
}
