// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qcolor_wrapper.h"

// Extra includes
#include <QVariant>

// Argument includes
#include <QAnyStringView>
#include <QString>
#include <QStringList>
#include <QStringView>
#include <QtCore/qlatin1stringview.h>
#include <QtGui/qcolor.h>
#include <QtGui/qrgba64.h>
#include <qdatastream.h>
#include <qnamespace.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QColor_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QColor >()))
        return -1;

    ::QColor *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
    if (numArgs == 2)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:QColor", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QColor::QColor()
    // 1: QColor::QColor(QColor::Spec,ushort,ushort,ushort,ushort,ushort=)
    // 2: QColor::QColor(QLatin1String)
    // 3: QColor::QColor(QRgba64)
    // 4: QColor::QColor(QStringView)
    // 5: QColor::QColor(QVariant)
    // 6: QColor::QColor(Qt::GlobalColor)
    // 7: QColor::QColor(QColor)
    // 8: QColor::QColor(QString)
    // 9: QColor::QColor(int,int,int,int=)
    // 10: QColor::QColor(uint)
    if (numArgs == 0) {
        overloadId = 0; // QColor()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 8; // QColor(QString)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_GlobalColor_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 6; // QColor(Qt::GlobalColor)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        overloadId = 4; // QColor(QStringView)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRgba64_IDX]), (pyArgs[0])))) {
        overloadId = 3; // QColor(QRgba64)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], (pyArgs[0])))) {
        overloadId = 2; // QColor(QLatin1String)
    } else if (numArgs >= 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_Spec_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[4])))) {
        if (numArgs == 5) {
            overloadId = 1; // QColor(QColor::Spec,ushort,ushort,ushort,ushort,ushort)
        } else if (numArgs >= 6
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[5])))) {
            overloadId = 1; // QColor(QColor::Spec,ushort,ushort,ushort,ushort,ushort)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))) {
        overloadId = 10; // QColor(uint)
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 9; // QColor(int,int,int,int)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 9; // QColor(int,int,int,int)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[0])))) {
        overloadId = 5; // QColor(QVariant)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[0])))) {
        overloadId = 7; // QColor(QColor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QColor()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }

            // QColor()
            cptr = new ::QColor();
            break;
        }
        case 1: // QColor(QColor::Spec spec, ushort a1, ushort a2, ushort a3, ushort a4, ushort a5)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_a5 = Shiboken::String::createStaticString("a5");
                if (PyDict_Contains(kwds, key_a5) != 0) {
                    value = PyDict_GetItem(kwds, key_a5);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_a5);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_a5);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
            }
            ::QColor::Spec cppArg0{QColor::Invalid};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ushort cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ushort cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ushort cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ushort cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ushort cppArg5 = 0;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColor(QColor::Spec,ushort,ushort,ushort,ushort,ushort)
                cptr = new ::QColor(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
        case 2: // QColor(QLatin1String name)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
            ::QLatin1String cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColor(QLatin1String)
                cptr = new ::QColor(cppArg0);
            }
            break;
        }
        case 3: // QColor(QRgba64 rgba64)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRgba64 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColor(QRgba64)
                cptr = new ::QColor(cppArg0);
            }
            break;
        }
        case 4: // QColor(QStringView name)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColor(QStringView)
                cptr = new ::QColor(QStringView(cppArg0));
            }
            break;
        }
        case 5: // QColor(QVariant color)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
            ::QVariant cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColor(QVariant)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qcolor)]
                if (cppArg0.type() == QVariant::Color)
                    cptr = new QColor(cppArg0.value<QColor>());
                else
                    PyErr_SetString(PyExc_TypeError, "QVariant must be holding a QColor");
                // END of custom code block [file: ../glue/qtgui.cpp (qcolor)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 6: // QColor(Qt::GlobalColor color)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
            ::Qt::GlobalColor cppArg0{Qt::color0};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColor(Qt::GlobalColor)
                cptr = new ::QColor(cppArg0);
            }
            break;
        }
        case 7: // QColor(const QColor &QColor)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QColor cppArg0_local;
            ::QColor *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QColor(QColor)
                cptr = new ::QColor(*cppArg0);
            }
            break;
        }
        case 8: // QColor(const QString &name)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColor(QString)
                cptr = new ::QColor(cppArg0);
            }
            break;
        }
        case 9: // QColor(int r, int g, int b, int a)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_a = Shiboken::String::createStaticString("a");
                if (PyDict_Contains(kwds, key_a) != 0) {
                    value = PyDict_GetItem(kwds, key_a);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_a);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_a);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = 255;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColor(int,int,int,int)
                cptr = new ::QColor(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 10: // QColor(unsigned int rgb)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
            unsigned int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QColor(uint)
                cptr = new ::QColor(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QColor >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QColorFunc___reduce__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __reduce__()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtgui.cpp (qcolor-reduce)]
        switch (cppSelf->spec()) {
            case QColor::Rgb:
            {
                float r, g, b, a;
                cppSelf->getRgbF(&r, &g, &b, &a);
                pyResult = Py_BuildValue("(ON(s(ffff)))", Py_TYPE(self), PyTuple_New(0),
                                         "setRgbF", r, g, b, a);
                break;
            }
            case QColor::Hsv:
            {
                float h, s, v, a;
                cppSelf->getHsvF(&h, &s, &v, &a);
                pyResult = Py_BuildValue("(ON(s(ffff)))", Py_TYPE(self), PyTuple_New(0),
                                         "setHsvF", h, s, v, a);
                break;
            }
            case QColor::Cmyk:
            {
                float c, m, y, k, a;
                cppSelf->getCmykF(&c, &m, &y, &k, &a);
                pyResult = Py_BuildValue("(ON(s(fffff)))", Py_TYPE(self), PyTuple_New(0),
                                         "setCmykF", c, m, y, k, a);
                break;
            }
            case QColor::Hsl:
            {
                float h, s, l, a;
                cppSelf->getHslF(&h, &s, &l, &a);
                pyResult = Py_BuildValue("(ON(s(ffff)))", Py_TYPE(self), PyTuple_New(0),
                                         "setHslF", h, s, l, a);
                break;
            }
            default:
            {
                pyResult = Py_BuildValue("(N(O))", PyObject_Type(self), Py_None);
            }
        }
        // END of custom code block [file: ../glue/qtgui.cpp (qcolor-reduce)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc___repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __repr__()
        // Begin code injection
        // TEMPLATE - qcolor_repr - START
         switch(cppSelf->spec()) {
           case QColor::Rgb:
           {
               float r, g, b, a;
               cppSelf->getRgbF(&r, &g, &b, &a);
               QString repr = QString::asprintf("PySide6.QtGui.QColor.fromRgbF(%.6f, %.6f, %.6f, %.6f)", r, g, b, a);
               pyResult = Shiboken::String::fromCString(qPrintable(repr));
               break;
           }
           case QColor::Hsv:
           {
               float h, s, v, a;
               cppSelf->getHsvF(&h, &s, &v, &a);
               QString repr = QString::asprintf("PySide6.QtGui.QColor.fromHsvF(%.6f, %.6f, %.6f, %.6f)", h, s, v, a);
               pyResult = Shiboken::String::fromCString(qPrintable(repr));
               break;
           }
           case QColor::Cmyk:
           {
               float c, m, y, k, a;
               cppSelf->getCmykF(&c, &m, &y, &k, &a);
               QString repr = QString::asprintf("PySide6.QtGui.QColor.fromCmykF(%.6f, %.6f, %.6f, %.6f, %.6f)", c, m, y, k, a);
               pyResult = Shiboken::String::fromCString(qPrintable(repr));
               break;
           }
           case QColor::Hsl:
           {
               float h, s, l, a;
               cppSelf->getHslF(&h, &s, &l, &a);
               QString repr = QString::asprintf("PySide6.QtGui.QColor.fromHslF(%.6f, %.6f, %.6f, %.6f)", h, s, l, a);
               pyResult = Shiboken::String::fromCString(qPrintable(repr));
               break;
           }
           default:
           {
               pyResult = Shiboken::String::fromCString("PySide6.QtGui.QColor()");
           }
        }
        // TEMPLATE - qcolor_repr - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc___setstate__(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColor::__setstate__(PyObject*)->PyObject
    if (true) {
        overloadId = 0; // __setstate__(PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "__setstate__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __setstate__(PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qcolor-setstate)]
            Shiboken::AutoDecRef func(PyObject_GetAttr(self, PyTuple_GetItem(pyArg, 0)));
            PyObject *args = PyTuple_GetItem(pyArg, 1);
            pyResult = PyObject_Call(func, args, nullptr);
            // END of custom code block [file: ../glue/qtgui.cpp (qcolor-setstate)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc___str__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __str__()
        // Begin code injection
        // TEMPLATE - qcolor_repr - START
         switch(cppSelf->spec()) {
           case QColor::Rgb:
           {
               float r, g, b, a;
               cppSelf->getRgbF(&r, &g, &b, &a);
               QString repr = QString::asprintf("PySide6.QtGui.QColor.fromRgbF(%.6f, %.6f, %.6f, %.6f)", r, g, b, a);
               pyResult = Shiboken::String::fromCString(qPrintable(repr));
               break;
           }
           case QColor::Hsv:
           {
               float h, s, v, a;
               cppSelf->getHsvF(&h, &s, &v, &a);
               QString repr = QString::asprintf("PySide6.QtGui.QColor.fromHsvF(%.6f, %.6f, %.6f, %.6f)", h, s, v, a);
               pyResult = Shiboken::String::fromCString(qPrintable(repr));
               break;
           }
           case QColor::Cmyk:
           {
               float c, m, y, k, a;
               cppSelf->getCmykF(&c, &m, &y, &k, &a);
               QString repr = QString::asprintf("PySide6.QtGui.QColor.fromCmykF(%.6f, %.6f, %.6f, %.6f, %.6f)", c, m, y, k, a);
               pyResult = Shiboken::String::fromCString(qPrintable(repr));
               break;
           }
           case QColor::Hsl:
           {
               float h, s, l, a;
               cppSelf->getHslF(&h, &s, &l, &a);
               QString repr = QString::asprintf("PySide6.QtGui.QColor.fromHslF(%.6f, %.6f, %.6f, %.6f)", h, s, l, a);
               pyResult = Shiboken::String::fromCString(qPrintable(repr));
               break;
           }
           default:
           {
               pyResult = Shiboken::String::fromCString("PySide6.QtGui.QColor()");
           }
        }
        // TEMPLATE - qcolor_repr - END
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_alpha(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // alpha()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->alpha();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_alphaF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // alphaF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->alphaF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_black(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // black()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->black();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_blackF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // blackF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->blackF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_blue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // blue()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->blue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_blueF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // blueF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->blueF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_colorNames(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // colorNames()
        QStringList cppResult = ::QColor::colorNames();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_convertTo(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColor::convertTo(QColor::Spec)const->QColor
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_Spec_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // convertTo(QColor::Spec)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "convertTo", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        ::QColor::Spec cppArg0{QColor::Invalid};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // convertTo(QColor::Spec)const
            QColor cppResult = const_cast<const ::QColor *>(cppSelf)->convertTo(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_cyan(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cyan()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->cyan();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_cyanF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cyanF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->cyanF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_darker(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "darker", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|O:darker", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColor::darker(int=)const->QColor
    if (numArgs == 0) {
        overloadId = 0; // darker(int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // darker(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "darker", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_f = Shiboken::String::createStaticString("f");
            if (PyDict_Contains(kwds, key_f) != 0) {
                value = PyDict_GetItem(kwds, key_f);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_f);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "darker", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "darker", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_f);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "darker", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        int cppArg0 = 200;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // darker(int)const
            QColor cppResult = const_cast<const ::QColor *>(cppSelf)->darker(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_fromCmyk(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 4, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromCmyk", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:fromCmyk", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QColor::fromCmyk(int,int,int,int,int=)->QColor
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 0; // fromCmyk(int,int,int,int,int)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
            overloadId = 0; // fromCmyk(int,int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromCmyk", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromCmyk", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "fromCmyk", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromCmyk", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4 = 255;
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromCmyk(int,int,int,int,int)
            QColor cppResult = ::QColor::fromCmyk(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_fromCmykF(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 4, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromCmykF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:fromCmykF", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QColor::fromCmykF(float,float,float,float,float=)->QColor
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 0; // fromCmykF(float,float,float,float,float)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4])))) {
            overloadId = 0; // fromCmykF(float,float,float,float,float)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromCmykF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromCmykF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "fromCmykF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromCmykF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        float cppArg4 = 1.0;
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromCmykF(float,float,float,float,float)
            QColor cppResult = ::QColor::fromCmykF(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_fromHsl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromHsl", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:fromHsl", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QColor::fromHsl(int,int,int,int=)->QColor
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // fromHsl(int,int,int,int)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 0; // fromHsl(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromHsl", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromHsl", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "fromHsl", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromHsl", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = 255;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromHsl(int,int,int,int)
            QColor cppResult = ::QColor::fromHsl(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_fromHslF(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromHslF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:fromHslF", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QColor::fromHslF(float,float,float,float=)->QColor
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // fromHslF(float,float,float,float)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
            overloadId = 0; // fromHslF(float,float,float,float)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromHslF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromHslF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "fromHslF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromHslF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3 = 1.0;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromHslF(float,float,float,float)
            QColor cppResult = ::QColor::fromHslF(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_fromHsv(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromHsv", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:fromHsv", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QColor::fromHsv(int,int,int,int=)->QColor
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // fromHsv(int,int,int,int)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 0; // fromHsv(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromHsv", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromHsv", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "fromHsv", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromHsv", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = 255;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromHsv(int,int,int,int)
            QColor cppResult = ::QColor::fromHsv(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_fromHsvF(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromHsvF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:fromHsvF", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QColor::fromHsvF(float,float,float,float=)->QColor
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // fromHsvF(float,float,float,float)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
            overloadId = 0; // fromHsvF(float,float,float,float)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromHsvF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromHsvF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "fromHsvF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromHsvF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3 = 1.0;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromHsvF(float,float,float,float)
            QColor cppResult = ::QColor::fromHsvF(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_fromRgb(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, "fromRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:fromRgb", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QColor::fromRgb(int,int,int,int=)->QColor
    // 1: static QColor::fromRgb(uint)->QColor
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))) {
        overloadId = 1; // fromRgb(uint)
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // fromRgb(int,int,int,int)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 0; // fromRgb(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fromRgb(int r, int g, int b, int a)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_a = Shiboken::String::createStaticString("a");
                if (PyDict_Contains(kwds, key_a) != 0) {
                    value = PyDict_GetItem(kwds, key_a);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_a);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "fromRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "fromRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_a);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "fromRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = 255;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromRgb(int,int,int,int)
                QColor cppResult = ::QColor::fromRgb(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fromRgb(unsigned int rgb)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
            unsigned int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromRgb(uint)
                QColor cppResult = ::QColor::fromRgb(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_fromRgbF(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromRgbF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:fromRgbF", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QColor::fromRgbF(float,float,float,float=)->QColor
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // fromRgbF(float,float,float,float)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
            overloadId = 0; // fromRgbF(float,float,float,float)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromRgbF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "fromRgbF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "fromRgbF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "fromRgbF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3 = 1.0;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromRgbF(float,float,float,float)
            QColor cppResult = ::QColor::fromRgbF(cppArg0, cppArg1, cppArg2, cppArg3);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_fromRgba(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QColor::fromRgba(uint)->QColor
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // fromRgba(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromRgba", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromRgba(uint)
            QColor cppResult = ::QColor::fromRgba(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_fromRgba64(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "fromRgba64", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, "fromRgba64", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:fromRgba64", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QColor::fromRgba64(QRgba64)->QColor
    // 1: static QColor::fromRgba64(ushort,ushort,ushort,ushort=)->QColor
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 1; // fromRgba64(ushort,ushort,ushort,ushort)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[3])))) {
            overloadId = 1; // fromRgba64(ushort,ushort,ushort,ushort)
        }
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRgba64_IDX]), (pyArgs[0])))) {
        overloadId = 0; // fromRgba64(QRgba64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fromRgba64", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fromRgba64(QRgba64 rgba)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "fromRgba64", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRgba64 cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromRgba64(QRgba64)
                QColor cppResult = ::QColor::fromRgba64(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
            }
            break;
        }
        case 1: // fromRgba64(ushort r, ushort g, ushort b, ushort a)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_a = Shiboken::String::createStaticString("a");
                if (PyDict_Contains(kwds, key_a) != 0) {
                    value = PyDict_GetItem(kwds, key_a);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_a);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "fromRgba64", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<ushort>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "fromRgba64", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_a);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "fromRgba64", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
            }
            ushort cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ushort cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ushort cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ushort cppArg3 = USHRT_MAX;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fromRgba64(ushort,ushort,ushort,ushort)
                QColor cppResult = ::QColor::fromRgba64(cppArg0, cppArg1, cppArg2, cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_fromString(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QColor::fromString(QAnyStringView)->QColor
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // fromString(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromString(QAnyStringView)
            QColor cppResult = ::QColor::fromString(QAnyStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_getCmyk(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getCmyk(int*,int*,int*,int*,int*)const
            // Begin code injection
            // TEMPLATE - fix_number*,number*,number*,number*,number* - START
            int a, b, c, d, e;
            cppSelf->getCmyk(&a, &b, &c, &d, &e);
            pyResult = PyTuple_New(5);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &a));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &b));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &c));
            PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &d));
            PyTuple_SetItem(pyResult, 4, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &e));
            // TEMPLATE - fix_number*,number*,number*,number*,number* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_getCmykF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getCmykF(float*,float*,float*,float*,float*)const
            // Begin code injection
            // TEMPLATE - fix_number*,number*,number*,number*,number* - START
            float a, b, c, d, e;
            cppSelf->getCmykF(&a, &b, &c, &d, &e);
            pyResult = PyTuple_New(5);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &a));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &b));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &c));
            PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &d));
            PyTuple_SetItem(pyResult, 4, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &e));
            // TEMPLATE - fix_number*,number*,number*,number*,number* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_getHsl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getHsl(int*,int*,int*,int*)const
            // Begin code injection
            // TEMPLATE - fix_number*,number*,number*,number* - START
            int a, b, c, d;
            cppSelf->::QColor::getHsl(&a, &b, &c, &d);
            // TEMPLATE - tuple_abcd_same_type - START
            pyResult = PyTuple_New(4);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &a));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &b));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &c));
            PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &d));
            // TEMPLATE - tuple_abcd_same_type - END
            // TEMPLATE - fix_number*,number*,number*,number* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_getHslF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getHslF(float*,float*,float*,float*)const
            // Begin code injection
            // TEMPLATE - fix_number*,number*,number*,number* - START
            float a, b, c, d;
            cppSelf->::QColor::getHslF(&a, &b, &c, &d);
            // TEMPLATE - tuple_abcd_same_type - START
            pyResult = PyTuple_New(4);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &a));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &b));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &c));
            PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &d));
            // TEMPLATE - tuple_abcd_same_type - END
            // TEMPLATE - fix_number*,number*,number*,number* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_getHsv(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getHsv(int*,int*,int*,int*)const
            // Begin code injection
            // TEMPLATE - fix_number*,number*,number*,number* - START
            int a, b, c, d;
            cppSelf->::QColor::getHsv(&a, &b, &c, &d);
            // TEMPLATE - tuple_abcd_same_type - START
            pyResult = PyTuple_New(4);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &a));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &b));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &c));
            PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &d));
            // TEMPLATE - tuple_abcd_same_type - END
            // TEMPLATE - fix_number*,number*,number*,number* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_getHsvF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getHsvF(float*,float*,float*,float*)const
            // Begin code injection
            // TEMPLATE - fix_number*,number*,number*,number* - START
            float a, b, c, d;
            cppSelf->::QColor::getHsvF(&a, &b, &c, &d);
            // TEMPLATE - tuple_abcd_same_type - START
            pyResult = PyTuple_New(4);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &a));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &b));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &c));
            PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &d));
            // TEMPLATE - tuple_abcd_same_type - END
            // TEMPLATE - fix_number*,number*,number*,number* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_getRgb(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getRgb(int*,int*,int*,int*)const
            // Begin code injection
            // TEMPLATE - fix_number*,number*,number*,number* - START
            int a, b, c, d;
            cppSelf->::QColor::getRgb(&a, &b, &c, &d);
            // TEMPLATE - tuple_abcd_same_type - START
            pyResult = PyTuple_New(4);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &a));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &b));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &c));
            PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &d));
            // TEMPLATE - tuple_abcd_same_type - END
            // TEMPLATE - fix_number*,number*,number*,number* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_getRgbF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // getRgbF(float*,float*,float*,float*)const
            // Begin code injection
            // TEMPLATE - fix_number*,number*,number*,number* - START
            float a, b, c, d;
            cppSelf->::QColor::getRgbF(&a, &b, &c, &d);
            // TEMPLATE - tuple_abcd_same_type - START
            pyResult = PyTuple_New(4);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &a));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &b));
            PyTuple_SetItem(pyResult, 2, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &c));
            PyTuple_SetItem(pyResult, 3, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &d));
            // TEMPLATE - tuple_abcd_same_type - END
            // TEMPLATE - fix_number*,number*,number*,number* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_green(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // green()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->green();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_greenF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // greenF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->greenF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_hslHue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hslHue()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->hslHue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_hslHueF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hslHueF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->hslHueF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_hslSaturation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hslSaturation()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->hslSaturation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_hslSaturationF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hslSaturationF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->hslSaturationF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_hsvHue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hsvHue()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->hsvHue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_hsvHueF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hsvHueF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->hsvHueF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_hsvSaturation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hsvSaturation()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->hsvSaturation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_hsvSaturationF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hsvSaturationF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->hsvSaturationF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_hue(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hue()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->hue();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_hueF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hueF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->hueF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QColor *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_isValidColor(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QColor::isValidColor(QLatin1String)->bool
    // 1: static QColor::isValidColor(QStringView)->bool
    // 2: static QColor::isValidColor(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 2; // isValidColor(QString)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // isValidColor(QStringView)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], (pyArg)))) {
        overloadId = 0; // isValidColor(QLatin1String)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isValidColor", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // isValidColor(QLatin1String arg__1)
        {
            Shiboken::Warnings::warnDeprecated("QColor", "isValidColor(QLatin1String arg__1)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            ::QLatin1String cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isValidColor(QLatin1String)
                bool cppResult = ::QColor::isValidColor(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // isValidColor(QStringView arg__1)
        {
            Shiboken::Warnings::warnDeprecated("QColor", "isValidColor(QStringView arg__1)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isValidColor(QStringView)
                bool cppResult = ::QColor::isValidColor(QStringView(cppArg0));
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 2: // isValidColor(const QString &name)
        {
            Shiboken::Warnings::warnDeprecated("QColor", "isValidColor(const QString &name)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // isValidColor(QString)
                bool cppResult = ::QColor::isValidColor(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_isValidColorName(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QColor::isValidColorName(QAnyStringView)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // isValidColorName(QAnyStringView)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isValidColorName", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isValidColorName(QAnyStringView)
            bool cppResult = ::QColor::isValidColorName(QAnyStringView(cppArg0));
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_lighter(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "lighter", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|O:lighter", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColor::lighter(int=)const->QColor
    if (numArgs == 0) {
        overloadId = 0; // lighter(int)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // lighter(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "lighter", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_f = Shiboken::String::createStaticString("f");
            if (PyDict_Contains(kwds, key_f) != 0) {
                value = PyDict_GetItem(kwds, key_f);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_f);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "lighter", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "lighter", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_f);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "lighter", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        int cppArg0 = 150;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // lighter(int)const
            QColor cppResult = const_cast<const ::QColor *>(cppSelf)->lighter(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_lightness(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lightness()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->lightness();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_lightnessF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lightnessF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->lightnessF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_magenta(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // magenta()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->magenta();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_magentaF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // magentaF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->magentaF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_name(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "name", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|O:name", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColor::name(QColor::NameFormat=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // name(QColor::NameFormat)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_NameFormat_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // name(QColor::NameFormat)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "name", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_format = Shiboken::String::createStaticString("format");
            if (PyDict_Contains(kwds, key_format) != 0) {
                value = PyDict_GetItem(kwds, key_format);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_format);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "name", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_NameFormat_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "name", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_format);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "name", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        ::QColor::NameFormat cppArg0(QColor::NameFormat::HexRgb);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // name(QColor::NameFormat)const
            QString cppResult = const_cast<const ::QColor *>(cppSelf)->name(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_red(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // red()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->red();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_redF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // redF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->redF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_rgb(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rgb()const
        unsigned int cppResult = const_cast<const ::QColor *>(cppSelf)->rgb();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_rgba(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rgba()const
        unsigned int cppResult = const_cast<const ::QColor *>(cppSelf)->rgba();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_rgba64(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rgba64()const
        QRgba64 cppResult = const_cast<const ::QColor *>(cppSelf)->rgba64();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRgba64_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_saturation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // saturation()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->saturation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_saturationF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // saturationF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->saturationF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_setAlpha(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColor::setAlpha(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setAlpha(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAlpha", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAlpha(int)
            cppSelf->setAlpha(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setAlphaF(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColor::setAlphaF(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setAlphaF(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAlphaF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAlphaF(float)
            cppSelf->setAlphaF(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setBlue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColor::setBlue(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setBlue(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBlue", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBlue(int)
            cppSelf->setBlue(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setBlueF(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColor::setBlueF(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setBlueF(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBlueF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBlueF(float)
            cppSelf->setBlueF(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setCmyk(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 4, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setCmyk", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:setCmyk", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColor::setCmyk(int,int,int,int,int=)
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 0; // setCmyk(int,int,int,int,int)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
            overloadId = 0; // setCmyk(int,int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCmyk", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setCmyk", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "setCmyk", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setCmyk", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4 = 255;
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCmyk(int,int,int,int,int)
            cppSelf->setCmyk(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setCmykF(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 4, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setCmykF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:setCmykF", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColor::setCmykF(float,float,float,float,float=)
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 0; // setCmykF(float,float,float,float,float)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4])))) {
            overloadId = 0; // setCmykF(float,float,float,float,float)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setCmykF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setCmykF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "setCmykF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setCmykF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        float cppArg4 = 1.0;
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCmykF(float,float,float,float,float)
            cppSelf->setCmykF(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setGreen(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColor::setGreen(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setGreen(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGreen", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGreen(int)
            cppSelf->setGreen(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setGreenF(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColor::setGreenF(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setGreenF(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setGreenF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setGreenF(float)
            cppSelf->setGreenF(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setHsl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setHsl", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:setHsl", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColor::setHsl(int,int,int,int=)
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // setHsl(int,int,int,int)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 0; // setHsl(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setHsl", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setHsl", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "setHsl", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setHsl", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = 255;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHsl(int,int,int,int)
            cppSelf->setHsl(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setHslF(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setHslF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:setHslF", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColor::setHslF(float,float,float,float=)
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // setHslF(float,float,float,float)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
            overloadId = 0; // setHslF(float,float,float,float)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setHslF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setHslF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "setHslF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setHslF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3 = 1.0;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHslF(float,float,float,float)
            cppSelf->setHslF(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setHsv(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setHsv", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:setHsv", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColor::setHsv(int,int,int,int=)
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // setHsv(int,int,int,int)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 0; // setHsv(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setHsv", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setHsv", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "setHsv", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setHsv", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = 255;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHsv(int,int,int,int)
            cppSelf->setHsv(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setHsvF(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setHsvF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:setHsvF", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColor::setHsvF(float,float,float,float=)
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // setHsvF(float,float,float,float)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
            overloadId = 0; // setHsvF(float,float,float,float)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setHsvF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setHsvF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "setHsvF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setHsvF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3 = 1.0;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHsvF(float,float,float,float)
            cppSelf->setHsvF(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setNamedColor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColor::setNamedColor(QLatin1String)
    // 1: QColor::setNamedColor(QStringView)
    // 2: QColor::setNamedColor(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 2; // setNamedColor(QString)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // setNamedColor(QStringView)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], (pyArg)))) {
        overloadId = 0; // setNamedColor(QLatin1String)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNamedColor", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setNamedColor(QLatin1String name)
        {
            Shiboken::Warnings::warnDeprecated("QColor", "setNamedColor(QLatin1String name)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            ::QLatin1String cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setNamedColor(QLatin1String)
                cppSelf->setNamedColor(cppArg0);
            }
            break;
        }
        case 1: // setNamedColor(QStringView name)
        {
            Shiboken::Warnings::warnDeprecated("QColor", "setNamedColor(QStringView name)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setNamedColor(QStringView)
                cppSelf->setNamedColor(QStringView(cppArg0));
            }
            break;
        }
        case 2: // setNamedColor(const QString &name)
        {
            Shiboken::Warnings::warnDeprecated("QColor", "setNamedColor(const QString &name)");
            if (Shiboken::Errors::occurred() != nullptr)
                return {};
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setNamedColor(QString)
                cppSelf->setNamedColor(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setRed(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColor::setRed(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setRed(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRed", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRed(int)
            cppSelf->setRed(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setRedF(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColor::setRedF(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setRedF(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRedF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRedF(float)
            cppSelf->setRedF(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setRgb(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, "setRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:setRgb", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColor::setRgb(int,int,int,int=)
    // 1: QColor::setRgb(uint)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))) {
        overloadId = 1; // setRgb(uint)
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // setRgb(int,int,int,int)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 0; // setRgb(int,int,int,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setRgb(int r, int g, int b, int a)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_a = Shiboken::String::createStaticString("a");
                if (PyDict_Contains(kwds, key_a) != 0) {
                    value = PyDict_GetItem(kwds, key_a);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_a);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "setRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_a);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = 255;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setRgb(int,int,int,int)
                cppSelf->setRgb(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // setRgb(unsigned int rgb)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setRgb", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
            unsigned int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setRgb(uint)
                cppSelf->setRgb(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setRgbF(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setRgbF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:setRgbF", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QColor::setRgbF(float,float,float,float=)
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // setRgbF(float,float,float,float)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
            overloadId = 0; // setRgbF(float,float,float,float)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRgbF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_a = Shiboken::String::createStaticString("a");
            if (PyDict_Contains(kwds, key_a) != 0) {
                value = PyDict_GetItem(kwds, key_a);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_a);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setRgbF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "setRgbF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_a);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setRgbF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);
            }
        }
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3 = 1.0;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRgbF(float,float,float,float)
            cppSelf->setRgbF(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setRgba(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColor::setRgba(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // setRgba(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRgba", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRgba(uint)
            cppSelf->setRgba(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_setRgba64(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QColor::setRgba64(QRgba64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRgba64_IDX]), (pyArg)))) {
        overloadId = 0; // setRgba64(QRgba64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRgba64", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRgba64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRgba64(QRgba64)
            cppSelf->setRgba64(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QColorFunc_spec(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // spec()const
        QColor::Spec cppResult = const_cast<const ::QColor *>(cppSelf)->spec();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_Spec_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_toCmyk(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toCmyk()const
        QColor cppResult = const_cast<const ::QColor *>(cppSelf)->toCmyk();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_toExtendedRgb(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toExtendedRgb()const
        QColor cppResult = const_cast<const ::QColor *>(cppSelf)->toExtendedRgb();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_toHsl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toHsl()const
        QColor cppResult = const_cast<const ::QColor *>(cppSelf)->toHsl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_toHsv(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toHsv()const
        QColor cppResult = const_cast<const ::QColor *>(cppSelf)->toHsv();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_toRgb(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toRgb()const
        QColor cppResult = const_cast<const ::QColor *>(cppSelf)->toRgb();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_toTuple(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toTuple()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtgui.cpp (qcolor-totuple)]
        switch (cppSelf->spec()) {
          case QColor::Rgb:
          {
                int r, g, b, a;
                cppSelf->getRgb(&r, &g, &b, &a);
                pyResult = Py_BuildValue("iiii", r, g, b, a);
                break;
          }
          case QColor::Hsv:
          {
                int h, s, v, a;
                cppSelf->getHsv(&h, &s, &v, &a);
                pyResult = Py_BuildValue("iiii", h, s, v, a);
                break;
          }
          case QColor::Cmyk:
          {
                int c, m, y, k, a;
                cppSelf->getCmyk(&c, &m, &y, &k, &a);
                pyResult = Py_BuildValue("iiiii", c, m, y, k, a);
                break;
          }
          case QColor::Hsl:
          {
                int h, s, l, a;
                cppSelf->getHsl(&h, &s, &l, &a);
                pyResult = Py_BuildValue("iiii", h, s, l, a);
                break;
          }
          default:
          {
                pyResult = 0;
          }
        }
        // END of custom code block [file: ../glue/qtgui.cpp (qcolor-totuple)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_value(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // value()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->value();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_valueF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // valueF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->valueF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_yellow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // yellow()const
        int cppResult = const_cast<const ::QColor *>(cppSelf)->yellow();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc_yellowF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // yellowF()const
        float cppResult = const_cast<const ::QColor *>(cppSelf)->yellowF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColor__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QColor_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QColor_EnumFlagInfo[] = {
    "NameFormat:Enum",
    "Spec:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QColor_methods[] = {
    {"__reduce__", reinterpret_cast<PyCFunction>(Sbk_QColorFunc___reduce__), METH_NOARGS, nullptr},
    {"__setstate__", reinterpret_cast<PyCFunction>(Sbk_QColorFunc___setstate__), METH_O, nullptr},
    {"alpha", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_alpha), METH_NOARGS, nullptr},
    {"alphaF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_alphaF), METH_NOARGS, nullptr},
    {"black", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_black), METH_NOARGS, nullptr},
    {"blackF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_blackF), METH_NOARGS, nullptr},
    {"blue", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_blue), METH_NOARGS, nullptr},
    {"blueF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_blueF), METH_NOARGS, nullptr},
    {"colorNames", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_colorNames), METH_NOARGS|METH_STATIC, nullptr},
    {"convertTo", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_convertTo), METH_O, nullptr},
    {"cyan", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_cyan), METH_NOARGS, nullptr},
    {"cyanF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_cyanF), METH_NOARGS, nullptr},
    {"darker", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_darker), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"fromCmyk", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_fromCmyk), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromCmykF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_fromCmykF), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromHsl", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_fromHsl), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromHslF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_fromHslF), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromHsv", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_fromHsv), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromHsvF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_fromHsvF), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromRgb", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_fromRgb), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromRgbF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_fromRgbF), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromRgba", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_fromRgba), METH_O|METH_STATIC, nullptr},
    {"fromRgba64", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_fromRgba64), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"fromString", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_fromString), METH_O|METH_STATIC, nullptr},
    {"getCmyk", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_getCmyk), METH_NOARGS, nullptr},
    {"getCmykF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_getCmykF), METH_NOARGS, nullptr},
    {"getHsl", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_getHsl), METH_NOARGS, nullptr},
    {"getHslF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_getHslF), METH_NOARGS, nullptr},
    {"getHsv", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_getHsv), METH_NOARGS, nullptr},
    {"getHsvF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_getHsvF), METH_NOARGS, nullptr},
    {"getRgb", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_getRgb), METH_NOARGS, nullptr},
    {"getRgbF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_getRgbF), METH_NOARGS, nullptr},
    {"green", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_green), METH_NOARGS, nullptr},
    {"greenF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_greenF), METH_NOARGS, nullptr},
    {"hslHue", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_hslHue), METH_NOARGS, nullptr},
    {"hslHueF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_hslHueF), METH_NOARGS, nullptr},
    {"hslSaturation", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_hslSaturation), METH_NOARGS, nullptr},
    {"hslSaturationF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_hslSaturationF), METH_NOARGS, nullptr},
    {"hsvHue", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_hsvHue), METH_NOARGS, nullptr},
    {"hsvHueF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_hsvHueF), METH_NOARGS, nullptr},
    {"hsvSaturation", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_hsvSaturation), METH_NOARGS, nullptr},
    {"hsvSaturationF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_hsvSaturationF), METH_NOARGS, nullptr},
    {"hue", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_hue), METH_NOARGS, nullptr},
    {"hueF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_hueF), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_isValid), METH_NOARGS, nullptr},
    {"isValidColor", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_isValidColor), METH_O|METH_STATIC, nullptr},
    {"isValidColorName", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_isValidColorName), METH_O|METH_STATIC, nullptr},
    {"lighter", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_lighter), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"lightness", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_lightness), METH_NOARGS, nullptr},
    {"lightnessF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_lightnessF), METH_NOARGS, nullptr},
    {"magenta", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_magenta), METH_NOARGS, nullptr},
    {"magentaF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_magentaF), METH_NOARGS, nullptr},
    {"name", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_name), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"red", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_red), METH_NOARGS, nullptr},
    {"redF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_redF), METH_NOARGS, nullptr},
    {"rgb", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_rgb), METH_NOARGS, nullptr},
    {"rgba", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_rgba), METH_NOARGS, nullptr},
    {"rgba64", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_rgba64), METH_NOARGS, nullptr},
    {"saturation", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_saturation), METH_NOARGS, nullptr},
    {"saturationF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_saturationF), METH_NOARGS, nullptr},
    {"setAlpha", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setAlpha), METH_O, nullptr},
    {"setAlphaF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setAlphaF), METH_O, nullptr},
    {"setBlue", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setBlue), METH_O, nullptr},
    {"setBlueF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setBlueF), METH_O, nullptr},
    {"setCmyk", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setCmyk), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setCmykF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setCmykF), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setGreen", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setGreen), METH_O, nullptr},
    {"setGreenF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setGreenF), METH_O, nullptr},
    {"setHsl", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setHsl), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setHslF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setHslF), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setHsv", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setHsv), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setHsvF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setHsvF), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setNamedColor", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setNamedColor), METH_O, nullptr},
    {"setRed", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setRed), METH_O, nullptr},
    {"setRedF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setRedF), METH_O, nullptr},
    {"setRgb", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setRgb), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setRgbF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setRgbF), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setRgba", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setRgba), METH_O, nullptr},
    {"setRgba64", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_setRgba64), METH_O, nullptr},
    {"spec", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_spec), METH_NOARGS, nullptr},
    {"toCmyk", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_toCmyk), METH_NOARGS, nullptr},
    {"toExtendedRgb", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_toExtendedRgb), METH_NOARGS, nullptr},
    {"toHsl", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_toHsl), METH_NOARGS, nullptr},
    {"toHsv", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_toHsv), METH_NOARGS, nullptr},
    {"toRgb", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_toRgb), METH_NOARGS, nullptr},
    {"toTuple", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_toTuple), METH_NOARGS, nullptr},
    {"value", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_value), METH_NOARGS, nullptr},
    {"valueF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_valueF), METH_NOARGS, nullptr},
    {"yellow", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_yellow), METH_NOARGS, nullptr},
    {"yellowF", reinterpret_cast<PyCFunction>(Sbk_QColorFunc_yellowF), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QColor__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QColorFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QColor::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QColor)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QColor) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QColorFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QColor::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QColor&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QColor&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QColor_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
                // operator!=(const QColor &c) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QColor cppArg0_local;
                ::QColor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
                // operator==(const QColor &c) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QColor cppArg0_local;
                ::QColor *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static int Sbk_QColor_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QColor_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QColor_Type = nullptr;
static PyTypeObject *Sbk_QColor_TypeF(void)
{
    return _Sbk_QColor_Type;
}

static PyType_Slot Sbk_QColor_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QColorFunc___repr__)},
    {Py_tp_str,         reinterpret_cast<void *>(Sbk_QColorFunc___str__)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QColor_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QColor_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QColor_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QColor_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QColor_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QColorFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QColorFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QColor_spec = {
    "2:PySide6.QtGui.QColor",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QColor_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QColor_Spec(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QColor::Spec>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QColor::Spec *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QColor_Spec_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_Spec_IDX])))
        return Enum_PythonToCpp_QColor_Spec;
    return {};
}

static PyObject *QColor_Spec_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QColor::Spec>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QColor::Spec *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_Spec_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QColor_NameFormat(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QColor::NameFormat>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QColor::NameFormat *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QColor_NameFormat_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_NameFormat_IDX])))
        return Enum_PythonToCpp_QColor_NameFormat;
    return {};
}

static PyObject *QColor_NameFormat_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QColor::NameFormat>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QColor::NameFormat *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_NameFormat_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QColor_PythonToCpp_QColor_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QColor_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QColor_PythonToCpp_QColor_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QColor_TypeF()))
        return QColor_PythonToCpp_QColor_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QColor_PTR_CppToPython_QColor(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QColor_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QColor_COPY_CppToPython_QColor(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QColor *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QColor_TypeF(), new ::QColor(*source), true, true);
}

// Python to C++ copy conversion.
static void QColor_PythonToCpp_QColor_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QColor *>(cppOut) = *reinterpret_cast< ::QColor *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QColor_PythonToCpp_QColor_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QColor_TypeF()))
        return QColor_PythonToCpp_QColor_COPY;
    return {};
}

// Implicit conversions.
static void PySide6_QtCore_QLatin1String_PythonToCpp_QColor(PyObject *pyIn, void *cppOut)
{
    ::QLatin1String cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QColor *>(cppOut) = ::QColor(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_QLatin1String_PythonToCpp_QColor_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return PySide6_QtCore_QLatin1String_PythonToCpp_QColor;
    return {};
}

static void QRgba64_PythonToCpp_QColor(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QColor *>(cppOut) = ::QColor( *reinterpret_cast< ::QRgba64 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRgba64_IDX]), reinterpret_cast<SbkObject *>(pyIn))));
}
static PythonToCppFunc is_QRgba64_PythonToCpp_QColor_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRgba64_IDX]), pyIn))
        return QRgba64_PythonToCpp_QColor;
    return {};
}

static void PySide6_QtCore_Qt_GlobalColor_PythonToCpp_QColor(PyObject *pyIn, void *cppOut)
{
    ::Qt::GlobalColor cppIn{Qt::color0};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_GlobalColor_IDX])))->converter, pyIn, &cppIn);
    *reinterpret_cast<::QColor *>(cppOut) = ::QColor(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_Qt_GlobalColor_PythonToCpp_QColor_Convertible(PyObject *pyIn)
{
    if (SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_GlobalColor_IDX]), pyIn))
        return PySide6_QtCore_Qt_GlobalColor_PythonToCpp_QColor;
    return {};
}

static void PySide6_QtCore_constQStringREF_PythonToCpp_QColor(PyObject *pyIn, void *cppOut)
{
    ::QString cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QColor *>(cppOut) = ::QColor(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_constQStringREF_PythonToCpp_QColor_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return PySide6_QtCore_constQStringREF_PythonToCpp_QColor;
    return {};
}

static void unsignedint_PythonToCpp_QColor(PyObject *pyIn, void *cppOut)
{
    unsigned int cppIn;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), pyIn, &cppIn);
    *reinterpret_cast<::QColor *>(cppOut) = ::QColor(cppIn);
}
static PythonToCppFunc is_unsignedint_PythonToCpp_QColor_Convertible(PyObject *pyIn)
{
    if (PyLong_Check(pyIn))
        return unsignedint_PythonToCpp_QColor;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QColor_SignatureStrings[] = {
    "10:PySide6.QtGui.QColor(self)",
    "9:PySide6.QtGui.QColor(self,spec:PySide6.QtGui.QColor.Spec,a1:ushort,a2:ushort,a3:ushort,a4:ushort,a5:ushort=0)",
    "8:PySide6.QtGui.QColor(self,name:QLatin1String)",
    "7:PySide6.QtGui.QColor(self,rgba64:PySide6.QtGui.QRgba64)",
    "6:PySide6.QtGui.QColor(self,name:QString)",
    "5:PySide6.QtGui.QColor(self,color:QVariant)",
    "4:PySide6.QtGui.QColor(self,color:PySide6.QtCore.Qt.GlobalColor)",
    "3:PySide6.QtGui.QColor(self,QColor:PySide6.QtGui.QColor)",
    "2:PySide6.QtGui.QColor(self,name:QString)",
    "1:PySide6.QtGui.QColor(self,r:int,g:int,b:int,a:int=255)",
    "0:PySide6.QtGui.QColor(self,rgb:unsigned int)",
    "PySide6.QtGui.QColor.__reduce__(self)->str",
    "PySide6.QtGui.QColor.__repr__(self)->str",
    "PySide6.QtGui.QColor.__setstate__(self,arg__1:PyObject)->PyObject",
    "PySide6.QtGui.QColor.__str__(self)->str",
    "PySide6.QtGui.QColor.alpha(self)->int",
    "PySide6.QtGui.QColor.alphaF(self)->float",
    "PySide6.QtGui.QColor.black(self)->int",
    "PySide6.QtGui.QColor.blackF(self)->float",
    "PySide6.QtGui.QColor.blue(self)->int",
    "PySide6.QtGui.QColor.blueF(self)->float",
    "PySide6.QtGui.QColor.colorNames()->QStringList",
    "PySide6.QtGui.QColor.convertTo(self,colorSpec:PySide6.QtGui.QColor.Spec)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.cyan(self)->int",
    "PySide6.QtGui.QColor.cyanF(self)->float",
    "PySide6.QtGui.QColor.darker(self,f:int=200)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.fromCmyk(c:int,m:int,y:int,k:int,a:int=255)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.fromCmykF(c:float,m:float,y:float,k:float,a:float=1.0)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.fromHsl(h:int,s:int,l:int,a:int=255)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.fromHslF(h:float,s:float,l:float,a:float=1.0)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.fromHsv(h:int,s:int,v:int,a:int=255)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.fromHsvF(h:float,s:float,v:float,a:float=1.0)->PySide6.QtGui.QColor",
    "1:PySide6.QtGui.QColor.fromRgb(r:int,g:int,b:int,a:int=255)->PySide6.QtGui.QColor",
    "0:PySide6.QtGui.QColor.fromRgb(rgb:unsigned int)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.fromRgbF(r:float,g:float,b:float,a:float=1.0)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.fromRgba(rgba:unsigned int)->PySide6.QtGui.QColor",
    "1:PySide6.QtGui.QColor.fromRgba64(rgba:PySide6.QtGui.QRgba64)->PySide6.QtGui.QColor",
    "0:PySide6.QtGui.QColor.fromRgba64(r:ushort,g:ushort,b:ushort,a:ushort=USHRT_MAX)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.fromString(name:QString)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.getCmyk(self)->PyObject*",
    "PySide6.QtGui.QColor.getCmykF(self)->PyObject*",
    "PySide6.QtGui.QColor.getHsl(self)->PyObject*",
    "PySide6.QtGui.QColor.getHslF(self)->PyObject*",
    "PySide6.QtGui.QColor.getHsv(self)->PyObject*",
    "PySide6.QtGui.QColor.getHsvF(self)->PyObject*",
    "PySide6.QtGui.QColor.getRgb(self)->PyObject*",
    "PySide6.QtGui.QColor.getRgbF(self)->PyObject*",
    "PySide6.QtGui.QColor.green(self)->int",
    "PySide6.QtGui.QColor.greenF(self)->float",
    "PySide6.QtGui.QColor.hslHue(self)->int",
    "PySide6.QtGui.QColor.hslHueF(self)->float",
    "PySide6.QtGui.QColor.hslSaturation(self)->int",
    "PySide6.QtGui.QColor.hslSaturationF(self)->float",
    "PySide6.QtGui.QColor.hsvHue(self)->int",
    "PySide6.QtGui.QColor.hsvHueF(self)->float",
    "PySide6.QtGui.QColor.hsvSaturation(self)->int",
    "PySide6.QtGui.QColor.hsvSaturationF(self)->float",
    "PySide6.QtGui.QColor.hue(self)->int",
    "PySide6.QtGui.QColor.hueF(self)->float",
    "PySide6.QtGui.QColor.isValid(self)->bool",
    "2:PySide6.QtGui.QColor.isValidColor(arg__1:QLatin1String)->bool",
    "1:PySide6.QtGui.QColor.isValidColor(arg__1:QString)->bool",
    "0:PySide6.QtGui.QColor.isValidColor(name:QString)->bool",
    "PySide6.QtGui.QColor.isValidColorName(arg__1:QString)->bool",
    "PySide6.QtGui.QColor.lighter(self,f:int=150)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.lightness(self)->int",
    "PySide6.QtGui.QColor.lightnessF(self)->float",
    "PySide6.QtGui.QColor.magenta(self)->int",
    "PySide6.QtGui.QColor.magentaF(self)->float",
    "PySide6.QtGui.QColor.name(self,format:PySide6.QtGui.QColor.NameFormat=QColor.NameFormat.HexRgb)->QString",
    "PySide6.QtGui.QColor.red(self)->int",
    "PySide6.QtGui.QColor.redF(self)->float",
    "PySide6.QtGui.QColor.rgb(self)->unsigned int",
    "PySide6.QtGui.QColor.rgba(self)->unsigned int",
    "PySide6.QtGui.QColor.rgba64(self)->PySide6.QtGui.QRgba64",
    "PySide6.QtGui.QColor.saturation(self)->int",
    "PySide6.QtGui.QColor.saturationF(self)->float",
    "PySide6.QtGui.QColor.setAlpha(self,alpha:int)",
    "PySide6.QtGui.QColor.setAlphaF(self,alpha:float)",
    "PySide6.QtGui.QColor.setBlue(self,blue:int)",
    "PySide6.QtGui.QColor.setBlueF(self,blue:float)",
    "PySide6.QtGui.QColor.setCmyk(self,c:int,m:int,y:int,k:int,a:int=255)",
    "PySide6.QtGui.QColor.setCmykF(self,c:float,m:float,y:float,k:float,a:float=1.0)",
    "PySide6.QtGui.QColor.setGreen(self,green:int)",
    "PySide6.QtGui.QColor.setGreenF(self,green:float)",
    "PySide6.QtGui.QColor.setHsl(self,h:int,s:int,l:int,a:int=255)",
    "PySide6.QtGui.QColor.setHslF(self,h:float,s:float,l:float,a:float=1.0)",
    "PySide6.QtGui.QColor.setHsv(self,h:int,s:int,v:int,a:int=255)",
    "PySide6.QtGui.QColor.setHsvF(self,h:float,s:float,v:float,a:float=1.0)",
    "2:PySide6.QtGui.QColor.setNamedColor(self,name:QLatin1String)",
    "1:PySide6.QtGui.QColor.setNamedColor(self,name:QString)",
    "0:PySide6.QtGui.QColor.setNamedColor(self,name:QString)",
    "PySide6.QtGui.QColor.setRed(self,red:int)",
    "PySide6.QtGui.QColor.setRedF(self,red:float)",
    "1:PySide6.QtGui.QColor.setRgb(self,r:int,g:int,b:int,a:int=255)",
    "0:PySide6.QtGui.QColor.setRgb(self,rgb:unsigned int)",
    "PySide6.QtGui.QColor.setRgbF(self,r:float,g:float,b:float,a:float=1.0)",
    "PySide6.QtGui.QColor.setRgba(self,rgba:unsigned int)",
    "PySide6.QtGui.QColor.setRgba64(self,rgba:PySide6.QtGui.QRgba64)",
    "PySide6.QtGui.QColor.spec(self)->PySide6.QtGui.QColor.Spec",
    "PySide6.QtGui.QColor.toCmyk(self)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.toExtendedRgb(self)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.toHsl(self)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.toHsv(self)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.toRgb(self)->PySide6.QtGui.QColor",
    "PySide6.QtGui.QColor.toTuple(self)->PyObject",
    "PySide6.QtGui.QColor.value(self)->int",
    "PySide6.QtGui.QColor.valueF(self)->float",
    "PySide6.QtGui.QColor.yellow(self)->int",
    "PySide6.QtGui.QColor.yellowF(self)->float",
    "PySide6.QtGui.QColor.__copy__(self)->typing.Self",
    "PySide6.QtGui.QColor.__lshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QColor.__rshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QColor.__ne__(self,c:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])->bool",
    "PySide6.QtGui.QColor.__eq__(self,c:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QColor_SignatureByteSize = 1066;
static constexpr uint8_t QColor_SignatureBytes[1066] = {
    0x78, 0xda, 0xcd, 0x58, 0x5d, 0x6f, 0xda, 0x30, 0x14, 0x7d, 0xe7, 0x57, 0xf4, 0x11, 0xa6, 0x0c,
    0x41, 0x5b, 0xba, 0x0d, 0xa9, 0x93, 0xda, 0x6e, 0x69, 0x1f, 0xf6, 0xd5, 0xd2, 0x56, 0x93, 0xa6,
    0x29, 0x32, 0xc1, 0x84, 0x0c, 0x93, 0x30, 0xdb, 0x64, 0xe5, 0xdf, 0xcf, 0x71, 0xec, 0x40, 0x20,
    0x76, 0xae, 0x69, 0x35, 0xed, 0x25, 0x36, 0xe4, 0xdc, 0xe3, 0x63, 0xc7, 0xbe, 0x1f, 0xee, 0xf7,
    0x86, 0xdf, 0xd6, 0xa3, 0x78, 0x82, 0xcf, 0xba, 0xb7, 0xfc, 0x7a, 0x15, 0x77, 0x6f, 0xaf, 0x52,
    0x92, 0xd2, 0x36, 0xc3, 0x64, 0xda, 0x69, 0xbd, 0x33, 0xbf, 0xf4, 0xd8, 0x12, 0x87, 0xb5, 0xaf,
    0xbb, 0x23, 0xf1, 0xc6, 0x43, 0xfd, 0xe1, 0x8a, 0xcd, 0x52, 0xca, 0x3d, 0x74, 0x5c, 0xf6, 0x4e,
    0xca, 0xde, 0x69, 0xd9, 0x1b, 0xa8, 0xde, 0x79, 0xaf, 0xd3, 0x7a, 0x6b, 0x19, 0x2f, 0x41, 0x0b,
    0x3c, 0xbc, 0xfd, 0x84, 0x78, 0x9c, 0xf4, 0x47, 0x9c, 0xc6, 0x49, 0xd4, 0x69, 0xbd, 0xb1, 0xe0,
    0x69, 0x34, 0x46, 0x67, 0xa7, 0xbb, 0x80, 0x3b, 0xf9, 0x6f, 0xa7, 0x75, 0xd6, 0x38, 0x92, 0x1e,
    0x63, 0x60, 0x41, 0x86, 0x79, 0x77, 0x78, 0xfb, 0x88, 0x68, 0x8c, 0x12, 0xde, 0x69, 0x9d, 0x36,
    0x62, 0x37, 0xef, 0xaf, 0x52, 0x8a, 0x45, 0xd3, 0xbd, 0x26, 0xe9, 0x18, 0x11, 0x09, 0xec, 0xb4,
    0x4e, 0x2c, 0x04, 0x45, 0xbf, 0x16, 0xd0, 0x69, 0x1d, 0x83, 0xe7, 0xd3, 0xb7, 0xad, 0xd9, 0x30,
    0x4e, 0xb8, 0x17, 0xc9, 0xe7, 0x58, 0x3e, 0x51, 0xfe, 0x3c, 0x3f, 0x1e, 0x0c, 0x3a, 0xad, 0x9e,
    0x7d, 0xb1, 0x87, 0xab, 0x84, 0xc5, 0x51, 0x82, 0x27, 0x47, 0x71, 0xbe, 0x14, 0xb5, 0x3b, 0x23,
    0x08, 0x28, 0x9e, 0xac, 0x42, 0x1c, 0x04, 0xc5, 0x06, 0x7b, 0xfd, 0x9e, 0x71, 0x6a, 0x86, 0x2e,
    0x29, 0x08, 0xc8, 0x30, 0x67, 0x1c, 0x71, 0xcd, 0xea, 0x21, 0x1a, 0x05, 0x41, 0x3e, 0xcd, 0xaf,
    0xe3, 0x5f, 0x38, 0xe4, 0xc2, 0x58, 0x77, 0x8d, 0x0c, 0x1c, 0x32, 0x12, 0x22, 0xcb, 0x19, 0xd2,
    0x28, 0x31, 0x49, 0x0b, 0xca, 0xd7, 0xb0, 0x29, 0x49, 0x91, 0x01, 0x38, 0x26, 0x28, 0x9c, 0x37,
    0xd2, 0x49, 0x14, 0x8c, 0x6e, 0x85, 0x01, 0x6c, 0x2b, 0x0c, 0x21, 0x93, 0x9b, 0xf5, 0x8b, 0xd8,
    0x37, 0xac, 0x2d, 0x80, 0x6a, 0xef, 0x7c, 0x8a, 0x99, 0x11, 0x9e, 0x64, 0x98, 0xf2, 0xfb, 0x74,
    0x6b, 0xab, 0x8f, 0xac, 0xfe, 0x41, 0x7e, 0x94, 0xfd, 0x77, 0x06, 0xfa, 0x35, 0x4a, 0x1a, 0xa7,
    0x96, 0x83, 0x20, 0x53, 0x9b, 0x20, 0x3a, 0xc7, 0x6a, 0xdb, 0x4e, 0x8b, 0xdd, 0xdd, 0xeb, 0x39,
    0xc9, 0x99, 0xd2, 0x74, 0x71, 0xb5, 0x58, 0xcf, 0xdb, 0xa1, 0x3c, 0x22, 0x0b, 0xf9, 0x5c, 0xcb,
    0xe7, 0x7c, 0xe7, 0xd0, 0x1c, 0x42, 0xeb, 0x0b, 0x5e, 0xa9, 0x5f, 0x30, 0x17, 0xed, 0x5a, 0xb5,
    0x73, 0xd5, 0xa2, 0xa2, 0x3d, 0xef, 0x77, 0xdd, 0x85, 0xdf, 0x30, 0xd2, 0x9e, 0x49, 0x95, 0x4c,
    0x3e, 0xc9, 0x33, 0x15, 0x0b, 0x3e, 0x5f, 0x10, 0x16, 0xc2, 0x98, 0x6a, 0xc9, 0x8b, 0x08, 0xcd,
    0x2a, 0x42, 0xb3, 0x67, 0x0b, 0xcd, 0xf6, 0x85, 0x66, 0x70, 0xa1, 0xf5, 0x7e, 0x53, 0x52, 0x8b,
    0xa0, 0xd2, 0xb6, 0xb9, 0x4e, 0x03, 0x63, 0xaf, 0x81, 0x71, 0xd7, 0xa7, 0xba, 0xce, 0x58, 0x90,
    0xf8, 0x42, 0x57, 0x31, 0xc3, 0x48, 0xb5, 0xe3, 0x17, 0xf8, 0x34, 0x79, 0x10, 0xcd, 0xe5, 0x21,
    0x90, 0x3e, 0xfb, 0xc2, 0x89, 0x68, 0x5c, 0x50, 0xd5, 0x07, 0xea, 0x83, 0x96, 0x4e, 0x72, 0xea,
    0x04, 0x23, 0xd2, 0x9d, 0x71, 0x99, 0x72, 0xe8, 0x8c, 0xe3, 0x61, 0x74, 0x73, 0x77, 0x1f, 0x7c,
    0xbe, 0xf8, 0xee, 0xbc, 0x02, 0x85, 0x43, 0x6c, 0x57, 0x22, 0xab, 0x0b, 0x47, 0x84, 0xb9, 0xf4,
    0x20, 0xca, 0x5d, 0xe9, 0xf8, 0xf4, 0xca, 0x8a, 0xf6, 0xe1, 0xf0, 0xfc, 0x94, 0xbb, 0x80, 0x9d,
    0xa8, 0x33, 0x27, 0xb0, 0x03, 0x75, 0xbe, 0xeb, 0x5d, 0xc0, 0x60, 0x6a, 0x8a, 0x71, 0x73, 0x00,
    0x91, 0x28, 0x48, 0x04, 0x99, 0x31, 0x72, 0x03, 0x88, 0xb5, 0x05, 0x0c, 0x48, 0x38, 0x42, 0x7c,
    0x45, 0x45, 0x6e, 0x9b, 0x26, 0x10, 0xde, 0x0d, 0x1a, 0x46, 0x9f, 0xc1, 0xf4, 0x66, 0x60, 0xbd,
    0x99, 0x93, 0xde, 0xcc, 0x51, 0x2f, 0x44, 0x2c, 0x4c, 0x69, 0xcc, 0x1e, 0x11, 0x89, 0x27, 0x1a,
    0x39, 0x4e, 0x53, 0x62, 0x48, 0x95, 0x35, 0xb4, 0x48, 0x6a, 0x55, 0x0a, 0x59, 0x2d, 0x37, 0x94,
    0x7d, 0xdf, 0xc1, 0xbe, 0x6a, 0xd9, 0x03, 0x58, 0xee, 0xb8, 0x14, 0x69, 0xd7, 0x68, 0x95, 0x67,
    0x6a, 0x86, 0x31, 0x6b, 0x6d, 0x49, 0x1c, 0xcd, 0x78, 0x35, 0x09, 0xea, 0x0f, 0xdc, 0xe2, 0x80,
    0xa4, 0x48, 0x30, 0x63, 0x8d, 0x9f, 0xaa, 0x44, 0x42, 0x3e, 0xd8, 0x02, 0x45, 0x38, 0xe1, 0xcd,
    0x59, 0xb6, 0xc2, 0x41, 0x28, 0xf3, 0x15, 0x55, 0x33, 0x4d, 0xe9, 0x02, 0xf1, 0xfa, 0x8f, 0x90,
    0x2f, 0xa1, 0x2f, 0xdf, 0x9f, 0xef, 0xfd, 0xd3, 0xbd, 0xc1, 0x4f, 0xc2, 0xdd, 0x6c, 0x32, 0xe1,
    0xfa, 0x81, 0x44, 0x6d, 0xd3, 0xa8, 0x5b, 0x60, 0x20, 0x9a, 0xe9, 0xc6, 0x13, 0x6e, 0x87, 0x58,
    0x23, 0x18, 0xb9, 0xa1, 0x45, 0x7c, 0x2c, 0x3d, 0x67, 0x4d, 0xd4, 0xad, 0x37, 0x64, 0xf0, 0x23,
    0xcf, 0x9c, 0xce, 0xbb, 0xa8, 0xdf, 0x2e, 0xca, 0xd2, 0xca, 0x93, 0xf5, 0xd3, 0xd0, 0x5c, 0x43,
    0x6a, 0xb4, 0xbf, 0x0d, 0x97, 0xec, 0x66, 0x83, 0x4b, 0x5d, 0x1b, 0x79, 0x79, 0x01, 0x64, 0x27,
    0xbf, 0x2c, 0x4b, 0xa4, 0x02, 0xdc, 0x40, 0x5d, 0x86, 0x71, 0xaf, 0xb9, 0x1a, 0xb0, 0x92, 0xf8,
    0x9a, 0x05, 0x9e, 0xfb, 0x1b, 0xf9, 0xae, 0xcb, 0x80, 0xe7, 0xc9, 0xa8, 0x66, 0x9f, 0xf1, 0xf5,
    0x26, 0xf0, 0x29, 0x78, 0xc3, 0x9c, 0x75, 0x76, 0xe1, 0xd9, 0x0a, 0x09, 0x9b, 0xb5, 0xaf, 0xcd,
    0x9b, 0xcb, 0x06, 0x0b, 0x4d, 0xb6, 0x2f, 0x22, 0x83, 0x8b, 0xc8, 0x0c, 0x22, 0xea, 0x4a, 0x02,
    0x53, 0xcc, 0x10, 0x44, 0xb9, 0x97, 0x98, 0x34, 0x5c, 0x53, 0xf5, 0x1d, 0xad, 0xb5, 0x5d, 0xef,
    0x40, 0x3b, 0x93, 0xd5, 0x9d, 0x72, 0x50, 0x9e, 0xf0, 0x42, 0xf6, 0x2d, 0x71, 0xa7, 0xdd, 0x94,
    0x84, 0xaa, 0xed, 0x60, 0x9e, 0x86, 0x4e, 0xdc, 0x0e, 0xb9, 0x40, 0xaa, 0xda, 0xc3, 0xee, 0x91,
    0xd8, 0x56, 0xfa, 0xe7, 0x41, 0x2a, 0x1c, 0x1b, 0x0d, 0xda, 0xdc, 0x17, 0xc2, 0xc7, 0xd6, 0x2e,
    0xd4, 0xb3, 0xd4, 0x2e, 0x06, 0xfb, 0x25, 0x0e, 0x0d, 0xde, 0x77, 0x73, 0x3d, 0x52, 0x6f, 0xca,
    0xd3, 0x6a, 0xd1, 0x00, 0x8d, 0xd5, 0x3c, 0xfd, 0xf8, 0xc4, 0x71, 0x32, 0xc1, 0x93, 0x4a, 0x86,
    0x0d, 0x37, 0xaf, 0x94, 0x13, 0x2e, 0x66, 0xd9, 0x21, 0x66, 0x07, 0x8a, 0xbc, 0x5f, 0x2d, 0x09,
    0xde, 0xad, 0x08, 0xea, 0xc1, 0x19, 0x82, 0x5c, 0x96, 0x49, 0x14, 0x24, 0x80, 0xad, 0x31, 0x21,
    0xe9, 0x9f, 0x46, 0xbe, 0x02, 0x06, 0x21, 0x0c, 0x82, 0x30, 0x5d, 0xae, 0x37, 0x57, 0x92, 0x7c,
    0xbd, 0x14, 0x07, 0xbb, 0x3b, 0x12, 0xbf, 0x4c, 0x06, 0x84, 0xcd, 0xe2, 0x29, 0xdf, 0xbb, 0x02,
    0xad, 0xde, 0x36, 0x7f, 0x40, 0x1c, 0x09, 0x27, 0x81, 0xd1, 0xa2, 0xb2, 0xb6, 0xbb, 0x2f, 0x8d,
    0x37, 0xb2, 0xff, 0x60, 0x8c, 0xa4, 0xbc, 0xc6, 0x0d, 0x87, 0x6a, 0xda, 0x0f, 0x89, 0x48, 0x24,
    0x7e, 0xd4, 0xe1, 0xbd, 0xa3, 0x8a, 0xa7, 0xf5, 0x8e, 0x6a, 0x0f, 0xa2, 0x40, 0xa9, 0x1b, 0xfa,
    0x6d, 0x40, 0xcd, 0xfd, 0xbb, 0x00, 0x6a, 0xa2, 0x6d, 0x47, 0xf0, 0xd3, 0x9a, 0x4b, 0x07, 0x01,
    0xfe, 0xfd, 0xff, 0x4a, 0xfe, 0x0b, 0xa2, 0xf9, 0xf2, 0x7f
};
#endif

PyTypeObject *init_QColor(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX].type;

    Shiboken::AutoDecRef Sbk_QColor_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QColor_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QColor",
        "QColor",
        &Sbk_QColor_spec,
        &Shiboken::callCppDestructor< ::QColor >,
        Sbk_QColor_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QColor_TypeF(); // references _Sbk_QColor_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QColor_SignatureStrings);
#else
    InitSignatureBytes(pyType, QColor_SignatureBytes, QColor_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QColor_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QColor_PythonToCpp_QColor_PTR,
        is_QColor_PythonToCpp_QColor_PTR_Convertible,
        QColor_PTR_CppToPython_QColor,
        QColor_COPY_CppToPython_QColor);

    Shiboken::Conversions::registerConverterName(converter, "QColor");
    Shiboken::Conversions::registerConverterName(converter, "QColor*");
    Shiboken::Conversions::registerConverterName(converter, "QColor&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QColor).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QColor_PythonToCpp_QColor_COPY,
        is_QColor_PythonToCpp_QColor_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_QLatin1String_PythonToCpp_QColor,
        is_PySide6_QtCore_QLatin1String_PythonToCpp_QColor_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QRgba64_PythonToCpp_QColor,
        is_QRgba64_PythonToCpp_QColor_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_Qt_GlobalColor_PythonToCpp_QColor,
        is_PySide6_QtCore_Qt_GlobalColor_PythonToCpp_QColor_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_constQStringREF_PythonToCpp_QColor,
        is_PySide6_QtCore_constQStringREF_PythonToCpp_QColor_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        unsignedint_PythonToCpp_QColor,
        is_unsignedint_PythonToCpp_QColor_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QColor_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Spec'.
    const char *Spec_Initializer[] = {
        "Invalid",
        "Rgb",
        "Hsv",
        "Cmyk",
        "Hsl",
        "ExtendedRgb",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Spec_InitializerValues[] = {
        uint8_t(QColor::Spec::Invalid),    //  0x00  0
        uint8_t(QColor::Spec::Rgb),        //  0x01  1
        uint8_t(QColor::Spec::Hsv),        //  0x02  2
        uint8_t(QColor::Spec::Cmyk),       //  0x03  3
        uint8_t(QColor::Spec::Hsl),        //  0x04  4
        uint8_t(QColor::Spec::ExtendedRgb) //  0x05  5
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QColor_TypeF(),
        "2:PySide6.QtGui.QColor.Spec",
        Spec_Initializer, Spec_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QColor_Spec_IDX].type = EType;
    // Register converter for enum 'QColor::Spec'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QColor_Spec_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QColor_Spec,
            is_Enum_PythonToCpp_QColor_Spec_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QColor::Spec");
        Shiboken::Conversions::registerConverterAlias(converter, "Spec");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Spec' enum.

    // Initialization of enum 'NameFormat'.
    const char *NameFormat_Initializer[] = {
        "HexRgb",
        "HexArgb",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t NameFormat_InitializerValues[] = {
        uint8_t(QColor::NameFormat::HexRgb), //  0x00  0
        uint8_t(QColor::NameFormat::HexArgb) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QColor_TypeF(),
        "2:PySide6.QtGui.QColor.NameFormat",
        NameFormat_Initializer, NameFormat_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QColor_NameFormat_IDX].type = EType;
    // Register converter for enum 'QColor::NameFormat'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QColor_NameFormat_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QColor_NameFormat,
            is_Enum_PythonToCpp_QColor_NameFormat_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QColor::NameFormat");
        Shiboken::Conversions::registerConverterAlias(converter, "NameFormat");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'NameFormat' enum.

    qRegisterMetaType< ::QColor >("QColor");
    qRegisterMetaType< ::QColor::Spec >("QColor::Spec");
    qRegisterMetaType< ::QColor::NameFormat >("QColor::NameFormat");

    return pyType;
}
