// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qfont_wrapper.h"

// inner classes
#include "qfont_tag_wrapper.h"

// Extra includes
#include <QStringList>

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGui/qfont.h>
#include <QtGui/qpaintdevice.h>
#include <qdatastream.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFont_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFont >()))
        return -1;

    ::QFont *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:QFont", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFont::QFont()
    // 1: QFont::QFont(QFont)
    // 2: QFont::QFont(QFont,const QPaintDevice*)
    // 3: QFont::QFont(QString,int=,int=,bool=)
    // 4: QFont::QFont(QStringList,int=,int=,bool=)
    if (numArgs == 0) {
        overloadId = 0; // QFont()
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // QFont(QString,int,int,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // QFont(QString,int,int,bool)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 3; // QFont(QString,int,int,bool)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
                    overloadId = 3; // QFont(QString,int,int,bool)
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 4; // QFont(QStringList,int,int,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 4; // QFont(QStringList,int,int,bool)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 4; // QFont(QStringList,int,int,bool)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
                    overloadId = 4; // QFont(QStringList,int,int,bool)
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QFont(QFont)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), (pyArgs[1])))) {
            overloadId = 2; // QFont(QFont,const QPaintDevice*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QFont()
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
            }

            // QFont()
            cptr = new ::QFont();
            break;
        }
        case 1: // QFont(const QFont &font)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFont cppArg0_local;
            ::QFont *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // QFont(QFont)
                cptr = new ::QFont(*cppArg0);
            }
            break;
        }
        case 2: // QFont(const QFont &font, const QPaintDevice *pd)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QFont cppArg0_local;
            ::QFont *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QPaintDevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFont(QFont,const QPaintDevice*)
                cptr = new ::QFont(*cppArg0, cppArg1);
            }
            break;
        }
        case 3: // QFont(const QString &family, int pointSize, int weight, bool italic)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_pointSize = Shiboken::String::createStaticString("pointSize");
                if (PyDict_Contains(kwds, key_pointSize) != 0) {
                    value = PyDict_GetItem(kwds, key_pointSize);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_pointSize);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pointSize);
                }
                static PyObject *const key_weight = Shiboken::String::createStaticString("weight");
                if (PyDict_Contains(kwds, key_weight) != 0) {
                    value = PyDict_GetItem(kwds, key_weight);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_weight);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_weight);
                }
                static PyObject *const key_italic = Shiboken::String::createStaticString("italic");
                if (PyDict_Contains(kwds, key_italic) != 0) {
                    value = PyDict_GetItem(kwds, key_italic);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_italic);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_italic);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = -1;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = -1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            bool cppArg3 = false;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFont(QString,int,int,bool)
                cptr = new ::QFont(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 4: // QFont(const QStringList &families, int pointSize, int weight, bool italic)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_pointSize = Shiboken::String::createStaticString("pointSize");
                if (PyDict_Contains(kwds, key_pointSize) != 0) {
                    value = PyDict_GetItem(kwds, key_pointSize);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_pointSize);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pointSize);
                }
                static PyObject *const key_weight = Shiboken::String::createStaticString("weight");
                if (PyDict_Contains(kwds, key_weight) != 0) {
                    value = PyDict_GetItem(kwds, key_weight);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_weight);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_weight);
                }
                static PyObject *const key_italic = Shiboken::String::createStaticString("italic");
                if (PyDict_Contains(kwds, key_italic) != 0) {
                    value = PyDict_GetItem(kwds, key_italic);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_italic);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_italic);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                }
            }
            ::QStringList cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = -1;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = -1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            bool cppArg3 = false;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFont(QStringList,int,int,bool)
                cptr = new ::QFont(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QFont >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QFontFunc_bold(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bold()const
        bool cppResult = const_cast<const ::QFont *>(cppSelf)->bold();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_cacheStatistics(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cacheStatistics()
        ::QFont::cacheStatistics();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_capitalization(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // capitalization()const
        QFont::Capitalization cppResult = const_cast<const ::QFont *>(cppSelf)->capitalization();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Capitalization_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_cleanup(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cleanup()
        ::QFont::cleanup();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_clearFeatures(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearFeatures()
        cppSelf->clearFeatures();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_clearVariableAxes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearVariableAxes()
        cppSelf->clearVariableAxes();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_defaultFamily(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultFamily()const
        QString cppResult = const_cast<const ::QFont *>(cppSelf)->defaultFamily();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_exactMatch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // exactMatch()const
        bool cppResult = const_cast<const ::QFont *>(cppSelf)->exactMatch();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_families(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // families()const
        QStringList cppResult = const_cast<const ::QFont *>(cppSelf)->families();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_family(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // family()const
        QString cppResult = const_cast<const ::QFont *>(cppSelf)->family();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_featureTags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // featureTags()const
        QList<QFont::Tag> cppResult = const_cast<const ::QFont *>(cppSelf)->featureTags();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QFont_Tag_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_featureValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::featureValue(QFont::Tag)const->quint32
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
        overloadId = 0; // featureValue(QFont::Tag)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "featureValue", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont::Tag cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // featureValue(QFont::Tag)const
            quint32 cppResult = const_cast<const ::QFont *>(cppSelf)->featureValue(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_fixedPitch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fixedPitch()const
        bool cppResult = const_cast<const ::QFont *>(cppSelf)->fixedPitch();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_fromString(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::fromString(QString)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // fromString(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "fromString", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // fromString(QString)
            bool cppResult = cppSelf->fromString(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_hintingPreference(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hintingPreference()const
        QFont::HintingPreference cppResult = const_cast<const ::QFont *>(cppSelf)->hintingPreference();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_initialize(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // initialize()
        ::QFont::initialize();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_insertSubstitution(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertSubstitution", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFont::insertSubstitution(QString,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // insertSubstitution(QString,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertSubstitution", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertSubstitution(QString,QString)
            ::QFont::insertSubstitution(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_insertSubstitutions(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "insertSubstitutions", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFont::insertSubstitutions(QString,QStringList)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[1])))) {
        overloadId = 0; // insertSubstitutions(QString,QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "insertSubstitutions", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QStringList cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertSubstitutions(QString,QStringList)
            ::QFont::insertSubstitutions(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_isCopyOf(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::isCopyOf(QFont)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // isCopyOf(QFont)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isCopyOf", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // isCopyOf(QFont)const
            bool cppResult = const_cast<const ::QFont *>(cppSelf)->isCopyOf(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_isFeatureSet(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::isFeatureSet(QFont::Tag)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
        overloadId = 0; // isFeatureSet(QFont::Tag)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isFeatureSet", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont::Tag cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isFeatureSet(QFont::Tag)const
            bool cppResult = const_cast<const ::QFont *>(cppSelf)->isFeatureSet(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_isVariableAxisSet(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::isVariableAxisSet(QFont::Tag)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
        overloadId = 0; // isVariableAxisSet(QFont::Tag)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isVariableAxisSet", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont::Tag cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isVariableAxisSet(QFont::Tag)const
            bool cppResult = const_cast<const ::QFont *>(cppSelf)->isVariableAxisSet(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_italic(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // italic()const
        bool cppResult = const_cast<const ::QFont *>(cppSelf)->italic();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_kerning(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // kerning()const
        bool cppResult = const_cast<const ::QFont *>(cppSelf)->kerning();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_key(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // key()const
        QString cppResult = const_cast<const ::QFont *>(cppSelf)->key();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_legacyWeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFont", "legacyWeight() const");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};

        // legacyWeight()const
        int cppResult = const_cast<const ::QFont *>(cppSelf)->legacyWeight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_letterSpacing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // letterSpacing()const
        qreal cppResult = const_cast<const ::QFont *>(cppSelf)->letterSpacing();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_letterSpacingType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // letterSpacingType()const
        QFont::SpacingType cppResult = const_cast<const ::QFont *>(cppSelf)->letterSpacingType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_SpacingType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_overline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // overline()const
        bool cppResult = const_cast<const ::QFont *>(cppSelf)->overline();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_pixelSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pixelSize()const
        int cppResult = const_cast<const ::QFont *>(cppSelf)->pixelSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_pointSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pointSize()const
        int cppResult = const_cast<const ::QFont *>(cppSelf)->pointSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_pointSizeF(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pointSizeF()const
        qreal cppResult = const_cast<const ::QFont *>(cppSelf)->pointSizeF();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_removeSubstitutions(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QFont::removeSubstitutions(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // removeSubstitutions(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeSubstitutions", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeSubstitutions(QString)
            ::QFont::removeSubstitutions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_resolve(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::resolve(QFont)const->QFont
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // resolve(QFont)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resolve", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // resolve(QFont)const
            QFont cppResult = const_cast<const ::QFont *>(cppSelf)->resolve(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_resolveMask(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resolveMask()const
        uint cppResult = const_cast<const ::QFont *>(cppSelf)->resolveMask();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_setBold(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setBold(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setBold(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBold", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBold(bool)
            cppSelf->setBold(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setCapitalization(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setCapitalization(QFont::Capitalization)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Capitalization_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setCapitalization(QFont::Capitalization)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCapitalization", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QFont::Capitalization cppArg0{QFont::MixedCase};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCapitalization(QFont::Capitalization)
            cppSelf->setCapitalization(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setFamilies(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setFamilies(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setFamilies(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFamilies", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFamilies(QStringList)
            cppSelf->setFamilies(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setFamily(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setFamily(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setFamily(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFamily", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFamily(QString)
            cppSelf->setFamily(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setFeature(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setFeature", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFont::setFeature(QFont::Tag,quint32)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArgs[1])))) {
        overloadId = 0; // setFeature(QFont::Tag,quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFeature", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QFont::Tag cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        quint32 cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFeature(QFont::Tag,quint32)
            cppSelf->setFeature(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setFixedPitch(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setFixedPitch(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFixedPitch(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFixedPitch", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFixedPitch(bool)
            cppSelf->setFixedPitch(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setHintingPreference(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setHintingPreference(QFont::HintingPreference)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setHintingPreference(QFont::HintingPreference)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHintingPreference", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QFont::HintingPreference cppArg0{QFont::PreferDefaultHinting};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHintingPreference(QFont::HintingPreference)
            cppSelf->setHintingPreference(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setItalic(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setItalic(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setItalic(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItalic", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItalic(bool)
            cppSelf->setItalic(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setKerning(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setKerning(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setKerning(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setKerning", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setKerning(bool)
            cppSelf->setKerning(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setLegacyWeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setLegacyWeight(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setLegacyWeight(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLegacyWeight", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        Shiboken::Warnings::warnDeprecated("QFont", "setLegacyWeight(int legacyWeight)");
        if (Shiboken::Errors::occurred() != nullptr)
            return {};
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLegacyWeight(int)
            cppSelf->setLegacyWeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setLetterSpacing(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setLetterSpacing", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFont::setLetterSpacing(QFont::SpacingType,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_SpacingType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // setLetterSpacing(QFont::SpacingType,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setLetterSpacing", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QFont::SpacingType cppArg0{QFont::PercentageSpacing};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLetterSpacing(QFont::SpacingType,qreal)
            cppSelf->setLetterSpacing(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setOverline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setOverline(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setOverline(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOverline", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOverline(bool)
            cppSelf->setOverline(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setPixelSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setPixelSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setPixelSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPixelSize", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPixelSize(int)
            cppSelf->setPixelSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setPointSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setPointSize(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setPointSize(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPointSize", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPointSize(int)
            cppSelf->setPointSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setPointSizeF(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setPointSizeF(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setPointSizeF(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPointSizeF", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPointSizeF(qreal)
            cppSelf->setPointSizeF(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setResolveMask(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setResolveMask(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<uint>(), (pyArg)))) {
        overloadId = 0; // setResolveMask(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setResolveMask", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        uint cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setResolveMask(uint)
            cppSelf->setResolveMask(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setStretch(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setStretch(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setStretch(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStretch", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStretch(int)
            cppSelf->setStretch(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setStrikeOut(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setStrikeOut(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setStrikeOut(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStrikeOut", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStrikeOut(bool)
            cppSelf->setStrikeOut(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setStyle(QFont::Style)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Style_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setStyle(QFont::Style)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStyle", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QFont::Style cppArg0{QFont::StyleNormal};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStyle(QFont::Style)
            cppSelf->setStyle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setStyleHint(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setStyleHint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setStyleHint", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFont::setStyleHint(QFont::StyleHint,QFont::StyleStrategy=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleHint_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setStyleHint(QFont::StyleHint,QFont::StyleStrategy)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleStrategy_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setStyleHint(QFont::StyleHint,QFont::StyleStrategy)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setStyleHint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_strategy = Shiboken::String::createStaticString("strategy");
            if (PyDict_Contains(kwds, key_strategy) != 0) {
                value = PyDict_GetItem(kwds, key_strategy);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_strategy);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setStyleHint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleStrategy_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setStyleHint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_strategy);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setStyleHint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);
            }
        }
        ::QFont::StyleHint cppArg0{QFont::SansSerif};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFont::StyleStrategy cppArg1(QFont::StyleStrategy::PreferDefault);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStyleHint(QFont::StyleHint,QFont::StyleStrategy)
            cppSelf->setStyleHint(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setStyleName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setStyleName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setStyleName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStyleName", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStyleName(QString)
            cppSelf->setStyleName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setStyleStrategy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setStyleStrategy(QFont::StyleStrategy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleStrategy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setStyleStrategy(QFont::StyleStrategy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStyleStrategy", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QFont::StyleStrategy cppArg0 = static_cast< ::QFont::StyleStrategy>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStyleStrategy(QFont::StyleStrategy)
            cppSelf->setStyleStrategy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setUnderline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setUnderline(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUnderline(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUnderline", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUnderline(bool)
            cppSelf->setUnderline(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setVariableAxis(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setVariableAxis", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFont::setVariableAxis(QFont::Tag,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // setVariableAxis(QFont::Tag,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setVariableAxis", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QFont::Tag cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVariableAxis(QFont::Tag,float)
            cppSelf->setVariableAxis(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setWeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setWeight(QFont::Weight)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Weight_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setWeight(QFont::Weight)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWeight", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QFont::Weight cppArg0 = static_cast< ::QFont::Weight>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWeight(QFont::Weight)
            cppSelf->setWeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_setWordSpacing(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::setWordSpacing(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setWordSpacing(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWordSpacing", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWordSpacing(qreal)
            cppSelf->setWordSpacing(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_stretch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stretch()const
        int cppResult = const_cast<const ::QFont *>(cppSelf)->stretch();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_strikeOut(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // strikeOut()const
        bool cppResult = const_cast<const ::QFont *>(cppSelf)->strikeOut();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_style(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // style()const
        QFont::Style cppResult = const_cast<const ::QFont *>(cppSelf)->style();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Style_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_styleHint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // styleHint()const
        QFont::StyleHint cppResult = const_cast<const ::QFont *>(cppSelf)->styleHint();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleHint_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_styleName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // styleName()const
        QString cppResult = const_cast<const ::QFont *>(cppSelf)->styleName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_styleStrategy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // styleStrategy()const
        QFont::StyleStrategy cppResult = const_cast<const ::QFont *>(cppSelf)->styleStrategy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleStrategy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_substitute(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QFont::substitute(QString)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // substitute(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "substitute", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // substitute(QString)
            QString cppResult = ::QFont::substitute(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_substitutes(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QFont::substitutes(QString)->QStringList
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // substitutes(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "substitutes", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // substitutes(QString)
            QStringList cppResult = ::QFont::substitutes(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_substitutions(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // substitutions()
        QStringList cppResult = ::QFont::substitutions();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_swap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::swap(QFont&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // swap(QFont&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "swap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // swap(QFont&)
            cppSelf->swap(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_toString(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toString()const
        QString cppResult = const_cast<const ::QFont *>(cppSelf)->toString();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_underline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // underline()const
        bool cppResult = const_cast<const ::QFont *>(cppSelf)->underline();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_unsetFeature(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::unsetFeature(QFont::Tag)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
        overloadId = 0; // unsetFeature(QFont::Tag)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "unsetFeature", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont::Tag cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unsetFeature(QFont::Tag)
            cppSelf->unsetFeature(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_unsetVariableAxis(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::unsetVariableAxis(QFont::Tag)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
        overloadId = 0; // unsetVariableAxis(QFont::Tag)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "unsetVariableAxis", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont::Tag cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // unsetVariableAxis(QFont::Tag)
            cppSelf->unsetVariableAxis(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFontFunc_variableAxisTags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // variableAxisTags()const
        QList<QFont::Tag> cppResult = const_cast<const ::QFont *>(cppSelf)->variableAxisTags();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QFont_Tag_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_variableAxisValue(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFont::variableAxisValue(QFont::Tag)const->float
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Tag_IDX]), (pyArg)))) {
        overloadId = 0; // variableAxisValue(QFont::Tag)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "variableAxisValue", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont::Tag cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // variableAxisValue(QFont::Tag)const
            float cppResult = const_cast<const ::QFont *>(cppSelf)->variableAxisValue(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_weight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // weight()const
        QFont::Weight cppResult = const_cast<const ::QFont *>(cppSelf)->weight();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Weight_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc_wordSpacing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wordSpacing()const
        qreal cppResult = const_cast<const ::QFont *>(cppSelf)->wordSpacing();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFont__copy__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppSelf);
    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QFont_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QFont_EnumFlagInfo[] = {
    "Capitalization:Enum",
    "HintingPreference:Enum",
    "SpacingType:Enum",
    "Stretch:IntEnum",
    "Style:Enum",
    "StyleHint:Enum",
    "StyleStrategy:Flag",
    "Weight:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFont_methods[] = {
    {"bold", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_bold), METH_NOARGS, nullptr},
    {"cacheStatistics", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_cacheStatistics), METH_NOARGS|METH_STATIC, nullptr},
    {"capitalization", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_capitalization), METH_NOARGS, nullptr},
    {"cleanup", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_cleanup), METH_NOARGS|METH_STATIC, nullptr},
    {"clearFeatures", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_clearFeatures), METH_NOARGS, nullptr},
    {"clearVariableAxes", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_clearVariableAxes), METH_NOARGS, nullptr},
    {"defaultFamily", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_defaultFamily), METH_NOARGS, nullptr},
    {"exactMatch", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_exactMatch), METH_NOARGS, nullptr},
    {"families", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_families), METH_NOARGS, nullptr},
    {"family", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_family), METH_NOARGS, nullptr},
    {"featureTags", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_featureTags), METH_NOARGS, nullptr},
    {"featureValue", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_featureValue), METH_O, nullptr},
    {"fixedPitch", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_fixedPitch), METH_NOARGS, nullptr},
    {"fromString", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_fromString), METH_O, nullptr},
    {"hintingPreference", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_hintingPreference), METH_NOARGS, nullptr},
    {"initialize", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_initialize), METH_NOARGS|METH_STATIC, nullptr},
    {"insertSubstitution", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_insertSubstitution), METH_VARARGS|METH_STATIC, nullptr},
    {"insertSubstitutions", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_insertSubstitutions), METH_VARARGS|METH_STATIC, nullptr},
    {"isCopyOf", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_isCopyOf), METH_O, nullptr},
    {"isFeatureSet", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_isFeatureSet), METH_O, nullptr},
    {"isVariableAxisSet", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_isVariableAxisSet), METH_O, nullptr},
    {"italic", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_italic), METH_NOARGS, nullptr},
    {"kerning", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_kerning), METH_NOARGS, nullptr},
    {"key", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_key), METH_NOARGS, nullptr},
    {"legacyWeight", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_legacyWeight), METH_NOARGS, nullptr},
    {"letterSpacing", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_letterSpacing), METH_NOARGS, nullptr},
    {"letterSpacingType", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_letterSpacingType), METH_NOARGS, nullptr},
    {"overline", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_overline), METH_NOARGS, nullptr},
    {"pixelSize", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_pixelSize), METH_NOARGS, nullptr},
    {"pointSize", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_pointSize), METH_NOARGS, nullptr},
    {"pointSizeF", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_pointSizeF), METH_NOARGS, nullptr},
    {"removeSubstitutions", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_removeSubstitutions), METH_O|METH_STATIC, nullptr},
    {"resolve", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_resolve), METH_O, nullptr},
    {"resolveMask", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_resolveMask), METH_NOARGS, nullptr},
    {"setBold", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setBold), METH_O, nullptr},
    {"setCapitalization", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setCapitalization), METH_O, nullptr},
    {"setFamilies", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setFamilies), METH_O, nullptr},
    {"setFamily", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setFamily), METH_O, nullptr},
    {"setFeature", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setFeature), METH_VARARGS, nullptr},
    {"setFixedPitch", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setFixedPitch), METH_O, nullptr},
    {"setHintingPreference", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setHintingPreference), METH_O, nullptr},
    {"setItalic", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setItalic), METH_O, nullptr},
    {"setKerning", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setKerning), METH_O, nullptr},
    {"setLegacyWeight", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setLegacyWeight), METH_O, nullptr},
    {"setLetterSpacing", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setLetterSpacing), METH_VARARGS, nullptr},
    {"setOverline", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setOverline), METH_O, nullptr},
    {"setPixelSize", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setPixelSize), METH_O, nullptr},
    {"setPointSize", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setPointSize), METH_O, nullptr},
    {"setPointSizeF", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setPointSizeF), METH_O, nullptr},
    {"setResolveMask", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setResolveMask), METH_O, nullptr},
    {"setStretch", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setStretch), METH_O, nullptr},
    {"setStrikeOut", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setStrikeOut), METH_O, nullptr},
    {"setStyle", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setStyle), METH_O, nullptr},
    {"setStyleHint", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setStyleHint), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setStyleName", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setStyleName), METH_O, nullptr},
    {"setStyleStrategy", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setStyleStrategy), METH_O, nullptr},
    {"setUnderline", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setUnderline), METH_O, nullptr},
    {"setVariableAxis", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setVariableAxis), METH_VARARGS, nullptr},
    {"setWeight", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setWeight), METH_O, nullptr},
    {"setWordSpacing", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_setWordSpacing), METH_O, nullptr},
    {"stretch", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_stretch), METH_NOARGS, nullptr},
    {"strikeOut", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_strikeOut), METH_NOARGS, nullptr},
    {"style", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_style), METH_NOARGS, nullptr},
    {"styleHint", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_styleHint), METH_NOARGS, nullptr},
    {"styleName", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_styleName), METH_NOARGS, nullptr},
    {"styleStrategy", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_styleStrategy), METH_NOARGS, nullptr},
    {"substitute", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_substitute), METH_O|METH_STATIC, nullptr},
    {"substitutes", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_substitutes), METH_O|METH_STATIC, nullptr},
    {"substitutions", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_substitutions), METH_NOARGS|METH_STATIC, nullptr},
    {"swap", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_swap), METH_O, nullptr},
    {"toString", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_toString), METH_NOARGS, nullptr},
    {"underline", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_underline), METH_NOARGS, nullptr},
    {"unsetFeature", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_unsetFeature), METH_O, nullptr},
    {"unsetVariableAxis", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_unsetVariableAxis), METH_O, nullptr},
    {"variableAxisTags", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_variableAxisTags), METH_NOARGS, nullptr},
    {"variableAxisValue", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_variableAxisValue), METH_O, nullptr},
    {"weight", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_weight), METH_NOARGS, nullptr},
    {"wordSpacing", reinterpret_cast<PyCFunction>(Sbk_QFontFunc_wordSpacing), METH_NOARGS, nullptr},
    {"__copy__", reinterpret_cast<PyCFunction>(Sbk_QFont__copy__), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyObject *Sbk_QFontFunc___lshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rlshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QFont::operator<<(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator<<(QDataStream&,QFont)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator<<", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator<<(QDataStream&,QFont) [reverse operator]
                QDataStream & cppResult = (*cppArg0) << (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFontFunc___rshift__(PyObject *self, PyObject *pyArg)
{
    bool isReverse = SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), pyArg)
                    && !SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), self);
    if (isReverse)
        std::swap(self, pyArg);
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    static PyObject *attrName = Shiboken::PyMagicName::rrshift();
    if (!isReverse
        && Shiboken::Object::checkType(pyArg)
        && !PyObject_TypeCheck(pyArg, self->ob_type)
        && PyObject_HasAttr(pyArg, attrName)) {
        PyObject *revOpMethod = PyObject_GetAttr(pyArg, attrName);
        if (revOpMethod && PyCallable_Check(revOpMethod)) {
            pyResult = PyObject_CallFunction(revOpMethod, "O", self);
            if (Shiboken::Errors::occurred() != nullptr && (PyErr_ExceptionMatches(PyExc_NotImplementedError) || PyErr_ExceptionMatches(PyExc_AttributeError))) {
                PyErr_Clear();
                Py_XDECREF(pyResult);
                pyResult = nullptr;
            }
        }
        Py_XDECREF(revOpMethod);

    }

    // Do not enter here if other object has implemented a reverse operator.
    if (pyResult == nullptr) {
        // Overloaded function decisor
        // 0: QFont::operator>>(QDataStream&)->QDataStream&
        if (isReverse
            && (pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
            overloadId = 0; // operator>>(QDataStream&,QFont&)
        }

        if (isReverse && overloadId == -1) {
            Shiboken::Errors::setReverseOperatorNotImplemented();
            return {};
        }

        // Function signature not found.
        if (overloadId == -1)
            return Shiboken::returnWrongArguments(pyArg, "operator>>", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]);

        // Call function/method
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDataStream *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // operator>>(QDataStream&,QFont&) [reverse operator]
                QDataStream & cppResult = (*cppArg0) >> (*cppSelf);
                pyResult = Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &cppResult);
            }
        }

    } // End of "if (!pyResult)"

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

// Rich comparison
static PyObject * Sbk_QFont_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto &cppSelf = *reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
                // operator!=(const QFont &arg__1) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFont cppArg0_local;
                ::QFont *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_LT:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
                // operator<(const QFont &arg__1) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFont cppArg0_local;
                ::QFont *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf < (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                return Shiboken::returnFromRichCompare(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
                // operator==(const QFont &arg__1) const
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::QFont cppArg0_local;
                ::QFont *cppArg0 = &cppArg0_local;
                if (pythonToCpp.isValue())
                    pythonToCpp(pyArg, &cppArg0_local);
                else
                    pythonToCpp(pyArg, &cppArg0);

                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

} // extern "C"

static Py_hash_t Sbk_QFont_HashFunc(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    return Py_hash_t(qHash(*cppSelf));
}

static int Sbk_QFont_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFont_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QFont__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << *cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFont_Type = nullptr;
static PyTypeObject *Sbk_QFont_TypeF(void)
{
    return _Sbk_QFont_Type;
}

static PyType_Slot Sbk_QFont_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QFont__repr__)},
    {Py_tp_hash,        reinterpret_cast<void *>(&Sbk_QFont_HashFunc)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFont_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFont_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_QFont_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFont_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFont_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    // type supports number protocol
    {Py_nb_lshift,      reinterpret_cast<void *>(Sbk_QFontFunc___lshift__)},
    {Py_nb_rshift,      reinterpret_cast<void *>(Sbk_QFontFunc___rshift__)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFont_spec = {
    "2:PySide6.QtGui.QFont",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFont_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QFont_StyleHint(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFont::StyleHint>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFont::StyleHint *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFont_StyleHint_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleHint_IDX])))
        return Enum_PythonToCpp_QFont_StyleHint;
    return {};
}

static PyObject *QFont_StyleHint_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFont::StyleHint>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFont::StyleHint *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleHint_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFont_StyleStrategy(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFont::StyleStrategy>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFont::StyleStrategy *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFont_StyleStrategy_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleStrategy_IDX])))
        return Enum_PythonToCpp_QFont_StyleStrategy;
    return {};
}

static PyObject *QFont_StyleStrategy_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFont::StyleStrategy>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFont::StyleStrategy *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleStrategy_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFont_HintingPreference(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFont::HintingPreference>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFont::HintingPreference *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFont_HintingPreference_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX])))
        return Enum_PythonToCpp_QFont_HintingPreference;
    return {};
}

static PyObject *QFont_HintingPreference_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFont::HintingPreference>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFont::HintingPreference *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFont_Weight(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFont::Weight>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFont::Weight *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFont_Weight_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Weight_IDX])))
        return Enum_PythonToCpp_QFont_Weight;
    return {};
}

static PyObject *QFont_Weight_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFont::Weight>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFont::Weight *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Weight_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFont_Style(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFont::Style>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFont::Style *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFont_Style_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Style_IDX])))
        return Enum_PythonToCpp_QFont_Style;
    return {};
}

static PyObject *QFont_Style_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFont::Style>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFont::Style *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Style_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFont_Stretch(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFont::Stretch>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFont::Stretch *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFont_Stretch_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Stretch_IDX])))
        return Enum_PythonToCpp_QFont_Stretch;
    return {};
}

static PyObject *QFont_Stretch_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFont::Stretch>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFont::Stretch *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Stretch_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFont_Capitalization(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFont::Capitalization>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFont::Capitalization *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFont_Capitalization_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Capitalization_IDX])))
        return Enum_PythonToCpp_QFont_Capitalization;
    return {};
}

static PyObject *QFont_Capitalization_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFont::Capitalization>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFont::Capitalization *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_Capitalization_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFont_SpacingType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFont::SpacingType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFont::SpacingType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFont_SpacingType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_SpacingType_IDX])))
        return Enum_PythonToCpp_QFont_SpacingType;
    return {};
}

static PyObject *QFont_SpacingType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFont::SpacingType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFont::SpacingType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_SpacingType_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFont_PythonToCpp_QFont_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFont_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFont_PythonToCpp_QFont_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFont_TypeF()))
        return QFont_PythonToCpp_QFont_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFont_PTR_CppToPython_QFont(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QFont_TypeF(), const_cast<void *>(cppIn), false);

}

// C++ to Python copy conversion.
static PyObject *QFont_COPY_CppToPython_QFont(const void *cppIn)
{
    auto *source = reinterpret_cast<const ::QFont *>(cppIn);
    return Shiboken::Object::newObject(Sbk_QFont_TypeF(), new ::QFont(*source), true, true);
}

// Python to C++ copy conversion.
static void QFont_PythonToCpp_QFont_COPY(PyObject *pyIn, void *cppOut)
{
    *reinterpret_cast<::QFont *>(cppOut) = *reinterpret_cast< ::QFont *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), reinterpret_cast<SbkObject *>(pyIn)));
}
static PythonToCppFunc is_QFont_PythonToCpp_QFont_COPY_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Sbk_QFont_TypeF()))
        return QFont_PythonToCpp_QFont_COPY;
    return {};
}

// Implicit conversions.
static void PySide6_QtCore_constQStringREF_PythonToCpp_QFont(PyObject *pyIn, void *cppOut)
{
    ::QString cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QFont *>(cppOut) = ::QFont(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_constQStringREF_PythonToCpp_QFont_Convertible(PyObject *pyIn)
{
    if (PyUnicode_Check(pyIn))
        return PySide6_QtCore_constQStringREF_PythonToCpp_QFont;
    return {};
}

static void PySide6_QtCore_constQStringListREF_PythonToCpp_QFont(PyObject *pyIn, void *cppOut)
{
    ::QStringList cppIn;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], pyIn, &cppIn);
    *reinterpret_cast<::QFont *>(cppOut) = ::QFont(cppIn);
}
static PythonToCppFunc is_PySide6_QtCore_constQStringListREF_PythonToCpp_QFont_Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::isPythonToCppConvertible(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], pyIn))
        return PySide6_QtCore_constQStringListREF_PythonToCpp_QFont;
    return {};
}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFont_SignatureStrings[] = {
    "4:PySide6.QtGui.QFont(self)",
    "3:PySide6.QtGui.QFont(self,font:PySide6.QtGui.QFont)",
    "2:PySide6.QtGui.QFont(self,font:typing.Union[PySide6.QtGui.QFont, QString, QStringList],pd:PySide6.QtGui.QPaintDevice)",
    "1:PySide6.QtGui.QFont(self,family:QString,pointSize:int=-1,weight:int=-1,italic:bool=false)",
    "0:PySide6.QtGui.QFont(self,families:QStringList,pointSize:int=-1,weight:int=-1,italic:bool=false)",
    "PySide6.QtGui.QFont.bold(self)->bool",
    "PySide6.QtGui.QFont.cacheStatistics()",
    "PySide6.QtGui.QFont.capitalization(self)->PySide6.QtGui.QFont.Capitalization",
    "PySide6.QtGui.QFont.cleanup()",
    "PySide6.QtGui.QFont.clearFeatures(self)",
    "PySide6.QtGui.QFont.clearVariableAxes(self)",
    "PySide6.QtGui.QFont.defaultFamily(self)->QString",
    "PySide6.QtGui.QFont.exactMatch(self)->bool",
    "PySide6.QtGui.QFont.families(self)->QStringList",
    "PySide6.QtGui.QFont.family(self)->QString",
    "PySide6.QtGui.QFont.featureTags(self)->QList[PySide6.QtGui.QFont.Tag]",
    "PySide6.QtGui.QFont.featureValue(self,tag:PySide6.QtGui.QFont.Tag)->quint32",
    "PySide6.QtGui.QFont.fixedPitch(self)->bool",
    "PySide6.QtGui.QFont.fromString(self,arg__1:QString)->bool",
    "PySide6.QtGui.QFont.hintingPreference(self)->PySide6.QtGui.QFont.HintingPreference",
    "PySide6.QtGui.QFont.initialize()",
    "PySide6.QtGui.QFont.insertSubstitution(arg__1:QString,arg__2:QString)",
    "PySide6.QtGui.QFont.insertSubstitutions(arg__1:QString,arg__2:QStringList)",
    "PySide6.QtGui.QFont.isCopyOf(self,arg__1:typing.Union[PySide6.QtGui.QFont, QString, QStringList])->bool",
    "PySide6.QtGui.QFont.isFeatureSet(self,tag:PySide6.QtGui.QFont.Tag)->bool",
    "PySide6.QtGui.QFont.isVariableAxisSet(self,tag:PySide6.QtGui.QFont.Tag)->bool",
    "PySide6.QtGui.QFont.italic(self)->bool",
    "PySide6.QtGui.QFont.kerning(self)->bool",
    "PySide6.QtGui.QFont.key(self)->QString",
    "PySide6.QtGui.QFont.legacyWeight(self)->int",
    "PySide6.QtGui.QFont.letterSpacing(self)->qreal",
    "PySide6.QtGui.QFont.letterSpacingType(self)->PySide6.QtGui.QFont.SpacingType",
    "PySide6.QtGui.QFont.overline(self)->bool",
    "PySide6.QtGui.QFont.pixelSize(self)->int",
    "PySide6.QtGui.QFont.pointSize(self)->int",
    "PySide6.QtGui.QFont.pointSizeF(self)->qreal",
    "PySide6.QtGui.QFont.removeSubstitutions(arg__1:QString)",
    "PySide6.QtGui.QFont.resolve(self,arg__1:typing.Union[PySide6.QtGui.QFont, QString, QStringList])->PySide6.QtGui.QFont",
    "PySide6.QtGui.QFont.resolveMask(self)->uint",
    "PySide6.QtGui.QFont.setBold(self,arg__1:bool)",
    "PySide6.QtGui.QFont.setCapitalization(self,arg__1:PySide6.QtGui.QFont.Capitalization)",
    "PySide6.QtGui.QFont.setFamilies(self,arg__1:QStringList)",
    "PySide6.QtGui.QFont.setFamily(self,arg__1:QString)",
    "PySide6.QtGui.QFont.setFeature(self,tag:PySide6.QtGui.QFont.Tag,value:quint32)",
    "PySide6.QtGui.QFont.setFixedPitch(self,arg__1:bool)",
    "PySide6.QtGui.QFont.setHintingPreference(self,hintingPreference:PySide6.QtGui.QFont.HintingPreference)",
    "PySide6.QtGui.QFont.setItalic(self,b:bool)",
    "PySide6.QtGui.QFont.setKerning(self,arg__1:bool)",
    "PySide6.QtGui.QFont.setLegacyWeight(self,legacyWeight:int)",
    "PySide6.QtGui.QFont.setLetterSpacing(self,type:PySide6.QtGui.QFont.SpacingType,spacing:qreal)",
    "PySide6.QtGui.QFont.setOverline(self,arg__1:bool)",
    "PySide6.QtGui.QFont.setPixelSize(self,arg__1:int)",
    "PySide6.QtGui.QFont.setPointSize(self,arg__1:int)",
    "PySide6.QtGui.QFont.setPointSizeF(self,arg__1:qreal)",
    "PySide6.QtGui.QFont.setResolveMask(self,mask:uint)",
    "PySide6.QtGui.QFont.setStretch(self,arg__1:int)",
    "PySide6.QtGui.QFont.setStrikeOut(self,arg__1:bool)",
    "PySide6.QtGui.QFont.setStyle(self,style:PySide6.QtGui.QFont.Style)",
    "PySide6.QtGui.QFont.setStyleHint(self,arg__1:PySide6.QtGui.QFont.StyleHint,strategy:PySide6.QtGui.QFont.StyleStrategy=QFont.StyleStrategy.PreferDefault)",
    "PySide6.QtGui.QFont.setStyleName(self,arg__1:QString)",
    "PySide6.QtGui.QFont.setStyleStrategy(self,s:PySide6.QtGui.QFont.StyleStrategy)",
    "PySide6.QtGui.QFont.setUnderline(self,arg__1:bool)",
    "PySide6.QtGui.QFont.setVariableAxis(self,tag:PySide6.QtGui.QFont.Tag,value:float)",
    "PySide6.QtGui.QFont.setWeight(self,weight:PySide6.QtGui.QFont.Weight)",
    "PySide6.QtGui.QFont.setWordSpacing(self,spacing:qreal)",
    "PySide6.QtGui.QFont.stretch(self)->int",
    "PySide6.QtGui.QFont.strikeOut(self)->bool",
    "PySide6.QtGui.QFont.style(self)->PySide6.QtGui.QFont.Style",
    "PySide6.QtGui.QFont.styleHint(self)->PySide6.QtGui.QFont.StyleHint",
    "PySide6.QtGui.QFont.styleName(self)->QString",
    "PySide6.QtGui.QFont.styleStrategy(self)->PySide6.QtGui.QFont.StyleStrategy",
    "PySide6.QtGui.QFont.substitute(arg__1:QString)->QString",
    "PySide6.QtGui.QFont.substitutes(arg__1:QString)->QStringList",
    "PySide6.QtGui.QFont.substitutions()->QStringList",
    "PySide6.QtGui.QFont.swap(self,other:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "PySide6.QtGui.QFont.toString(self)->QString",
    "PySide6.QtGui.QFont.underline(self)->bool",
    "PySide6.QtGui.QFont.unsetFeature(self,tag:PySide6.QtGui.QFont.Tag)",
    "PySide6.QtGui.QFont.unsetVariableAxis(self,tag:PySide6.QtGui.QFont.Tag)",
    "PySide6.QtGui.QFont.variableAxisTags(self)->QList[PySide6.QtGui.QFont.Tag]",
    "PySide6.QtGui.QFont.variableAxisValue(self,tag:PySide6.QtGui.QFont.Tag)->float",
    "PySide6.QtGui.QFont.weight(self)->PySide6.QtGui.QFont.Weight",
    "PySide6.QtGui.QFont.wordSpacing(self)->qreal",
    "PySide6.QtGui.QFont.__copy__(self)->typing.Self",
    "PySide6.QtGui.QFont.__lshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QFont.__rshift__(self,arg__1:PySide6.QtCore.QDataStream)->PySide6.QtCore.QDataStream",
    "PySide6.QtGui.QFont.__ne__(self,arg__1:typing.Union[PySide6.QtGui.QFont, QString, QStringList])->bool",
    "PySide6.QtGui.QFont.__lt__(self,arg__1:typing.Union[PySide6.QtGui.QFont, QString, QStringList])->bool",
    "PySide6.QtGui.QFont.__eq__(self,arg__1:typing.Union[PySide6.QtGui.QFont, QString, QStringList])->bool",
    "PySide6.QtGui.QFont.__hash__(self)->int",
    nullptr}; // Sentinel
#else
static constexpr size_t QFont_SignatureByteSize = 970;
static constexpr uint8_t QFont_SignatureBytes[970] = {
    0x78, 0xda, 0xbd, 0x57, 0x51, 0x4f, 0xdb, 0x30, 0x10, 0x7e, 0xe7, 0x57, 0xec, 0x91, 0x4a, 0xa1,
    0x1a, 0x30, 0xed, 0x21, 0x12, 0x93, 0xb6, 0xa2, 0x8e, 0x69, 0x30, 0xca, 0x02, 0xec, 0x61, 0x42,
    0x95, 0x9b, 0x5e, 0x5a, 0x0b, 0x37, 0x0e, 0xb6, 0x53, 0x08, 0xbf, 0x7e, 0x4e, 0x13, 0xb7, 0x49,
    0xea, 0x73, 0x52, 0x18, 0x3c, 0xe1, 0x92, 0xef, 0xbe, 0xbb, 0xb3, 0xbf, 0xbb, 0xb3, 0x3f, 0xf9,
    0xa3, 0x2c, 0xa0, 0x53, 0xf8, 0xdc, 0xbf, 0x52, 0xdf, 0x53, 0xda, 0xbf, 0x1a, 0xf2, 0x58, 0xed,
    0x4b, 0x60, 0x51, 0x6f, 0xef, 0x18, 0xfd, 0xe6, 0x45, 0x7a, 0x65, 0xfb, 0xda, 0xdb, 0x3b, 0x6a,
    0x31, 0x52, 0x59, 0x42, 0xe3, 0x59, 0xff, 0x26, 0xa6, 0x3c, 0xfe, 0x6b, 0x81, 0x7a, 0x1f, 0xae,
    0x02, 0x25, 0x34, 0x64, 0xbd, 0x38, 0xa7, 0x52, 0xdd, 0x79, 0xc9, 0xb4, 0x49, 0x3c, 0x22, 0x34,
    0x56, 0xa7, 0xb0, 0xa4, 0x21, 0xf4, 0xf6, 0x0e, 0x1d, 0x6e, 0xc9, 0x82, 0xb2, 0xcc, 0x37, 0xb4,
    0x09, 0xd7, 0x66, 0x01, 0x7d, 0x06, 0x5f, 0xff, 0x3d, 0x39, 0x38, 0xf4, 0x1e, 0x81, 0xce, 0xe6,
    0xca, 0xfc, 0xa2, 0x8a, 0x30, 0x1a, 0xfa, 0x13, 0xce, 0xd9, 0x49, 0x44, 0x98, 0xd4, 0xdc, 0x1f,
    0x5b, 0xb8, 0x29, 0x48, 0xbf, 0x12, 0xeb, 0x0b, 0x3c, 0x58, 0xf8, 0xfb, 0x13, 0xce, 0xa6, 0xc5,
    0x41, 0x1c, 0x7c, 0xc9, 0xb1, 0x56, 0x50, 0x48, 0xc2, 0x39, 0x04, 0x8a, 0x28, 0xed, 0x97, 0x86,
    0x72, 0xbf, 0x87, 0xa0, 0x92, 0x95, 0xd3, 0x67, 0x8d, 0xe3, 0xb1, 0x21, 0xb5, 0x21, 0x07, 0x35,
    0xa4, 0x9d, 0x8c, 0x01, 0x89, 0xd3, 0x04, 0x73, 0xa5, 0xbf, 0x8a, 0x21, 0x10, 0x95, 0x0a, 0x90,
    0xa5, 0x8e, 0x50, 0xdc, 0x2d, 0x11, 0x94, 0x4c, 0x18, 0x7c, 0x7d, 0x72, 0x62, 0xa7, 0x10, 0x91,
    0x94, 0xa9, 0xe1, 0xea, 0x1c, 0x4d, 0xf4, 0xe5, 0x86, 0x5b, 0x0d, 0xe0, 0x89, 0x84, 0xea, 0x82,
    0xa8, 0x70, 0xde, 0xba, 0x81, 0xe6, 0x00, 0x1b, 0xb4, 0xf9, 0x39, 0xe2, 0xf8, 0x4e, 0x41, 0x44,
    0xc5, 0x26, 0x5c, 0x93, 0xd9, 0x86, 0x3c, 0xa7, 0xb5, 0x89, 0xbe, 0xaf, 0x51, 0x77, 0x2e, 0x96,
    0x5b, 0xc2, 0x52, 0x28, 0x24, 0xa7, 0xc8, 0xcc, 0x47, 0x28, 0xb4, 0x8b, 0x87, 0x54, 0xab, 0xec,
    0xf8, 0xc8, 0xce, 0x45, 0x9f, 0x60, 0x3a, 0xa2, 0x9d, 0xb6, 0x45, 0xf0, 0x45, 0x91, 0x5b, 0xe1,
    0x94, 0x88, 0xd9, 0x78, 0x7c, 0x68, 0x54, 0xee, 0xb2, 0x9c, 0x6b, 0xff, 0x1a, 0x32, 0x12, 0x10,
    0x81, 0x80, 0x38, 0x04, 0x97, 0xdc, 0xce, 0x9a, 0x60, 0x2b, 0x25, 0x8d, 0xa9, 0xa2, 0xb9, 0x28,
    0x01, 0x11, 0x1d, 0x8d, 0x25, 0x08, 0x15, 0xa4, 0x13, 0x5d, 0x04, 0x2a, 0x5d, 0x69, 0xbc, 0x1e,
    0x70, 0x11, 0xff, 0xd1, 0x3a, 0xfe, 0x8e, 0x2c, 0xd2, 0x4d, 0x93, 0x9f, 0x26, 0x42, 0x25, 0x07,
    0x3c, 0xc9, 0x2e, 0xa3, 0xda, 0xe6, 0xbd, 0xb0, 0xf3, 0xb9, 0x36, 0x9b, 0xca, 0xb2, 0xd4, 0x02,
    0x50, 0x5d, 0xd4, 0xe1, 0x20, 0xda, 0xd4, 0x22, 0x95, 0xaf, 0x66, 0x5b, 0x75, 0xb8, 0x56, 0x91,
    0xdd, 0x83, 0x88, 0x8d, 0xc2, 0xdc, 0xb8, 0x4e, 0x05, 0xc7, 0x60, 0x46, 0xc2, 0xec, 0xcf, 0xaa,
    0xd7, 0x1a, 0xbc, 0xd6, 0x17, 0x82, 0x55, 0x0a, 0x44, 0x90, 0x90, 0xb0, 0x12, 0xc0, 0x83, 0x00,
    0xc2, 0xda, 0xe1, 0xd7, 0x59, 0xe2, 0x14, 0x75, 0x05, 0x66, 0x25, 0xe3, 0x4b, 0x10, 0x8c, 0xc6,
    0xd0, 0x9a, 0x77, 0xa2, 0xeb, 0x95, 0xe5, 0x73, 0xa4, 0x2d, 0x9b, 0xf5, 0xc0, 0xe9, 0x0c, 0x1c,
    0xb6, 0xe7, 0x2c, 0x60, 0xa1, 0x23, 0x75, 0x95, 0x43, 0x0f, 0xb1, 0x93, 0x9c, 0x2d, 0xe1, 0x3f,
    0x49, 0xdf, 0x02, 0x76, 0x79, 0xbd, 0x20, 0xf2, 0xde, 0xa4, 0x96, 0x62, 0xbb, 0x20, 0x41, 0x7d,
    0x33, 0xc3, 0xd5, 0x44, 0x98, 0x1f, 0x42, 0x0f, 0x43, 0x0f, 0xb6, 0xe7, 0xa7, 0xb1, 0x6b, 0x1f,
    0xa2, 0x28, 0xeb, 0xb0, 0x3a, 0x7a, 0x1a, 0x1d, 0x16, 0x6f, 0x2d, 0xc6, 0x30, 0xb3, 0x36, 0x66,
    0xd4, 0xa4, 0x68, 0x13, 0xad, 0x55, 0xed, 0x2d, 0xf3, 0x41, 0xe3, 0x97, 0x53, 0x04, 0xa7, 0xab,
    0x4f, 0x92, 0x4e, 0x9b, 0x78, 0x66, 0x1d, 0x0c, 0xde, 0xd6, 0xbc, 0xf0, 0x3b, 0x0d, 0x0a, 0xd4,
    0xcd, 0x8f, 0x4d, 0xef, 0xf1, 0x26, 0xee, 0x88, 0x7e, 0x56, 0xfa, 0x4f, 0xa7, 0x14, 0xce, 0x9b,
    0x1d, 0xc6, 0xab, 0xf6, 0x9c, 0xfc, 0x7e, 0xe7, 0x30, 0x6d, 0x36, 0x1c, 0x4f, 0x17, 0x85, 0x3d,
    0xd9, 0x4a, 0x03, 0xf1, 0x64, 0xb1, 0xf6, 0x57, 0x75, 0x8a, 0xb2, 0x5f, 0x56, 0x5b, 0x4a, 0xa7,
    0x54, 0x46, 0xb5, 0xde, 0x62, 0x4c, 0x5c, 0x19, 0x8c, 0x6a, 0x4d, 0x66, 0x27, 0x8b, 0x61, 0xcd,
    0xc4, 0x9d, 0xca, 0xef, 0x46, 0x21, 0x7b, 0x0b, 0xbd, 0xf2, 0x53, 0x97, 0x1f, 0xad, 0x7d, 0x68,
    0x4a, 0xb1, 0x05, 0x4f, 0xef, 0xe1, 0x32, 0x55, 0xdd, 0xb7, 0x2b, 0x50, 0x19, 0x2b, 0x13, 0x97,
    0xf9, 0xd2, 0x7e, 0x6e, 0xf9, 0x17, 0x37, 0x45, 0xae, 0xe3, 0xd6, 0xfe, 0xb1, 0x46, 0x6a, 0x5f,
    0x82, 0x28, 0x98, 0x65, 0x38, 0x2c, 0x28, 0x11, 0x27, 0x96, 0xff, 0xf5, 0x8b, 0x72, 0x39, 0x2d,
    0xae, 0xcf, 0xee, 0xc0, 0x7e, 0x91, 0x05, 0xec, 0xd4, 0x51, 0x6a, 0x9e, 0xca, 0x9d, 0x69, 0x0f,
    0x13, 0xa5, 0xbb, 0x89, 0xa7, 0xbb, 0x4a, 0xb8, 0x7a, 0x63, 0xe9, 0xda, 0xd8, 0x22, 0xc6, 0x09,
    0xbe, 0x13, 0xd5, 0xca, 0x2e, 0xdf, 0x6c, 0x36, 0x64, 0x01, 0xc3, 0x59, 0xb8, 0x98, 0xd6, 0x0a,
    0xbd, 0x4b, 0x0d, 0x57, 0x24, 0xec, 0x98, 0xdf, 0xb2, 0xa6, 0x5c, 0xd7, 0xdd, 0x41, 0xae, 0x05,
    0x8b, 0xdd, 0x52, 0x72, 0x00, 0x6e, 0xba, 0x16, 0xaa, 0xcb, 0xfc, 0x0c, 0x8f, 0xb3, 0x2a, 0xa9,
    0x96, 0x7b, 0x9b, 0xdc, 0x52, 0x92, 0xcb, 0xa7, 0x01, 0xda, 0xa9, 0xcc, 0x6d, 0x05, 0xf6, 0xb7,
    0x5e, 0x2c, 0xce, 0x10, 0xd6, 0x76, 0x12, 0x35, 0x44, 0x9f, 0x84, 0xb2, 0x76, 0x45, 0xea, 0x62,
    0xf0, 0x48, 0x92, 0x42, 0x19, 0x5c, 0xcd, 0x41, 0xbc, 0xf8, 0x76, 0x64, 0x25, 0x57, 0xbc, 0xf2,
    0x6e, 0x6b, 0x49, 0x3b, 0xad, 0x15, 0x9d, 0x4b, 0x4e, 0x69, 0xbc, 0xc3, 0x25, 0xa2, 0x87, 0x53,
    0xec, 0x54, 0xb3, 0x76, 0x9e, 0x65, 0x85, 0xe2, 0x95, 0x8f, 0xeb, 0x2a, 0x55, 0xe7, 0x17, 0xf6,
    0xaa, 0x85, 0x58, 0xe9, 0x1e, 0x6b, 0x4f, 0x0f, 0xbc, 0x73, 0xd8, 0x8d, 0x1b, 0x5d, 0xc3, 0x79,
    0x37, 0x1f, 0x8f, 0x43, 0xfd, 0xbe, 0x1c, 0x8f, 0x0d, 0xb2, 0x54, 0x50, 0xa0, 0x7f, 0x21, 0x78,
    0x26, 0xe7, 0x34, 0x52, 0xa5, 0xc5, 0xf6, 0xf0, 0x19, 0x70, 0x01, 0xfd, 0xab, 0x53, 0xa2, 0x48,
    0x3e, 0x4c, 0xc9, 0xa2, 0x16, 0x7f, 0xf3, 0x23, 0xe2, 0x42, 0xbc, 0xbd, 0x8b, 0x18, 0x1a, 0xf4,
    0x6f, 0xf0, 0xa6, 0xd6, 0x7b, 0xa5, 0xde, 0xc3, 0x0b, 0x3c, 0xbc, 0x87, 0x97, 0x39, 0x91, 0xf3,
    0x8d, 0x4e, 0xf2, 0x7e, 0xfd, 0x0f, 0x89, 0x85, 0xc5, 0x76
};
#endif

PyTypeObject *init_QFont(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX].type;

    Shiboken::AutoDecRef Sbk_QFont_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QFont_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFont",
        "QFont",
        &Sbk_QFont_spec,
        &Shiboken::callCppDestructor< ::QFont >,
        Sbk_QFont_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::Value);
    auto *pyType = Sbk_QFont_TypeF(); // references _Sbk_QFont_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFont_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFont_SignatureBytes, QFont_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFont_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFont_PythonToCpp_QFont_PTR,
        is_QFont_PythonToCpp_QFont_PTR_Convertible,
        QFont_PTR_CppToPython_QFont,
        QFont_COPY_CppToPython_QFont);

    Shiboken::Conversions::registerConverterName(converter, "QFont");
    Shiboken::Conversions::registerConverterName(converter, "QFont*");
    Shiboken::Conversions::registerConverterName(converter, "QFont&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFont).name());

    // Add Python to C++ copy (value, not pointer neither reference) conversion to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        QFont_PythonToCpp_QFont_COPY,
        is_QFont_PythonToCpp_QFont_COPY_Convertible);
    // Add implicit conversions to type converter.
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_constQStringREF_PythonToCpp_QFont,
        is_PySide6_QtCore_constQStringREF_PythonToCpp_QFont_Convertible);
    Shiboken::Conversions::addPythonToCppValueConversion(converter,
        PySide6_QtCore_constQStringListREF_PythonToCpp_QFont,
        is_PySide6_QtCore_constQStringListREF_PythonToCpp_QFont_Convertible);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QFont_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'StyleHint'.
    const char *StyleHint_Initializer[] = {
        "Helvetica",
        "SansSerif",
        "Times",
        "Serif",
        "Courier",
        "TypeWriter",
        "OldEnglish",
        "Decorative",
        "System",
        "AnyStyle",
        "Cursive",
        "Monospace",
        "Fantasy",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StyleHint_InitializerValues[] = {
        uint8_t(QFont::StyleHint::Helvetica),  //  0x00  0
        uint8_t(QFont::StyleHint::SansSerif),  //  0x00  0
        uint8_t(QFont::StyleHint::Times),      //  0x01  1
        uint8_t(QFont::StyleHint::Serif),      //  0x01  1
        uint8_t(QFont::StyleHint::Courier),    //  0x02  2
        uint8_t(QFont::StyleHint::TypeWriter), //  0x02  2
        uint8_t(QFont::StyleHint::OldEnglish), //  0x03  3
        uint8_t(QFont::StyleHint::Decorative), //  0x03  3
        uint8_t(QFont::StyleHint::System),     //  0x04  4
        uint8_t(QFont::StyleHint::AnyStyle),   //  0x05  5
        uint8_t(QFont::StyleHint::Cursive),    //  0x06  6
        uint8_t(QFont::StyleHint::Monospace),  //  0x07  7
        uint8_t(QFont::StyleHint::Fantasy)     //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFont_TypeF(),
        "2:PySide6.QtGui.QFont.StyleHint",
        StyleHint_Initializer, StyleHint_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleHint_IDX].type = EType;
    // Register converter for enum 'QFont::StyleHint'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFont_StyleHint_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFont_StyleHint,
            is_Enum_PythonToCpp_QFont_StyleHint_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFont::StyleHint");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleHint");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleHint' enum.

    // Initialization of enum 'StyleStrategy'.
    const char *StyleStrategy_Initializer[] = {
        "PreferDefault",
        "PreferBitmap",
        "PreferDevice",
        "PreferOutline",
        "ForceOutline",
        "PreferMatch",
        "PreferQuality",
        "PreferAntialias",
        "NoAntialias",
        "NoSubpixelAntialias",
        "PreferNoShaping",
        "ContextFontMerging",
        "PreferTypoLineMetrics",
        "NoFontMerging",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t StyleStrategy_InitializerValues[] = {
        uint16_t(QFont::StyleStrategy::PreferDefault),         //  0x0001  1
        uint16_t(QFont::StyleStrategy::PreferBitmap),          //  0x0002  2
        uint16_t(QFont::StyleStrategy::PreferDevice),          //  0x0004  4
        uint16_t(QFont::StyleStrategy::PreferOutline),         //  0x0008  8
        uint16_t(QFont::StyleStrategy::ForceOutline),          //  0x0010  16
        uint16_t(QFont::StyleStrategy::PreferMatch),           //  0x0020  32
        uint16_t(QFont::StyleStrategy::PreferQuality),         //  0x0040  64
        uint16_t(QFont::StyleStrategy::PreferAntialias),       //  0x0080  128
        uint16_t(QFont::StyleStrategy::NoAntialias),           //  0x0100  256
        uint16_t(QFont::StyleStrategy::NoSubpixelAntialias),   //  0x0800  2048
        uint16_t(QFont::StyleStrategy::PreferNoShaping),       //  0x1000  4096
        uint16_t(QFont::StyleStrategy::ContextFontMerging),    //  0x2000  8192
        uint16_t(QFont::StyleStrategy::PreferTypoLineMetrics), //  0x4000  16384
        uint16_t(QFont::StyleStrategy::NoFontMerging)          //  0x8000  32768
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFont_TypeF(),
        "2:PySide6.QtGui.QFont.StyleStrategy",
        StyleStrategy_Initializer, StyleStrategy_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QFont_StyleStrategy_IDX].type = EType;
    // Register converter for enum 'QFont::StyleStrategy'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFont_StyleStrategy_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFont_StyleStrategy,
            is_Enum_PythonToCpp_QFont_StyleStrategy_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFont::StyleStrategy");
        Shiboken::Conversions::registerConverterAlias(converter, "StyleStrategy");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StyleStrategy' enum.

    // Initialization of enum 'HintingPreference'.
    const char *HintingPreference_Initializer[] = {
        "PreferDefaultHinting",
        "PreferNoHinting",
        "PreferVerticalHinting",
        "PreferFullHinting",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t HintingPreference_InitializerValues[] = {
        uint8_t(QFont::HintingPreference::PreferDefaultHinting),  //  0x00  0
        uint8_t(QFont::HintingPreference::PreferNoHinting),       //  0x01  1
        uint8_t(QFont::HintingPreference::PreferVerticalHinting), //  0x02  2
        uint8_t(QFont::HintingPreference::PreferFullHinting)      //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFont_TypeF(),
        "2:PySide6.QtGui.QFont.HintingPreference",
        HintingPreference_Initializer, HintingPreference_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QFont_HintingPreference_IDX].type = EType;
    // Register converter for enum 'QFont::HintingPreference'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFont_HintingPreference_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFont_HintingPreference,
            is_Enum_PythonToCpp_QFont_HintingPreference_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFont::HintingPreference");
        Shiboken::Conversions::registerConverterAlias(converter, "HintingPreference");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'HintingPreference' enum.

    // Initialization of enum 'Weight'.
    const char *Weight_Initializer[] = {
        "Thin",
        "ExtraLight",
        "Light",
        "Normal",
        "Medium",
        "DemiBold",
        "Bold",
        "ExtraBold",
        "Black",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t Weight_InitializerValues[] = {
        uint16_t(QFont::Weight::Thin),       //  0x0064  100
        uint16_t(QFont::Weight::ExtraLight), //  0x00c8  200
        uint16_t(QFont::Weight::Light),      //  0x012c  300
        uint16_t(QFont::Weight::Normal),     //  0x0190  400
        uint16_t(QFont::Weight::Medium),     //  0x01f4  500
        uint16_t(QFont::Weight::DemiBold),   //  0x0258  600
        uint16_t(QFont::Weight::Bold),       //  0x02bc  700
        uint16_t(QFont::Weight::ExtraBold),  //  0x0320  800
        uint16_t(QFont::Weight::Black)       //  0x0384  900
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFont_TypeF(),
        "2:PySide6.QtGui.QFont.Weight",
        Weight_Initializer, Weight_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QFont_Weight_IDX].type = EType;
    // Register converter for enum 'QFont::Weight'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFont_Weight_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFont_Weight,
            is_Enum_PythonToCpp_QFont_Weight_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFont::Weight");
        Shiboken::Conversions::registerConverterAlias(converter, "Weight");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Weight' enum.

    // Initialization of enum 'Style'.
    const char *Style_Initializer[] = {
        "StyleNormal",
        "StyleItalic",
        "StyleOblique",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Style_InitializerValues[] = {
        uint8_t(QFont::Style::StyleNormal), //  0x00  0
        uint8_t(QFont::Style::StyleItalic), //  0x01  1
        uint8_t(QFont::Style::StyleOblique) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFont_TypeF(),
        "2:PySide6.QtGui.QFont.Style",
        Style_Initializer, Style_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QFont_Style_IDX].type = EType;
    // Register converter for enum 'QFont::Style'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFont_Style_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFont_Style,
            is_Enum_PythonToCpp_QFont_Style_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFont::Style");
        Shiboken::Conversions::registerConverterAlias(converter, "Style");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Style' enum.

    // Initialization of enum 'Stretch'.
    const char *Stretch_Initializer[] = {
        "AnyStretch",
        "UltraCondensed",
        "ExtraCondensed",
        "Condensed",
        "SemiCondensed",
        "Unstretched",
        "SemiExpanded",
        "Expanded",
        "ExtraExpanded",
        "UltraExpanded",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Stretch_InitializerValues[] = {
        uint8_t(QFont::Stretch::AnyStretch),     //  0x00  0
        uint8_t(QFont::Stretch::UltraCondensed), //  0x32  50
        uint8_t(QFont::Stretch::ExtraCondensed), //  0x3e  62
        uint8_t(QFont::Stretch::Condensed),      //  0x4b  75
        uint8_t(QFont::Stretch::SemiCondensed),  //  0x57  87
        uint8_t(QFont::Stretch::Unstretched),    //  0x64  100
        uint8_t(QFont::Stretch::SemiExpanded),   //  0x70  112
        uint8_t(QFont::Stretch::Expanded),       //  0x7d  125
        uint8_t(QFont::Stretch::ExtraExpanded),  //  0x96  150
        uint8_t(QFont::Stretch::UltraExpanded)   //  0xc8  200
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFont_TypeF(),
        "2:PySide6.QtGui.QFont.Stretch",
        Stretch_Initializer, Stretch_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QFont_Stretch_IDX].type = EType;
    // Register converter for enum 'QFont::Stretch'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFont_Stretch_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFont_Stretch,
            is_Enum_PythonToCpp_QFont_Stretch_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFont::Stretch");
        Shiboken::Conversions::registerConverterAlias(converter, "Stretch");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Stretch' enum.

    // Initialization of enum 'Capitalization'.
    const char *Capitalization_Initializer[] = {
        "MixedCase",
        "AllUppercase",
        "AllLowercase",
        "SmallCaps",
        "Capitalize",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Capitalization_InitializerValues[] = {
        uint8_t(QFont::Capitalization::MixedCase),    //  0x00  0
        uint8_t(QFont::Capitalization::AllUppercase), //  0x01  1
        uint8_t(QFont::Capitalization::AllLowercase), //  0x02  2
        uint8_t(QFont::Capitalization::SmallCaps),    //  0x03  3
        uint8_t(QFont::Capitalization::Capitalize)    //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFont_TypeF(),
        "2:PySide6.QtGui.QFont.Capitalization",
        Capitalization_Initializer, Capitalization_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QFont_Capitalization_IDX].type = EType;
    // Register converter for enum 'QFont::Capitalization'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFont_Capitalization_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFont_Capitalization,
            is_Enum_PythonToCpp_QFont_Capitalization_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFont::Capitalization");
        Shiboken::Conversions::registerConverterAlias(converter, "Capitalization");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Capitalization' enum.

    // Initialization of enum 'SpacingType'.
    const char *SpacingType_Initializer[] = {
        "PercentageSpacing",
        "AbsoluteSpacing",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SpacingType_InitializerValues[] = {
        uint8_t(QFont::SpacingType::PercentageSpacing), //  0x00  0
        uint8_t(QFont::SpacingType::AbsoluteSpacing)    //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFont_TypeF(),
        "2:PySide6.QtGui.QFont.SpacingType",
        SpacingType_Initializer, SpacingType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QFont_SpacingType_IDX].type = EType;
    // Register converter for enum 'QFont::SpacingType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFont_SpacingType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFont_SpacingType,
            is_Enum_PythonToCpp_QFont_SpacingType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFont::SpacingType");
        Shiboken::Conversions::registerConverterAlias(converter, "SpacingType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SpacingType' enum.

    qRegisterMetaType< ::QFont >("QFont");
    qRegisterMetaType< ::QFont::StyleHint >("QFont::StyleHint");
    qRegisterMetaType< ::QFont::StyleStrategy >("QFont::StyleStrategy");
    qRegisterMetaType< ::QFont::HintingPreference >("QFont::HintingPreference");
    qRegisterMetaType< ::QFont::Weight >("QFont::Weight");
    qRegisterMetaType< ::QFont::Style >("QFont::Style");
    qRegisterMetaType< ::QFont::Stretch >("QFont::Stretch");
    qRegisterMetaType< ::QFont::Capitalization >("QFont::Capitalization");
    qRegisterMetaType< ::QFont::SpacingType >("QFont::SpacingType");

    return pyType;
}
