// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qpainter_wrapper.h"

// inner classes
#include "qpainter_pixmapfragment_wrapper.h"

// Extra includes
#include <QPainterPath>
#include <QPixmap>
#include <pyside_numpy.h>

// Argument includes
#include <QList>
#include <QPainter>
#include <QString>
#include <QtGui/qbrush.h>
#include <QtGui/qcolor.h>
#include <QtGui/qfont.h>
#include <QtGui/qfontinfo.h>
#include <QtGui/qfontmetrics.h>
#include <QtGui/qglyphrun.h>
#include <QtGui/qimage.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpen.h>
#include <QtGui/qpicture.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qregion.h>
#include <QtGui/qstatictext.h>
#include <QtGui/qtextoption.h>
#include <QtGui/qtransform.h>
#include <qline.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPainter_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPainter >()))
        return -1;

    ::QPainter *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QPainter", 0, 1, &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPainter::QPainter()
    // 1: QPainter::QPainter(QPaintDevice*)
    if (numArgs == 0) {
        overloadId = 0; // QPainter()
    } else if (numArgs == 1
        && (pyArgs[0] != Py_None && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), (pyArgs[0]))))) {
        overloadId = 1; // QPainter(QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPainter()
        {

            // QPainter()
            cptr = new ::QPainter();
            break;
        }
        case 1: // QPainter(QPaintDevice *arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QPaintDevice *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPainter(QPaintDevice*)
                cptr = new ::QPainter(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< ::QPainter >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QPainterFunc___enter__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // __enter__()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtgui.cpp (qpainter-enter)]
        Py_INCREF(self);
        pyResult = self;
        // END of custom code block [file: ../glue/qtgui.cpp (qpainter-enter)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc___exit__(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "__exit__", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::__exit__(PyObject*,PyObject*,PyObject*)
    if (numArgs == 3
        && true
        && true
        && true) {
        overloadId = 0; // __exit__(PyObject*,PyObject*,PyObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "__exit__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // __exit__(PyObject*,PyObject*,PyObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qpainter-exit)]
            cppSelf->end();
            // END of custom code block [file: ../glue/qtgui.cpp (qpainter-exit)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_background(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // background()const
        const QBrush & cppResult = const_cast<const ::QPainter *>(cppSelf)->background();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_backgroundMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // backgroundMode()const
        Qt::BGMode cppResult = const_cast<const ::QPainter *>(cppSelf)->backgroundMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_BGMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_begin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::begin(QPaintDevice*)->bool
    if ((pyArg != Py_None && (pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), (pyArg))))) {
        overloadId = 0; // begin(QPaintDevice*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "begin", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPaintDevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // begin(QPaintDevice*)
            bool cppResult = cppSelf->begin(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_beginNativePainting(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // beginNativePainting()
        cppSelf->beginNativePainting();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_boundingRect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
    if (numArgs == 4 || numArgs == 5)
        return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:boundingRect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::boundingRect(QRect,int,QString)->QRect
    // 1: QPainter::boundingRect(QRectF,QString,const QTextOption&=)->QRectF
    // 2: QPainter::boundingRect(QRectF,int,QString)->QRectF
    // 3: QPainter::boundingRect(int,int,int,int,int,QString)->QRect
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[5])))) {
        overloadId = 3; // boundingRect(int,int,int,int,int,QString)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 0; // boundingRect(QRect,int,QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 2; // boundingRect(QRectF,int,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // boundingRect(QRectF,QString,QTextOption)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), (pyArgs[2])))) {
                overloadId = 1; // boundingRect(QRectF,QString,QTextOption)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // boundingRect(const QRect &rect, int flags, const QString &text)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // boundingRect(QRect,int,QString)
                QRect cppResult = cppSelf->boundingRect(*cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
            }
            break;
        }
        case 1: // boundingRect(const QRectF &rect, const QString &text, const QTextOption &o)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_o = Shiboken::String::createStaticString("o");
                if (PyDict_Contains(kwds, key_o) != 0) {
                    value = PyDict_GetItem(kwds, key_o);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_o);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_o);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QTextOption cppArg2_local = QTextOption();
            ::QTextOption *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2]) {
                if (pythonToCpp[2].isValue())
                    pythonToCpp[2](pyArgs[2], &cppArg2_local);
                else
                    pythonToCpp[2](pyArgs[2], &cppArg2);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // boundingRect(QRectF,QString,QTextOption)
                QRectF cppResult = cppSelf->boundingRect(*cppArg0, cppArg1, *cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
            }
            break;
        }
        case 2: // boundingRect(const QRectF &rect, int flags, const QString &text)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // boundingRect(QRectF,int,QString)
                QRectF cppResult = cppSelf->boundingRect(*cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
            }
            break;
        }
        case 3: // boundingRect(int x, int y, int w, int h, int flags, const QString &text)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "boundingRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QString cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // boundingRect(int,int,int,int,int,QString)
                QRect cppResult = cppSelf->boundingRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_brush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // brush()const
        const QBrush & cppResult = const_cast<const ::QPainter *>(cppSelf)->brush();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_brushOrigin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // brushOrigin()const
        QPoint cppResult = const_cast<const ::QPainter *>(cppSelf)->brushOrigin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_clipBoundingRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clipBoundingRect()const
        QRectF cppResult = const_cast<const ::QPainter *>(cppSelf)->clipBoundingRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_clipPath(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clipPath()const
        QPainterPath cppResult = const_cast<const ::QPainter *>(cppSelf)->clipPath();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_clipRegion(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clipRegion()const
        QRegion cppResult = const_cast<const ::QPainter *>(cppSelf)->clipRegion();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_combinedTransform(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // combinedTransform()const
        QTransform cppResult = const_cast<const ::QPainter *>(cppSelf)->combinedTransform();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_compositionMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // compositionMode()const
        QPainter::CompositionMode cppResult = const_cast<const ::QPainter *>(cppSelf)->compositionMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_CompositionMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_device(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // device()const
        QPaintDevice * cppResult = const_cast<const ::QPainter *>(cppSelf)->device();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_deviceTransform(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // deviceTransform()const
        const QTransform & cppResult = const_cast<const ::QPainter *>(cppSelf)->deviceTransform();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_drawArc(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 5)
        return Shiboken::returnWrongArguments(args, "drawArc", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_UnpackTuple(args, "drawArc", 3, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawArc(QRect,int,int)
    // 1: QPainter::drawArc(QRectF,int,int)
    // 2: QPainter::drawArc(int,int,int,int,int,int)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
        overloadId = 2; // drawArc(int,int,int,int,int,int)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // drawArc(QRect,int,int)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 1; // drawArc(QRectF,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawArc", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawArc(const QRect &arg__1, int a, int alen)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawArc(QRect,int,int)
                cppSelf->drawArc(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // drawArc(const QRectF &rect, int a, int alen)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawArc(QRectF,int,int)
                cppSelf->drawArc(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 2: // drawArc(int x, int y, int w, int h, int a, int alen)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawArc(int,int,int,int,int,int)
                cppSelf->drawArc(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawChord(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 5)
        return Shiboken::returnWrongArguments(args, "drawChord", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_UnpackTuple(args, "drawChord", 3, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawChord(QRect,int,int)
    // 1: QPainter::drawChord(QRectF,int,int)
    // 2: QPainter::drawChord(int,int,int,int,int,int)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
        overloadId = 2; // drawChord(int,int,int,int,int,int)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // drawChord(QRect,int,int)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 1; // drawChord(QRectF,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawChord", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawChord(const QRect &arg__1, int a, int alen)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawChord(QRect,int,int)
                cppSelf->drawChord(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // drawChord(const QRectF &rect, int a, int alen)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawChord(QRectF,int,int)
                cppSelf->drawChord(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 2: // drawChord(int x, int y, int w, int h, int a, int alen)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawChord(int,int,int,int,int,int)
                cppSelf->drawChord(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawConvexPolygon(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::drawConvexPolygon(QList<QPoint>)
    // 1: QPainter::drawConvexPolygon(QList<QPointF>)
    // 2: QPainter::drawConvexPolygon(QPolygon)
    // 3: QPainter::drawConvexPolygon(QPolygonF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPoint_IDX], (pyArg)))) {
        overloadId = 0; // drawConvexPolygon(QList<QPoint>)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygon_IDX]), (pyArg)))) {
        overloadId = 2; // drawConvexPolygon(QPolygon)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPointF_IDX], (pyArg)))) {
        overloadId = 1; // drawConvexPolygon(QList<QPointF>)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), (pyArg)))) {
        overloadId = 3; // drawConvexPolygon(QPolygonF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "drawConvexPolygon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawConvexPolygon(QList<QPoint> points)
        {
            ::QList<QPoint> cppArg0_local;
            ::QList<QPoint> *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);

            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawConvexPolygon(QList<QPoint>)
                // Begin code injection
                // TEMPLATE - qpainter_drawlist - START
                cppSelf->drawConvexPolygon((*cppArg0).constData(), (*cppArg0).size());
                // TEMPLATE - qpainter_drawlist - END
                // End of code injection

            }
            break;
        }
        case 1: // drawConvexPolygon(QList<QPointF> points)
        {
            ::QList<QPointF> cppArg0_local;
            ::QList<QPointF> *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);

            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawConvexPolygon(QList<QPointF>)
                // Begin code injection
                // TEMPLATE - qpainter_drawlist - START
                cppSelf->drawConvexPolygon((*cppArg0).constData(), (*cppArg0).size());
                // TEMPLATE - qpainter_drawlist - END
                // End of code injection

            }
            break;
        }
        case 2: // drawConvexPolygon(const QPolygon &polygon)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPolygon cppArg0_local;
            ::QPolygon *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawConvexPolygon(QPolygon)
                cppSelf->drawConvexPolygon(*cppArg0);
            }
            break;
        }
        case 3: // drawConvexPolygon(const QPolygonF &polygon)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPolygonF cppArg0_local;
            ::QPolygonF *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawConvexPolygon(QPolygonF)
                cppSelf->drawConvexPolygon(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawEllipse(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2)
        return Shiboken::returnWrongArguments(args, "drawEllipse", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_UnpackTuple(args, "drawEllipse", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawEllipse(QPoint,int,int)
    // 1: QPainter::drawEllipse(QPointF,qreal,qreal)
    // 2: QPainter::drawEllipse(QRect)
    // 3: QPainter::drawEllipse(QRectF)
    // 4: QPainter::drawEllipse(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 4; // drawEllipse(int,int,int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))) {
        overloadId = 2; // drawEllipse(QRect)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        overloadId = 3; // drawEllipse(QRectF)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // drawEllipse(QPoint,int,int)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))) {
        overloadId = 1; // drawEllipse(QPointF,qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawEllipse", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawEllipse(const QPoint &center, int rx, int ry)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawEllipse(QPoint,int,int)
                cppSelf->drawEllipse(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // drawEllipse(const QPointF &center, qreal rx, qreal ry)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawEllipse(QPointF,qreal,qreal)
                cppSelf->drawEllipse(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 2: // drawEllipse(const QRect &r)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawEllipse(QRect)
                cppSelf->drawEllipse(*cppArg0);
            }
            break;
        }
        case 3: // drawEllipse(const QRectF &r)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawEllipse(QRectF)
                cppSelf->drawEllipse(*cppArg0);
            }
            break;
        }
        case 4: // drawEllipse(int x, int y, int w, int h)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawEllipse(int,int,int,int)
                cppSelf->drawEllipse(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawGlyphRun(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawGlyphRun", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawGlyphRun(QPointF,QGlyphRun)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGlyphRun_IDX]), (pyArgs[1])))) {
        overloadId = 0; // drawGlyphRun(QPointF,QGlyphRun)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawGlyphRun", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QGlyphRun cppArg1_local;
        ::QGlyphRun *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // drawGlyphRun(QPointF,QGlyphRun)
            cppSelf->drawGlyphRun(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawImage(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 8));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOOO:drawImage", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawImage(QPoint,QImage)
    // 1: QPainter::drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>=)
    // 2: QPainter::drawImage(QPointF,QImage)
    // 3: QPainter::drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>=)
    // 4: QPainter::drawImage(QRect,QImage)
    // 5: QPainter::drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>=)
    // 6: QPainter::drawImage(QRectF,QImage)
    // 7: QPainter::drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>=)
    // 8: QPainter::drawImage(int,int,QImage,int=,int=,int=,int=,QFlags<Qt::ImageConversionFlag>=)
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
                    if (numArgs == 6) {
                        overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                    } else if (numArgs >= 7
                        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))) {
                        if (numArgs == 7) {
                            overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                        } else if (numArgs >= 8
                            && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[7])))) {
                            overloadId = 8; // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                        }
                    }
                }
            }
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 4; // drawImage(QRect,QImage)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 5; // drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[3])))) {
                overloadId = 5; // drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            }
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 6; // drawImage(QRectF,QImage)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 7; // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[3])))) {
                overloadId = 7; // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            }
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // drawImage(QPoint,QImage)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[3])))) {
                overloadId = 1; // drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
            }
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QImage_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // drawImage(QPointF,QImage)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 3; // drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[3])))) {
                overloadId = 3; // drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawImage(const QPoint &p, const QImage &image)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QImage cppArg1_local;
            ::QImage *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawImage(QPoint,QImage)
                cppSelf->drawImage(*cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // drawImage(const QPoint &p, const QImage &image, const QRect &sr, QFlags<Qt::ImageConversionFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QImage cppArg1_local;
            ::QImage *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRect cppArg2_local;
            ::QRect *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            ::QFlags<Qt::ImageConversionFlag> cppArg3(Qt::AutoColor);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawImage(QPoint,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
                cppSelf->drawImage(*cppArg0, *cppArg1, *cppArg2, cppArg3);
            }
            break;
        }
        case 2: // drawImage(const QPointF &p, const QImage &image)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QImage cppArg1_local;
            ::QImage *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawImage(QPointF,QImage)
                cppSelf->drawImage(*cppArg0, *cppArg1);
            }
            break;
        }
        case 3: // drawImage(const QPointF &p, const QImage &image, const QRectF &sr, QFlags<Qt::ImageConversionFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QImage cppArg1_local;
            ::QImage *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRectF cppArg2_local;
            ::QRectF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            ::QFlags<Qt::ImageConversionFlag> cppArg3(Qt::AutoColor);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawImage(QPointF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
                cppSelf->drawImage(*cppArg0, *cppArg1, *cppArg2, cppArg3);
            }
            break;
        }
        case 4: // drawImage(const QRect &r, const QImage &image)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QImage cppArg1_local;
            ::QImage *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawImage(QRect,QImage)
                cppSelf->drawImage(*cppArg0, *cppArg1);
            }
            break;
        }
        case 5: // drawImage(const QRect &targetRect, const QImage &image, const QRect &sourceRect, QFlags<Qt::ImageConversionFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QImage cppArg1_local;
            ::QImage *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRect cppArg2_local;
            ::QRect *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            ::QFlags<Qt::ImageConversionFlag> cppArg3(Qt::AutoColor);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawImage(QRect,QImage,QRect,QFlags<Qt::ImageConversionFlag>)
                cppSelf->drawImage(*cppArg0, *cppArg1, *cppArg2, cppArg3);
            }
            break;
        }
        case 6: // drawImage(const QRectF &r, const QImage &image)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QImage cppArg1_local;
            ::QImage *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawImage(QRectF,QImage)
                cppSelf->drawImage(*cppArg0, *cppArg1);
            }
            break;
        }
        case 7: // drawImage(const QRectF &targetRect, const QImage &image, const QRectF &sourceRect, QFlags<Qt::ImageConversionFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QImage cppArg1_local;
            ::QImage *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRectF cppArg2_local;
            ::QRectF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            ::QFlags<Qt::ImageConversionFlag> cppArg3(Qt::AutoColor);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawImage(QRectF,QImage,QRectF,QFlags<Qt::ImageConversionFlag>)
                cppSelf->drawImage(*cppArg0, *cppArg1, *cppArg2, cppArg3);
            }
            break;
        }
        case 8: // drawImage(int x, int y, const QImage &image, int sx, int sy, int sw, int sh, QFlags<Qt::ImageConversionFlag> flags)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sx = Shiboken::String::createStaticString("sx");
                if (PyDict_Contains(kwds, key_sx) != 0) {
                    value = PyDict_GetItem(kwds, key_sx);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_sx);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sx);
                }
                static PyObject *const key_sy = Shiboken::String::createStaticString("sy");
                if (PyDict_Contains(kwds, key_sy) != 0) {
                    value = PyDict_GetItem(kwds, key_sy);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_sy);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sy);
                }
                static PyObject *const key_sw = Shiboken::String::createStaticString("sw");
                if (PyDict_Contains(kwds, key_sw) != 0) {
                    value = PyDict_GetItem(kwds, key_sw);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_sw);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sw);
                }
                static PyObject *const key_sh = Shiboken::String::createStaticString("sh");
                if (PyDict_Contains(kwds, key_sh) != 0) {
                    value = PyDict_GetItem(kwds, key_sh);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_sh);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sh);
                }
                static PyObject *const key_flags = Shiboken::String::createStaticString("flags");
                if (PyDict_Contains(kwds, key_flags) != 0) {
                    value = PyDict_GetItem(kwds, key_flags);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_flags);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_ImageConversionFlag_IDX])))->flagsConverter, (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_flags);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawImage", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QImage cppArg2_local;
            ::QImage *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            int cppArg3 = 0;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = 0;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5 = -1;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6 = -1;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            ::QFlags<Qt::ImageConversionFlag> cppArg7(Qt::AutoColor);
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawImage(int,int,QImage,int,int,int,int,QFlags<Qt::ImageConversionFlag>)
                cppSelf->drawImage(cppArg0, cppArg1, *cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawLine(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3)
        return Shiboken::returnWrongArguments(args, "drawLine", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_UnpackTuple(args, "drawLine", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawLine(QLine)
    // 1: QPainter::drawLine(QLineF)
    // 2: QPainter::drawLine(QPoint,QPoint)
    // 3: QPainter::drawLine(QPointF,QPointF)
    // 4: QPainter::drawLine(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 4; // drawLine(int,int,int,int)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[1])))) {
        overloadId = 2; // drawLine(QPoint,QPoint)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))) {
        overloadId = 3; // drawLine(QPointF,QPointF)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), (pyArgs[0])))) {
        overloadId = 0; // drawLine(QLine)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArgs[0])))) {
        overloadId = 1; // drawLine(QLineF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawLine", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawLine(const QLine &line)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLine cppArg0_local;
            ::QLine *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawLine(QLine)
                cppSelf->drawLine(*cppArg0);
            }
            break;
        }
        case 1: // drawLine(const QLineF &line)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLineF cppArg0_local;
            ::QLineF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawLine(QLineF)
                cppSelf->drawLine(*cppArg0);
            }
            break;
        }
        case 2: // drawLine(const QPoint &p1, const QPoint &p2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPoint cppArg1_local;
            ::QPoint *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawLine(QPoint,QPoint)
                cppSelf->drawLine(*cppArg0, *cppArg1);
            }
            break;
        }
        case 3: // drawLine(const QPointF &p1, const QPointF &p2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawLine(QPointF,QPointF)
                cppSelf->drawLine(*cppArg0, *cppArg1);
            }
            break;
        }
        case 4: // drawLine(int x1, int y1, int x2, int y2)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawLine(int,int,int,int)
                cppSelf->drawLine(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawLines(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawLines", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawLines(const QLineF*,int)
    // 1: QPainter::drawLines(QList<QLine>)
    // 2: QPainter::drawLines(QList<QLineF>)
    // 3: QPainter::drawLines(QList<QPoint>)
    // 4: QPainter::drawLines(QList<QPointF>)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPoint_IDX], (pyArgs[0])))) {
        overloadId = 3; // drawLines(QList<QPoint>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPointF_IDX], (pyArgs[0])))) {
        overloadId = 4; // drawLines(QList<QPointF>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QLine_IDX], (pyArgs[0])))) {
        overloadId = 1; // drawLines(QList<QLine>)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // drawLines(const QLineF*,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QLineF_IDX], (pyArgs[0])))) {
        overloadId = 2; // drawLines(QList<QLineF>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawLines", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawLines(const QLineF *lines, int lineCount)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLineF *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawLines(const QLineF*,int)
                cppSelf->drawLines(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // drawLines(const QList<QLine> &lines)
        {
            ::QList<QLine> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawLines(QList<QLine>)
                cppSelf->drawLines(cppArg0);
            }
            break;
        }
        case 2: // drawLines(const QList<QLineF> &lines)
        {
            ::QList<QLineF> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawLines(QList<QLineF>)
                cppSelf->drawLines(cppArg0);
            }
            break;
        }
        case 3: // drawLines(const QList<QPoint> &pointPairs)
        {
            ::QList<QPoint> cppArg0_local;
            ::QList<QPoint> *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawLines(QList<QPoint>)
                cppSelf->drawLines(*cppArg0);
            }
            break;
        }
        case 4: // drawLines(const QList<QPointF> &pointPairs)
        {
            ::QList<QPointF> cppArg0_local;
            ::QList<QPointF> *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawLines(QList<QPointF>)
                cppSelf->drawLines(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawPath(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::drawPath(QPainterPath)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), (pyArg)))) {
        overloadId = 0; // drawPath(QPainterPath)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "drawPath", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPainterPath cppArg0_local;
        ::QPainterPath *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // drawPath(QPainterPath)
            cppSelf->drawPath(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawPicture(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawPicture", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawPicture(QPoint,QPicture)
    // 1: QPainter::drawPicture(QPointF,QPicture)
    // 2: QPainter::drawPicture(int,int,QPicture)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPicture_IDX]), (pyArgs[2])))) {
        overloadId = 2; // drawPicture(int,int,QPicture)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPicture_IDX]), (pyArgs[1])))) {
        overloadId = 0; // drawPicture(QPoint,QPicture)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPicture_IDX]), (pyArgs[1])))) {
        overloadId = 1; // drawPicture(QPointF,QPicture)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawPicture", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawPicture(const QPoint &p, const QPicture &picture)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPicture cppArg1_local;
            ::QPicture *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPicture(QPoint,QPicture)
                cppSelf->drawPicture(*cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // drawPicture(const QPointF &p, const QPicture &picture)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPicture cppArg1_local;
            ::QPicture *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPicture(QPointF,QPicture)
                cppSelf->drawPicture(*cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // drawPicture(int x, int y, const QPicture &picture)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPicture cppArg2_local;
            ::QPicture *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPicture(int,int,QPicture)
                cppSelf->drawPicture(cppArg0, cppArg1, *cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawPie(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 5)
        return Shiboken::returnWrongArguments(args, "drawPie", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_UnpackTuple(args, "drawPie", 3, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawPie(QRect,int,int)
    // 1: QPainter::drawPie(QRectF,int,int)
    // 2: QPainter::drawPie(int,int,int,int,int,int)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
        overloadId = 2; // drawPie(int,int,int,int,int,int)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // drawPie(QRect,int,int)
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 1; // drawPie(QRectF,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawPie", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawPie(const QRect &arg__1, int a, int alen)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPie(QRect,int,int)
                cppSelf->drawPie(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // drawPie(const QRectF &rect, int a, int alen)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPie(QRectF,int,int)
                cppSelf->drawPie(*cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 2: // drawPie(int x, int y, int w, int h, int a, int alen)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPie(int,int,int,int,int,int)
                cppSelf->drawPie(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawPixmap(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 4 || numArgs == 6 || numArgs == 8)
        return Shiboken::returnWrongArguments(args, "drawPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_UnpackTuple(args, "drawPixmap", 2, 9, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawPixmap(QPoint,QPixmap)
    // 1: QPainter::drawPixmap(QPoint,QPixmap,QRect)
    // 2: QPainter::drawPixmap(QPointF,QPixmap)
    // 3: QPainter::drawPixmap(QPointF,QPixmap,QRectF)
    // 4: QPainter::drawPixmap(QRect,QPixmap)
    // 5: QPainter::drawPixmap(QRect,QPixmap,QRect)
    // 6: QPainter::drawPixmap(QRectF,QPixmap,QRectF)
    // 7: QPainter::drawPixmap(int,int,QPixmap)
    // 8: QPainter::drawPixmap(int,int,QPixmap,int,int,int,int)
    // 9: QPainter::drawPixmap(int,int,int,int,QPixmap)
    // 10: QPainter::drawPixmap(int,int,int,int,QPixmap,int,int,int,int)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs >= 5
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[4])))) {
            if (numArgs == 5) {
                overloadId = 9; // drawPixmap(int,int,int,int,QPixmap)
            } else if (numArgs == 9
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))
                && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))
                && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8])))) {
                overloadId = 10; // drawPixmap(int,int,int,int,QPixmap,int,int,int,int)
            }
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 7; // drawPixmap(int,int,QPixmap)
            } else if (numArgs == 7
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))) {
                overloadId = 8; // drawPixmap(int,int,QPixmap,int,int,int,int)
            }
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 4; // drawPixmap(QRect,QPixmap)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[2])))) {
            overloadId = 5; // drawPixmap(QRect,QPixmap,QRect)
        }
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[2])))) {
        overloadId = 6; // drawPixmap(QRectF,QPixmap,QRectF)
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // drawPixmap(QPoint,QPixmap)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[2])))) {
            overloadId = 1; // drawPixmap(QPoint,QPixmap,QRect)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 2; // drawPixmap(QPointF,QPixmap)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[2])))) {
            overloadId = 3; // drawPixmap(QPointF,QPixmap,QRectF)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawPixmap(const QPoint &p, const QPixmap &pm)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPixmap cppArg1_local;
            ::QPixmap *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPixmap(QPoint,QPixmap)
                cppSelf->drawPixmap(*cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // drawPixmap(const QPoint &p, const QPixmap &pm, const QRect &sr)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPixmap cppArg1_local;
            ::QPixmap *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRect cppArg2_local;
            ::QRect *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPixmap(QPoint,QPixmap,QRect)
                cppSelf->drawPixmap(*cppArg0, *cppArg1, *cppArg2);
            }
            break;
        }
        case 2: // drawPixmap(const QPointF &p, const QPixmap &pm)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPixmap cppArg1_local;
            ::QPixmap *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPixmap(QPointF,QPixmap)
                cppSelf->drawPixmap(*cppArg0, *cppArg1);
            }
            break;
        }
        case 3: // drawPixmap(const QPointF &p, const QPixmap &pm, const QRectF &sr)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPixmap cppArg1_local;
            ::QPixmap *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRectF cppArg2_local;
            ::QRectF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPixmap(QPointF,QPixmap,QRectF)
                cppSelf->drawPixmap(*cppArg0, *cppArg1, *cppArg2);
            }
            break;
        }
        case 4: // drawPixmap(const QRect &r, const QPixmap &pm)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPixmap cppArg1_local;
            ::QPixmap *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPixmap(QRect,QPixmap)
                cppSelf->drawPixmap(*cppArg0, *cppArg1);
            }
            break;
        }
        case 5: // drawPixmap(const QRect &targetRect, const QPixmap &pixmap, const QRect &sourceRect)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPixmap cppArg1_local;
            ::QPixmap *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRect cppArg2_local;
            ::QRect *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPixmap(QRect,QPixmap,QRect)
                cppSelf->drawPixmap(*cppArg0, *cppArg1, *cppArg2);
            }
            break;
        }
        case 6: // drawPixmap(const QRectF &targetRect, const QPixmap &pixmap, const QRectF &sourceRect)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPixmap cppArg1_local;
            ::QPixmap *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QRectF cppArg2_local;
            ::QRectF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPixmap(QRectF,QPixmap,QRectF)
                cppSelf->drawPixmap(*cppArg0, *cppArg1, *cppArg2);
            }
            break;
        }
        case 7: // drawPixmap(int x, int y, const QPixmap &pm)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPixmap cppArg2_local;
            ::QPixmap *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPixmap(int,int,QPixmap)
                cppSelf->drawPixmap(cppArg0, cppArg1, *cppArg2);
            }
            break;
        }
        case 8: // drawPixmap(int x, int y, const QPixmap &pm, int sx, int sy, int sw, int sh)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPixmap cppArg2_local;
            ::QPixmap *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPixmap(int,int,QPixmap,int,int,int,int)
                cppSelf->drawPixmap(cppArg0, cppArg1, *cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
            }
            break;
        }
        case 9: // drawPixmap(int x, int y, int w, int h, const QPixmap &pm)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QPixmap cppArg4_local;
            ::QPixmap *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4].isValue())
                pythonToCpp[4](pyArgs[4], &cppArg4_local);
            else
                pythonToCpp[4](pyArgs[4], &cppArg4);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPixmap(int,int,int,int,QPixmap)
                cppSelf->drawPixmap(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4);
            }
            break;
        }
        case 10: // drawPixmap(int x, int y, int w, int h, const QPixmap &pm, int sx, int sy, int sw, int sh)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QPixmap cppArg4_local;
            ::QPixmap *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4].isValue())
                pythonToCpp[4](pyArgs[4], &cppArg4_local);
            else
                pythonToCpp[4](pyArgs[4], &cppArg4);

            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            int cppArg7;
            pythonToCpp[7](pyArgs[7], &cppArg7);
            int cppArg8;
            pythonToCpp[8](pyArgs[8], &cppArg8);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPixmap(int,int,int,int,QPixmap,int,int,int,int)
                cppSelf->drawPixmap(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawPixmapFragments(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "drawPixmapFragments", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:drawPixmapFragments", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawPixmapFragments(const QPainter::PixmapFragment*,int,QPixmap,QFlags<QPainter::PixmapFragmentHint>=)
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_PixmapFragment_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // drawPixmapFragments(const QPainter::PixmapFragment*,int,QPixmap,QFlags<QPainter::PixmapFragmentHint>)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPainter_PixmapFragmentHint_IDX])))->flagsConverter, (pyArgs[3])))) {
            overloadId = 0; // drawPixmapFragments(const QPainter::PixmapFragment*,int,QPixmap,QFlags<QPainter::PixmapFragmentHint>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawPixmapFragments", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_hints = Shiboken::String::createStaticString("hints");
            if (PyDict_Contains(kwds, key_hints) != 0) {
                value = PyDict_GetItem(kwds, key_hints);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_hints);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "drawPixmapFragments", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPainter_PixmapFragmentHint_IDX])))->flagsConverter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "drawPixmapFragments", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_hints);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "drawPixmapFragments", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter::PixmapFragment *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPixmap cppArg2_local;
        ::QPixmap *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2].isValue())
            pythonToCpp[2](pyArgs[2], &cppArg2_local);
        else
            pythonToCpp[2](pyArgs[2], &cppArg2);

        ::QFlags<QPainter::PixmapFragmentHint> cppArg3 = QPainter::PixmapFragmentHints();
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawPixmapFragments(const QPainter::PixmapFragment*,int,QPixmap,QFlags<QPainter::PixmapFragmentHint>)
            cppSelf->drawPixmapFragments(cppArg0, cppArg1, *cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawPoint(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawPoint", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawPoint(QPoint)
    // 1: QPainter::drawPoint(QPointF)
    // 2: QPainter::drawPoint(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 2; // drawPoint(int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))) {
        overloadId = 0; // drawPoint(QPoint)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        overloadId = 1; // drawPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawPoint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawPoint(const QPoint &p)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPoint(QPoint)
                cppSelf->drawPoint(*cppArg0);
            }
            break;
        }
        case 1: // drawPoint(const QPointF &pt)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPoint(QPointF)
                cppSelf->drawPoint(*cppArg0);
            }
            break;
        }
        case 2: // drawPoint(int x, int y)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPoint(int,int)
                cppSelf->drawPoint(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawPoints(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawPoints", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawPoints(QList<QPoint>)
    // 1: QPainter::drawPoints(QList<QPointF>)
    // 2: QPainter::drawPoints(const QPointF*,int)
    // 3: QPainter::drawPoints(QPolygon)
    // 4: QPainter::drawPoints(QPolygonF)
    if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygon_IDX]), (pyArgs[0])))) {
        overloadId = 3; // drawPoints(QPolygon)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), (pyArgs[0])))) {
        overloadId = 4; // drawPoints(QPolygonF)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPoint_IDX], (pyArgs[0])))) {
        overloadId = 0; // drawPoints(QList<QPoint>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPointF_IDX], (pyArgs[0])))) {
        overloadId = 1; // drawPoints(QList<QPointF>)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 2; // drawPoints(const QPointF*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawPoints", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawPoints(QList<QPoint> points)
        {
            ::QList<QPoint> cppArg0_local;
            ::QList<QPoint> *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPoints(QList<QPoint>)
                // Begin code injection
                // TEMPLATE - qpainter_drawlist - START
                cppSelf->drawPoints((*cppArg0).constData(), (*cppArg0).size());
                // TEMPLATE - qpainter_drawlist - END
                // End of code injection

            }
            break;
        }
        case 1: // drawPoints(QList<QPointF> points)
        {
            ::QList<QPointF> cppArg0_local;
            ::QList<QPointF> *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPoints(QList<QPointF>)
                // Begin code injection
                // TEMPLATE - qpainter_drawlist - START
                cppSelf->drawPoints((*cppArg0).constData(), (*cppArg0).size());
                // TEMPLATE - qpainter_drawlist - END
                // End of code injection

            }
            break;
        }
        case 2: // drawPoints(const QPointF *points, int pointCount)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPoints(const QPointF*,int)
                cppSelf->drawPoints(cppArg0, cppArg1);
            }
            break;
        }
        case 3: // drawPoints(const QPolygon &points)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPolygon cppArg0_local;
            ::QPolygon *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPoints(QPolygon)
                cppSelf->drawPoints(*cppArg0);
            }
            break;
        }
        case 4: // drawPoints(const QPolygonF &points)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPolygonF cppArg0_local;
            ::QPolygonF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPoints(QPolygonF)
                cppSelf->drawPoints(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawPointsNp(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawPointsNp", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawPointsNp(PyArrayObject*,PyArrayObject*)
    if (numArgs == 2
        && PyArray_Check(pyArgs[0])
        && PyArray_Check(pyArgs[1])) {
        overloadId = 0; // drawPointsNp(PyArrayObject*,PyArrayObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawPointsNp", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawPointsNp(PyArrayObject*,PyArrayObject*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qpainter-drawpointsnp-numpy-x-y)]
            const auto points = PySide::Numpy::xyDataToQPointFList(pyArgs[1-1], pyArgs[2-1]);
            cppSelf->drawPoints(points);
            // END of custom code block [file: ../glue/qtgui.cpp (qpainter-drawpointsnp-numpy-x-y)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawPolygon(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "drawPolygon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OO:drawPolygon", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawPolygon(QList<QPoint>,Qt::FillRule)
    // 1: QPainter::drawPolygon(QList<QPointF>,Qt::FillRule)
    // 2: QPainter::drawPolygon(QPolygon,Qt::FillRule=)
    // 3: QPainter::drawPolygon(QPolygonF,Qt::FillRule=)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPoint_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FillRule_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // drawPolygon(QList<QPoint>,Qt::FillRule)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygon_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // drawPolygon(QPolygon,Qt::FillRule)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FillRule_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 2; // drawPolygon(QPolygon,Qt::FillRule)
        }
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPointF_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FillRule_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 1; // drawPolygon(QList<QPointF>,Qt::FillRule)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // drawPolygon(QPolygonF,Qt::FillRule)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FillRule_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 3; // drawPolygon(QPolygonF,Qt::FillRule)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawPolygon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawPolygon(QList<QPoint> points, Qt::FillRule fill_rule)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "drawPolygon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            ::QList<QPoint> cppArg0_local;
            ::QList<QPoint> *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)
            ::Qt::FillRule cppArg1{Qt::OddEvenFill};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPolygon(QList<QPoint>,Qt::FillRule)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qpainter-drawpolygon)]
                cppSelf->drawPolygon((*cppArg0).constData(), (*cppArg0).size(), cppArg1);
                // END of custom code block [file: ../glue/qtgui.cpp (qpainter-drawpolygon)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 1: // drawPolygon(QList<QPointF> points, Qt::FillRule fill_rule)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "drawPolygon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            ::QList<QPointF> cppArg0_local;
            ::QList<QPointF> *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            SBK_UNUSED(cppArg0)
            ::Qt::FillRule cppArg1{Qt::OddEvenFill};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            SBK_UNUSED(cppArg1)

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPolygon(QList<QPointF>,Qt::FillRule)
                // Begin code injection
                // ========================================================================
                // START of custom code block [file: ../glue/qtgui.cpp (qpainter-drawpolygon)]
                cppSelf->drawPolygon((*cppArg0).constData(), (*cppArg0).size(), cppArg1);
                // END of custom code block [file: ../glue/qtgui.cpp (qpainter-drawpolygon)]
                // ========================================================================
                // End of code injection

            }
            break;
        }
        case 2: // drawPolygon(const QPolygon &polygon, Qt::FillRule fillRule)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_fillRule = Shiboken::String::createStaticString("fillRule");
                if (PyDict_Contains(kwds, key_fillRule) != 0) {
                    value = PyDict_GetItem(kwds, key_fillRule);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_fillRule);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawPolygon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FillRule_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "drawPolygon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_fillRule);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawPolygon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPolygon cppArg0_local;
            ::QPolygon *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::FillRule cppArg1(Qt::OddEvenFill);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPolygon(QPolygon,Qt::FillRule)
                cppSelf->drawPolygon(*cppArg0, cppArg1);
            }
            break;
        }
        case 3: // drawPolygon(const QPolygonF &polygon, Qt::FillRule fillRule)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_fillRule = Shiboken::String::createStaticString("fillRule");
                if (PyDict_Contains(kwds, key_fillRule) != 0) {
                    value = PyDict_GetItem(kwds, key_fillRule);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_fillRule);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawPolygon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FillRule_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "drawPolygon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_fillRule);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawPolygon", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPolygonF cppArg0_local;
            ::QPolygonF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::FillRule cppArg1(Qt::OddEvenFill);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPolygon(QPolygonF,Qt::FillRule)
                cppSelf->drawPolygon(*cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawPolyline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::drawPolyline(QList<QPoint>)
    // 1: QPainter::drawPolyline(QList<QPointF>)
    // 2: QPainter::drawPolyline(QPolygon)
    // 3: QPainter::drawPolyline(QPolygonF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygon_IDX]), (pyArg)))) {
        overloadId = 2; // drawPolyline(QPolygon)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), (pyArg)))) {
        overloadId = 3; // drawPolyline(QPolygonF)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPoint_IDX], (pyArg)))) {
        overloadId = 0; // drawPolyline(QList<QPoint>)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QPointF_IDX], (pyArg)))) {
        overloadId = 1; // drawPolyline(QList<QPointF>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "drawPolyline", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawPolyline(QList<QPoint> points)
        {
            ::QList<QPoint> cppArg0_local;
            ::QList<QPoint> *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);

            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPolyline(QList<QPoint>)
                // Begin code injection
                // TEMPLATE - qpainter_drawlist - START
                cppSelf->drawPolyline((*cppArg0).constData(), (*cppArg0).size());
                // TEMPLATE - qpainter_drawlist - END
                // End of code injection

            }
            break;
        }
        case 1: // drawPolyline(QList<QPointF> points)
        {
            ::QList<QPointF> cppArg0_local;
            ::QList<QPointF> *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);

            SBK_UNUSED(cppArg0)

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPolyline(QList<QPointF>)
                // Begin code injection
                // TEMPLATE - qpainter_drawlist - START
                cppSelf->drawPolyline((*cppArg0).constData(), (*cppArg0).size());
                // TEMPLATE - qpainter_drawlist - END
                // End of code injection

            }
            break;
        }
        case 2: // drawPolyline(const QPolygon &polygon)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPolygon cppArg0_local;
            ::QPolygon *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPolyline(QPolygon)
                cppSelf->drawPolyline(*cppArg0);
            }
            break;
        }
        case 3: // drawPolyline(const QPolygonF &polyline)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPolygonF cppArg0_local;
            ::QPolygonF *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawPolyline(QPolygonF)
                cppSelf->drawPolyline(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawRect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "drawRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_UnpackTuple(args, "drawRect", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawRect(QRect)
    // 1: QPainter::drawRect(QRectF)
    // 2: QPainter::drawRect(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 2; // drawRect(int,int,int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))) {
        overloadId = 0; // drawRect(QRect)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        overloadId = 1; // drawRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawRect(const QRect &rect)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawRect(QRect)
                cppSelf->drawRect(*cppArg0);
            }
            break;
        }
        case 1: // drawRect(const QRectF &rect)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawRect(QRectF)
                cppSelf->drawRect(*cppArg0);
            }
            break;
        }
        case 2: // drawRect(int x1, int y1, int w, int h)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawRect(int,int,int,int)
                cppSelf->drawRect(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawRects(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawRects", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawRects(QList<QRect>)
    // 1: QPainter::drawRects(QList<QRectF>)
    // 2: QPainter::drawRects(const QRectF*,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 2; // drawRects(const QRectF*,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRect_IDX], (pyArgs[0])))) {
        overloadId = 0; // drawRects(QList<QRect>)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRectF_IDX], (pyArgs[0])))) {
        overloadId = 1; // drawRects(QList<QRectF>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawRects", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawRects(const QList<QRect> &rectangles)
        {
            ::QList<QRect> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawRects(QList<QRect>)
                cppSelf->drawRects(cppArg0);
            }
            break;
        }
        case 1: // drawRects(const QList<QRectF> &rectangles)
        {
            ::QList<QRectF> cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawRects(QList<QRectF>)
                cppSelf->drawRects(cppArg0);
            }
            break;
        }
        case 2: // drawRects(const QRectF *rects, int rectCount)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawRects(const QRectF*,int)
                cppSelf->drawRects(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawRoundedRect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 7));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "drawRoundedRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
    if (numArgs == 5)
        return Shiboken::returnWrongArguments(args, "drawRoundedRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOO:drawRoundedRect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode=)
    // 1: QPainter::drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode=)
    // 2: QPainter::drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode=)
    if (numArgs >= 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[5])))) {
        if (numArgs == 6) {
            overloadId = 2; // drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode)
        } else if (numArgs >= 7
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SizeMode_IDX])))->converter, (pyArgs[6])))) {
            overloadId = 2; // drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode)
        }
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SizeMode_IDX])))->converter, (pyArgs[3])))) {
            overloadId = 0; // drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode)
        }
    } else if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 1; // drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SizeMode_IDX])))->converter, (pyArgs[3])))) {
            overloadId = 1; // drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawRoundedRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawRoundedRect(const QRect &rect, qreal xRadius, qreal yRadius, Qt::SizeMode mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawRoundedRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SizeMode_IDX])))->converter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "drawRoundedRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawRoundedRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::Qt::SizeMode cppArg3(Qt::AbsoluteSize);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawRoundedRect(QRect,qreal,qreal,Qt::SizeMode)
                cppSelf->drawRoundedRect(*cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // drawRoundedRect(const QRectF &rect, qreal xRadius, qreal yRadius, Qt::SizeMode mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawRoundedRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SizeMode_IDX])))->converter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "drawRoundedRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawRoundedRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::Qt::SizeMode cppArg3(Qt::AbsoluteSize);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawRoundedRect(QRectF,qreal,qreal,Qt::SizeMode)
                cppSelf->drawRoundedRect(*cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 2: // drawRoundedRect(int x, int y, int w, int h, qreal xRadius, qreal yRadius, Qt::SizeMode mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawRoundedRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SizeMode_IDX])))->converter, (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, "drawRoundedRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawRoundedRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            qreal cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            qreal cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            ::Qt::SizeMode cppArg6(Qt::AbsoluteSize);
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawRoundedRect(int,int,int,int,qreal,qreal,Qt::SizeMode)
                cppSelf->drawRoundedRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawStaticText(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawStaticText", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawStaticText(QPoint,QStaticText)
    // 1: QPainter::drawStaticText(QPointF,QStaticText)
    // 2: QPainter::drawStaticText(int,int,QStaticText)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStaticText_IDX]), (pyArgs[2])))) {
        overloadId = 2; // drawStaticText(int,int,QStaticText)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStaticText_IDX]), (pyArgs[1])))) {
        overloadId = 0; // drawStaticText(QPoint,QStaticText)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QStaticText_IDX]), (pyArgs[1])))) {
        overloadId = 1; // drawStaticText(QPointF,QStaticText)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawStaticText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawStaticText(const QPoint &topLeftPosition, const QStaticText &staticText)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QStaticText cppArg1_local;
            ::QStaticText *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawStaticText(QPoint,QStaticText)
                cppSelf->drawStaticText(*cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // drawStaticText(const QPointF &topLeftPosition, const QStaticText &staticText)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QStaticText cppArg1_local;
            ::QStaticText *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawStaticText(QPointF,QStaticText)
                cppSelf->drawStaticText(*cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // drawStaticText(int left, int top, const QStaticText &staticText)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QStaticText cppArg2_local;
            ::QStaticText *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // drawStaticText(int,int,QStaticText)
                cppSelf->drawStaticText(cppArg0, cppArg1, *cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawText(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "drawText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
    if (numArgs == 4 || numArgs == 5)
        return Shiboken::returnWrongArguments(args, "drawText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:drawText", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawText(QPoint,QString)
    // 1: QPainter::drawText(QPointF,QString)
    // 2: QPainter::drawText(QRect,int,QString,QRect*)
    // 3: QPainter::drawText(QRectF,QString,const QTextOption&=)
    // 4: QPainter::drawText(QRectF,int,QString,QRectF*)
    // 5: QPainter::drawText(int,int,QString)
    // 6: QPainter::drawText(int,int,int,int,int,QString,QRect*)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        if (numArgs == 6
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[5])))) {
            overloadId = 6; // drawText(int,int,int,int,int,QString,QRect*)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 5; // drawText(int,int,QString)
        }
    } else if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
        overloadId = 2; // drawText(QRect,int,QString,QRect*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        if (numArgs == 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
            overloadId = 4; // drawText(QRectF,int,QString,QRectF*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // drawText(QRectF,QString,QTextOption)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), (pyArgs[2])))) {
                overloadId = 3; // drawText(QRectF,QString,QTextOption)
            }
        }
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // drawText(QPoint,QString)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 1; // drawText(QPointF,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawText(const QPoint &p, const QString &s)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "drawText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawText(QPoint,QString)
                cppSelf->drawText(*cppArg0, cppArg1);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 1: // drawText(const QPointF &p, const QString &s)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "drawText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawText(QPointF,QString)
                cppSelf->drawText(*cppArg0, cppArg1);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 2: // drawText(const QRect &r, int flags, const QString &text, QRect *br)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "drawText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawText(QRect,int,QString,QRect*)
                // Begin code injection
                // TEMPLATE - fix_args,QRect* - START
                QRect rect_;
                cppSelf->drawText((*cppArg0), cppArg1, cppArg2, &rect_);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect_);
                // TEMPLATE - fix_args,QRect* - END
                // End of code injection

            }
            break;
        }
        case 3: // drawText(const QRectF &r, const QString &text, const QTextOption &o)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_o = Shiboken::String::createStaticString("o");
                if (PyDict_Contains(kwds, key_o) != 0) {
                    value = PyDict_GetItem(kwds, key_o);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_o);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "drawText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_o);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QString cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QTextOption cppArg2_local = QTextOption();
            ::QTextOption *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2]) {
                if (pythonToCpp[2].isValue())
                    pythonToCpp[2](pyArgs[2], &cppArg2_local);
                else
                    pythonToCpp[2](pyArgs[2], &cppArg2);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawText(QRectF,QString,QTextOption)
                cppSelf->drawText(*cppArg0, cppArg1, *cppArg2);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 4: // drawText(const QRectF &r, int flags, const QString &text, QRectF *br)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "drawText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawText(QRectF,int,QString,QRectF*)
                // Begin code injection
                // TEMPLATE - fix_args,QRectF* - START
                QRectF rect_;
                cppSelf->drawText((*cppArg0), cppArg1, cppArg2, &rect_);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &rect_);
                // TEMPLATE - fix_args,QRectF* - END
                // End of code injection

            }
            break;
        }
        case 5: // drawText(int x, int y, const QString &s)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "drawText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawText(int,int,QString)
                cppSelf->drawText(cppArg0, cppArg1, cppArg2);
                pyResult = Py_None;
                Py_INCREF(Py_None);
            }
            break;
        }
        case 6: // drawText(int x, int y, int w, int h, int flags, const QString &text, QRect *br)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "drawText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::QString cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawText(int,int,int,int,int,QString,QRect*)
                // Begin code injection
                // TEMPLATE - fix_args,QRect* - START
                QRect rect_;
                cppSelf->drawText(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, &rect_);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &rect_);
                // TEMPLATE - fix_args,QRect* - END
                // End of code injection

            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_drawTextItem(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawTextItem", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawTextItem(QPoint,QTextItem)
    // 1: QPainter::drawTextItem(QPointF,QTextItem)
    // 2: QPainter::drawTextItem(int,int,QTextItem)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX]), (pyArgs[2])))) {
        overloadId = 2; // drawTextItem(int,int,QTextItem)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX]), (pyArgs[1])))) {
        overloadId = 0; // drawTextItem(QPoint,QTextItem)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextItem_IDX]), (pyArgs[1])))) {
        overloadId = 1; // drawTextItem(QPointF,QTextItem)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawTextItem", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawTextItem(const QPoint &p, const QTextItem &ti)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTextItem *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawTextItem(QPoint,QTextItem)
                cppSelf->drawTextItem(*cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // drawTextItem(const QPointF &p, const QTextItem &ti)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTextItem *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawTextItem(QPointF,QTextItem)
                cppSelf->drawTextItem(*cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // drawTextItem(int x, int y, const QTextItem &ti)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QTextItem *cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawTextItem(int,int,QTextItem)
                cppSelf->drawTextItem(cppArg0, cppArg1, *cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_drawTiledPixmap(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 7));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
    if (numArgs == 4)
        return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOO:drawTiledPixmap", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::drawTiledPixmap(QRect,QPixmap,const QPoint&=)
    // 1: QPainter::drawTiledPixmap(QRectF,QPixmap,const QPointF&=)
    // 2: QPainter::drawTiledPixmap(int,int,int,int,QPixmap,int=,int=)
    if (numArgs >= 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[4])))) {
        if (numArgs == 5) {
            overloadId = 2; // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
        } else if (numArgs >= 6
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 2; // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))) {
                overloadId = 2; // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
            }
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // drawTiledPixmap(QRect,QPixmap,QPoint)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[2])))) {
            overloadId = 0; // drawTiledPixmap(QRect,QPixmap,QPoint)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // drawTiledPixmap(QRectF,QPixmap,QPointF)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[2])))) {
            overloadId = 1; // drawTiledPixmap(QRectF,QPixmap,QPointF)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // drawTiledPixmap(const QRect &arg__1, const QPixmap &arg__2, const QPoint &pos)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_pos = Shiboken::String::createStaticString("pos");
                if (PyDict_Contains(kwds, key_pos) != 0) {
                    value = PyDict_GetItem(kwds, key_pos);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_pos);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pos);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPixmap cppArg1_local;
            ::QPixmap *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPoint cppArg2_local = QPoint();
            ::QPoint *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2]) {
                if (pythonToCpp[2].isValue())
                    pythonToCpp[2](pyArgs[2], &cppArg2_local);
                else
                    pythonToCpp[2](pyArgs[2], &cppArg2);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawTiledPixmap(QRect,QPixmap,QPoint)
                cppSelf->drawTiledPixmap(*cppArg0, *cppArg1, *cppArg2);
            }
            break;
        }
        case 1: // drawTiledPixmap(const QRectF &rect, const QPixmap &pm, const QPointF &offset)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_offset = Shiboken::String::createStaticString("offset");
                if (PyDict_Contains(kwds, key_offset) != 0) {
                    value = PyDict_GetItem(kwds, key_offset);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_offset);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_offset);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPixmap cppArg1_local;
            ::QPixmap *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPointF cppArg2_local = QPointF();
            ::QPointF *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2]) {
                if (pythonToCpp[2].isValue())
                    pythonToCpp[2](pyArgs[2], &cppArg2_local);
                else
                    pythonToCpp[2](pyArgs[2], &cppArg2);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawTiledPixmap(QRectF,QPixmap,QPointF)
                cppSelf->drawTiledPixmap(*cppArg0, *cppArg1, *cppArg2);
            }
            break;
        }
        case 2: // drawTiledPixmap(int x, int y, int w, int h, const QPixmap &arg__5, int sx, int sy)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sx = Shiboken::String::createStaticString("sx");
                if (PyDict_Contains(kwds, key_sx) != 0) {
                    value = PyDict_GetItem(kwds, key_sx);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_sx);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sx);
                }
                static PyObject *const key_sy = Shiboken::String::createStaticString("sy");
                if (PyDict_Contains(kwds, key_sy) != 0) {
                    value = PyDict_GetItem(kwds, key_sy);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_sy);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sy);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "drawTiledPixmap", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QPixmap cppArg4_local;
            ::QPixmap *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4].isValue())
                pythonToCpp[4](pyArgs[4], &cppArg4_local);
            else
                pythonToCpp[4](pyArgs[4], &cppArg4);

            int cppArg5 = 0;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6 = 0;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // drawTiledPixmap(int,int,int,int,QPixmap,int,int)
                cppSelf->drawTiledPixmap(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4, cppArg5, cppArg6);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_end(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // end()
        bool cppResult = cppSelf->end();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_endNativePainting(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // endNativePainting()
        cppSelf->endNativePainting();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_eraseRect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "eraseRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_UnpackTuple(args, "eraseRect", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::eraseRect(QRect)
    // 1: QPainter::eraseRect(QRectF)
    // 2: QPainter::eraseRect(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 2; // eraseRect(int,int,int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))) {
        overloadId = 0; // eraseRect(QRect)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        overloadId = 1; // eraseRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "eraseRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // eraseRect(const QRect &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // eraseRect(QRect)
                cppSelf->eraseRect(*cppArg0);
            }
            break;
        }
        case 1: // eraseRect(const QRectF &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // eraseRect(QRectF)
                cppSelf->eraseRect(*cppArg0);
            }
            break;
        }
        case 2: // eraseRect(int x, int y, int w, int h)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // eraseRect(int,int,int,int)
                cppSelf->eraseRect(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_fillPath(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "fillPath", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::fillPath(QPainterPath,QBrush)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[1])))) {
        overloadId = 0; // fillPath(QPainterPath,QBrush)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fillPath", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainterPath cppArg0_local;
        ::QPainterPath *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QBrush cppArg1_local;
        ::QBrush *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // fillPath(QPainterPath,QBrush)
            cppSelf->fillPath(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_fillRect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3 || numArgs == 4)
        return Shiboken::returnWrongArguments(args, "fillRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_UnpackTuple(args, "fillRect", 2, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::fillRect(QRect,QBrush)
    // 1: QPainter::fillRect(QRect,QColor)
    // 2: QPainter::fillRect(QRect,QGradient::Preset)
    // 3: QPainter::fillRect(QRect,Qt::BrushStyle)
    // 4: QPainter::fillRect(QRect,Qt::GlobalColor)
    // 5: QPainter::fillRect(QRectF,QBrush)
    // 6: QPainter::fillRect(QRectF,QColor)
    // 7: QPainter::fillRect(QRectF,QGradient::Preset)
    // 8: QPainter::fillRect(QRectF,Qt::BrushStyle)
    // 9: QPainter::fillRect(QRectF,Qt::GlobalColor)
    // 10: QPainter::fillRect(int,int,int,int,QGradient::Preset)
    // 11: QPainter::fillRect(int,int,int,int,Qt::BrushStyle)
    // 12: QPainter::fillRect(int,int,int,int,Qt::GlobalColor)
    // 13: QPainter::fillRect(int,int,int,int,QBrush)
    // 14: QPainter::fillRect(int,int,int,int,QColor)
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        if (numArgs == 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_GlobalColor_IDX])))->converter, (pyArgs[4])))) {
            overloadId = 12; // fillRect(int,int,int,int,Qt::GlobalColor)
        } else if (numArgs == 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_BrushStyle_IDX])))->converter, (pyArgs[4])))) {
            overloadId = 11; // fillRect(int,int,int,int,Qt::BrushStyle)
        } else if (numArgs == 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Preset_IDX])))->converter, (pyArgs[4])))) {
            overloadId = 10; // fillRect(int,int,int,int,QGradient::Preset)
        } else if (numArgs == 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[4])))) {
            overloadId = 14; // fillRect(int,int,int,int,QColor)
        } else if (numArgs == 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[4])))) {
            overloadId = 13; // fillRect(int,int,int,int,QBrush)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_GlobalColor_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 4; // fillRect(QRect,Qt::GlobalColor)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_BrushStyle_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 3; // fillRect(QRect,Qt::BrushStyle)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Preset_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 2; // fillRect(QRect,QGradient::Preset)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[1])))) {
            overloadId = 1; // fillRect(QRect,QColor)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[1])))) {
            overloadId = 0; // fillRect(QRect,QBrush)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_GlobalColor_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 9; // fillRect(QRectF,Qt::GlobalColor)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_BrushStyle_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 8; // fillRect(QRectF,Qt::BrushStyle)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QGradient_Preset_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 7; // fillRect(QRectF,QGradient::Preset)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[1])))) {
            overloadId = 6; // fillRect(QRectF,QColor)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[1])))) {
            overloadId = 5; // fillRect(QRectF,QBrush)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "fillRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // fillRect(const QRect &arg__1, const QBrush &arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QBrush cppArg1_local;
            ::QBrush *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(QRect,QBrush)
                cppSelf->fillRect(*cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // fillRect(const QRect &arg__1, const QColor &color)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QColor cppArg1_local;
            ::QColor *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(QRect,QColor)
                cppSelf->fillRect(*cppArg0, *cppArg1);
            }
            break;
        }
        case 2: // fillRect(const QRect &r, QGradient::Preset preset)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QGradient::Preset cppArg1 = static_cast< ::QGradient::Preset>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(QRect,QGradient::Preset)
                cppSelf->fillRect(*cppArg0, cppArg1);
            }
            break;
        }
        case 3: // fillRect(const QRect &r, Qt::BrushStyle style)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::BrushStyle cppArg1{Qt::NoBrush};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(QRect,Qt::BrushStyle)
                cppSelf->fillRect(*cppArg0, cppArg1);
            }
            break;
        }
        case 4: // fillRect(const QRect &r, Qt::GlobalColor c)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::GlobalColor cppArg1{Qt::color0};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(QRect,Qt::GlobalColor)
                cppSelf->fillRect(*cppArg0, cppArg1);
            }
            break;
        }
        case 5: // fillRect(const QRectF &arg__1, const QBrush &arg__2)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QBrush cppArg1_local;
            ::QBrush *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(QRectF,QBrush)
                cppSelf->fillRect(*cppArg0, *cppArg1);
            }
            break;
        }
        case 6: // fillRect(const QRectF &arg__1, const QColor &color)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QColor cppArg1_local;
            ::QColor *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(QRectF,QColor)
                cppSelf->fillRect(*cppArg0, *cppArg1);
            }
            break;
        }
        case 7: // fillRect(const QRectF &r, QGradient::Preset preset)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QGradient::Preset cppArg1 = static_cast< ::QGradient::Preset>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(QRectF,QGradient::Preset)
                cppSelf->fillRect(*cppArg0, cppArg1);
            }
            break;
        }
        case 8: // fillRect(const QRectF &r, Qt::BrushStyle style)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::BrushStyle cppArg1{Qt::NoBrush};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(QRectF,Qt::BrushStyle)
                cppSelf->fillRect(*cppArg0, cppArg1);
            }
            break;
        }
        case 9: // fillRect(const QRectF &r, Qt::GlobalColor c)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::GlobalColor cppArg1{Qt::color0};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(QRectF,Qt::GlobalColor)
                cppSelf->fillRect(*cppArg0, cppArg1);
            }
            break;
        }
        case 10: // fillRect(int x, int y, int w, int h, QGradient::Preset preset)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QGradient::Preset cppArg4 = static_cast< ::QGradient::Preset>(0);
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(int,int,int,int,QGradient::Preset)
                cppSelf->fillRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 11: // fillRect(int x, int y, int w, int h, Qt::BrushStyle style)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::Qt::BrushStyle cppArg4{Qt::NoBrush};
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(int,int,int,int,Qt::BrushStyle)
                cppSelf->fillRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 12: // fillRect(int x, int y, int w, int h, Qt::GlobalColor c)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::Qt::GlobalColor cppArg4{Qt::color0};
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(int,int,int,int,Qt::GlobalColor)
                cppSelf->fillRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 13: // fillRect(int x, int y, int w, int h, const QBrush &arg__5)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QBrush cppArg4_local;
            ::QBrush *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4].isValue())
                pythonToCpp[4](pyArgs[4], &cppArg4_local);
            else
                pythonToCpp[4](pyArgs[4], &cppArg4);


            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(int,int,int,int,QBrush)
                cppSelf->fillRect(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4);
            }
            break;
        }
        case 14: // fillRect(int x, int y, int w, int h, const QColor &color)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QColor cppArg4_local;
            ::QColor *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4].isValue())
                pythonToCpp[4](pyArgs[4], &cppArg4_local);
            else
                pythonToCpp[4](pyArgs[4], &cppArg4);


            if (Shiboken::Errors::occurred() == nullptr) {
                // fillRect(int,int,int,int,QColor)
                cppSelf->fillRect(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_font(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // font()const
        const QFont & cppResult = const_cast<const ::QPainter *>(cppSelf)->font();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_fontInfo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fontInfo()const
        QFontInfo cppResult = const_cast<const ::QPainter *>(cppSelf)->fontInfo();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontInfo_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_fontMetrics(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fontMetrics()const
        QFontMetrics cppResult = const_cast<const ::QPainter *>(cppSelf)->fontMetrics();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFontMetrics_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_hasClipping(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasClipping()const
        bool cppResult = const_cast<const ::QPainter *>(cppSelf)->hasClipping();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_isActive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isActive()const
        bool cppResult = const_cast<const ::QPainter *>(cppSelf)->isActive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_layoutDirection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // layoutDirection()const
        Qt::LayoutDirection cppResult = const_cast<const ::QPainter *>(cppSelf)->layoutDirection();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_opacity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // opacity()const
        qreal cppResult = const_cast<const ::QPainter *>(cppSelf)->opacity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_paintEngine(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // paintEngine()const
        QPaintEngine * cppResult = const_cast<const ::QPainter *>(cppSelf)->paintEngine();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_pen(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pen()const
        const QPen & cppResult = const_cast<const ::QPainter *>(cppSelf)->pen();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_renderHints(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // renderHints()const
        QFlags<QPainter::RenderHint> cppResult = const_cast<const ::QPainter *>(cppSelf)->renderHints();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPainter_RenderHint_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_resetTransform(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetTransform()
        cppSelf->resetTransform();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_restore(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // restore()
        cppSelf->restore();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_rotate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::rotate(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // rotate(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "rotate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // rotate(qreal)
            cppSelf->rotate(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_save(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // save()
        cppSelf->save();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_scale(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "scale", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::scale(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // scale(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scale", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scale(qreal,qreal)
            cppSelf->scale(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setBackground(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::setBackground(QBrush)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArg)))) {
        overloadId = 0; // setBackground(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackground", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBrush cppArg0_local;
        ::QBrush *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackground(QBrush)
            cppSelf->setBackground(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setBackgroundMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::setBackgroundMode(Qt::BGMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_BGMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setBackgroundMode(Qt::BGMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackgroundMode", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        ::Qt::BGMode cppArg0{Qt::TransparentMode};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackgroundMode(Qt::BGMode)
            cppSelf->setBackgroundMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setBrush(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::setBrush(Qt::BrushStyle)
    // 1: QPainter::setBrush(QBrush)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_BrushStyle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setBrush(Qt::BrushStyle)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArg)))) {
        overloadId = 1; // setBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBrush", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setBrush(Qt::BrushStyle style)
        {
            ::Qt::BrushStyle cppArg0{Qt::NoBrush};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setBrush(Qt::BrushStyle)
                cppSelf->setBrush(cppArg0);
            }
            break;
        }
        case 1: // setBrush(const QBrush &brush)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QBrush cppArg0_local;
            ::QBrush *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setBrush(QBrush)
                cppSelf->setBrush(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setBrushOrigin(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setBrushOrigin", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::setBrushOrigin(QPoint)
    // 1: QPainter::setBrushOrigin(QPointF)
    // 2: QPainter::setBrushOrigin(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 2; // setBrushOrigin(int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setBrushOrigin(QPoint)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        overloadId = 1; // setBrushOrigin(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setBrushOrigin", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setBrushOrigin(const QPoint &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setBrushOrigin(QPoint)
                cppSelf->setBrushOrigin(*cppArg0);
            }
            break;
        }
        case 1: // setBrushOrigin(const QPointF &arg__1)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setBrushOrigin(QPointF)
                cppSelf->setBrushOrigin(*cppArg0);
            }
            break;
        }
        case 2: // setBrushOrigin(int x, int y)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setBrushOrigin(int,int)
                cppSelf->setBrushOrigin(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setClipPath(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setClipPath", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setClipPath", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::setClipPath(QPainterPath,Qt::ClipOperation=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setClipPath(QPainterPath,Qt::ClipOperation)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ClipOperation_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setClipPath(QPainterPath,Qt::ClipOperation)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setClipPath", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_op = Shiboken::String::createStaticString("op");
            if (PyDict_Contains(kwds, key_op) != 0) {
                value = PyDict_GetItem(kwds, key_op);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_op);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setClipPath", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ClipOperation_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setClipPath", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_op);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setClipPath", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainterPath cppArg0_local;
        ::QPainterPath *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::Qt::ClipOperation cppArg1(Qt::ReplaceClip);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setClipPath(QPainterPath,Qt::ClipOperation)
            cppSelf->setClipPath(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setClipRect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
    if (numArgs == 3)
        return Shiboken::returnWrongArguments(args, "setClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:setClipRect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::setClipRect(QRect,Qt::ClipOperation=)
    // 1: QPainter::setClipRect(QRectF,Qt::ClipOperation=)
    // 2: QPainter::setClipRect(int,int,int,int,Qt::ClipOperation=)
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 2; // setClipRect(int,int,int,int,Qt::ClipOperation)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ClipOperation_IDX])))->converter, (pyArgs[4])))) {
            overloadId = 2; // setClipRect(int,int,int,int,Qt::ClipOperation)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setClipRect(QRect,Qt::ClipOperation)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ClipOperation_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setClipRect(QRect,Qt::ClipOperation)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // setClipRect(QRectF,Qt::ClipOperation)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ClipOperation_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // setClipRect(QRectF,Qt::ClipOperation)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setClipRect(const QRect &arg__1, Qt::ClipOperation op)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_op = Shiboken::String::createStaticString("op");
                if (PyDict_Contains(kwds, key_op) != 0) {
                    value = PyDict_GetItem(kwds, key_op);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_op);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ClipOperation_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "setClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_op);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::ClipOperation cppArg1(Qt::ReplaceClip);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setClipRect(QRect,Qt::ClipOperation)
                cppSelf->setClipRect(*cppArg0, cppArg1);
            }
            break;
        }
        case 1: // setClipRect(const QRectF &arg__1, Qt::ClipOperation op)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_op = Shiboken::String::createStaticString("op");
                if (PyDict_Contains(kwds, key_op) != 0) {
                    value = PyDict_GetItem(kwds, key_op);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_op);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ClipOperation_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "setClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_op);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::ClipOperation cppArg1(Qt::ReplaceClip);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setClipRect(QRectF,Qt::ClipOperation)
                cppSelf->setClipRect(*cppArg0, cppArg1);
            }
            break;
        }
        case 2: // setClipRect(int x, int y, int w, int h, Qt::ClipOperation op)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_op = Shiboken::String::createStaticString("op");
                if (PyDict_Contains(kwds, key_op) != 0) {
                    value = PyDict_GetItem(kwds, key_op);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_op);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ClipOperation_IDX])))->converter, (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "setClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_op);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setClipRect", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
            }
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::Qt::ClipOperation cppArg4(Qt::ReplaceClip);
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setClipRect(int,int,int,int,Qt::ClipOperation)
                cppSelf->setClipRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setClipRegion(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setClipRegion", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setClipRegion", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::setClipRegion(QRegion,Qt::ClipOperation=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRegion_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setClipRegion(QRegion,Qt::ClipOperation)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ClipOperation_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setClipRegion(QRegion,Qt::ClipOperation)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setClipRegion", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_op = Shiboken::String::createStaticString("op");
            if (PyDict_Contains(kwds, key_op) != 0) {
                value = PyDict_GetItem(kwds, key_op);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_op);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setClipRegion", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ClipOperation_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setClipRegion", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_op);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setClipRegion", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRegion cppArg0_local;
        ::QRegion *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::Qt::ClipOperation cppArg1(Qt::ReplaceClip);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setClipRegion(QRegion,Qt::ClipOperation)
            cppSelf->setClipRegion(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setClipping(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::setClipping(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setClipping(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setClipping", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setClipping(bool)
            cppSelf->setClipping(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setCompositionMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::setCompositionMode(QPainter::CompositionMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_CompositionMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setCompositionMode(QPainter::CompositionMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCompositionMode", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        ::QPainter::CompositionMode cppArg0{QPainter::CompositionMode_SourceOver};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCompositionMode(QPainter::CompositionMode)
            cppSelf->setCompositionMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setFont(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::setFont(QFont)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFont", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFont(QFont)
            cppSelf->setFont(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setLayoutDirection(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::setLayoutDirection(Qt::LayoutDirection)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_LayoutDirection_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setLayoutDirection(Qt::LayoutDirection)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLayoutDirection", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        ::Qt::LayoutDirection cppArg0{Qt::LeftToRight};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayoutDirection(Qt::LayoutDirection)
            cppSelf->setLayoutDirection(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setOpacity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::setOpacity(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setOpacity(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOpacity", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOpacity(qreal)
            cppSelf->setOpacity(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setPen(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::setPen(Qt::PenStyle)
    // 1: QPainter::setPen(QColor)
    // 2: QPainter::setPen(QPen)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_PenStyle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPen(Qt::PenStyle)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArg)))) {
        overloadId = 1; // setPen(QColor)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArg)))) {
        overloadId = 2; // setPen(QPen)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPen", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setPen(Qt::PenStyle style)
        {
            ::Qt::PenStyle cppArg0{Qt::NoPen};
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setPen(Qt::PenStyle)
                cppSelf->setPen(cppArg0);
            }
            break;
        }
        case 1: // setPen(const QColor &color)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QColor cppArg0_local;
            ::QColor *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setPen(QColor)
                cppSelf->setPen(*cppArg0);
            }
            break;
        }
        case 2: // setPen(const QPen &pen)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QPen cppArg0_local;
            ::QPen *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setPen(QPen)
                cppSelf->setPen(*cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setRenderHint(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setRenderHint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setRenderHint", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::setRenderHint(QPainter::RenderHint,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_RenderHint_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setRenderHint(QPainter::RenderHint,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setRenderHint(QPainter::RenderHint,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRenderHint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_on = Shiboken::String::createStaticString("on");
            if (PyDict_Contains(kwds, key_on) != 0) {
                value = PyDict_GetItem(kwds, key_on);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_on);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setRenderHint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setRenderHint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_on);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setRenderHint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
        }
        ::QPainter::RenderHint cppArg0 = static_cast< ::QPainter::RenderHint>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRenderHint(QPainter::RenderHint,bool)
            cppSelf->setRenderHint(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setRenderHints(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setRenderHints", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setRenderHints", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::setRenderHints(QFlags<QPainter::RenderHint>,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPainter_RenderHint_IDX])))->flagsConverter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setRenderHints(QFlags<QPainter::RenderHint>,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setRenderHints(QFlags<QPainter::RenderHint>,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setRenderHints", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_on = Shiboken::String::createStaticString("on");
            if (PyDict_Contains(kwds, key_on) != 0) {
                value = PyDict_GetItem(kwds, key_on);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_on);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setRenderHints", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setRenderHints", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_on);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setRenderHints", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
        }
        ::QFlags<QPainter::RenderHint> cppArg0 = QFlags<QPainter::RenderHint>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRenderHints(QFlags<QPainter::RenderHint>,bool)
            cppSelf->setRenderHints(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setTransform(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setTransform", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setTransform", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::setTransform(QTransform,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setTransform(QTransform,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setTransform(QTransform,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setTransform", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_combine = Shiboken::String::createStaticString("combine");
            if (PyDict_Contains(kwds, key_combine) != 0) {
                value = PyDict_GetItem(kwds, key_combine);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_combine);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setTransform", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setTransform", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_combine);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setTransform", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTransform cppArg0_local;
        ::QTransform *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = false;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTransform(QTransform,bool)
            cppSelf->setTransform(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setViewTransformEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::setViewTransformEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setViewTransformEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setViewTransformEnabled", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setViewTransformEnabled(bool)
            cppSelf->setViewTransformEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setViewport(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "setViewport", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_UnpackTuple(args, "setViewport", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::setViewport(QRect)
    // 1: QPainter::setViewport(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 1; // setViewport(int,int,int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setViewport(QRect)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setViewport", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setViewport(const QRect &viewport)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setViewport(QRect)
                cppSelf->setViewport(*cppArg0);
            }
            break;
        }
        case 1: // setViewport(int x, int y, int w, int h)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setViewport(int,int,int,int)
                cppSelf->setViewport(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setWindow(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "setWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_UnpackTuple(args, "setWindow", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::setWindow(QRect)
    // 1: QPainter::setWindow(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 1; // setWindow(int,int,int,int)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setWindow(QRect)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setWindow", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setWindow(const QRect &window)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRect cppArg0_local;
            ::QRect *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setWindow(QRect)
                cppSelf->setWindow(*cppArg0);
            }
            break;
        }
        case 1: // setWindow(int x, int y, int w, int h)
        {
            int cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setWindow(int,int,int,int)
                cppSelf->setWindow(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setWorldMatrixEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::setWorldMatrixEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setWorldMatrixEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWorldMatrixEnabled", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWorldMatrixEnabled(bool)
            cppSelf->setWorldMatrixEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_setWorldTransform(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setWorldTransform", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setWorldTransform", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::setWorldTransform(QTransform,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setWorldTransform(QTransform,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setWorldTransform(QTransform,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setWorldTransform", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_combine = Shiboken::String::createStaticString("combine");
            if (PyDict_Contains(kwds, key_combine) != 0) {
                value = PyDict_GetItem(kwds, key_combine);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_combine);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setWorldTransform", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setWorldTransform", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_combine);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setWorldTransform", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTransform cppArg0_local;
        ::QTransform *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = false;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWorldTransform(QTransform,bool)
            cppSelf->setWorldTransform(*cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_shear(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "shear", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::shear(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // shear(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "shear", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // shear(qreal,qreal)
            cppSelf->shear(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_strokePath(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "strokePath", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::strokePath(QPainterPath,QPen)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[1])))) {
        overloadId = 0; // strokePath(QPainterPath,QPen)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "strokePath", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainterPath cppArg0_local;
        ::QPainterPath *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPen cppArg1_local;
        ::QPen *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // strokePath(QPainterPath,QPen)
            cppSelf->strokePath(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_testRenderHint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPainter::testRenderHint(QPainter::RenderHint)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_RenderHint_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // testRenderHint(QPainter::RenderHint)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "testRenderHint", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    {
        ::QPainter::RenderHint cppArg0 = static_cast< ::QPainter::RenderHint>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // testRenderHint(QPainter::RenderHint)const
            bool cppResult = const_cast<const ::QPainter *>(cppSelf)->testRenderHint(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_transform(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transform()const
        const QTransform & cppResult = const_cast<const ::QPainter *>(cppSelf)->transform();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_translate(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "translate", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPainter::translate(QPoint)
    // 1: QPainter::translate(QPointF)
    // 2: QPainter::translate(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 2; // translate(qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))) {
        overloadId = 0; // translate(QPoint)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        overloadId = 1; // translate(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "translate", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // translate(const QPoint &offset)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // translate(QPoint)
                cppSelf->translate(*cppArg0);
            }
            break;
        }
        case 1: // translate(const QPointF &offset)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // translate(QPointF)
                cppSelf->translate(*cppArg0);
            }
            break;
        }
        case 2: // translate(qreal dx, qreal dy)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // translate(qreal,qreal)
                cppSelf->translate(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPainterFunc_viewTransformEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewTransformEnabled()const
        bool cppResult = const_cast<const ::QPainter *>(cppSelf)->viewTransformEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_viewport(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewport()const
        QRect cppResult = const_cast<const ::QPainter *>(cppSelf)->viewport();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_window(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // window()const
        QRect cppResult = const_cast<const ::QPainter *>(cppSelf)->window();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_worldMatrixEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // worldMatrixEnabled()const
        bool cppResult = const_cast<const ::QPainter *>(cppSelf)->worldMatrixEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPainterFunc_worldTransform(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPainter *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // worldTransform()const
        const QTransform & cppResult = const_cast<const ::QPainter *>(cppSelf)->worldTransform();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QPainter_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QPainter_EnumFlagInfo[] = {
    "CompositionMode:Enum",
    "PixmapFragmentHint:Flag:PixmapFragmentHints",
    "RenderHint:Flag:RenderHints",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPainter_methods[] = {
    {"__enter__", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc___enter__), METH_NOARGS, nullptr},
    {"__exit__", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc___exit__), METH_VARARGS, nullptr},
    {"background", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_background), METH_NOARGS, nullptr},
    {"backgroundMode", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_backgroundMode), METH_NOARGS, nullptr},
    {"begin", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_begin), METH_O, nullptr},
    {"beginNativePainting", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_beginNativePainting), METH_NOARGS, nullptr},
    {"boundingRect", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_boundingRect), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"brush", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_brush), METH_NOARGS, nullptr},
    {"brushOrigin", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_brushOrigin), METH_NOARGS, nullptr},
    {"clipBoundingRect", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_clipBoundingRect), METH_NOARGS, nullptr},
    {"clipPath", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_clipPath), METH_NOARGS, nullptr},
    {"clipRegion", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_clipRegion), METH_NOARGS, nullptr},
    {"combinedTransform", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_combinedTransform), METH_NOARGS, nullptr},
    {"compositionMode", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_compositionMode), METH_NOARGS, nullptr},
    {"device", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_device), METH_NOARGS, nullptr},
    {"deviceTransform", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_deviceTransform), METH_NOARGS, nullptr},
    {"drawArc", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawArc), METH_VARARGS, nullptr},
    {"drawChord", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawChord), METH_VARARGS, nullptr},
    {"drawConvexPolygon", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawConvexPolygon), METH_O, nullptr},
    {"drawEllipse", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawEllipse), METH_VARARGS, nullptr},
    {"drawGlyphRun", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawGlyphRun), METH_VARARGS, nullptr},
    {"drawImage", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawImage), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"drawLine", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawLine), METH_VARARGS, nullptr},
    {"drawLines", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawLines), METH_VARARGS, nullptr},
    {"drawPath", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawPath), METH_O, nullptr},
    {"drawPicture", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawPicture), METH_VARARGS, nullptr},
    {"drawPie", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawPie), METH_VARARGS, nullptr},
    {"drawPixmap", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawPixmap), METH_VARARGS, nullptr},
    {"drawPixmapFragments", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawPixmapFragments), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"drawPoint", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawPoint), METH_VARARGS, nullptr},
    {"drawPoints", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawPoints), METH_VARARGS, nullptr},
    {"drawPointsNp", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawPointsNp), METH_VARARGS, nullptr},
    {"drawPolygon", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawPolygon), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"drawPolyline", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawPolyline), METH_O, nullptr},
    {"drawRect", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawRect), METH_VARARGS, nullptr},
    {"drawRects", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawRects), METH_VARARGS, nullptr},
    {"drawRoundedRect", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawRoundedRect), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"drawStaticText", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawStaticText), METH_VARARGS, nullptr},
    {"drawText", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawText), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"drawTextItem", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawTextItem), METH_VARARGS, nullptr},
    {"drawTiledPixmap", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_drawTiledPixmap), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"end", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_end), METH_NOARGS, nullptr},
    {"endNativePainting", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_endNativePainting), METH_NOARGS, nullptr},
    {"eraseRect", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_eraseRect), METH_VARARGS, nullptr},
    {"fillPath", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_fillPath), METH_VARARGS, nullptr},
    {"fillRect", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_fillRect), METH_VARARGS, nullptr},
    {"font", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_font), METH_NOARGS, nullptr},
    {"fontInfo", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_fontInfo), METH_NOARGS, nullptr},
    {"fontMetrics", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_fontMetrics), METH_NOARGS, nullptr},
    {"hasClipping", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_hasClipping), METH_NOARGS, nullptr},
    {"isActive", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_isActive), METH_NOARGS, nullptr},
    {"layoutDirection", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_layoutDirection), METH_NOARGS, nullptr},
    {"opacity", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_opacity), METH_NOARGS, nullptr},
    {"paintEngine", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_paintEngine), METH_NOARGS, nullptr},
    {"pen", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_pen), METH_NOARGS, nullptr},
    {"renderHints", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_renderHints), METH_NOARGS, nullptr},
    {"resetTransform", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_resetTransform), METH_NOARGS, nullptr},
    {"restore", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_restore), METH_NOARGS, nullptr},
    {"rotate", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_rotate), METH_O, nullptr},
    {"save", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_save), METH_NOARGS, nullptr},
    {"scale", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_scale), METH_VARARGS, nullptr},
    {"setBackground", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setBackground), METH_O, nullptr},
    {"setBackgroundMode", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setBackgroundMode), METH_O, nullptr},
    {"setBrush", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setBrush), METH_O, nullptr},
    {"setBrushOrigin", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setBrushOrigin), METH_VARARGS, nullptr},
    {"setClipPath", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setClipPath), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setClipRect", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setClipRect), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setClipRegion", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setClipRegion), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setClipping", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setClipping), METH_O, nullptr},
    {"setCompositionMode", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setCompositionMode), METH_O, nullptr},
    {"setFont", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setFont), METH_O, nullptr},
    {"setLayoutDirection", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setLayoutDirection), METH_O, nullptr},
    {"setOpacity", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setOpacity), METH_O, nullptr},
    {"setPen", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setPen), METH_O, nullptr},
    {"setRenderHint", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setRenderHint), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setRenderHints", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setRenderHints), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setTransform", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setTransform), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setViewTransformEnabled", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setViewTransformEnabled), METH_O, nullptr},
    {"setViewport", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setViewport), METH_VARARGS, nullptr},
    {"setWindow", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setWindow), METH_VARARGS, nullptr},
    {"setWorldMatrixEnabled", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setWorldMatrixEnabled), METH_O, nullptr},
    {"setWorldTransform", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_setWorldTransform), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"shear", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_shear), METH_VARARGS, nullptr},
    {"strokePath", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_strokePath), METH_VARARGS, nullptr},
    {"testRenderHint", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_testRenderHint), METH_O, nullptr},
    {"transform", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_transform), METH_NOARGS, nullptr},
    {"translate", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_translate), METH_VARARGS, nullptr},
    {"viewTransformEnabled", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_viewTransformEnabled), METH_NOARGS, nullptr},
    {"viewport", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_viewport), METH_NOARGS, nullptr},
    {"window", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_window), METH_NOARGS, nullptr},
    {"worldMatrixEnabled", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_worldMatrixEnabled), METH_NOARGS, nullptr},
    {"worldTransform", reinterpret_cast<PyCFunction>(Sbk_QPainterFunc_worldTransform), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QPainter_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPainter_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPainter_Type = nullptr;
static PyTypeObject *Sbk_QPainter_TypeF(void)
{
    return _Sbk_QPainter_Type;
}

static PyType_Slot Sbk_QPainter_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPainter_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPainter_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPainter_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPainter_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPainter_spec = {
    "2:PySide6.QtGui.QPainter",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPainter_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QPainter_RenderHint(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPainter::RenderHint>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPainter::RenderHint *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPainter_RenderHint_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_RenderHint_IDX])))
        return Enum_PythonToCpp_QPainter_RenderHint;
    return {};
}

static PyObject *QPainter_RenderHint_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPainter::RenderHint>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPainter::RenderHint *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_RenderHint_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QPainter_RenderHint(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QPainter::RenderHint>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QPainter::RenderHint> *>(cppOut) = value;

}

static PyObject *QPainter_RenderHint_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QPainter::RenderHint> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_RenderHint_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QPainter_PixmapFragmentHint(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPainter::PixmapFragmentHint>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPainter::PixmapFragmentHint *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPainter_PixmapFragmentHint_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_PixmapFragmentHint_IDX])))
        return Enum_PythonToCpp_QPainter_PixmapFragmentHint;
    return {};
}

static PyObject *QPainter_PixmapFragmentHint_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPainter::PixmapFragmentHint>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPainter::PixmapFragmentHint *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_PixmapFragmentHint_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QPainter_PixmapFragmentHint(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QPainter::PixmapFragmentHint>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QPainter::PixmapFragmentHint> *>(cppOut) = value;

}

static PyObject *QPainter_PixmapFragmentHint_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QPainter::PixmapFragmentHint> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_PixmapFragmentHint_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QPainter_CompositionMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPainter::CompositionMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPainter::CompositionMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPainter_CompositionMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_CompositionMode_IDX])))
        return Enum_PythonToCpp_QPainter_CompositionMode;
    return {};
}

static PyObject *QPainter_CompositionMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPainter::CompositionMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPainter::CompositionMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_CompositionMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPainter_PythonToCpp_QPainter_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPainter_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPainter_PythonToCpp_QPainter_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPainter_TypeF()))
        return QPainter_PythonToCpp_QPainter_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPainter_PTR_CppToPython_QPainter(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    return Shiboken::Object::newObjectWithHeuristics(Sbk_QPainter_TypeF(), const_cast<void *>(cppIn), false);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPainter_SignatureStrings[] = {
    "1:PySide6.QtGui.QPainter(self)",
    "0:PySide6.QtGui.QPainter(self,arg__1:PySide6.QtGui.QPaintDevice)",
    "PySide6.QtGui.QPainter.__enter__(self)->PySide6.QtGui.QPainter",
    "PySide6.QtGui.QPainter.__exit__(self,arg__1:PyObject,arg__2:PyObject,arg__3:PyObject)",
    "PySide6.QtGui.QPainter.background(self)->PySide6.QtGui.QBrush",
    "PySide6.QtGui.QPainter.backgroundMode(self)->PySide6.QtCore.Qt.BGMode",
    "PySide6.QtGui.QPainter.begin(self,arg__1:PySide6.QtGui.QPaintDevice)->bool",
    "PySide6.QtGui.QPainter.beginNativePainting(self)",
    "3:PySide6.QtGui.QPainter.boundingRect(self,rect:PySide6.QtCore.QRect,flags:int,text:QString)->PySide6.QtCore.QRect",
    "2:PySide6.QtGui.QPainter.boundingRect(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],text:QString,o:typing.Union[PySide6.QtGui.QTextOption, PySide6.QtCore.Qt.AlignmentFlag]=QTextOption())->PySide6.QtCore.QRectF",
    "1:PySide6.QtGui.QPainter.boundingRect(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],flags:int,text:QString)->PySide6.QtCore.QRectF",
    "0:PySide6.QtGui.QPainter.boundingRect(self,x:int,y:int,w:int,h:int,flags:int,text:QString)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QPainter.brush(self)->PySide6.QtGui.QBrush",
    "PySide6.QtGui.QPainter.brushOrigin(self)->PySide6.QtCore.QPoint",
    "PySide6.QtGui.QPainter.clipBoundingRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtGui.QPainter.clipPath(self)->PySide6.QtGui.QPainterPath",
    "PySide6.QtGui.QPainter.clipRegion(self)->PySide6.QtGui.QRegion",
    "PySide6.QtGui.QPainter.combinedTransform(self)->PySide6.QtGui.QTransform",
    "PySide6.QtGui.QPainter.compositionMode(self)->PySide6.QtGui.QPainter.CompositionMode",
    "PySide6.QtGui.QPainter.device(self)->PySide6.QtGui.QPaintDevice",
    "PySide6.QtGui.QPainter.deviceTransform(self)->PySide6.QtGui.QTransform",
    "2:PySide6.QtGui.QPainter.drawArc(self,arg__1:PySide6.QtCore.QRect,a:int,alen:int)",
    "1:PySide6.QtGui.QPainter.drawArc(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],a:int,alen:int)",
    "0:PySide6.QtGui.QPainter.drawArc(self,x:int,y:int,w:int,h:int,a:int,alen:int)",
    "2:PySide6.QtGui.QPainter.drawChord(self,arg__1:PySide6.QtCore.QRect,a:int,alen:int)",
    "1:PySide6.QtGui.QPainter.drawChord(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],a:int,alen:int)",
    "0:PySide6.QtGui.QPainter.drawChord(self,x:int,y:int,w:int,h:int,a:int,alen:int)",
    "3:PySide6.QtGui.QPainter.drawConvexPolygon(self,points:QList[PySide6.QtCore.QPoint])",
    "2:PySide6.QtGui.QPainter.drawConvexPolygon(self,points:QList[PySide6.QtCore.QPointF])",
    "1:PySide6.QtGui.QPainter.drawConvexPolygon(self,polygon:typing.Union[PySide6.QtGui.QPolygon, QList[PySide6.QtCore.QPoint], PySide6.QtCore.QRect])",
    "0:PySide6.QtGui.QPainter.drawConvexPolygon(self,polygon:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF])",
    "4:PySide6.QtGui.QPainter.drawEllipse(self,center:PySide6.QtCore.QPoint,rx:int,ry:int)",
    "3:PySide6.QtGui.QPainter.drawEllipse(self,center:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],rx:qreal,ry:qreal)",
    "2:PySide6.QtGui.QPainter.drawEllipse(self,r:PySide6.QtCore.QRect)",
    "1:PySide6.QtGui.QPainter.drawEllipse(self,r:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "0:PySide6.QtGui.QPainter.drawEllipse(self,x:int,y:int,w:int,h:int)",
    "PySide6.QtGui.QPainter.drawGlyphRun(self,position:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],glyphRun:PySide6.QtGui.QGlyphRun)",
    "8:PySide6.QtGui.QPainter.drawImage(self,p:PySide6.QtCore.QPoint,image:PySide6.QtGui.QImage)",
    "7:PySide6.QtGui.QPainter.drawImage(self,p:PySide6.QtCore.QPoint,image:PySide6.QtGui.QImage,sr:PySide6.QtCore.QRect,flags:PySide6.QtCore.Qt.ImageConversionFlag=Qt.AutoColor)",
    "6:PySide6.QtGui.QPainter.drawImage(self,p:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],image:PySide6.QtGui.QImage)",
    "5:PySide6.QtGui.QPainter.drawImage(self,p:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],image:PySide6.QtGui.QImage,sr:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],flags:PySide6.QtCore.Qt.ImageConversionFlag=Qt.AutoColor)",
    "4:PySide6.QtGui.QPainter.drawImage(self,r:PySide6.QtCore.QRect,image:PySide6.QtGui.QImage)",
    "3:PySide6.QtGui.QPainter.drawImage(self,targetRect:PySide6.QtCore.QRect,image:PySide6.QtGui.QImage,sourceRect:PySide6.QtCore.QRect,flags:PySide6.QtCore.Qt.ImageConversionFlag=Qt.AutoColor)",
    "2:PySide6.QtGui.QPainter.drawImage(self,r:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],image:PySide6.QtGui.QImage)",
    "1:PySide6.QtGui.QPainter.drawImage(self,targetRect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],image:PySide6.QtGui.QImage,sourceRect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],flags:PySide6.QtCore.Qt.ImageConversionFlag=Qt.AutoColor)",
    "0:PySide6.QtGui.QPainter.drawImage(self,x:int,y:int,image:PySide6.QtGui.QImage,sx:int=0,sy:int=0,sw:int=-1,sh:int=-1,flags:PySide6.QtCore.Qt.ImageConversionFlag=Qt.AutoColor)",
    "4:PySide6.QtGui.QPainter.drawLine(self,line:PySide6.QtCore.QLine)",
    "3:PySide6.QtGui.QPainter.drawLine(self,line:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine])",
    "2:PySide6.QtGui.QPainter.drawLine(self,p1:PySide6.QtCore.QPoint,p2:PySide6.QtCore.QPoint)",
    "1:PySide6.QtGui.QPainter.drawLine(self,p1:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],p2:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "0:PySide6.QtGui.QPainter.drawLine(self,x1:int,y1:int,x2:int,y2:int)",
    "4:PySide6.QtGui.QPainter.drawLines(self,lines:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine],lineCount:int)",
    "3:PySide6.QtGui.QPainter.drawLines(self,lines:QList[PySide6.QtCore.QLine])",
    "2:PySide6.QtGui.QPainter.drawLines(self,lines:QList[PySide6.QtCore.QLineF])",
    "1:PySide6.QtGui.QPainter.drawLines(self,pointPairs:QList[PySide6.QtCore.QPoint])",
    "0:PySide6.QtGui.QPainter.drawLines(self,pointPairs:QList[PySide6.QtCore.QPointF])",
    "PySide6.QtGui.QPainter.drawPath(self,path:PySide6.QtGui.QPainterPath)",
    "2:PySide6.QtGui.QPainter.drawPicture(self,p:PySide6.QtCore.QPoint,picture:typing.Union[PySide6.QtGui.QPicture, int])",
    "1:PySide6.QtGui.QPainter.drawPicture(self,p:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],picture:typing.Union[PySide6.QtGui.QPicture, int])",
    "0:PySide6.QtGui.QPainter.drawPicture(self,x:int,y:int,picture:typing.Union[PySide6.QtGui.QPicture, int])",
    "2:PySide6.QtGui.QPainter.drawPie(self,arg__1:PySide6.QtCore.QRect,a:int,alen:int)",
    "1:PySide6.QtGui.QPainter.drawPie(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],a:int,alen:int)",
    "0:PySide6.QtGui.QPainter.drawPie(self,x:int,y:int,w:int,h:int,a:int,alen:int)",
    "10:PySide6.QtGui.QPainter.drawPixmap(self,p:PySide6.QtCore.QPoint,pm:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage])",
    "9:PySide6.QtGui.QPainter.drawPixmap(self,p:PySide6.QtCore.QPoint,pm:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage],sr:PySide6.QtCore.QRect)",
    "8:PySide6.QtGui.QPainter.drawPixmap(self,p:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],pm:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage])",
    "7:PySide6.QtGui.QPainter.drawPixmap(self,p:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],pm:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage],sr:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "6:PySide6.QtGui.QPainter.drawPixmap(self,r:PySide6.QtCore.QRect,pm:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage])",
    "5:PySide6.QtGui.QPainter.drawPixmap(self,targetRect:PySide6.QtCore.QRect,pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage],sourceRect:PySide6.QtCore.QRect)",
    "4:PySide6.QtGui.QPainter.drawPixmap(self,targetRect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage],sourceRect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "3:PySide6.QtGui.QPainter.drawPixmap(self,x:int,y:int,pm:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage])",
    "2:PySide6.QtGui.QPainter.drawPixmap(self,x:int,y:int,pm:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage],sx:int,sy:int,sw:int,sh:int)",
    "1:PySide6.QtGui.QPainter.drawPixmap(self,x:int,y:int,w:int,h:int,pm:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage])",
    "0:PySide6.QtGui.QPainter.drawPixmap(self,x:int,y:int,w:int,h:int,pm:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage],sx:int,sy:int,sw:int,sh:int)",
    "PySide6.QtGui.QPainter.drawPixmapFragments(self,fragments:PySide6.QtGui.QPainter.PixmapFragment,fragmentCount:int,pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage],hints:PySide6.QtGui.QPainter.PixmapFragmentHint=QPainter.PixmapFragmentHints())",
    "2:PySide6.QtGui.QPainter.drawPoint(self,p:PySide6.QtCore.QPoint)",
    "1:PySide6.QtGui.QPainter.drawPoint(self,pt:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "0:PySide6.QtGui.QPainter.drawPoint(self,x:int,y:int)",
    "4:PySide6.QtGui.QPainter.drawPoints(self,points:QList[PySide6.QtCore.QPoint])",
    "3:PySide6.QtGui.QPainter.drawPoints(self,points:QList[PySide6.QtCore.QPointF])",
    "2:PySide6.QtGui.QPainter.drawPoints(self,points:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],pointCount:int)",
    "1:PySide6.QtGui.QPainter.drawPoints(self,points:typing.Union[PySide6.QtGui.QPolygon, QList[PySide6.QtCore.QPoint], PySide6.QtCore.QRect])",
    "0:PySide6.QtGui.QPainter.drawPoints(self,points:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF])",
    "PySide6.QtGui.QPainter.drawPointsNp(self,x:PyArrayObject,y:PyArrayObject)",
    "3:PySide6.QtGui.QPainter.drawPolygon(self,points:QList[PySide6.QtCore.QPoint],fill_rule:PySide6.QtCore.Qt.FillRule)",
    "2:PySide6.QtGui.QPainter.drawPolygon(self,points:QList[PySide6.QtCore.QPointF],fill_rule:PySide6.QtCore.Qt.FillRule)",
    "1:PySide6.QtGui.QPainter.drawPolygon(self,polygon:typing.Union[PySide6.QtGui.QPolygon, QList[PySide6.QtCore.QPoint], PySide6.QtCore.QRect],fillRule:PySide6.QtCore.Qt.FillRule=Qt.OddEvenFill)",
    "0:PySide6.QtGui.QPainter.drawPolygon(self,polygon:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF],fillRule:PySide6.QtCore.Qt.FillRule=Qt.OddEvenFill)",
    "3:PySide6.QtGui.QPainter.drawPolyline(self,points:QList[PySide6.QtCore.QPoint])",
    "2:PySide6.QtGui.QPainter.drawPolyline(self,points:QList[PySide6.QtCore.QPointF])",
    "1:PySide6.QtGui.QPainter.drawPolyline(self,polygon:typing.Union[PySide6.QtGui.QPolygon, QList[PySide6.QtCore.QPoint], PySide6.QtCore.QRect])",
    "0:PySide6.QtGui.QPainter.drawPolyline(self,polyline:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF])",
    "2:PySide6.QtGui.QPainter.drawRect(self,rect:PySide6.QtCore.QRect)",
    "1:PySide6.QtGui.QPainter.drawRect(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "0:PySide6.QtGui.QPainter.drawRect(self,x1:int,y1:int,w:int,h:int)",
    "2:PySide6.QtGui.QPainter.drawRects(self,rectangles:QList[PySide6.QtCore.QRect])",
    "1:PySide6.QtGui.QPainter.drawRects(self,rectangles:QList[PySide6.QtCore.QRectF])",
    "0:PySide6.QtGui.QPainter.drawRects(self,rects:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],rectCount:int)",
    "2:PySide6.QtGui.QPainter.drawRoundedRect(self,rect:PySide6.QtCore.QRect,xRadius:qreal,yRadius:qreal,mode:PySide6.QtCore.Qt.SizeMode=Qt.AbsoluteSize)",
    "1:PySide6.QtGui.QPainter.drawRoundedRect(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],xRadius:qreal,yRadius:qreal,mode:PySide6.QtCore.Qt.SizeMode=Qt.AbsoluteSize)",
    "0:PySide6.QtGui.QPainter.drawRoundedRect(self,x:int,y:int,w:int,h:int,xRadius:qreal,yRadius:qreal,mode:PySide6.QtCore.Qt.SizeMode=Qt.AbsoluteSize)",
    "2:PySide6.QtGui.QPainter.drawStaticText(self,topLeftPosition:PySide6.QtCore.QPoint,staticText:PySide6.QtGui.QStaticText)",
    "1:PySide6.QtGui.QPainter.drawStaticText(self,topLeftPosition:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],staticText:PySide6.QtGui.QStaticText)",
    "0:PySide6.QtGui.QPainter.drawStaticText(self,left:int,top:int,staticText:PySide6.QtGui.QStaticText)",
    "6:PySide6.QtGui.QPainter.drawText(self,p:PySide6.QtCore.QPoint,s:QString)",
    "5:PySide6.QtGui.QPainter.drawText(self,p:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],s:QString)",
    "4:PySide6.QtGui.QPainter.drawText(self,r:PySide6.QtCore.QRect,flags:int,text:QString)->QRect",
    "3:PySide6.QtGui.QPainter.drawText(self,r:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],text:QString,o:typing.Union[PySide6.QtGui.QTextOption, PySide6.QtCore.Qt.AlignmentFlag]=QTextOption())",
    "2:PySide6.QtGui.QPainter.drawText(self,r:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],flags:int,text:QString)->QRectF",
    "1:PySide6.QtGui.QPainter.drawText(self,x:int,y:int,s:QString)",
    "0:PySide6.QtGui.QPainter.drawText(self,x:int,y:int,w:int,h:int,flags:int,text:QString)",
    "2:PySide6.QtGui.QPainter.drawTextItem(self,p:PySide6.QtCore.QPoint,ti:PySide6.QtGui.QTextItem)",
    "1:PySide6.QtGui.QPainter.drawTextItem(self,p:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],ti:PySide6.QtGui.QTextItem)",
    "0:PySide6.QtGui.QPainter.drawTextItem(self,x:int,y:int,ti:PySide6.QtGui.QTextItem)",
    "2:PySide6.QtGui.QPainter.drawTiledPixmap(self,arg__1:PySide6.QtCore.QRect,arg__2:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage],pos:PySide6.QtCore.QPoint=QPoint())",
    "1:PySide6.QtGui.QPainter.drawTiledPixmap(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],pm:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage],offset:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element]=QPointF())",
    "0:PySide6.QtGui.QPainter.drawTiledPixmap(self,x:int,y:int,w:int,h:int,arg__5:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage],sx:int=0,sy:int=0)",
    "PySide6.QtGui.QPainter.end(self)->bool",
    "PySide6.QtGui.QPainter.endNativePainting(self)",
    "2:PySide6.QtGui.QPainter.eraseRect(self,arg__1:PySide6.QtCore.QRect)",
    "1:PySide6.QtGui.QPainter.eraseRect(self,arg__1:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "0:PySide6.QtGui.QPainter.eraseRect(self,x:int,y:int,w:int,h:int)",
    "PySide6.QtGui.QPainter.fillPath(self,path:PySide6.QtGui.QPainterPath,brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "14:PySide6.QtGui.QPainter.fillRect(self,arg__1:PySide6.QtCore.QRect,arg__2:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "13:PySide6.QtGui.QPainter.fillRect(self,arg__1:PySide6.QtCore.QRect,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "12:PySide6.QtGui.QPainter.fillRect(self,r:PySide6.QtCore.QRect,preset:PySide6.QtGui.QGradient.Preset)",
    "11:PySide6.QtGui.QPainter.fillRect(self,r:PySide6.QtCore.QRect,style:PySide6.QtCore.Qt.BrushStyle)",
    "10:PySide6.QtGui.QPainter.fillRect(self,r:PySide6.QtCore.QRect,c:PySide6.QtCore.Qt.GlobalColor)",
    "9:PySide6.QtGui.QPainter.fillRect(self,arg__1:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],arg__2:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "8:PySide6.QtGui.QPainter.fillRect(self,arg__1:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "7:PySide6.QtGui.QPainter.fillRect(self,r:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],preset:PySide6.QtGui.QGradient.Preset)",
    "6:PySide6.QtGui.QPainter.fillRect(self,r:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],style:PySide6.QtCore.Qt.BrushStyle)",
    "5:PySide6.QtGui.QPainter.fillRect(self,r:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],c:PySide6.QtCore.Qt.GlobalColor)",
    "4:PySide6.QtGui.QPainter.fillRect(self,x:int,y:int,w:int,h:int,preset:PySide6.QtGui.QGradient.Preset)",
    "3:PySide6.QtGui.QPainter.fillRect(self,x:int,y:int,w:int,h:int,style:PySide6.QtCore.Qt.BrushStyle)",
    "2:PySide6.QtGui.QPainter.fillRect(self,x:int,y:int,w:int,h:int,c:PySide6.QtCore.Qt.GlobalColor)",
    "1:PySide6.QtGui.QPainter.fillRect(self,x:int,y:int,w:int,h:int,arg__5:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "0:PySide6.QtGui.QPainter.fillRect(self,x:int,y:int,w:int,h:int,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "PySide6.QtGui.QPainter.font(self)->PySide6.QtGui.QFont",
    "PySide6.QtGui.QPainter.fontInfo(self)->PySide6.QtGui.QFontInfo",
    "PySide6.QtGui.QPainter.fontMetrics(self)->PySide6.QtGui.QFontMetrics",
    "PySide6.QtGui.QPainter.hasClipping(self)->bool",
    "PySide6.QtGui.QPainter.isActive(self)->bool",
    "PySide6.QtGui.QPainter.layoutDirection(self)->PySide6.QtCore.Qt.LayoutDirection",
    "PySide6.QtGui.QPainter.opacity(self)->qreal",
    "PySide6.QtGui.QPainter.paintEngine(self)->PySide6.QtGui.QPaintEngine",
    "PySide6.QtGui.QPainter.pen(self)->PySide6.QtGui.QPen",
    "PySide6.QtGui.QPainter.renderHints(self)->PySide6.QtGui.QPainter.RenderHint",
    "PySide6.QtGui.QPainter.resetTransform(self)",
    "PySide6.QtGui.QPainter.restore(self)",
    "PySide6.QtGui.QPainter.rotate(self,a:qreal)",
    "PySide6.QtGui.QPainter.save(self)",
    "PySide6.QtGui.QPainter.scale(self,sx:qreal,sy:qreal)",
    "PySide6.QtGui.QPainter.setBackground(self,bg:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "PySide6.QtGui.QPainter.setBackgroundMode(self,mode:PySide6.QtCore.Qt.BGMode)",
    "1:PySide6.QtGui.QPainter.setBrush(self,style:PySide6.QtCore.Qt.BrushStyle)",
    "0:PySide6.QtGui.QPainter.setBrush(self,brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "2:PySide6.QtGui.QPainter.setBrushOrigin(self,arg__1:PySide6.QtCore.QPoint)",
    "1:PySide6.QtGui.QPainter.setBrushOrigin(self,arg__1:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "0:PySide6.QtGui.QPainter.setBrushOrigin(self,x:int,y:int)",
    "PySide6.QtGui.QPainter.setClipPath(self,path:PySide6.QtGui.QPainterPath,op:PySide6.QtCore.Qt.ClipOperation=Qt.ReplaceClip)",
    "2:PySide6.QtGui.QPainter.setClipRect(self,arg__1:PySide6.QtCore.QRect,op:PySide6.QtCore.Qt.ClipOperation=Qt.ReplaceClip)",
    "1:PySide6.QtGui.QPainter.setClipRect(self,arg__1:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],op:PySide6.QtCore.Qt.ClipOperation=Qt.ReplaceClip)",
    "0:PySide6.QtGui.QPainter.setClipRect(self,x:int,y:int,w:int,h:int,op:PySide6.QtCore.Qt.ClipOperation=Qt.ReplaceClip)",
    "PySide6.QtGui.QPainter.setClipRegion(self,arg__1:typing.Union[PySide6.QtGui.QRegion, PySide6.QtGui.QBitmap, PySide6.QtGui.QPolygon, PySide6.QtCore.QRect],op:PySide6.QtCore.Qt.ClipOperation=Qt.ReplaceClip)",
    "PySide6.QtGui.QPainter.setClipping(self,enable:bool)",
    "PySide6.QtGui.QPainter.setCompositionMode(self,mode:PySide6.QtGui.QPainter.CompositionMode)",
    "PySide6.QtGui.QPainter.setFont(self,f:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "PySide6.QtGui.QPainter.setLayoutDirection(self,direction:PySide6.QtCore.Qt.LayoutDirection)",
    "PySide6.QtGui.QPainter.setOpacity(self,opacity:qreal)",
    "2:PySide6.QtGui.QPainter.setPen(self,style:PySide6.QtCore.Qt.PenStyle)",
    "1:PySide6.QtGui.QPainter.setPen(self,color:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int])",
    "0:PySide6.QtGui.QPainter.setPen(self,pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor])",
    "PySide6.QtGui.QPainter.setRenderHint(self,hint:PySide6.QtGui.QPainter.RenderHint,on:bool=true)",
    "PySide6.QtGui.QPainter.setRenderHints(self,hints:PySide6.QtGui.QPainter.RenderHint,on:bool=true)",
    "PySide6.QtGui.QPainter.setTransform(self,transform:PySide6.QtGui.QTransform,combine:bool=false)",
    "PySide6.QtGui.QPainter.setViewTransformEnabled(self,enable:bool)",
    "1:PySide6.QtGui.QPainter.setViewport(self,viewport:PySide6.QtCore.QRect)",
    "0:PySide6.QtGui.QPainter.setViewport(self,x:int,y:int,w:int,h:int)",
    "1:PySide6.QtGui.QPainter.setWindow(self,window:PySide6.QtCore.QRect)",
    "0:PySide6.QtGui.QPainter.setWindow(self,x:int,y:int,w:int,h:int)",
    "PySide6.QtGui.QPainter.setWorldMatrixEnabled(self,enabled:bool)",
    "PySide6.QtGui.QPainter.setWorldTransform(self,matrix:PySide6.QtGui.QTransform,combine:bool=false)",
    "PySide6.QtGui.QPainter.shear(self,sh:qreal,sv:qreal)",
    "PySide6.QtGui.QPainter.strokePath(self,path:PySide6.QtGui.QPainterPath,pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor])",
    "PySide6.QtGui.QPainter.testRenderHint(self,hint:PySide6.QtGui.QPainter.RenderHint)->bool",
    "PySide6.QtGui.QPainter.transform(self)->PySide6.QtGui.QTransform",
    "2:PySide6.QtGui.QPainter.translate(self,offset:PySide6.QtCore.QPoint)",
    "1:PySide6.QtGui.QPainter.translate(self,offset:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "0:PySide6.QtGui.QPainter.translate(self,dx:qreal,dy:qreal)",
    "PySide6.QtGui.QPainter.viewTransformEnabled(self)->bool",
    "PySide6.QtGui.QPainter.viewport(self)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QPainter.window(self)->PySide6.QtCore.QRect",
    "PySide6.QtGui.QPainter.worldMatrixEnabled(self)->bool",
    "PySide6.QtGui.QPainter.worldTransform(self)->PySide6.QtGui.QTransform",
    nullptr}; // Sentinel
#else
static constexpr size_t QPainter_SignatureByteSize = 2483;
static constexpr uint8_t QPainter_SignatureBytes[2483] = {
    0x78, 0xda, 0xdd, 0x5c, 0x5b, 0x6f, 0xe3, 0xb6, 0x12, 0x7e, 0xcf, 0xaf, 0xc8, 0xe3, 0x1a, 0xd0,
    0x06, 0xbe, 0xec, 0xa5, 0x35, 0x90, 0x02, 0x9b, 0x34, 0x4e, 0x17, 0xc8, 0x6e, 0x1c, 0xa7, 0xa7,
    0xe7, 0xa1, 0x08, 0x02, 0xda, 0xa2, 0x6d, 0x9d, 0x2a, 0xa2, 0x0e, 0x49, 0x3b, 0x76, 0x7f, 0x7d,
    0x49, 0xea, 0x62, 0xc9, 0x26, 0x87, 0x94, 0x64, 0x25, 0xe9, 0xbe, 0x24, 0x92, 0x49, 0x7e, 0x33,
    0x1c, 0xce, 0x0c, 0x67, 0x48, 0x8a, 0xbd, 0xe1, 0x78, 0x7b, 0x1f, 0xf8, 0xf8, 0xd3, 0xd9, 0x1d,
    0xbf, 0x5e, 0x05, 0x67, 0x77, 0x63, 0x14, 0x44, 0x1c, 0xd3, 0x77, 0x0c, 0x87, 0xf3, 0xce, 0x49,
    0x17, 0x2a, 0xf6, 0x10, 0x5d, 0x3c, 0x3e, 0xf6, 0xb4, 0x55, 0x7e, 0xc5, 0xeb, 0x60, 0x86, 0x3b,
    0x27, 0xfa, 0xe6, 0x67, 0x8f, 0x8f, 0x58, 0xfe, 0x7f, 0x7c, 0x4c, 0xe8, 0xbc, 0xff, 0x45, 0x5f,
    0x0f, 0x68, 0xbe, 0x09, 0x78, 0xda, 0x7a, 0xc7, 0xc6, 0xed, 0xf4, 0x7f, 0x78, 0xc6, 0x93, 0xf7,
    0xfe, 0xde, 0xfb, 0x20, 0x7f, 0x37, 0x32, 0x35, 0x45, 0xb3, 0xbf, 0x16, 0x94, 0xac, 0x22, 0xdf,
    0xc0, 0xd5, 0x05, 0x5d, 0xb1, 0xa5, 0xbd, 0xf5, 0x37, 0xe2, 0xe3, 0x43, 0x84, 0x4b, 0x42, 0xb1,
    0xf8, 0x77, 0x76, 0x71, 0x2d, 0xcb, 0x8d, 0x28, 0x78, 0x11, 0x44, 0xae, 0xd2, 0x7d, 0xff, 0xcb,
    0x94, 0x90, 0x10, 0x84, 0xfa, 0x8e, 0x78, 0xb0, 0xc6, 0xea, 0xa7, 0x20, 0x5a, 0xa4, 0xa3, 0x3a,
    0x18, 0x9a, 0x9a, 0x48, 0xf6, 0x45, 0xbd, 0x89, 0x10, 0x53, 0xc2, 0x04, 0x15, 0x4f, 0xc3, 0xfd,
    0x4e, 0xc8, 0x62, 0x6f, 0x1e, 0xa2, 0x05, 0x1b, 0x8a, 0x76, 0x1e, 0xc7, 0x1b, 0x3e, 0xbc, 0xbb,
    0xe7, 0x54, 0xb4, 0xd4, 0x74, 0x59, 0xd6, 0x3e, 0xe9, 0x57, 0x24, 0xc9, 0xb7, 0xb1, 0xf8, 0xf1,
    0xec, 0x3f, 0x51, 0x40, 0xa2, 0x3f, 0x75, 0x88, 0x23, 0xef, 0x54, 0xf7, 0xf3, 0x43, 0x89, 0x1b,
    0x8f, 0x98, 0x80, 0x14, 0x0f, 0xbf, 0x8b, 0xaa, 0xb7, 0x31, 0x17, 0x25, 0x87, 0x60, 0xfc, 0xec,
    0x4b, 0x18, 0x2c, 0xa2, 0x27, 0xa1, 0xa7, 0x23, 0xd1, 0xd3, 0x87, 0xf3, 0x42, 0xed, 0x77, 0x1d,
    0x43, 0x37, 0x47, 0x27, 0xbd, 0x17, 0xeb, 0x67, 0x25, 0xf9, 0x8f, 0x8c, 0x96, 0xac, 0x61, 0x6c,
    0xa3, 0x50, 0xb7, 0xea, 0xef, 0xb3, 0xfa, 0xbb, 0x54, 0x7f, 0xab, 0x8d, 0xb8, 0x89, 0x9c, 0xb4,
    0xa1, 0x5a, 0xf6, 0x25, 0x0b, 0x6f, 0x69, 0x90, 0xd9, 0x87, 0x86, 0xee, 0x98, 0x88, 0xaa, 0xa6,
    0xf6, 0xb3, 0x30, 0x88, 0x2f, 0xf6, 0xfb, 0x6a, 0x14, 0x17, 0x00, 0x32, 0x46, 0x7c, 0x09, 0xbb,
    0x2d, 0x59, 0x03, 0x42, 0x98, 0x08, 0xcb, 0x24, 0x91, 0x01, 0x23, 0x29, 0x34, 0x36, 0x27, 0x4f,
    0xd3, 0x20, 0xc2, 0xfe, 0xef, 0x14, 0x45, 0x6c, 0x4e, 0xe8, 0x93, 0x01, 0x25, 0x2f, 0x07, 0x80,
    0x62, 0xc2, 0x02, 0xa9, 0xce, 0x7a, 0x7f, 0x55, 0xaa, 0x7d, 0x59, 0xae, 0x6d, 0x02, 0xf5, 0x95,
    0x5f, 0x82, 0xb0, 0x12, 0xcf, 0x05, 0xb7, 0x77, 0xef, 0x9b, 0xd1, 0xab, 0xf8, 0x14, 0x3d, 0x7f,
    0xa1, 0x33, 0x83, 0x23, 0x2d, 0x78, 0x31, 0xa4, 0xf4, 0x19, 0x85, 0x38, 0x92, 0x0f, 0x1d, 0xb3,
    0xfd, 0x96, 0x10, 0x1b, 0x9a, 0xee, 0x3e, 0xd1, 0xae, 0x13, 0x51, 0x93, 0x59, 0xee, 0xa3, 0x81,
    0x42, 0xb9, 0x5c, 0x12, 0xea, 0x1f, 0x59, 0x2c, 0x05, 0xcc, 0x97, 0x14, 0x4c, 0x81, 0xac, 0xab,
    0x68, 0x06, 0x20, 0x1e, 0x89, 0xd6, 0x78, 0x33, 0x26, 0xe1, 0x76, 0x91, 0x1a, 0xa7, 0x17, 0x4b,
    0x87, 0xc2, 0x86, 0x77, 0x37, 0x01, 0xe3, 0x7f, 0x6a, 0xbd, 0xcd, 0x83, 0x4d, 0xde, 0x75, 0x40,
    0x47, 0x0f, 0x36, 0x89, 0xeb, 0x50, 0xd5, 0x0b, 0x38, 0xdf, 0xa5, 0x0d, 0xbc, 0x53, 0xa8, 0x43,
    0x86, 0xb1, 0xb1, 0x0d, 0x46, 0x23, 0x8e, 0x46, 0x20, 0x4b, 0xa3, 0x12, 0x4f, 0xe5, 0x9e, 0x68,
    0xd5, 0x4b, 0x30, 0xfb, 0x01, 0x62, 0xf6, 0x2a, 0x14, 0x4e, 0x98, 0x25, 0x7e, 0xca, 0x9b, 0xa9,
    0x48, 0x74, 0xa8, 0xa5, 0xec, 0xd1, 0x44, 0xb3, 0xe8, 0xd6, 0x41, 0x7f, 0x74, 0xa8, 0xa0, 0x29,
    0x24, 0x9d, 0x3b, 0xec, 0x43, 0x42, 0xfa, 0xd4, 0x3c, 0xb7, 0x9c, 0x5d, 0x85, 0x58, 0x06, 0x26,
    0x0f, 0x92, 0xbf, 0xff, 0x53, 0x8c, 0x42, 0xc9, 0xa1, 0x7a, 0xb0, 0xa8, 0x63, 0x89, 0x47, 0xaa,
    0xb5, 0x7d, 0x8b, 0xea, 0xed, 0x21, 0xd4, 0xb6, 0x75, 0x8b, 0x3e, 0x95, 0xc8, 0x18, 0xcc, 0xdb,
    0x18, 0xc8, 0x4b, 0x80, 0xeb, 0x70, 0x1b, 0x2f, 0x27, 0xab, 0x5c, 0x17, 0x93, 0xc9, 0xab, 0xf5,
    0x01, 0x59, 0xa4, 0x64, 0xf7, 0xfb, 0x96, 0xb1, 0xd3, 0x39, 0xf9, 0x09, 0xea, 0xf6, 0xd7, 0x27,
    0xb4, 0x48, 0x3b, 0x1d, 0x1b, 0x54, 0x32, 0x90, 0x55, 0xf6, 0x31, 0x54, 0xbb, 0xce, 0xc9, 0xe7,
    0xd6, 0xb0, 0x3d, 0x46, 0xa1, 0x34, 0xe0, 0x30, 0x7a, 0x56, 0xad, 0x94, 0x57, 0xa0, 0x4c, 0xc8,
    0x5a, 0xc6, 0xd0, 0xe7, 0x32, 0xa8, 0x5e, 0x71, 0x72, 0x49, 0x42, 0x42, 0x3b, 0x27, 0x9f, 0x9c,
    0x99, 0x6d, 0x7b, 0xd0, 0x20, 0x91, 0x7e, 0xfc, 0x17, 0x70, 0x29, 0x07, 0xa7, 0x69, 0x22, 0x51,
    0x67, 0x04, 0x3f, 0x38, 0xca, 0xc6, 0xa0, 0x3a, 0x90, 0xd8, 0x07, 0x8e, 0xd0, 0x5c, 0x44, 0x31,
    0x98, 0x4f, 0x8c, 0x59, 0x2a, 0x24, 0x34, 0xb2, 0xa2, 0x33, 0x3c, 0xb1, 0x24, 0xb8, 0x75, 0xe4,
    0xd2, 0x77, 0x96, 0x4b, 0xfd, 0x51, 0x83, 0x84, 0xd7, 0xab, 0x2e, 0xbc, 0x36, 0x18, 0x29, 0x4a,
    0xf8, 0x35, 0xd4, 0xb3, 0xeb, 0x28, 0x86, 0xe2, 0xf4, 0x02, 0xf5, 0x46, 0xd5, 0x3b, 0xef, 0x7a,
    0x6c, 0x9b, 0x3d, 0xa8, 0xc9, 0xe8, 0xfc, 0x7d, 0xcf, 0x63, 0xcb, 0xec, 0xa9, 0x25, 0x6b, 0xba,
    0x11, 0x49, 0x5f, 0xc2, 0x6d, 0x28, 0x9e, 0x0e, 0xf0, 0x65, 0xb1, 0xc5, 0x68, 0xf6, 0x10, 0xc0,
    0x01, 0x91, 0x75, 0x35, 0x03, 0x22, 0x7f, 0xb6, 0x05, 0xbc, 0x3b, 0x32, 0x71, 0xcf, 0x30, 0xcb,
    0xc4, 0x7d, 0x7d, 0x81, 0x45, 0x71, 0x4b, 0xc8, 0x6d, 0x3b, 0x5b, 0xc1, 0x63, 0xcb, 0x24, 0x2c,
    0xfa, 0xb9, 0xeb, 0xed, 0xa6, 0x97, 0xe8, 0x67, 0xf2, 0x6f, 0xd3, 0x4f, 0xde, 0xfa, 0x49, 0x04,
    0x64, 0x55, 0x1a, 0xb6, 0x1b, 0x73, 0x56, 0x7f, 0xd0, 0x55, 0xfb, 0x4b, 0xb2, 0x8a, 0xb8, 0x43,
    0x20, 0x7c, 0x40, 0x56, 0x1f, 0xdb, 0xbb, 0x6a, 0x93, 0x23, 0x94, 0x35, 0x69, 0x2a, 0x60, 0xa9,
    0x14, 0x4c, 0x94, 0x51, 0x5b, 0x6e, 0xd7, 0x3d, 0x2a, 0xa0, 0x64, 0x11, 0xc0, 0xcb, 0x17, 0x96,
    0xbc, 0x58, 0x3c, 0x0d, 0xcd, 0x3a, 0x64, 0x11, 0xda, 0x38, 0x98, 0xf1, 0x15, 0xb5, 0x84, 0x7a,
    0x71, 0x52, 0x09, 0xce, 0xce, 0x92, 0x3a, 0xde, 0x69, 0x22, 0x8c, 0x5e, 0x05, 0xa2, 0xad, 0xdb,
    0x67, 0x75, 0xf6, 0xbb, 0xce, 0xec, 0x17, 0x27, 0x84, 0x1a, 0x84, 0x2c, 0x83, 0x83, 0x8f, 0xbc,
    0xfc, 0x92, 0x23, 0xbe, 0xe4, 0xe2, 0x4b, 0x4e, 0xd4, 0x75, 0xe9, 0xa5, 0x67, 0x81, 0xdb, 0x3c,
    0xa1, 0xd8, 0xa2, 0xb1, 0x4f, 0x96, 0x41, 0x90, 0x10, 0x07, 0xda, 0xa3, 0xe6, 0x5d, 0x31, 0x28,
    0x3f, 0xbf, 0x26, 0x79, 0x53, 0xf6, 0x64, 0xc9, 0x06, 0xcb, 0x6c, 0xb5, 0x6e, 0x52, 0x8d, 0xe4,
    0xfb, 0xf9, 0xc7, 0xe8, 0x48, 0xa3, 0x54, 0xca, 0x92, 0xd3, 0x16, 0xa5, 0x60, 0x48, 0x89, 0x9a,
    0x8d, 0xc1, 0x47, 0x57, 0xea, 0xb6, 0xac, 0x29, 0x56, 0x75, 0x9b, 0x48, 0x11, 0xce, 0xad, 0x2c,
    0x71, 0x8b, 0x81, 0xd5, 0xfa, 0xae, 0xed, 0x98, 0xfd, 0x69, 0xa0, 0x1d, 0x03, 0xd7, 0x4e, 0x97,
    0x26, 0xa0, 0x46, 0x2a, 0xd1, 0x7f, 0x69, 0x92, 0x69, 0x9a, 0x94, 0x26, 0x49, 0x69, 0x8a, 0x94,
    0xe6, 0x47, 0xd6, 0x89, 0x4c, 0xcf, 0x4e, 0x71, 0x5a, 0x69, 0x26, 0x8d, 0xee, 0x6b, 0x92, 0x87,
    0x25, 0x63, 0x65, 0x6c, 0x44, 0xd1, 0x42, 0xfa, 0xb7, 0x34, 0xe2, 0x9c, 0x67, 0xaf, 0xa6, 0x2e,
    0x95, 0x5b, 0xe5, 0xf5, 0xf3, 0x20, 0xbe, 0xb9, 0x51, 0x2c, 0x03, 0x67, 0xf2, 0xbf, 0xc9, 0xec,
    0x18, 0x28, 0x63, 0xef, 0x3a, 0x36, 0x5d, 0x95, 0xfe, 0x1f, 0x9c, 0xa1, 0x6d, 0xda, 0x55, 0x00,
    0xe0, 0xaf, 0x9c, 0xdc, 0x15, 0x78, 0x29, 0x68, 0x9a, 0xcd, 0x2b, 0xaa, 0x7d, 0xa3, 0x0a, 0x1b,
    0x53, 0x83, 0xe3, 0xa1, 0x8d, 0x1e, 0x5c, 0x86, 0xa7, 0x0c, 0xd7, 0xfa, 0x34, 0x2f, 0xab, 0x16,
    0x72, 0xd2, 0xde, 0x71, 0xf8, 0x6b, 0x7b, 0xa7, 0xac, 0x1e, 0x27, 0xc7, 0xdf, 0x21, 0xb3, 0xb2,
    0xf8, 0x3d, 0xf7, 0x85, 0xe3, 0xed, 0x17, 0x4a, 0x51, 0x76, 0x9c, 0x6a, 0x5b, 0x7e, 0xb7, 0xea,
    0x59, 0xb5, 0xfd, 0x54, 0x6f, 0x1e, 0x84, 0xe1, 0x23, 0x5d, 0x85, 0x58, 0xb3, 0x88, 0x36, 0x12,
    0x65, 0x13, 0x51, 0x64, 0x55, 0xc6, 0x8a, 0xdb, 0xad, 0x8e, 0x44, 0x7b, 0x15, 0x88, 0xb6, 0xbb,
    0x1b, 0xab, 0x18, 0x9e, 0xc0, 0xfc, 0xca, 0xe5, 0xc5, 0x5b, 0xdf, 0xbf, 0x5a, 0xe3, 0x48, 0xfe,
    0x64, 0x55, 0xcb, 0xb7, 0xb1, 0x75, 0x5b, 0xab, 0x67, 0x56, 0x0d, 0x0c, 0x77, 0x6b, 0x87, 0x8d,
    0xb7, 0xf4, 0xab, 0xe2, 0x59, 0x17, 0xa6, 0xf6, 0x01, 0x5f, 0x75, 0x23, 0xff, 0x90, 0x19, 0x68,
    0xb9, 0xb8, 0x5d, 0x17, 0x05, 0x0e, 0x83, 0xc3, 0x19, 0x45, 0x8b, 0xdc, 0x8f, 0x75, 0x14, 0xcf,
    0x22, 0xd1, 0xc2, 0xc1, 0xba, 0xd2, 0x4a, 0x6e, 0x69, 0x27, 0xdb, 0xda, 0x55, 0xb6, 0xe3, 0x14,
    0x45, 0x8b, 0xd0, 0xb8, 0x14, 0x9a, 0x72, 0xd4, 0x3b, 0x26, 0xde, 0xc8, 0xa5, 0x8b, 0x05, 0x40,
    0xd6, 0x20, 0x55, 0x93, 0xed, 0x0b, 0x93, 0x3a, 0x2c, 0x17, 0x79, 0x9c, 0x0f, 0xfb, 0x2e, 0xa7,
    0x55, 0x37, 0x13, 0xe4, 0x07, 0x2b, 0x96, 0x9e, 0x96, 0xd8, 0x96, 0xde, 0x9e, 0x88, 0xaf, 0xf3,
    0x36, 0xf7, 0xc1, 0xdf, 0x58, 0x1e, 0x76, 0x53, 0xdb, 0x34, 0x53, 0x46, 0xc2, 0x15, 0xc7, 0xf2,
    0x37, 0x9b, 0x70, 0xb5, 0x4c, 0xd5, 0x17, 0xc8, 0x51, 0x39, 0xef, 0x56, 0xe2, 0xdc, 0x94, 0x05,
    0x1d, 0x95, 0x25, 0x70, 0x84, 0xef, 0x39, 0xe2, 0xc1, 0x4c, 0x9e, 0xbc, 0x4d, 0x57, 0x03, 0x48,
    0x7c, 0x83, 0xe7, 0x7c, 0x9c, 0x1d, 0xe7, 0xd0, 0x87, 0x8f, 0x2c, 0x6f, 0xb5, 0x8f, 0xbd, 0xc3,
    0xb3, 0x8c, 0xa2, 0x8d, 0x70, 0xdb, 0xc1, 0xad, 0x5b, 0x17, 0xba, 0x55, 0xba, 0x10, 0x0a, 0xfe,
    0x93, 0xd3, 0xbb, 0x24, 0x1e, 0xba, 0x8b, 0x09, 0x5c, 0xd2, 0xda, 0xa1, 0x9b, 0x96, 0x4d, 0x59,
    0x7e, 0x4e, 0x18, 0x5e, 0x9e, 0x2a, 0x22, 0xb5, 0x2e, 0xdc, 0x1d, 0x4f, 0x1f, 0xdc, 0x78, 0xa2,
    0x15, 0xcf, 0xc0, 0x27, 0x47, 0xa0, 0x07, 0xae, 0xe0, 0x6f, 0xfd, 0xb4, 0x3b, 0x6c, 0xa4, 0xc7,
    0xe9, 0x09, 0x2c, 0xcb, 0x11, 0x6c, 0xae, 0x3b, 0x16, 0x8a, 0x3e, 0xab, 0x30, 0xce, 0xdd, 0xea,
    0xad, 0x1d, 0x8e, 0xbe, 0xdb, 0xe5, 0xf2, 0x95, 0xe3, 0x27, 0xd8, 0x40, 0x78, 0x30, 0xd4, 0x0c,
    0x94, 0x6c, 0xd7, 0xb1, 0xf7, 0xb9, 0x08, 0xdf, 0xb6, 0xd5, 0x40, 0x8c, 0x76, 0xdd, 0x19, 0x2d,
    0x8a, 0x18, 0x82, 0x84, 0x45, 0x1b, 0x84, 0xd8, 0x2f, 0x2e, 0xd8, 0x81, 0xbb, 0x69, 0xc9, 0xf7,
    0x40, 0xf5, 0x17, 0xba, 0x62, 0xc2, 0xf4, 0x83, 0x77, 0x9e, 0xfc, 0x93, 0x16, 0xd2, 0xab, 0xc4,
    0x6e, 0xc3, 0x98, 0xa0, 0xd1, 0x32, 0x24, 0x99, 0xcf, 0x19, 0x6e, 0x7d, 0x05, 0x2c, 0x15, 0xcd,
    0x48, 0xca, 0xa6, 0x5b, 0x49, 0x36, 0xc6, 0x1d, 0x45, 0x39, 0x8c, 0x1f, 0x1b, 0xaf, 0xbf, 0x16,
    0x0e, 0xf0, 0x18, 0x17, 0x41, 0xf0, 0xee, 0x13, 0x30, 0xe8, 0x0b, 0x2b, 0x51, 0x4d, 0xfb, 0x7d,
    0x95, 0x51, 0x75, 0x31, 0x45, 0x0c, 0xef, 0xe2, 0x2b, 0x40, 0x69, 0x01, 0x85, 0xd2, 0x83, 0xb4,
    0x91, 0xbd, 0xec, 0x51, 0xaa, 0x7a, 0x0c, 0x57, 0x66, 0xf2, 0xce, 0x67, 0x1a, 0x3c, 0xf5, 0x7d,
    0x0f, 0x38, 0xba, 0xea, 0xf3, 0x20, 0xdd, 0xdc, 0xa5, 0x0a, 0xee, 0xf9, 0x36, 0xc4, 0xba, 0xd2,
    0xeb, 0x90, 0x4c, 0x51, 0xa8, 0x0e, 0x59, 0x1d, 0x68, 0x86, 0xfe, 0xd7, 0x6b, 0x2a, 0x22, 0x5a,
    0xac, 0x51, 0xf4, 0xe4, 0x20, 0xd8, 0xa9, 0x56, 0xeb, 0x64, 0xd2, 0x65, 0x8c, 0x26, 0xd4, 0xa2,
    0x86, 0xcb, 0xb8, 0xbb, 0x38, 0xab, 0xb7, 0x2f, 0x87, 0x41, 0x73, 0x39, 0xcc, 0x24, 0x47, 0xa0,
    0x18, 0x52, 0x9e, 0xef, 0x6e, 0x84, 0x09, 0x46, 0xbd, 0x34, 0x04, 0xda, 0xe7, 0x69, 0xb2, 0x98,
    0xa2, 0x4f, 0x1f, 0x44, 0xad, 0x3f, 0x10, 0x0d, 0x50, 0xb9, 0x2b, 0x5a, 0xc1, 0x64, 0xb1, 0xd4,
    0xe9, 0x2a, 0x62, 0x22, 0x22, 0xc2, 0x7e, 0x76, 0xf8, 0xa5, 0xef, 0xd6, 0x27, 0xd3, 0xc6, 0x2e,
    0xc5, 0xd2, 0xe9, 0x1a, 0x04, 0x7c, 0x36, 0x56, 0xc5, 0x82, 0x4a, 0xaf, 0x11, 0x15, 0x26, 0xc7,
    0x7e, 0x08, 0x29, 0x06, 0x74, 0x10, 0xc3, 0x89, 0xc4, 0x6c, 0x08, 0x0a, 0x10, 0x38, 0x68, 0xa1,
    0x1d, 0xfb, 0x06, 0xc7, 0x55, 0x7e, 0x00, 0x43, 0xf9, 0xe9, 0x85, 0x64, 0xf5, 0xd6, 0x8c, 0xe9,
    0xb3, 0xab, 0x0a, 0x36, 0x08, 0x91, 0xdc, 0x0c, 0xee, 0x53, 0xfb, 0x9c, 0xb8, 0x18, 0xe5, 0xc7,
    0xf6, 0xd9, 0xb0, 0x1a, 0xae, 0xe3, 0xe4, 0x65, 0xdc, 0x1a, 0x77, 0x13, 0xf8, 0xa0, 0x19, 0x15,
    0x17, 0x61, 0xf6, 0x9b, 0x91, 0xb0, 0x0a, 0xaa, 0xd7, 0x0c, 0xdf, 0x21, 0x8e, 0x7d, 0xf3, 0x8e,
    0xab, 0xdb, 0x50, 0xc4, 0x6f, 0xcc, 0x1f, 0x99, 0x3a, 0x43, 0x22, 0x6e, 0xf8, 0x06, 0x79, 0x44,
    0xcc, 0x5f, 0x9a, 0xcb, 0x66, 0x5f, 0xa3, 0x39, 0x01, 0x9a, 0xca, 0x62, 0xa8, 0xf9, 0x37, 0x2c,
    0x18, 0x9d, 0x31, 0x00, 0x21, 0xad, 0x61, 0x02, 0x59, 0x22, 0x76, 0x19, 0x06, 0x71, 0x9c, 0x27,
    0x25, 0x70, 0x26, 0x13, 0xb0, 0x2f, 0x33, 0x99, 0xc8, 0xb8, 0xd4, 0x0d, 0xd1, 0x96, 0xac, 0xf8,
    0xaf, 0x81, 0xcc, 0x61, 0xb5, 0x9f, 0xb1, 0x67, 0xa2, 0xbf, 0x29, 0x57, 0x34, 0xe1, 0x91, 0x18,
    0xcd, 0x02, 0xbe, 0xcd, 0x70, 0xd4, 0x32, 0xb2, 0xa9, 0x6e, 0x2c, 0xff, 0x5f, 0x45, 0x8b, 0x6c,
    0x83, 0xca, 0xf0, 0x95, 0x79, 0x52, 0xc3, 0x08, 0x82, 0x4d, 0xdf, 0xde, 0x8f, 0xb1, 0x91, 0x4b,
    0x2a, 0x92, 0x3d, 0x4c, 0x7f, 0xcb, 0xf7, 0xee, 0xcd, 0xdf, 0xca, 0x4f, 0xf2, 0x9a, 0x66, 0x2c,
    0xe1, 0x0a, 0xf7, 0xbe, 0x72, 0x07, 0xea, 0x72, 0x92, 0x1e, 0x4c, 0x36, 0x57, 0x22, 0x1c, 0xf1,
    0xec, 0x5c, 0x71, 0xf6, 0x21, 0xa8, 0xa1, 0x2e, 0x43, 0x6b, 0x0b, 0x1a, 0x9b, 0xa1, 0x30, 0x05,
    0x63, 0xd9, 0xf7, 0xa5, 0x6c, 0x6b, 0x83, 0xc5, 0xfc, 0xa2, 0x7c, 0x7f, 0x8a, 0x37, 0x5d, 0xfc,
    0xbb, 0x9d, 0x9c, 0x4b, 0x4f, 0xf3, 0xbb, 0x13, 0x4c, 0x1b, 0x1f, 0xc9, 0x75, 0x2f, 0xc0, 0xa4,
    0x21, 0xe1, 0xf2, 0x3b, 0x31, 0x9c, 0xe6, 0xb7, 0xae, 0x1b, 0xd4, 0x0f, 0x90, 0x50, 0xf7, 0x6d,
    0x3d, 0x2d, 0xdc, 0x07, 0x62, 0xca, 0x26, 0x6d, 0x67, 0xc3, 0x00, 0xa8, 0xd7, 0x3b, 0x24, 0xa6,
    0x63, 0xaa, 0x74, 0x52, 0xcc, 0xdc, 0xee, 0xb2, 0x78, 0x45, 0x89, 0x75, 0xd5, 0x85, 0xc4, 0x1a,
    0x65, 0x93, 0x10, 0xb7, 0x31, 0xa6, 0x48, 0xba, 0x6d, 0xb9, 0x63, 0x37, 0xc1, 0x71, 0x88, 0x66,
    0x58, 0xfe, 0x0e, 0x0f, 0xca, 0xa5, 0xba, 0xdd, 0xc4, 0x25, 0xbf, 0xaf, 0x41, 0xb8, 0x57, 0x95,
    0x70, 0xfd, 0x60, 0xb9, 0x06, 0x77, 0x5d, 0x67, 0xee, 0x4c, 0x51, 0x51, 0x0d, 0xa2, 0x36, 0x92,
    0xf9, 0x3d, 0x33, 0x16, 0x91, 0x14, 0x6e, 0x9e, 0x39, 0x50, 0xdd, 0x8b, 0x80, 0xeb, 0x16, 0x55,
    0xc1, 0xd3, 0x1b, 0x0f, 0xc7, 0xef, 0x4c, 0x1e, 0xca, 0x78, 0x38, 0x42, 0x53, 0xe1, 0x24, 0x65,
    0x8c, 0x02, 0x36, 0xd2, 0xdc, 0x70, 0xb3, 0xef, 0xa5, 0xa1, 0x4b, 0x6e, 0x20, 0xec, 0x51, 0x16,
    0x19, 0x7a, 0x73, 0x50, 0xa4, 0xb2, 0x5e, 0x21, 0xec, 0x4c, 0x1f, 0xe4, 0x41, 0x0b, 0x70, 0x7e,
    0xb9, 0xd1, 0x84, 0x58, 0x9e, 0x9f, 0xbd, 0x0e, 0xad, 0xa1, 0x16, 0x84, 0x7d, 0x5b, 0x08, 0xb7,
    0xbc, 0x34, 0xf6, 0xb2, 0xde, 0x1d, 0x21, 0xda, 0x8d, 0xd3, 0xa8, 0xc9, 0x38, 0x45, 0x89, 0x0a,
    0xd9, 0x12, 0x93, 0x0b, 0xcc, 0x5b, 0xcb, 0x01, 0xba, 0x2e, 0x4c, 0x8b, 0xd0, 0x11, 0xde, 0x80,
    0xc0, 0xda, 0xcd, 0xd5, 0x4c, 0x34, 0xfa, 0xe9, 0x12, 0x54, 0x85, 0x5d, 0x34, 0x99, 0x70, 0x20,
    0x0f, 0x5d, 0x0f, 0xad, 0x91, 0xa7, 0x27, 0xb4, 0x44, 0xda, 0xc7, 0x39, 0xa7, 0x2b, 0xec, 0x06,
    0xcf, 0x76, 0xf8, 0xec, 0x88, 0x04, 0xca, 0x61, 0xae, 0xc7, 0xb3, 0xd7, 0xa1, 0xe9, 0x52, 0x27,
    0x2f, 0xbd, 0xe2, 0x2a, 0x81, 0x9f, 0xa3, 0x90, 0x81, 0xf8, 0x7f, 0x04, 0xf8, 0x39, 0x6f, 0x7b,
    0xa5, 0x3c, 0x83, 0xaf, 0x71, 0x13, 0x90, 0x4a, 0x4a, 0x88, 0x98, 0xd0, 0x54, 0xc0, 0xeb, 0xf4,
    0xcd, 0xb0, 0x2d, 0xd3, 0x75, 0x06, 0x32, 0x6e, 0x97, 0x40, 0xbc, 0xfc, 0x37, 0x88, 0x7c, 0xf2,
    0x9c, 0x00, 0x3c, 0xab, 0xe7, 0x1a, 0x7c, 0x14, 0x41, 0xaa, 0x6e, 0xda, 0xc8, 0xe6, 0x84, 0x86,
    0xfe, 0x37, 0x24, 0xcc, 0x64, 0xa3, 0x11, 0xa8, 0x6f, 0x75, 0xbc, 0xaa, 0xfd, 0xde, 0xb8, 0x3f,
    0x29, 0xb8, 0xe3, 0x0c, 0xfa, 0x12, 0xa3, 0xf4, 0x02, 0x4a, 0x11, 0xdf, 0xa6, 0xe9, 0xc9, 0xda,
    0x96, 0x9e, 0x70, 0x4a, 0xfe, 0xc2, 0xee, 0x71, 0xd1, 0x0b, 0x1b, 0x3a, 0x17, 0x59, 0x5e, 0x3d,
    0x4b, 0xb7, 0x24, 0xeb, 0xbc, 0xf9, 0x5d, 0x6a, 0x0a, 0x22, 0xcc, 0xf3, 0xcb, 0x74, 0xfb, 0xb8,
    0x6a, 0x98, 0xad, 0x47, 0x79, 0xbd, 0x08, 0x7b, 0x8f, 0x1f, 0x3f, 0x4b, 0x74, 0x7d, 0x5b, 0xa2,
    0xbb, 0x36, 0x39, 0x1c, 0xcb, 0x48, 0xac, 0x8b, 0xce, 0xa1, 0xe2, 0xa5, 0x89, 0xcf, 0x3b, 0x83,
    0xae, 0xda, 0x52, 0x6f, 0xcb, 0x16, 0x5e, 0x9f, 0x0f, 0x2d, 0x18, 0x52, 0x9d, 0x7f, 0x00, 0xa7,
    0x3a, 0x8e, 0x07
};
#endif

PyTypeObject *init_QPainter(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX].type;

    Shiboken::AutoDecRef Sbk_QPainter_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QPainter_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPainter",
        "QPainter*",
        &Sbk_QPainter_spec,
        &Shiboken::callCppDestructor< ::QPainter >,
        Sbk_QPainter_Type_bases.object(),
        0);
    auto *pyType = Sbk_QPainter_TypeF(); // references _Sbk_QPainter_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPainter_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPainter_SignatureBytes, QPainter_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPainter_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPainter_PythonToCpp_QPainter_PTR,
        is_QPainter_PythonToCpp_QPainter_PTR_Convertible,
        QPainter_PTR_CppToPython_QPainter);

    Shiboken::Conversions::registerConverterName(converter, "QPainter");
    Shiboken::Conversions::registerConverterName(converter, "QPainter*");
    Shiboken::Conversions::registerConverterName(converter, "QPainter&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPainter).name());

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPainter_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'RenderHint'.
    const char *RenderHint_Initializer[] = {
        "Antialiasing",
        "TextAntialiasing",
        "SmoothPixmapTransform",
        "VerticalSubpixelPositioning",
        "LosslessImageRendering",
        "NonCosmeticBrushPatterns",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t RenderHint_InitializerValues[] = {
        uint8_t(QPainter::RenderHint::Antialiasing),                //  0x01  1
        uint8_t(QPainter::RenderHint::TextAntialiasing),            //  0x02  2
        uint8_t(QPainter::RenderHint::SmoothPixmapTransform),       //  0x04  4
        uint8_t(QPainter::RenderHint::VerticalSubpixelPositioning), //  0x08  8
        uint8_t(QPainter::RenderHint::LosslessImageRendering),      //  0x40  64
        uint8_t(QPainter::RenderHint::NonCosmeticBrushPatterns)     //  0x80  128
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPainter_TypeF(),
        "2:PySide6.QtGui.QPainter.RenderHint",
        RenderHint_Initializer, RenderHint_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QPainter_RenderHint_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPainter_RenderHint_IDX].type =
        EType;
    // Register converter for enum 'QPainter::RenderHint'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPainter_RenderHint_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPainter_RenderHint,
            is_Enum_PythonToCpp_QPainter_RenderHint_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPainter::RenderHint");
        Shiboken::Conversions::registerConverterAlias(converter, "RenderHint");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QPainter_RenderHint_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QPainter_RenderHint,
            is_Enum_PythonToCpp_QPainter_RenderHint_Convertible);
        // Register converter for flag 'QFlags<QPainter::RenderHint>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QPainter::RenderHint>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QPainter::RenderHints");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'RenderHint' enum/flags.

    // Initialization of enum 'PixmapFragmentHint'.
    const char *PixmapFragmentHint_Initializer[] = {
        "OpaqueHint",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PixmapFragmentHint_InitializerValues[] = {
        uint8_t(QPainter::PixmapFragmentHint::OpaqueHint) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPainter_TypeF(),
        "2:PySide6.QtGui.QPainter.PixmapFragmentHint",
        PixmapFragmentHint_Initializer, PixmapFragmentHint_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QPainter_PixmapFragmentHint_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QPainter_PixmapFragmentHint_IDX].type =
        EType;
    // Register converter for enum 'QPainter::PixmapFragmentHint'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPainter_PixmapFragmentHint_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPainter_PixmapFragmentHint,
            is_Enum_PythonToCpp_QPainter_PixmapFragmentHint_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPainter::PixmapFragmentHint");
        Shiboken::Conversions::registerConverterAlias(converter, "PixmapFragmentHint");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QPainter_PixmapFragmentHint_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QPainter_PixmapFragmentHint,
            is_Enum_PythonToCpp_QPainter_PixmapFragmentHint_Convertible);
        // Register converter for flag 'QFlags<QPainter::PixmapFragmentHint>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QPainter::PixmapFragmentHint>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QPainter::PixmapFragmentHints");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'PixmapFragmentHint' enum/flags.

    // Initialization of enum 'CompositionMode'.
    const char *CompositionMode_Initializer[] = {
        "CompositionMode_SourceOver",
        "CompositionMode_DestinationOver",
        "CompositionMode_Clear",
        "CompositionMode_Source",
        "CompositionMode_Destination",
        "CompositionMode_SourceIn",
        "CompositionMode_DestinationIn",
        "CompositionMode_SourceOut",
        "CompositionMode_DestinationOut",
        "CompositionMode_SourceAtop",
        "CompositionMode_DestinationAtop",
        "CompositionMode_Xor",
        "CompositionMode_Plus",
        "CompositionMode_Multiply",
        "CompositionMode_Screen",
        "CompositionMode_Overlay",
        "CompositionMode_Darken",
        "CompositionMode_Lighten",
        "CompositionMode_ColorDodge",
        "CompositionMode_ColorBurn",
        "CompositionMode_HardLight",
        "CompositionMode_SoftLight",
        "CompositionMode_Difference",
        "CompositionMode_Exclusion",
        "RasterOp_SourceOrDestination",
        "RasterOp_SourceAndDestination",
        "RasterOp_SourceXorDestination",
        "RasterOp_NotSourceAndNotDestination",
        "RasterOp_NotSourceOrNotDestination",
        "RasterOp_NotSourceXorDestination",
        "RasterOp_NotSource",
        "RasterOp_NotSourceAndDestination",
        "RasterOp_SourceAndNotDestination",
        "RasterOp_NotSourceOrDestination",
        "RasterOp_SourceOrNotDestination",
        "RasterOp_ClearDestination",
        "RasterOp_SetDestination",
        "RasterOp_NotDestination",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CompositionMode_InitializerValues[] = {
        uint8_t(QPainter::CompositionMode::CompositionMode_SourceOver),          //  0x00  0
        uint8_t(QPainter::CompositionMode::CompositionMode_DestinationOver),     //  0x01  1
        uint8_t(QPainter::CompositionMode::CompositionMode_Clear),               //  0x02  2
        uint8_t(QPainter::CompositionMode::CompositionMode_Source),              //  0x03  3
        uint8_t(QPainter::CompositionMode::CompositionMode_Destination),         //  0x04  4
        uint8_t(QPainter::CompositionMode::CompositionMode_SourceIn),            //  0x05  5
        uint8_t(QPainter::CompositionMode::CompositionMode_DestinationIn),       //  0x06  6
        uint8_t(QPainter::CompositionMode::CompositionMode_SourceOut),           //  0x07  7
        uint8_t(QPainter::CompositionMode::CompositionMode_DestinationOut),      //  0x08  8
        uint8_t(QPainter::CompositionMode::CompositionMode_SourceAtop),          //  0x09  9
        uint8_t(QPainter::CompositionMode::CompositionMode_DestinationAtop),     //  0x0a  10
        uint8_t(QPainter::CompositionMode::CompositionMode_Xor),                 //  0x0b  11
        uint8_t(QPainter::CompositionMode::CompositionMode_Plus),                //  0x0c  12
        uint8_t(QPainter::CompositionMode::CompositionMode_Multiply),            //  0x0d  13
        uint8_t(QPainter::CompositionMode::CompositionMode_Screen),              //  0x0e  14
        uint8_t(QPainter::CompositionMode::CompositionMode_Overlay),             //  0x0f  15
        uint8_t(QPainter::CompositionMode::CompositionMode_Darken),              //  0x10  16
        uint8_t(QPainter::CompositionMode::CompositionMode_Lighten),             //  0x11  17
        uint8_t(QPainter::CompositionMode::CompositionMode_ColorDodge),          //  0x12  18
        uint8_t(QPainter::CompositionMode::CompositionMode_ColorBurn),           //  0x13  19
        uint8_t(QPainter::CompositionMode::CompositionMode_HardLight),           //  0x14  20
        uint8_t(QPainter::CompositionMode::CompositionMode_SoftLight),           //  0x15  21
        uint8_t(QPainter::CompositionMode::CompositionMode_Difference),          //  0x16  22
        uint8_t(QPainter::CompositionMode::CompositionMode_Exclusion),           //  0x17  23
        uint8_t(QPainter::CompositionMode::RasterOp_SourceOrDestination),        //  0x18  24
        uint8_t(QPainter::CompositionMode::RasterOp_SourceAndDestination),       //  0x19  25
        uint8_t(QPainter::CompositionMode::RasterOp_SourceXorDestination),       //  0x1a  26
        uint8_t(QPainter::CompositionMode::RasterOp_NotSourceAndNotDestination), //  0x1b  27
        uint8_t(QPainter::CompositionMode::RasterOp_NotSourceOrNotDestination),  //  0x1c  28
        uint8_t(QPainter::CompositionMode::RasterOp_NotSourceXorDestination),    //  0x1d  29
        uint8_t(QPainter::CompositionMode::RasterOp_NotSource),                  //  0x1e  30
        uint8_t(QPainter::CompositionMode::RasterOp_NotSourceAndDestination),    //  0x1f  31
        uint8_t(QPainter::CompositionMode::RasterOp_SourceAndNotDestination),    //  0x20  32
        uint8_t(QPainter::CompositionMode::RasterOp_NotSourceOrDestination),     //  0x21  33
        uint8_t(QPainter::CompositionMode::RasterOp_SourceOrNotDestination),     //  0x22  34
        uint8_t(QPainter::CompositionMode::RasterOp_ClearDestination),           //  0x23  35
        uint8_t(QPainter::CompositionMode::RasterOp_SetDestination),             //  0x24  36
        uint8_t(QPainter::CompositionMode::RasterOp_NotDestination)              //  0x25  37
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPainter_TypeF(),
        "2:PySide6.QtGui.QPainter.CompositionMode",
        CompositionMode_Initializer, CompositionMode_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QPainter_CompositionMode_IDX].type = EType;
    // Register converter for enum 'QPainter::CompositionMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPainter_CompositionMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPainter_CompositionMode,
            is_Enum_PythonToCpp_QPainter_CompositionMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPainter::CompositionMode");
        Shiboken::Conversions::registerConverterAlias(converter, "CompositionMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CompositionMode' enum.

    qRegisterMetaType< ::QPainter *>();
    qRegisterMetaType< ::QPainter::RenderHint >("QPainter::RenderHint");
    qRegisterMetaType< ::QPainter::PixmapFragmentHint >("QPainter::PixmapFragmentHint");
    qRegisterMetaType< ::QPainter::CompositionMode >("QPainter::CompositionMode");

    return pyType;
}
