// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qrhigraphicspipeline_wrapper.h"

// inner classes
#include "qrhigraphicspipeline_stencilopstate_wrapper.h"
#include "qrhigraphicspipeline_targetblend_wrapper.h"

// Argument includes
#include <QList>
#include <qbytearray.h>
#include <rhi/qrhi.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QRhiGraphicsPipelineWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

bool QRhiGraphicsPipelineWrapper::create()
{
    if (m_PyMethodCache[0]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiGraphicsPipeline.create");
        return false;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "create";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiGraphicsPipeline.create");
        return false;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiGraphicsPipeline", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiGraphicsPipeline", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QRhiGraphicsPipelineWrapper::destroy()
{
    if (m_PyMethodCache[1]) {
        Shiboken::GilState gil;
        Shiboken::Errors::setPureVirtualMethodError("QRhiGraphicsPipeline.destroy");
        return;
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "destroy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        Shiboken::Errors::setPureVirtualMethodError("QRhiGraphicsPipeline.destroy");
        return;
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiGraphicsPipeline", funcName);
        return;
    }
}

::QRhiResource::Type QRhiGraphicsPipelineWrapper::resourceType() const
{
    if (m_PyMethodCache[2])
        return this->::QRhiGraphicsPipeline::resourceType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return QRhiResource::Buffer;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resourceType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QRhiGraphicsPipeline::resourceType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QRhiGraphicsPipeline", funcName);
        return QRhiResource::Buffer;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QRhiGraphicsPipeline", funcName, Shiboken::SbkType< QRhiResource::Type >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return QRhiResource::Buffer;
    }
    ::QRhiResource::Type cppResult{QRhiResource::Buffer};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QRhiGraphicsPipelineWrapper::~QRhiGraphicsPipelineWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QRhiGraphicsPipelineFunc_cbeginShaderStages(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cbeginShaderStages()const
        const QRhiShaderStage * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->cbeginShaderStages();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_cbeginTargetBlends(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cbeginTargetBlends()const
        const QRhiGraphicsPipeline::TargetBlend * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->cbeginTargetBlends();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_TargetBlend_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_cendShaderStages(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cendShaderStages()const
        const QRhiShaderStage * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->cendShaderStages();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_cendTargetBlends(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cendTargetBlends()const
        const QRhiGraphicsPipeline::TargetBlend * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->cendTargetBlends();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_TargetBlend_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_create(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // create()
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("QRhiGraphicsPipeline.create");
            return {};
        }
        bool cppResult = cppSelf->create();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_cullMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cullMode()const
        QRhiGraphicsPipeline::CullMode cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->cullMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_depthBias(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depthBias()const
        int cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->depthBias();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_depthOp(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // depthOp()const
        QRhiGraphicsPipeline::CompareOp cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->depthOp();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QRhiGraphicsPipeline::Flag> cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiGraphicsPipeline_Flag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_frontFace(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // frontFace()const
        QRhiGraphicsPipeline::FrontFace cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->frontFace();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_hasDepthTest(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasDepthTest()const
        bool cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->hasDepthTest();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_hasDepthWrite(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasDepthWrite()const
        bool cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->hasDepthWrite();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_hasStencilTest(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasStencilTest()const
        bool cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->hasStencilTest();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_lineWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lineWidth()const
        float cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->lineWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_multiViewCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // multiViewCount()const
        int cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->multiViewCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_patchControlPointCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // patchControlPointCount()const
        int cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->patchControlPointCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_polygonMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // polygonMode()const
        QRhiGraphicsPipeline::PolygonMode cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->polygonMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_renderPassDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // renderPassDescriptor()const
        QRhiRenderPassDescriptor * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->renderPassDescriptor();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_resourceType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resourceType()const
        QRhiResource::Type cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->::QRhiGraphicsPipeline::resourceType()
            : const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->resourceType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_Type_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_sampleCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sampleCount()const
        int cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->sampleCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setCullMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setCullMode(QRhiGraphicsPipeline::CullMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setCullMode(QRhiGraphicsPipeline::CullMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCullMode", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        ::QRhiGraphicsPipeline::CullMode cppArg0{QRhiGraphicsPipeline::None};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCullMode(QRhiGraphicsPipeline::CullMode)
            cppSelf->setCullMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setDepthBias(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setDepthBias(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setDepthBias(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepthBias", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthBias(int)
            cppSelf->setDepthBias(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setDepthOp(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setDepthOp(QRhiGraphicsPipeline::CompareOp)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDepthOp(QRhiGraphicsPipeline::CompareOp)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepthOp", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        ::QRhiGraphicsPipeline::CompareOp cppArg0{QRhiGraphicsPipeline::Never};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthOp(QRhiGraphicsPipeline::CompareOp)
            cppSelf->setDepthOp(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setDepthTest(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setDepthTest(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDepthTest(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepthTest", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthTest(bool)
            cppSelf->setDepthTest(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setDepthWrite(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setDepthWrite(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setDepthWrite(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDepthWrite", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDepthWrite(bool)
            cppSelf->setDepthWrite(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setFlags(QFlags<QRhiGraphicsPipeline::Flag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiGraphicsPipeline_Flag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QRhiGraphicsPipeline::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlags", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        ::QFlags<QRhiGraphicsPipeline::Flag> cppArg0 = QFlags<QRhiGraphicsPipeline::Flag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QRhiGraphicsPipeline::Flag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setFrontFace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setFrontFace(QRhiGraphicsPipeline::FrontFace)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFrontFace(QRhiGraphicsPipeline::FrontFace)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFrontFace", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        ::QRhiGraphicsPipeline::FrontFace cppArg0{QRhiGraphicsPipeline::CCW};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFrontFace(QRhiGraphicsPipeline::FrontFace)
            cppSelf->setFrontFace(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setLineWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setLineWidth(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setLineWidth(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLineWidth", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLineWidth(float)
            cppSelf->setLineWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setMultiViewCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setMultiViewCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMultiViewCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMultiViewCount", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMultiViewCount(int)
            cppSelf->setMultiViewCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setPatchControlPointCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setPatchControlPointCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setPatchControlPointCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPatchControlPointCount", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPatchControlPointCount(int)
            cppSelf->setPatchControlPointCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setPolygonMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setPolygonMode(QRhiGraphicsPipeline::PolygonMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setPolygonMode(QRhiGraphicsPipeline::PolygonMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPolygonMode", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        ::QRhiGraphicsPipeline::PolygonMode cppArg0{QRhiGraphicsPipeline::Fill};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPolygonMode(QRhiGraphicsPipeline::PolygonMode)
            cppSelf->setPolygonMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setRenderPassDescriptor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setRenderPassDescriptor(QRhiRenderPassDescriptor*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), (pyArg)))) {
        overloadId = 0; // setRenderPassDescriptor(QRhiRenderPassDescriptor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRenderPassDescriptor", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiRenderPassDescriptor *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRenderPassDescriptor(QRhiRenderPassDescriptor*)
            cppSelf->setRenderPassDescriptor(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setSampleCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setSampleCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setSampleCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSampleCount", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSampleCount(int)
            cppSelf->setSampleCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setShaderResourceBindings(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setShaderResourceBindings(QRhiShaderResourceBindings*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), (pyArg)))) {
        overloadId = 0; // setShaderResourceBindings(QRhiShaderResourceBindings*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShaderResourceBindings", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiShaderResourceBindings *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShaderResourceBindings(QRhiShaderResourceBindings*)
            cppSelf->setShaderResourceBindings(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setShaderStages(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setShaderStages(QList<QRhiShaderStage>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiShaderStage_IDX], (pyArg)))) {
        overloadId = 0; // setShaderStages(QList<QRhiShaderStage>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setShaderStages", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        ::QList<QRhiShaderStage> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // setShaderStages(QList<QRhiShaderStage>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            cppSelf->setShaderStages(cppArg0.cbegin(), cppArg0.cend());
            // END of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setSlopeScaledDepthBias(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setSlopeScaledDepthBias(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // setSlopeScaledDepthBias(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSlopeScaledDepthBias", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSlopeScaledDepthBias(float)
            cppSelf->setSlopeScaledDepthBias(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setStencilBack(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setStencilBack(QRhiGraphicsPipeline::StencilOpState)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), (pyArg)))) {
        overloadId = 0; // setStencilBack(QRhiGraphicsPipeline::StencilOpState)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStencilBack", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiGraphicsPipeline::StencilOpState cppArg0_local;
        ::QRhiGraphicsPipeline::StencilOpState *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilBack(QRhiGraphicsPipeline::StencilOpState)
            cppSelf->setStencilBack(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setStencilFront(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setStencilFront(QRhiGraphicsPipeline::StencilOpState)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), (pyArg)))) {
        overloadId = 0; // setStencilFront(QRhiGraphicsPipeline::StencilOpState)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStencilFront", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiGraphicsPipeline::StencilOpState cppArg0_local;
        ::QRhiGraphicsPipeline::StencilOpState *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilFront(QRhiGraphicsPipeline::StencilOpState)
            cppSelf->setStencilFront(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setStencilReadMask(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setStencilReadMask(quint32)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 0; // setStencilReadMask(quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStencilReadMask", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        quint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilReadMask(quint32)
            cppSelf->setStencilReadMask(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setStencilTest(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setStencilTest(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setStencilTest(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStencilTest", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilTest(bool)
            cppSelf->setStencilTest(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setStencilWriteMask(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setStencilWriteMask(quint32)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyArg)))) {
        overloadId = 0; // setStencilWriteMask(quint32)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStencilWriteMask", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        quint32 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStencilWriteMask(quint32)
            cppSelf->setStencilWriteMask(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setTargetBlends(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setTargetBlends(QList<QRhiGraphicsPipeline::TargetBlend>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QRhiGraphicsPipeline_TargetBlend_IDX], (pyArg)))) {
        overloadId = 0; // setTargetBlends(QList<QRhiGraphicsPipeline::TargetBlend>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTargetBlends", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        ::QList<QRhiGraphicsPipeline::TargetBlend> cppArg0;
        pythonToCpp(pyArg, &cppArg0);
        SBK_UNUSED(cppArg0)

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTargetBlends(QList<QRhiGraphicsPipeline::TargetBlend>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            cppSelf->setTargetBlends(cppArg0.cbegin(), cppArg0.cend());
            // END of custom code block [file: ../glue/qtgui.cpp (qrhi-initializer-list)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setTopology(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setTopology(QRhiGraphicsPipeline::Topology)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTopology(QRhiGraphicsPipeline::Topology)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTopology", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        ::QRhiGraphicsPipeline::Topology cppArg0{QRhiGraphicsPipeline::Triangles};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTopology(QRhiGraphicsPipeline::Topology)
            cppSelf->setTopology(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_setVertexInputLayout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::setVertexInputLayout(QRhiVertexInputLayout)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), (pyArg)))) {
        overloadId = 0; // setVertexInputLayout(QRhiVertexInputLayout)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVertexInputLayout", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRhiVertexInputLayout cppArg0_local;
        ::QRhiVertexInputLayout *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setVertexInputLayout(QRhiVertexInputLayout)
            cppSelf->setVertexInputLayout(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_shaderResourceBindings(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shaderResourceBindings()const
        QRhiShaderResourceBindings * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->shaderResourceBindings();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_shaderStageAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::shaderStageAt(qsizetype)const->const QRhiShaderStage*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // shaderStageAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "shaderStageAt", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // shaderStageAt(qsizetype)const
            const QRhiShaderStage * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->shaderStageAt(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderStage_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_shaderStageCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // shaderStageCount()const
        qsizetype cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->shaderStageCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_slopeScaledDepthBias(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // slopeScaledDepthBias()const
        float cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->slopeScaledDepthBias();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_stencilBack(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stencilBack()const
        QRhiGraphicsPipeline::StencilOpState cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->stencilBack();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_stencilFront(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stencilFront()const
        QRhiGraphicsPipeline::StencilOpState cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->stencilFront();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_stencilReadMask(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stencilReadMask()const
        quint32 cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->stencilReadMask();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_stencilWriteMask(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stencilWriteMask()const
        quint32 cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->stencilWriteMask();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_targetBlendAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QRhiGraphicsPipeline::targetBlendAt(qsizetype)const->const QRhiGraphicsPipeline::TargetBlend*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArg)))) {
        overloadId = 0; // targetBlendAt(qsizetype)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "targetBlendAt", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]);

    // Call function/method
    {
        qsizetype cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // targetBlendAt(qsizetype)const
            const QRhiGraphicsPipeline::TargetBlend * cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->targetBlendAt(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_TargetBlend_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_targetBlendCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // targetBlendCount()const
        qsizetype cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->targetBlendCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_topology(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // topology()const
        QRhiGraphicsPipeline::Topology cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->topology();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QRhiGraphicsPipelineFunc_vertexInputLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // vertexInputLayout()const
        QRhiVertexInputLayout cppResult = const_cast<const ::QRhiGraphicsPipeline *>(cppSelf)->vertexInputLayout();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QRhiGraphicsPipeline_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QRhiGraphicsPipeline_EnumFlagInfo[] = {
    "BlendFactor:Enum",
    "BlendOp:Enum",
    "ColorMaskComponent:Flag:ColorMask",
    "CompareOp:Enum",
    "CullMode:Enum",
    "Flag:Flag:Flags",
    "FrontFace:Enum",
    "PolygonMode:Enum",
    "StencilOp:Enum",
    "Topology:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QRhiGraphicsPipeline_methods[] = {
    {"cbeginShaderStages", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_cbeginShaderStages), METH_NOARGS, nullptr},
    {"cbeginTargetBlends", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_cbeginTargetBlends), METH_NOARGS, nullptr},
    {"cendShaderStages", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_cendShaderStages), METH_NOARGS, nullptr},
    {"cendTargetBlends", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_cendTargetBlends), METH_NOARGS, nullptr},
    {"create", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_create), METH_NOARGS, nullptr},
    {"cullMode", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_cullMode), METH_NOARGS, nullptr},
    {"depthBias", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_depthBias), METH_NOARGS, nullptr},
    {"depthOp", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_depthOp), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_flags), METH_NOARGS, nullptr},
    {"frontFace", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_frontFace), METH_NOARGS, nullptr},
    {"hasDepthTest", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_hasDepthTest), METH_NOARGS, nullptr},
    {"hasDepthWrite", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_hasDepthWrite), METH_NOARGS, nullptr},
    {"hasStencilTest", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_hasStencilTest), METH_NOARGS, nullptr},
    {"lineWidth", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_lineWidth), METH_NOARGS, nullptr},
    {"multiViewCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_multiViewCount), METH_NOARGS, nullptr},
    {"patchControlPointCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_patchControlPointCount), METH_NOARGS, nullptr},
    {"polygonMode", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_polygonMode), METH_NOARGS, nullptr},
    {"renderPassDescriptor", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_renderPassDescriptor), METH_NOARGS, nullptr},
    {"resourceType", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_resourceType), METH_NOARGS, nullptr},
    {"sampleCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_sampleCount), METH_NOARGS, nullptr},
    {"setCullMode", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setCullMode), METH_O, nullptr},
    {"setDepthBias", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setDepthBias), METH_O, nullptr},
    {"setDepthOp", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setDepthOp), METH_O, nullptr},
    {"setDepthTest", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setDepthTest), METH_O, nullptr},
    {"setDepthWrite", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setDepthWrite), METH_O, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setFlags), METH_O, nullptr},
    {"setFrontFace", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setFrontFace), METH_O, nullptr},
    {"setLineWidth", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setLineWidth), METH_O, nullptr},
    {"setMultiViewCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setMultiViewCount), METH_O, nullptr},
    {"setPatchControlPointCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setPatchControlPointCount), METH_O, nullptr},
    {"setPolygonMode", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setPolygonMode), METH_O, nullptr},
    {"setRenderPassDescriptor", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setRenderPassDescriptor), METH_O, nullptr},
    {"setSampleCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setSampleCount), METH_O, nullptr},
    {"setShaderResourceBindings", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setShaderResourceBindings), METH_O, nullptr},
    {"setShaderStages", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setShaderStages), METH_O, nullptr},
    {"setSlopeScaledDepthBias", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setSlopeScaledDepthBias), METH_O, nullptr},
    {"setStencilBack", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setStencilBack), METH_O, nullptr},
    {"setStencilFront", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setStencilFront), METH_O, nullptr},
    {"setStencilReadMask", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setStencilReadMask), METH_O, nullptr},
    {"setStencilTest", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setStencilTest), METH_O, nullptr},
    {"setStencilWriteMask", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setStencilWriteMask), METH_O, nullptr},
    {"setTargetBlends", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setTargetBlends), METH_O, nullptr},
    {"setTopology", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setTopology), METH_O, nullptr},
    {"setVertexInputLayout", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_setVertexInputLayout), METH_O, nullptr},
    {"shaderResourceBindings", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_shaderResourceBindings), METH_NOARGS, nullptr},
    {"shaderStageAt", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_shaderStageAt), METH_O, nullptr},
    {"shaderStageCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_shaderStageCount), METH_NOARGS, nullptr},
    {"slopeScaledDepthBias", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_slopeScaledDepthBias), METH_NOARGS, nullptr},
    {"stencilBack", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_stencilBack), METH_NOARGS, nullptr},
    {"stencilFront", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_stencilFront), METH_NOARGS, nullptr},
    {"stencilReadMask", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_stencilReadMask), METH_NOARGS, nullptr},
    {"stencilWriteMask", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_stencilWriteMask), METH_NOARGS, nullptr},
    {"targetBlendAt", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_targetBlendAt), METH_O, nullptr},
    {"targetBlendCount", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_targetBlendCount), METH_NOARGS, nullptr},
    {"topology", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_topology), METH_NOARGS, nullptr},
    {"vertexInputLayout", reinterpret_cast<PyCFunction>(Sbk_QRhiGraphicsPipelineFunc_vertexInputLayout), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QRhiGraphicsPipeline_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QRhiGraphicsPipelineWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_flags(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiGraphicsPipeline_Flag_IDX])))->flagsConverter, &cppSelf->m_flags);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_flags(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_flags");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiGraphicsPipeline_Flag_IDX])))->flagsConverter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_flags", "Flags");
        return -1;
    }

    auto cppOut_local = cppSelf->m_flags;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_flags = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_topology(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiGraphicsPipeline::Topology cppOut_local = cppSelf->m_topology;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_topology(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_topology");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_topology", "Topology");
        return -1;
    }

    auto cppOut_local = cppSelf->m_topology;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_topology = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_cullMode(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiGraphicsPipeline::CullMode cppOut_local = cppSelf->m_cullMode;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_cullMode(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_cullMode");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_cullMode", "CullMode");
        return -1;
    }

    auto cppOut_local = cppSelf->m_cullMode;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_cullMode = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_frontFace(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiGraphicsPipeline::FrontFace cppOut_local = cppSelf->m_frontFace;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_frontFace(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_frontFace");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_frontFace", "FrontFace");
        return -1;
    }

    auto cppOut_local = cppSelf->m_frontFace;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_frontFace = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_depthTest(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->m_depthTest;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_depthTest(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_depthTest");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_depthTest", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->m_depthTest;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_depthTest = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_depthWrite(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->m_depthWrite;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_depthWrite(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_depthWrite");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_depthWrite", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->m_depthWrite;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_depthWrite = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_depthOp(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiGraphicsPipeline::CompareOp cppOut_local = cppSelf->m_depthOp;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_depthOp(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_depthOp");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_depthOp", "CompareOp");
        return -1;
    }

    auto cppOut_local = cppSelf->m_depthOp;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_depthOp = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_stencilTest(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    bool cppOut_local = cppSelf->m_stencilTest;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_stencilTest(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_stencilTest");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_stencilTest", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->m_stencilTest;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_stencilTest = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_stencilFront(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->m_stencilFront)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->m_stencilFront))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->m_stencilFront)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), &(cppSelf->m_stencilFront), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_stencilFront(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_stencilFront");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_stencilFront", "StencilOpState");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_stencilFront;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_stencilBack(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->m_stencilBack)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->m_stencilBack))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->m_stencilBack)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), &(cppSelf->m_stencilBack), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_stencilBack(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_stencilBack");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOpState_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_stencilBack", "StencilOpState");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_stencilBack;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_stencilReadMask(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint32 cppOut_local = cppSelf->m_stencilReadMask;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_stencilReadMask(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_stencilReadMask");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_stencilReadMask", "quint32");
        return -1;
    }

    auto cppOut_local = cppSelf->m_stencilReadMask;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_stencilReadMask = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_stencilWriteMask(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    quint32 cppOut_local = cppSelf->m_stencilWriteMask;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_stencilWriteMask(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_stencilWriteMask");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_stencilWriteMask", "quint32");
        return -1;
    }

    auto cppOut_local = cppSelf->m_stencilWriteMask;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_stencilWriteMask = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_sampleCount(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_sampleCount;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_sampleCount(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_sampleCount");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_sampleCount", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_sampleCount;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_sampleCount = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_lineWidth(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppSelf->m_lineWidth);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_lineWidth(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_lineWidth");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_lineWidth", "float");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_lineWidth;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_depthBias(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_depthBias;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_depthBias(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_depthBias");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_depthBias", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_depthBias;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_depthBias = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_slopeScaledDepthBias(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &cppSelf->m_slopeScaledDepthBias);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_slopeScaledDepthBias(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_slopeScaledDepthBias");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_slopeScaledDepthBias", "float");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_slopeScaledDepthBias;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_patchControlPointCount(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_patchControlPointCount;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_patchControlPointCount(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_patchControlPointCount");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_patchControlPointCount", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_patchControlPointCount;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_patchControlPointCount = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_polygonMode(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    ::QRhiGraphicsPipeline::PolygonMode cppOut_local = cppSelf->m_polygonMode;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX])))->converter, &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_polygonMode(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_polygonMode");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX])))->converter, (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_polygonMode", "PolygonMode");
        return -1;
    }

    auto cppOut_local = cppSelf->m_polygonMode;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_polygonMode = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_multiViewCount(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    int cppOut_local = cppSelf->m_multiViewCount;
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppOut_local);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_multiViewCount(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_multiViewCount");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_multiViewCount", "int");
        return -1;
    }

    auto cppOut_local = cppSelf->m_multiViewCount;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->m_multiViewCount = cppOut_local;

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_vertexInputLayout(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    if (reinterpret_cast<void *>(&(cppSelf->m_vertexInputLayout)) == reinterpret_cast<void *>(cppSelf)) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::Object::findColocatedChild(reinterpret_cast<SbkObject *>(self), Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX])));
        if (pyOut != nullptr) {
            Py_IncRef(pyOut);
            return pyOut;
        }
    } else if (Shiboken::BindingManager::instance().hasWrapper(&(cppSelf->m_vertexInputLayout))) {
        pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(&(cppSelf->m_vertexInputLayout)));
        Py_IncRef(pyOut);
        return pyOut;
    }
    pyOut = Shiboken::Object::newObject(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), &(cppSelf->m_vertexInputLayout), false, true);
    Shiboken::Object::setParent(self, pyOut);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_vertexInputLayout(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_vertexInputLayout");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiVertexInputLayout_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_vertexInputLayout", "QRhiVertexInputLayout");
        return -1;
    }

    auto &cppOut_ptr = cppSelf->m_vertexInputLayout;
    pythonToCpp(pyIn, &cppOut_ptr);

    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_shaderResourceBindings(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), cppSelf->m_shaderResourceBindings);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_shaderResourceBindings(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_shaderResourceBindings");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiShaderResourceBindings_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_shaderResourceBindings", "QRhiShaderResourceBindings");
        return -1;
    }

    auto *&cppOut_ptr = cppSelf->m_shaderResourceBindings;
    pythonToCpp(pyIn, &cppOut_ptr);

    Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "m_shaderResourceBindings", pyIn);
    return 0;
}

static PyObject *Sbk_QRhiGraphicsPipeline_get_m_renderPassDesc(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyOut = {};
    pyOut = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), cppSelf->m_renderPassDesc);
    return pyOut;
}
static int Sbk_QRhiGraphicsPipeline_set_m_renderPassDesc(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    auto *cppSelf = reinterpret_cast< ::QRhiGraphicsPipeline *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("m_renderPassDesc");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiRenderPassDescriptor_IDX]), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("m_renderPassDesc", "QRhiRenderPassDescriptor");
        return -1;
    }

    auto *&cppOut_ptr = cppSelf->m_renderPassDesc;
    pythonToCpp(pyIn, &cppOut_ptr);

    Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "m_renderPassDesc", pyIn);
    return 0;
}

// Getters and Setters for QRhiGraphicsPipeline
static PyGetSetDef Sbk_QRhiGraphicsPipeline_getsetlist[] = {
    {const_cast<char *>("m_flags"), Sbk_QRhiGraphicsPipeline_get_m_flags, Sbk_QRhiGraphicsPipeline_set_m_flags, nullptr, nullptr},
    {const_cast<char *>("m_topology"), Sbk_QRhiGraphicsPipeline_get_m_topology, Sbk_QRhiGraphicsPipeline_set_m_topology, nullptr, nullptr},
    {const_cast<char *>("m_cullMode"), Sbk_QRhiGraphicsPipeline_get_m_cullMode, Sbk_QRhiGraphicsPipeline_set_m_cullMode, nullptr, nullptr},
    {const_cast<char *>("m_frontFace"), Sbk_QRhiGraphicsPipeline_get_m_frontFace, Sbk_QRhiGraphicsPipeline_set_m_frontFace, nullptr, nullptr},
    {const_cast<char *>("m_depthTest"), Sbk_QRhiGraphicsPipeline_get_m_depthTest, Sbk_QRhiGraphicsPipeline_set_m_depthTest, nullptr, nullptr},
    {const_cast<char *>("m_depthWrite"), Sbk_QRhiGraphicsPipeline_get_m_depthWrite, Sbk_QRhiGraphicsPipeline_set_m_depthWrite, nullptr, nullptr},
    {const_cast<char *>("m_depthOp"), Sbk_QRhiGraphicsPipeline_get_m_depthOp, Sbk_QRhiGraphicsPipeline_set_m_depthOp, nullptr, nullptr},
    {const_cast<char *>("m_stencilTest"), Sbk_QRhiGraphicsPipeline_get_m_stencilTest, Sbk_QRhiGraphicsPipeline_set_m_stencilTest, nullptr, nullptr},
    {const_cast<char *>("m_stencilFront"), Sbk_QRhiGraphicsPipeline_get_m_stencilFront, Sbk_QRhiGraphicsPipeline_set_m_stencilFront, nullptr, nullptr},
    {const_cast<char *>("m_stencilBack"), Sbk_QRhiGraphicsPipeline_get_m_stencilBack, Sbk_QRhiGraphicsPipeline_set_m_stencilBack, nullptr, nullptr},
    {const_cast<char *>("m_stencilReadMask"), Sbk_QRhiGraphicsPipeline_get_m_stencilReadMask, Sbk_QRhiGraphicsPipeline_set_m_stencilReadMask, nullptr, nullptr},
    {const_cast<char *>("m_stencilWriteMask"), Sbk_QRhiGraphicsPipeline_get_m_stencilWriteMask, Sbk_QRhiGraphicsPipeline_set_m_stencilWriteMask, nullptr, nullptr},
    {const_cast<char *>("m_sampleCount"), Sbk_QRhiGraphicsPipeline_get_m_sampleCount, Sbk_QRhiGraphicsPipeline_set_m_sampleCount, nullptr, nullptr},
    {const_cast<char *>("m_lineWidth"), Sbk_QRhiGraphicsPipeline_get_m_lineWidth, Sbk_QRhiGraphicsPipeline_set_m_lineWidth, nullptr, nullptr},
    {const_cast<char *>("m_depthBias"), Sbk_QRhiGraphicsPipeline_get_m_depthBias, Sbk_QRhiGraphicsPipeline_set_m_depthBias, nullptr, nullptr},
    {const_cast<char *>("m_slopeScaledDepthBias"), Sbk_QRhiGraphicsPipeline_get_m_slopeScaledDepthBias, Sbk_QRhiGraphicsPipeline_set_m_slopeScaledDepthBias, nullptr, nullptr},
    {const_cast<char *>("m_patchControlPointCount"), Sbk_QRhiGraphicsPipeline_get_m_patchControlPointCount, Sbk_QRhiGraphicsPipeline_set_m_patchControlPointCount, nullptr, nullptr},
    {const_cast<char *>("m_polygonMode"), Sbk_QRhiGraphicsPipeline_get_m_polygonMode, Sbk_QRhiGraphicsPipeline_set_m_polygonMode, nullptr, nullptr},
    {const_cast<char *>("m_multiViewCount"), Sbk_QRhiGraphicsPipeline_get_m_multiViewCount, Sbk_QRhiGraphicsPipeline_set_m_multiViewCount, nullptr, nullptr},
    {const_cast<char *>("m_vertexInputLayout"), Sbk_QRhiGraphicsPipeline_get_m_vertexInputLayout, Sbk_QRhiGraphicsPipeline_set_m_vertexInputLayout, nullptr, nullptr},
    {const_cast<char *>("m_shaderResourceBindings"), Sbk_QRhiGraphicsPipeline_get_m_shaderResourceBindings, Sbk_QRhiGraphicsPipeline_set_m_shaderResourceBindings, nullptr, nullptr},
    {const_cast<char *>("m_renderPassDesc"), Sbk_QRhiGraphicsPipeline_get_m_renderPassDesc, Sbk_QRhiGraphicsPipeline_set_m_renderPassDesc, nullptr, nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QRhiGraphicsPipeline_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QRhiGraphicsPipeline_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QRhiGraphicsPipeline_Type = nullptr;
static PyTypeObject *Sbk_QRhiGraphicsPipeline_TypeF(void)
{
    return _Sbk_QRhiGraphicsPipeline_Type;
}

static PyType_Slot Sbk_QRhiGraphicsPipeline_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QRhiGraphicsPipeline_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QRhiGraphicsPipeline_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QRhiGraphicsPipeline_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QRhiGraphicsPipeline_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_QRhiGraphicsPipeline_getsetlist)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QRhiGraphicsPipeline_spec = {
    "2:PySide6.QtGui.QRhiGraphicsPipeline",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QRhiGraphicsPipeline_slots
};

} //extern "C"

static void *Sbk_QRhiGraphicsPipeline_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QRhiResource >())
        return dynamic_cast< ::QRhiGraphicsPipeline *>(reinterpret_cast< ::QRhiResource *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QRhiGraphicsPipeline_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Flag_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_Flag;
    return {};
}

static PyObject *QRhiGraphicsPipeline_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiGraphicsPipeline::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiGraphicsPipeline::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QRhiGraphicsPipeline_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QRhiGraphicsPipeline::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QRhiGraphicsPipeline::Flag> *>(cppOut) = value;

}

static PyObject *QRhiGraphicsPipeline_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QRhiGraphicsPipeline::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Flag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_Topology(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::Topology>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::Topology *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_Topology_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_Topology;
    return {};
}

static PyObject *QRhiGraphicsPipeline_Topology_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiGraphicsPipeline::Topology>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiGraphicsPipeline::Topology *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_CullMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::CullMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::CullMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_CullMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_CullMode;
    return {};
}

static PyObject *QRhiGraphicsPipeline_CullMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiGraphicsPipeline::CullMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiGraphicsPipeline::CullMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_FrontFace(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::FrontFace>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::FrontFace *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_FrontFace_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_FrontFace;
    return {};
}

static PyObject *QRhiGraphicsPipeline_FrontFace_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiGraphicsPipeline::FrontFace>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiGraphicsPipeline::FrontFace *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_ColorMaskComponent(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::ColorMaskComponent>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::ColorMaskComponent *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_ColorMaskComponent_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_ColorMaskComponent_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_ColorMaskComponent;
    return {};
}

static PyObject *QRhiGraphicsPipeline_ColorMaskComponent_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiGraphicsPipeline::ColorMaskComponent>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiGraphicsPipeline::ColorMaskComponent *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_ColorMaskComponent_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QRhiGraphicsPipeline_ColorMaskComponent(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QRhiGraphicsPipeline::ColorMaskComponent>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QRhiGraphicsPipeline::ColorMaskComponent> *>(cppOut) = value;

}

static PyObject *QRhiGraphicsPipeline_ColorMaskComponent_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QRhiGraphicsPipeline::ColorMaskComponent> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_ColorMaskComponent_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_BlendFactor(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::BlendFactor>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::BlendFactor *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_BlendFactor_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_BlendFactor_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_BlendFactor;
    return {};
}

static PyObject *QRhiGraphicsPipeline_BlendFactor_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiGraphicsPipeline::BlendFactor>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiGraphicsPipeline::BlendFactor *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_BlendFactor_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_BlendOp(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::BlendOp>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::BlendOp *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_BlendOp_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_BlendOp_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_BlendOp;
    return {};
}

static PyObject *QRhiGraphicsPipeline_BlendOp_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiGraphicsPipeline::BlendOp>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiGraphicsPipeline::BlendOp *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_BlendOp_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_CompareOp(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::CompareOp>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::CompareOp *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_CompareOp_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_CompareOp;
    return {};
}

static PyObject *QRhiGraphicsPipeline_CompareOp_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiGraphicsPipeline::CompareOp>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiGraphicsPipeline::CompareOp *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_StencilOp(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::StencilOp>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::StencilOp *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_StencilOp_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOp_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_StencilOp;
    return {};
}

static PyObject *QRhiGraphicsPipeline_StencilOp_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiGraphicsPipeline::StencilOp>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiGraphicsPipeline::StencilOp *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOp_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QRhiGraphicsPipeline_PolygonMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QRhiGraphicsPipeline::PolygonMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QRhiGraphicsPipeline::PolygonMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QRhiGraphicsPipeline_PolygonMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX])))
        return Enum_PythonToCpp_QRhiGraphicsPipeline_PolygonMode;
    return {};
}

static PyObject *QRhiGraphicsPipeline_PolygonMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QRhiGraphicsPipeline::PolygonMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QRhiGraphicsPipeline::PolygonMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QRhiGraphicsPipeline_PythonToCpp_QRhiGraphicsPipeline_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QRhiGraphicsPipeline_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QRhiGraphicsPipeline_PythonToCpp_QRhiGraphicsPipeline_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QRhiGraphicsPipeline_TypeF()))
        return QRhiGraphicsPipeline_PythonToCpp_QRhiGraphicsPipeline_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QRhiGraphicsPipeline_PTR_CppToPython_QRhiGraphicsPipeline(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QRhiGraphicsPipeline *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QRhiGraphicsPipeline_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QRhiGraphicsPipeline_SignatureStrings[] = {
    "PySide6.QtGui.QRhiGraphicsPipeline.cbeginShaderStages(self)->PySide6.QtGui.QRhiShaderStage",
    "PySide6.QtGui.QRhiGraphicsPipeline.cbeginTargetBlends(self)->PySide6.QtGui.QRhiGraphicsPipeline.TargetBlend",
    "PySide6.QtGui.QRhiGraphicsPipeline.cendShaderStages(self)->PySide6.QtGui.QRhiShaderStage",
    "PySide6.QtGui.QRhiGraphicsPipeline.cendTargetBlends(self)->PySide6.QtGui.QRhiGraphicsPipeline.TargetBlend",
    "PySide6.QtGui.QRhiGraphicsPipeline.create(self)->bool",
    "PySide6.QtGui.QRhiGraphicsPipeline.cullMode(self)->PySide6.QtGui.QRhiGraphicsPipeline.CullMode",
    "PySide6.QtGui.QRhiGraphicsPipeline.depthBias(self)->int",
    "PySide6.QtGui.QRhiGraphicsPipeline.depthOp(self)->PySide6.QtGui.QRhiGraphicsPipeline.CompareOp",
    "PySide6.QtGui.QRhiGraphicsPipeline.flags(self)->PySide6.QtGui.QRhiGraphicsPipeline.Flag",
    "PySide6.QtGui.QRhiGraphicsPipeline.frontFace(self)->PySide6.QtGui.QRhiGraphicsPipeline.FrontFace",
    "PySide6.QtGui.QRhiGraphicsPipeline.hasDepthTest(self)->bool",
    "PySide6.QtGui.QRhiGraphicsPipeline.hasDepthWrite(self)->bool",
    "PySide6.QtGui.QRhiGraphicsPipeline.hasStencilTest(self)->bool",
    "PySide6.QtGui.QRhiGraphicsPipeline.lineWidth(self)->float",
    "PySide6.QtGui.QRhiGraphicsPipeline.multiViewCount(self)->int",
    "PySide6.QtGui.QRhiGraphicsPipeline.patchControlPointCount(self)->int",
    "PySide6.QtGui.QRhiGraphicsPipeline.polygonMode(self)->PySide6.QtGui.QRhiGraphicsPipeline.PolygonMode",
    "PySide6.QtGui.QRhiGraphicsPipeline.renderPassDescriptor(self)->PySide6.QtGui.QRhiRenderPassDescriptor",
    "PySide6.QtGui.QRhiGraphicsPipeline.resourceType(self)->PySide6.QtGui.QRhiResource.Type",
    "PySide6.QtGui.QRhiGraphicsPipeline.sampleCount(self)->int",
    "PySide6.QtGui.QRhiGraphicsPipeline.setCullMode(self,mode:PySide6.QtGui.QRhiGraphicsPipeline.CullMode)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setDepthBias(self,bias:int)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setDepthOp(self,op:PySide6.QtGui.QRhiGraphicsPipeline.CompareOp)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setDepthTest(self,enable:bool)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setDepthWrite(self,enable:bool)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setFlags(self,f:PySide6.QtGui.QRhiGraphicsPipeline.Flag)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setFrontFace(self,f:PySide6.QtGui.QRhiGraphicsPipeline.FrontFace)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setLineWidth(self,width:float)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setMultiViewCount(self,count:int)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setPatchControlPointCount(self,count:int)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setPolygonMode(self,mode:PySide6.QtGui.QRhiGraphicsPipeline.PolygonMode)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setRenderPassDescriptor(self,desc:PySide6.QtGui.QRhiRenderPassDescriptor)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setSampleCount(self,s:int)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setShaderResourceBindings(self,srb:PySide6.QtGui.QRhiShaderResourceBindings)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setShaderStages(self,stages:QList[PySide6.QtGui.QRhiShaderStage])",
    "PySide6.QtGui.QRhiGraphicsPipeline.setSlopeScaledDepthBias(self,bias:float)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setStencilBack(self,state:PySide6.QtGui.QRhiGraphicsPipeline.StencilOpState)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setStencilFront(self,state:PySide6.QtGui.QRhiGraphicsPipeline.StencilOpState)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setStencilReadMask(self,mask:quint32)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setStencilTest(self,enable:bool)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setStencilWriteMask(self,mask:quint32)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setTargetBlends(self,blends:QList[PySide6.QtGui.QRhiGraphicsPipeline.TargetBlend])",
    "PySide6.QtGui.QRhiGraphicsPipeline.setTopology(self,t:PySide6.QtGui.QRhiGraphicsPipeline.Topology)",
    "PySide6.QtGui.QRhiGraphicsPipeline.setVertexInputLayout(self,layout:PySide6.QtGui.QRhiVertexInputLayout)",
    "PySide6.QtGui.QRhiGraphicsPipeline.shaderResourceBindings(self)->PySide6.QtGui.QRhiShaderResourceBindings",
    "PySide6.QtGui.QRhiGraphicsPipeline.shaderStageAt(self,index:qsizetype)->PySide6.QtGui.QRhiShaderStage",
    "PySide6.QtGui.QRhiGraphicsPipeline.shaderStageCount(self)->qsizetype",
    "PySide6.QtGui.QRhiGraphicsPipeline.slopeScaledDepthBias(self)->float",
    "PySide6.QtGui.QRhiGraphicsPipeline.stencilBack(self)->PySide6.QtGui.QRhiGraphicsPipeline.StencilOpState",
    "PySide6.QtGui.QRhiGraphicsPipeline.stencilFront(self)->PySide6.QtGui.QRhiGraphicsPipeline.StencilOpState",
    "PySide6.QtGui.QRhiGraphicsPipeline.stencilReadMask(self)->quint32",
    "PySide6.QtGui.QRhiGraphicsPipeline.stencilWriteMask(self)->quint32",
    "PySide6.QtGui.QRhiGraphicsPipeline.targetBlendAt(self,index:qsizetype)->PySide6.QtGui.QRhiGraphicsPipeline.TargetBlend",
    "PySide6.QtGui.QRhiGraphicsPipeline.targetBlendCount(self)->qsizetype",
    "PySide6.QtGui.QRhiGraphicsPipeline.topology(self)->PySide6.QtGui.QRhiGraphicsPipeline.Topology",
    "PySide6.QtGui.QRhiGraphicsPipeline.vertexInputLayout(self)->PySide6.QtGui.QRhiVertexInputLayout",
    nullptr}; // Sentinel
#else
static constexpr size_t QRhiGraphicsPipeline_SignatureByteSize = 696;
static constexpr uint8_t QRhiGraphicsPipeline_SignatureBytes[696] = {
    0x78, 0xda, 0xbd, 0x58, 0x4d, 0x6f, 0xda, 0x40, 0x10, 0xbd, 0xe7, 0x97, 0x34, 0x92, 0xcb, 0xa1,
    0x91, 0x7a, 0xf0, 0xa1, 0x52, 0x21, 0x22, 0xaa, 0x14, 0x84, 0xc1, 0x28, 0x39, 0x54, 0x3d, 0xac,
    0xed, 0xc1, 0x5e, 0x75, 0xf1, 0x6e, 0x76, 0xd7, 0x4d, 0xe8, 0xaf, 0xef, 0xda, 0xd8, 0x60, 0x03,
    0x46, 0x33, 0xa6, 0xc9, 0x05, 0x0d, 0xd2, 0xbc, 0xf7, 0xf6, 0x63, 0xe6, 0x31, 0x4b, 0xb0, 0x0d,
    0x79, 0x02, 0x5f, 0x47, 0x0b, 0xfb, 0x50, 0xf0, 0xd1, 0x62, 0x99, 0xf1, 0x07, 0xcd, 0x54, 0xc6,
    0x63, 0x13, 0x70, 0x05, 0x82, 0xe7, 0x30, 0x8a, 0x23, 0x48, 0x79, 0x1e, 0x66, 0x2c, 0x01, 0x1d,
    0x5a, 0x96, 0x82, 0xf9, 0x64, 0x40, 0xac, 0x6f, 0x3f, 0x7f, 0x0b, 0x4e, 0xc0, 0xad, 0xac, 0x9b,
    0x00, 0x4b, 0xbd, 0x62, 0x3a, 0x05, 0x3b, 0x16, 0x90, 0x27, 0x17, 0xa8, 0x4f, 0xc0, 0x2d, 0x18,
    0x4a, 0xcb, 0xe5, 0xbd, 0xcf, 0x26, 0x1c, 0xf1, 0x07, 0x6d, 0x41, 0x03, 0xb3, 0xd0, 0xf0, 0x47,
    0x52, 0x0a, 0x14, 0xaa, 0x10, 0x62, 0x26, 0x13, 0x20, 0xac, 0x6b, 0x52, 0x43, 0x30, 0xf4, 0x09,
    0x28, 0x9b, 0x8d, 0x39, 0xdb, 0xef, 0x9b, 0xe7, 0x16, 0x8d, 0x9b, 0x2b, 0xca, 0xaa, 0xe4, 0x46,
    0x31, 0x0d, 0x73, 0x85, 0xa1, 0x5f, 0x0b, 0x96, 0x52, 0xae, 0x62, 0xea, 0xf2, 0x51, 0xbc, 0x5a,
    0xe6, 0x76, 0xca, 0x62, 0xca, 0x71, 0x4e, 0x1b, 0x0c, 0x46, 0x20, 0x63, 0xe6, 0xbe, 0x3c, 0x9a,
    0x15, 0x18, 0x4b, 0xbd, 0xea, 0x06, 0xfb, 0xac, 0x39, 0xbd, 0x4e, 0x1c, 0x38, 0xb4, 0x90, 0xc7,
    0x5c, 0x0c, 0x91, 0x2e, 0x3f, 0x9e, 0x79, 0x62, 0xb3, 0x06, 0xb8, 0x16, 0x92, 0xa1, 0x0a, 0x61,
    0x53, 0x08, 0xcb, 0x9f, 0x38, 0xbc, 0x4e, 0x64, 0x91, 0x5b, 0x62, 0x15, 0x29, 0x66, 0xe3, 0x6c,
    0xe2, 0x8e, 0x57, 0x4b, 0x11, 0x48, 0x07, 0x1a, 0x44, 0x22, 0xc5, 0x36, 0x95, 0x39, 0xb1, 0x49,
    0x82, 0x03, 0x0a, 0x23, 0xa2, 0x5d, 0x93, 0x83, 0x0e, 0x98, 0x71, 0x57, 0x64, 0x62, 0xcd, 0x95,
    0x95, 0xba, 0x5f, 0x6d, 0x79, 0x26, 0x1b, 0xa7, 0x62, 0x64, 0xa1, 0x63, 0x58, 0x6d, 0x15, 0x5c,
    0x62, 0xdf, 0x65, 0x8d, 0xca, 0x34, 0x0c, 0xad, 0x61, 0x1b, 0x25, 0x60, 0xc8, 0xd9, 0x1a, 0xb0,
    0x93, 0xb6, 0x01, 0x79, 0x1b, 0x17, 0xf9, 0x04, 0x0f, 0xba, 0x45, 0xaa, 0xdc, 0x77, 0x7c, 0xc8,
    0x8b, 0x5c, 0xe4, 0xbb, 0x35, 0x92, 0xe0, 0xb5, 0x1d, 0x79, 0x52, 0xf9, 0x14, 0x3f, 0x22, 0x69,
    0xec, 0x9b, 0xcb, 0x83, 0x9c, 0x45, 0x02, 0xfc, 0xb2, 0xc3, 0x48, 0x0c, 0x87, 0xee, 0x1e, 0x42,
    0x31, 0xdd, 0x1b, 0xa3, 0xb7, 0xf6, 0x91, 0xc6, 0x88, 0xe6, 0xee, 0x98, 0x23, 0x92, 0xbf, 0xc1,
    0x60, 0x45, 0x1e, 0x3b, 0x4e, 0xe3, 0xbd, 0x96, 0xa1, 0x5f, 0xb9, 0x0d, 0x96, 0x61, 0x76, 0xea,
    0x38, 0x5e, 0x5c, 0x86, 0x94, 0x82, 0x09, 0xfa, 0x9d, 0x67, 0x00, 0xd9, 0x91, 0x03, 0xa1, 0xbb,
    0xa4, 0x05, 0xc4, 0x6a, 0x2d, 0xfb, 0x8c, 0xc8, 0x4b, 0xdc, 0x77, 0x1f, 0xe7, 0x45, 0x58, 0xb1,
    0xf0, 0xc8, 0x38, 0x3c, 0x52, 0x53, 0xee, 0x26, 0xb1, 0xc6, 0xad, 0xc6, 0x3c, 0x4f, 0x78, 0xde,
    0x14, 0xaf, 0xd1, 0x91, 0xdf, 0x37, 0xbb, 0x1d, 0x23, 0x68, 0x7a, 0xad, 0xf9, 0xd0, 0x33, 0x55,
    0xec, 0x2f, 0x1e, 0xb9, 0xb1, 0x3f, 0x2f, 0x8e, 0x8a, 0xbf, 0xd0, 0x22, 0x42, 0x2a, 0x08, 0x63,
    0x26, 0x20, 0x39, 0xe7, 0x59, 0xa4, 0x4a, 0xae, 0x7f, 0xb0, 0xc7, 0x2c, 0xfe, 0xbd, 0x5f, 0xaf,
    0x45, 0x15, 0x4e, 0x8d, 0x9c, 0xab, 0xb0, 0x44, 0x10, 0xf5, 0xaa, 0x9e, 0xfd, 0x48, 0xc1, 0x25,
    0xb0, 0x64, 0xc6, 0x4c, 0xbd, 0xc9, 0x8d, 0x8b, 0xfc, 0x97, 0xc2, 0x15, 0xd2, 0xdd, 0x17, 0x22,
    0xd1, 0x55, 0xee, 0x5b, 0x73, 0x54, 0xfe, 0x7b, 0xdd, 0x6a, 0x4e, 0xde, 0x0b, 0x5e, 0x54, 0xc5,
    0xbd, 0x85, 0x76, 0xe9, 0xe9, 0x80, 0xae, 0xbc, 0x95, 0x74, 0x93, 0x8e, 0x4c, 0xb7, 0x3b, 0x45,
    0x8b, 0xb9, 0xb5, 0x06, 0x82, 0x95, 0x78, 0x02, 0x6d, 0xe1, 0xed, 0x47, 0xae, 0x0a, 0xfb, 0xc8,
    0xb6, 0xb2, 0xa8, 0x0f, 0x5b, 0x54, 0xf1, 0x19, 0xc1, 0x93, 0x7c, 0x9c, 0x50, 0xbf, 0x2f, 0x5c,
    0x78, 0xd1, 0x1d, 0xe7, 0xe3, 0x95, 0xaa, 0x06, 0xff, 0x5e, 0xef, 0xc5, 0xa1, 0xe1, 0xcd, 0x7f,
    0x31, 0xfc, 0x2f, 0x58, 0x37, 0x3e, 0xfd, 0x8f, 0x27, 0x64, 0x4b, 0xa5, 0x33, 0x63, 0xed, 0x45,
    0x50, 0x24, 0x7d, 0xbe, 0x42, 0x19, 0xc6, 0xcd, 0x91, 0xa1, 0xe0, 0x46, 0xe1, 0x6e, 0x6f, 0x13,
    0x74, 0x0e, 0x46, 0xf2, 0xce, 0x42, 0x1d, 0x03, 0x29, 0x4f, 0x76, 0xd7, 0xaf, 0x04, 0x86, 0x6e,
    0xd7, 0xd3, 0x28, 0xec, 0xa1, 0x59, 0x29, 0x55, 0x74, 0xed, 0xff, 0x05, 0x2d, 0xd9, 0xe1, 0x65,
    0x65, 0xdb, 0xa6, 0x81, 0x5c, 0x66, 0x0d, 0xc1, 0xd0, 0xff, 0x39, 0x6b, 0x18, 0x67, 0x75, 0x4e,
    0xbc, 0xe2, 0xe6, 0x1f, 0x87, 0xb3, 0xe0, 0x00
};
#endif

PyTypeObject *init_QRhiGraphicsPipeline(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX].type;

    Shiboken::AutoDecRef Sbk_QRhiGraphicsPipeline_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QRhiResource_IDX]))));

    _Sbk_QRhiGraphicsPipeline_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QRhiGraphicsPipeline",
        "QRhiGraphicsPipeline*",
        &Sbk_QRhiGraphicsPipeline_spec,
        &Shiboken::callCppDestructor< QRhiGraphicsPipeline >,
        Sbk_QRhiGraphicsPipeline_Type_bases.object(),
        0);
    auto *pyType = Sbk_QRhiGraphicsPipeline_TypeF(); // references _Sbk_QRhiGraphicsPipeline_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QRhiGraphicsPipeline_SignatureStrings);
#else
    InitSignatureBytes(pyType, QRhiGraphicsPipeline_SignatureBytes, QRhiGraphicsPipeline_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QRhiGraphicsPipeline_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QRhiGraphicsPipeline_PythonToCpp_QRhiGraphicsPipeline_PTR,
        is_QRhiGraphicsPipeline_PythonToCpp_QRhiGraphicsPipeline_PTR_Convertible,
        QRhiGraphicsPipeline_PTR_CppToPython_QRhiGraphicsPipeline);

    Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline");
    Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline*");
    Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QRhiGraphicsPipeline).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QRhiGraphicsPipelineWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QRhiGraphicsPipeline_TypeF(), &Sbk_QRhiGraphicsPipeline_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QRhiGraphicsPipeline_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "UsesBlendConstants",
        "UsesStencilRef",
        "UsesScissor",
        "CompileShadersWithDebugInfo",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flag_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::Flag::UsesBlendConstants),         //  0x01  1
        uint8_t(QRhiGraphicsPipeline::Flag::UsesStencilRef),             //  0x02  2
        uint8_t(QRhiGraphicsPipeline::Flag::UsesScissor),                //  0x04  4
        uint8_t(QRhiGraphicsPipeline::Flag::CompileShadersWithDebugInfo) //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiGraphicsPipeline_Flag_IDX].type =
        EType;
    // Register converter for enum 'QRhiGraphicsPipeline::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_Flag,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QRhiGraphicsPipeline_Flag,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_Flag_Convertible);
        // Register converter for flag 'QFlags<QRhiGraphicsPipeline::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QRhiGraphicsPipeline::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QRhiGraphicsPipeline::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    // Initialization of enum 'Topology'.
    const char *Topology_Initializer[] = {
        "Triangles",
        "TriangleStrip",
        "TriangleFan",
        "Lines",
        "LineStrip",
        "Points",
        "Patches",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Topology_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::Topology::Triangles),     //  0x00  0
        uint8_t(QRhiGraphicsPipeline::Topology::TriangleStrip), //  0x01  1
        uint8_t(QRhiGraphicsPipeline::Topology::TriangleFan),   //  0x02  2
        uint8_t(QRhiGraphicsPipeline::Topology::Lines),         //  0x03  3
        uint8_t(QRhiGraphicsPipeline::Topology::LineStrip),     //  0x04  4
        uint8_t(QRhiGraphicsPipeline::Topology::Points),        //  0x05  5
        uint8_t(QRhiGraphicsPipeline::Topology::Patches)        //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.Topology",
        Topology_Initializer, Topology_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_Topology_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::Topology'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_Topology_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_Topology,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_Topology_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::Topology");
        Shiboken::Conversions::registerConverterAlias(converter, "Topology");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Topology' enum.

    // Initialization of enum 'CullMode'.
    const char *CullMode_Initializer[] = {
        "None_",
        "Front",
        "Back",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CullMode_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::CullMode::None),  //  0x00  0
        uint8_t(QRhiGraphicsPipeline::CullMode::Front), //  0x01  1
        uint8_t(QRhiGraphicsPipeline::CullMode::Back)   //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.CullMode",
        CullMode_Initializer, CullMode_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CullMode_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::CullMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_CullMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_CullMode,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_CullMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::CullMode");
        Shiboken::Conversions::registerConverterAlias(converter, "CullMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CullMode' enum.

    // Initialization of enum 'FrontFace'.
    const char *FrontFace_Initializer[] = {
        "CCW",
        "CW",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FrontFace_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::FrontFace::CCW), //  0x00  0
        uint8_t(QRhiGraphicsPipeline::FrontFace::CW)   //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.FrontFace",
        FrontFace_Initializer, FrontFace_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_FrontFace_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::FrontFace'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_FrontFace_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_FrontFace,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_FrontFace_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::FrontFace");
        Shiboken::Conversions::registerConverterAlias(converter, "FrontFace");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FrontFace' enum.

    // Initialization of enum 'ColorMaskComponent'.
    const char *ColorMaskComponent_Initializer[] = {
        "R",
        "G",
        "B",
        "A",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ColorMaskComponent_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::ColorMaskComponent::R), //  0x01  1
        uint8_t(QRhiGraphicsPipeline::ColorMaskComponent::G), //  0x02  2
        uint8_t(QRhiGraphicsPipeline::ColorMaskComponent::B), //  0x04  4
        uint8_t(QRhiGraphicsPipeline::ColorMaskComponent::A)  //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.ColorMaskComponent",
        ColorMaskComponent_Initializer, ColorMaskComponent_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_ColorMaskComponent_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QRhiGraphicsPipeline_ColorMaskComponent_IDX].type =
        EType;
    // Register converter for enum 'QRhiGraphicsPipeline::ColorMaskComponent'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_ColorMaskComponent_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_ColorMaskComponent,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_ColorMaskComponent_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::ColorMaskComponent");
        Shiboken::Conversions::registerConverterAlias(converter, "ColorMaskComponent");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_ColorMaskComponent_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QRhiGraphicsPipeline_ColorMaskComponent,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_ColorMaskComponent_Convertible);
        // Register converter for flag 'QFlags<QRhiGraphicsPipeline::ColorMaskComponent>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QRhiGraphicsPipeline::ColorMaskComponent>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QRhiGraphicsPipeline::ColorMask");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'ColorMaskComponent' enum/flags.

    // Initialization of enum 'BlendFactor'.
    const char *BlendFactor_Initializer[] = {
        "Zero",
        "One",
        "SrcColor",
        "OneMinusSrcColor",
        "DstColor",
        "OneMinusDstColor",
        "SrcAlpha",
        "OneMinusSrcAlpha",
        "DstAlpha",
        "OneMinusDstAlpha",
        "ConstantColor",
        "OneMinusConstantColor",
        "ConstantAlpha",
        "OneMinusConstantAlpha",
        "SrcAlphaSaturate",
        "Src1Color",
        "OneMinusSrc1Color",
        "Src1Alpha",
        "OneMinusSrc1Alpha",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t BlendFactor_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::BlendFactor::Zero),                  //  0x00  0
        uint8_t(QRhiGraphicsPipeline::BlendFactor::One),                   //  0x01  1
        uint8_t(QRhiGraphicsPipeline::BlendFactor::SrcColor),              //  0x02  2
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusSrcColor),      //  0x03  3
        uint8_t(QRhiGraphicsPipeline::BlendFactor::DstColor),              //  0x04  4
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusDstColor),      //  0x05  5
        uint8_t(QRhiGraphicsPipeline::BlendFactor::SrcAlpha),              //  0x06  6
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusSrcAlpha),      //  0x07  7
        uint8_t(QRhiGraphicsPipeline::BlendFactor::DstAlpha),              //  0x08  8
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusDstAlpha),      //  0x09  9
        uint8_t(QRhiGraphicsPipeline::BlendFactor::ConstantColor),         //  0x0a  10
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusConstantColor), //  0x0b  11
        uint8_t(QRhiGraphicsPipeline::BlendFactor::ConstantAlpha),         //  0x0c  12
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusConstantAlpha), //  0x0d  13
        uint8_t(QRhiGraphicsPipeline::BlendFactor::SrcAlphaSaturate),      //  0x0e  14
        uint8_t(QRhiGraphicsPipeline::BlendFactor::Src1Color),             //  0x0f  15
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusSrc1Color),     //  0x10  16
        uint8_t(QRhiGraphicsPipeline::BlendFactor::Src1Alpha),             //  0x11  17
        uint8_t(QRhiGraphicsPipeline::BlendFactor::OneMinusSrc1Alpha)      //  0x12  18
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.BlendFactor",
        BlendFactor_Initializer, BlendFactor_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_BlendFactor_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::BlendFactor'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_BlendFactor_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_BlendFactor,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_BlendFactor_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::BlendFactor");
        Shiboken::Conversions::registerConverterAlias(converter, "BlendFactor");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'BlendFactor' enum.

    // Initialization of enum 'BlendOp'.
    const char *BlendOp_Initializer[] = {
        "Add",
        "Subtract",
        "ReverseSubtract",
        "Min",
        "Max",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t BlendOp_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::BlendOp::Add),             //  0x00  0
        uint8_t(QRhiGraphicsPipeline::BlendOp::Subtract),        //  0x01  1
        uint8_t(QRhiGraphicsPipeline::BlendOp::ReverseSubtract), //  0x02  2
        uint8_t(QRhiGraphicsPipeline::BlendOp::Min),             //  0x03  3
        uint8_t(QRhiGraphicsPipeline::BlendOp::Max)              //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.BlendOp",
        BlendOp_Initializer, BlendOp_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_BlendOp_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::BlendOp'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_BlendOp_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_BlendOp,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_BlendOp_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::BlendOp");
        Shiboken::Conversions::registerConverterAlias(converter, "BlendOp");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'BlendOp' enum.

    // Initialization of enum 'CompareOp'.
    const char *CompareOp_Initializer[] = {
        "Never",
        "Less",
        "Equal",
        "LessOrEqual",
        "Greater",
        "NotEqual",
        "GreaterOrEqual",
        "Always",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t CompareOp_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::CompareOp::Never),          //  0x00  0
        uint8_t(QRhiGraphicsPipeline::CompareOp::Less),           //  0x01  1
        uint8_t(QRhiGraphicsPipeline::CompareOp::Equal),          //  0x02  2
        uint8_t(QRhiGraphicsPipeline::CompareOp::LessOrEqual),    //  0x03  3
        uint8_t(QRhiGraphicsPipeline::CompareOp::Greater),        //  0x04  4
        uint8_t(QRhiGraphicsPipeline::CompareOp::NotEqual),       //  0x05  5
        uint8_t(QRhiGraphicsPipeline::CompareOp::GreaterOrEqual), //  0x06  6
        uint8_t(QRhiGraphicsPipeline::CompareOp::Always)          //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.CompareOp",
        CompareOp_Initializer, CompareOp_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_CompareOp_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::CompareOp'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_CompareOp_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_CompareOp,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_CompareOp_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::CompareOp");
        Shiboken::Conversions::registerConverterAlias(converter, "CompareOp");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'CompareOp' enum.

    // Initialization of enum 'StencilOp'.
    const char *StencilOp_Initializer[] = {
        "StencilZero",
        "Keep",
        "Replace",
        "IncrementAndClamp",
        "DecrementAndClamp",
        "Invert",
        "IncrementAndWrap",
        "DecrementAndWrap",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t StencilOp_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::StencilOp::StencilZero),       //  0x00  0
        uint8_t(QRhiGraphicsPipeline::StencilOp::Keep),              //  0x01  1
        uint8_t(QRhiGraphicsPipeline::StencilOp::Replace),           //  0x02  2
        uint8_t(QRhiGraphicsPipeline::StencilOp::IncrementAndClamp), //  0x03  3
        uint8_t(QRhiGraphicsPipeline::StencilOp::DecrementAndClamp), //  0x04  4
        uint8_t(QRhiGraphicsPipeline::StencilOp::Invert),            //  0x05  5
        uint8_t(QRhiGraphicsPipeline::StencilOp::IncrementAndWrap),  //  0x06  6
        uint8_t(QRhiGraphicsPipeline::StencilOp::DecrementAndWrap)   //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.StencilOp",
        StencilOp_Initializer, StencilOp_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_StencilOp_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::StencilOp'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_StencilOp_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_StencilOp,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_StencilOp_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::StencilOp");
        Shiboken::Conversions::registerConverterAlias(converter, "StencilOp");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'StencilOp' enum.

    // Initialization of enum 'PolygonMode'.
    const char *PolygonMode_Initializer[] = {
        "Fill",
        "Line",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PolygonMode_InitializerValues[] = {
        uint8_t(QRhiGraphicsPipeline::PolygonMode::Fill), //  0x00  0
        uint8_t(QRhiGraphicsPipeline::PolygonMode::Line)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QRhiGraphicsPipeline_TypeF(),
        "2:PySide6.QtGui.QRhiGraphicsPipeline.PolygonMode",
        PolygonMode_Initializer, PolygonMode_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QRhiGraphicsPipeline_PolygonMode_IDX].type = EType;
    // Register converter for enum 'QRhiGraphicsPipeline::PolygonMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QRhiGraphicsPipeline_PolygonMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QRhiGraphicsPipeline_PolygonMode,
            is_Enum_PythonToCpp_QRhiGraphicsPipeline_PolygonMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QRhiGraphicsPipeline::PolygonMode");
        Shiboken::Conversions::registerConverterAlias(converter, "PolygonMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'PolygonMode' enum.

    qRegisterMetaType< ::QRhiGraphicsPipeline *>();
    qRegisterMetaType< ::QRhiGraphicsPipeline::Flag >("QRhiGraphicsPipeline::Flag");
    qRegisterMetaType< ::QRhiGraphicsPipeline::Topology >("QRhiGraphicsPipeline::Topology");
    qRegisterMetaType< ::QRhiGraphicsPipeline::CullMode >("QRhiGraphicsPipeline::CullMode");
    qRegisterMetaType< ::QRhiGraphicsPipeline::FrontFace >("QRhiGraphicsPipeline::FrontFace");
    qRegisterMetaType< ::QRhiGraphicsPipeline::ColorMaskComponent >("QRhiGraphicsPipeline::ColorMaskComponent");
    qRegisterMetaType< ::QRhiGraphicsPipeline::BlendFactor >("QRhiGraphicsPipeline::BlendFactor");
    qRegisterMetaType< ::QRhiGraphicsPipeline::BlendOp >("QRhiGraphicsPipeline::BlendOp");
    qRegisterMetaType< ::QRhiGraphicsPipeline::CompareOp >("QRhiGraphicsPipeline::CompareOp");
    qRegisterMetaType< ::QRhiGraphicsPipeline::StencilOp >("QRhiGraphicsPipeline::StencilOp");
    qRegisterMetaType< ::QRhiGraphicsPipeline::PolygonMode >("QRhiGraphicsPipeline::PolygonMode");

    return pyType;
}
