// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtgui_python.h"
#include "pyside6_qtgui_python_p.h"

// main header
#include "qtextdocument_wrapper.h"

// Extra includes
#include <QTextBlock>
#include <QTextCursor>
#include <QTextFormat>

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qabstracttextdocumentlayout.h>
#include <QtGui/qfont.h>
#include <QtGui/qpagedpaintdevice.h>
#include <QtGui/qpainter.h>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextobject.h>
#include <QtGui/qtextoption.h>
#include <qbytearray.h>
#include <qchar.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qrect.h>
#include <qregularexpression.h>
#include <qsize.h>
#include <qthread.h>
#include <qurl.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QTextDocumentWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QTextDocumentWrapper::QTextDocumentWrapper(::QObject * parent) : QTextDocument(parent)
{
}

QTextDocumentWrapper::QTextDocumentWrapper(const ::QString & text, ::QObject * parent) : QTextDocument(text, parent)
{
}

void QTextDocumentWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTextDocument", funcName);
        return;
    }
}

void QTextDocumentWrapper::clear()
{
    if (m_PyMethodCache[1]) {
        return this->::QTextDocument::clear();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clear";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QTextDocument::clear();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTextDocument", funcName);
        return;
    }
}

void QTextDocumentWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[2]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTextDocument", funcName);
        return;
    }
}

::QTextObject * QTextDocumentWrapper::createObject(const ::QTextFormat & f)
{
    if (m_PyMethodCache[3])
        return this->::QTextDocument::createObject(f);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createObject";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QTextDocument::createObject(f);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), &f)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), &f)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTextDocument", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextObject_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QTextDocument", funcName, Shiboken::SbkType< QTextObject >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QTextObject *cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (Shiboken::Object::checkType(pyResult))
        Shiboken::Object::releaseOwnership(pyResult);
    return cppResult;
}

void QTextDocumentWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTextDocument", funcName);
        return;
    }
}

void QTextDocumentWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[5]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTextDocument", funcName);
        return;
    }
}

bool QTextDocumentWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[6])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTextDocument", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QTextDocument", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QTextDocumentWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[7])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTextDocument", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QTextDocument", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QVariant QTextDocumentWrapper::loadResource(int type, const ::QUrl & name)
{
    if (m_PyMethodCache[8])
        return this->::QTextDocument::loadResource(type, name);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "loadResource";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QTextDocument::loadResource(type, name);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &type),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &name)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(iN)",
        type,
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &name)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTextDocument", funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QTextDocument", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QTextDocumentWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[9]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QTextDocument", funcName);
        return;
    }
}

const QMetaObject *QTextDocumentWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QTextDocument::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QTextDocumentWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QTextDocument::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QTextDocumentWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QTextDocumentWrapper *>(this));
    return QTextDocument::qt_metacast(_clname);
}

QTextDocumentWrapper::~QTextDocumentWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QTextDocument_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QTextDocument >()))
        return -1;

    QTextDocumentWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QTextDocument", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QTextDocument::QTextDocument(QObject*=)
    // 1: QTextDocument::QTextDocument(QString,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QTextDocument(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QTextDocument(QObject*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QTextDocument(QString,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QTextDocument(QString,QObject*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QTextDocument(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextDocument(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QTextDocumentWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QTextDocumentWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QTextDocument(const QString &text, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QTextDocument(QString,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QTextDocumentWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QTextDocumentWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QTextDocument >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QTextDocumentFunc_addResource(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addResource", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::addResource(int,QUrl,QVariant)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[2])))) {
        overloadId = 0; // addResource(int,QUrl,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addResource", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QUrl cppArg1_local;
        ::QUrl *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);

        ::QVariant cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addResource(int,QUrl,QVariant)
            cppSelf->addResource(cppArg0, *cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_adjustSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // adjustSize()
        cppSelf->adjustSize();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_allFormats(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // allFormats()const
        QList<QTextFormat> cppResult = const_cast<const ::QTextDocument *>(cppSelf)->allFormats();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtGuiTypeConverters[SBK_QtGui_QList_QTextFormat_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_availableRedoSteps(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availableRedoSteps()const
        int cppResult = const_cast<const ::QTextDocument *>(cppSelf)->availableRedoSteps();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_availableUndoSteps(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // availableUndoSteps()const
        int cppResult = const_cast<const ::QTextDocument *>(cppSelf)->availableUndoSteps();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_baseUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // baseUrl()const
        QUrl cppResult = const_cast<const ::QTextDocument *>(cppSelf)->baseUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_baselineOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // baselineOffset()const
        qreal cppResult = const_cast<const ::QTextDocument *>(cppSelf)->baselineOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_begin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // begin()const
        QTextBlock cppResult = const_cast<const ::QTextDocument *>(cppSelf)->begin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_blockCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // blockCount()const
        int cppResult = const_cast<const ::QTextDocument *>(cppSelf)->blockCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_characterAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::characterAt(int)const->QChar
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // characterAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "characterAt", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // characterAt(int)const
            QChar cppResult = const_cast<const ::QTextDocument *>(cppSelf)->characterAt(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QChar_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_characterCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // characterCount()const
        int cppResult = const_cast<const ::QTextDocument *>(cppSelf)->characterCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QTextDocument::clear()
            : cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_clearUndoRedoStacks(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "clearUndoRedoStacks", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    if (PyArg_ParseTuple(args, "|O:clearUndoRedoStacks", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::clearUndoRedoStacks(QTextDocument::Stacks=)
    if (numArgs == 0) {
        overloadId = 0; // clearUndoRedoStacks(QTextDocument::Stacks)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_Stacks_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // clearUndoRedoStacks(QTextDocument::Stacks)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "clearUndoRedoStacks", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_historyToClear = Shiboken::String::createStaticString("historyToClear");
            if (PyDict_Contains(kwds, key_historyToClear) != 0) {
                value = PyDict_GetItem(kwds, key_historyToClear);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_historyToClear);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "clearUndoRedoStacks", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_Stacks_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "clearUndoRedoStacks", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_historyToClear);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "clearUndoRedoStacks", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
            }
        }
        ::QTextDocument::Stacks cppArg0(QTextDocument::Stacks::UndoAndRedoStacks);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // clearUndoRedoStacks(QTextDocument::Stacks)
            cppSelf->clearUndoRedoStacks(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_clone(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "clone", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    if (PyArg_ParseTuple(args, "|O:clone", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::clone(QObject*=)const->QTextDocument*
    if (numArgs == 0) {
        overloadId = 0; // clone(QObject*)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // clone(QObject*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "clone", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "clone", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "clone", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "clone", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // clone(QObject*)const
            QTextDocument * cppResult = const_cast<const ::QTextDocument *>(cppSelf)->clone(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_createObject(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::createObject(QTextFormat)->QTextObject*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), (pyArg)))) {
        overloadId = 0; // createObject(QTextFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createObject", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextFormat cppArg0_local;
        ::QTextFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // createObject(QTextFormat)
            QTextObject * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QTextDocument::createObject(*cppArg0)
                : cppSelf->createObject(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextObject_IDX]), cppResult);

            // Ownership transferences.
            Shiboken::Object::getOwnership(pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_defaultCursorMoveStyle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultCursorMoveStyle()const
        Qt::CursorMoveStyle cppResult = const_cast<const ::QTextDocument *>(cppSelf)->defaultCursorMoveStyle();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CursorMoveStyle_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_defaultFont(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultFont()const
        QFont cppResult = const_cast<const ::QTextDocument *>(cppSelf)->defaultFont();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_defaultStyleSheet(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultStyleSheet()const
        QString cppResult = const_cast<const ::QTextDocument *>(cppSelf)->defaultStyleSheet();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_defaultTextOption(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultTextOption()const
        QTextOption cppResult = const_cast<const ::QTextDocument *>(cppSelf)->defaultTextOption();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_documentLayout(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // documentLayout()const
        QAbstractTextDocumentLayout * cppResult = const_cast<const ::QTextDocument *>(cppSelf)->documentLayout();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_documentMargin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // documentMargin()const
        qreal cppResult = const_cast<const ::QTextDocument *>(cppSelf)->documentMargin();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_drawContents(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "drawContents", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    if (PyArg_ParseTuple(args, "|OO:drawContents", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::drawContents(QPainter*,const QRectF&=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // drawContents(QPainter*,QRectF)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
            overloadId = 0; // drawContents(QPainter*,QRectF)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawContents", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_rect = Shiboken::String::createStaticString("rect");
            if (PyDict_Contains(kwds, key_rect) != 0) {
                value = PyDict_GetItem(kwds, key_rect);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_rect);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "drawContents", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "drawContents", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_rect);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "drawContents", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRectF cppArg1_local = QRectF();
        ::QRectF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // drawContents(QPainter*,QRectF)
            cppSelf->drawContents(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_end(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // end()const
        QTextBlock cppResult = const_cast<const ::QTextDocument *>(cppSelf)->end();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_find(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:find", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::find(QRegularExpression,QTextCursor,QFlags<QTextDocument::FindFlag>=)const->QTextCursor
    // 1: QTextDocument::find(QRegularExpression,int=,QFlags<QTextDocument::FindFlag>=)const->QTextCursor
    // 2: QTextDocument::find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>=)const->QTextCursor
    // 3: QTextDocument::find(QString,int=,QFlags<QTextDocument::FindFlag>=)const->QTextCursor
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // find(QString,int,QFlags<QTextDocument::FindFlag>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // find(QString,int,QFlags<QTextDocument::FindFlag>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_FindFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 3; // find(QString,int,QFlags<QTextDocument::FindFlag>)const
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_FindFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 2; // find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // find(QRegularExpression,int,QFlags<QTextDocument::FindFlag>)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // find(QRegularExpression,int,QFlags<QTextDocument::FindFlag>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_FindFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 1; // find(QRegularExpression,int,QFlags<QTextDocument::FindFlag>)const
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // find(QRegularExpression,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_FindFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 0; // find(QRegularExpression,QTextCursor,QFlags<QTextDocument::FindFlag>)const
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // find(const QRegularExpression &expr, const QTextCursor &cursor, QFlags<QTextDocument::FindFlag> options) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_FindFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRegularExpression cppArg0_local;
            ::QRegularExpression *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTextCursor cppArg1_local;
            ::QTextCursor *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QFlags<QTextDocument::FindFlag> cppArg2 = QTextDocument::FindFlags();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // find(QRegularExpression,QTextCursor,QFlags<QTextDocument::FindFlag>)const
                QTextCursor cppResult = const_cast<const ::QTextDocument *>(cppSelf)->find(*cppArg0, *cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), &cppResult);
            }
            break;
        }
        case 1: // find(const QRegularExpression &expr, int from, QFlags<QTextDocument::FindFlag> options) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_from = Shiboken::String::createStaticString("from");
                if (PyDict_Contains(kwds, key_from) != 0) {
                    value = PyDict_GetItem(kwds, key_from);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_from);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_from);
                }
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_FindFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRegularExpression cppArg0_local;
            ::QRegularExpression *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            int cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QTextDocument::FindFlag> cppArg2 = QTextDocument::FindFlags();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // find(QRegularExpression,int,QFlags<QTextDocument::FindFlag>)const
                QTextCursor cppResult = const_cast<const ::QTextDocument *>(cppSelf)->find(*cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), &cppResult);
            }
            break;
        }
        case 2: // find(const QString &subString, const QTextCursor &cursor, QFlags<QTextDocument::FindFlag> options) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_FindFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTextCursor cppArg1_local;
            ::QTextCursor *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            ::QFlags<QTextDocument::FindFlag> cppArg2 = QTextDocument::FindFlags();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // find(QString,QTextCursor,QFlags<QTextDocument::FindFlag>)const
                QTextCursor cppResult = const_cast<const ::QTextDocument *>(cppSelf)->find(cppArg0, *cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), &cppResult);
            }
            break;
        }
        case 3: // find(const QString &subString, int from, QFlags<QTextDocument::FindFlag> options) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_from = Shiboken::String::createStaticString("from");
                if (PyDict_Contains(kwds, key_from) != 0) {
                    value = PyDict_GetItem(kwds, key_from);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_from);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_from);
                }
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_FindFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QTextDocument::FindFlag> cppArg2 = QTextDocument::FindFlags();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // find(QString,int,QFlags<QTextDocument::FindFlag>)const
                QTextCursor cppResult = const_cast<const ::QTextDocument *>(cppSelf)->find(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_findBlock(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::findBlock(int)const->QTextBlock
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // findBlock(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "findBlock", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // findBlock(int)const
            QTextBlock cppResult = const_cast<const ::QTextDocument *>(cppSelf)->findBlock(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_findBlockByLineNumber(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::findBlockByLineNumber(int)const->QTextBlock
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // findBlockByLineNumber(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "findBlockByLineNumber", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // findBlockByLineNumber(int)const
            QTextBlock cppResult = const_cast<const ::QTextDocument *>(cppSelf)->findBlockByLineNumber(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_findBlockByNumber(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::findBlockByNumber(int)const->QTextBlock
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // findBlockByNumber(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "findBlockByNumber", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // findBlockByNumber(int)const
            QTextBlock cppResult = const_cast<const ::QTextDocument *>(cppSelf)->findBlockByNumber(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_firstBlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // firstBlock()const
        QTextBlock cppResult = const_cast<const ::QTextDocument *>(cppSelf)->firstBlock();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_frameAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::frameAt(int)const->QTextFrame*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // frameAt(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "frameAt", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // frameAt(int)const
            QTextFrame * cppResult = const_cast<const ::QTextDocument *>(cppSelf)->frameAt(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_idealWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // idealWidth()const
        qreal cppResult = const_cast<const ::QTextDocument *>(cppSelf)->idealWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_indentWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // indentWidth()const
        qreal cppResult = const_cast<const ::QTextDocument *>(cppSelf)->indentWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_isEmpty(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEmpty()const
        bool cppResult = const_cast<const ::QTextDocument *>(cppSelf)->isEmpty();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_isLayoutEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isLayoutEnabled()const
        bool cppResult = const_cast<const ::QTextDocument *>(cppSelf)->isLayoutEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_isModified(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isModified()const
        bool cppResult = const_cast<const ::QTextDocument *>(cppSelf)->isModified();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_isRedoAvailable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isRedoAvailable()const
        bool cppResult = const_cast<const ::QTextDocument *>(cppSelf)->isRedoAvailable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_isUndoAvailable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isUndoAvailable()const
        bool cppResult = const_cast<const ::QTextDocument *>(cppSelf)->isUndoAvailable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_isUndoRedoEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isUndoRedoEnabled()const
        bool cppResult = const_cast<const ::QTextDocument *>(cppSelf)->isUndoRedoEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_lastBlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lastBlock()const
        QTextBlock cppResult = const_cast<const ::QTextDocument *>(cppSelf)->lastBlock();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_lineCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lineCount()const
        int cppResult = const_cast<const ::QTextDocument *>(cppSelf)->lineCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_loadResource(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "loadResource", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::loadResource(int,QUrl)->QVariant
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1])))) {
        overloadId = 0; // loadResource(int,QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "loadResource", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QUrl cppArg1_local;
        ::QUrl *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // loadResource(int,QUrl)
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QTextDocument::loadResource(cppArg0, *cppArg1)
                : cppSelf->loadResource(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_markContentsDirty(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "markContentsDirty", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::markContentsDirty(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // markContentsDirty(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "markContentsDirty", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // markContentsDirty(int,int)
            cppSelf->markContentsDirty(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_maximumBlockCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumBlockCount()const
        int cppResult = const_cast<const ::QTextDocument *>(cppSelf)->maximumBlockCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_metaInformation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::metaInformation(QTextDocument::MetaInformation)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_MetaInformation_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // metaInformation(QTextDocument::MetaInformation)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "metaInformation", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        ::QTextDocument::MetaInformation cppArg0{QTextDocument::DocumentTitle};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // metaInformation(QTextDocument::MetaInformation)const
            QString cppResult = const_cast<const ::QTextDocument *>(cppSelf)->metaInformation(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_object(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::object(int)const->QTextObject*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // object(int)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "object", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // object(int)const
            QTextObject * cppResult = const_cast<const ::QTextDocument *>(cppSelf)->object(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextObject_IDX]), cppResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_objectForFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::objectForFormat(QTextFormat)const->QTextObject*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFormat_IDX]), (pyArg)))) {
        overloadId = 0; // objectForFormat(QTextFormat)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "objectForFormat", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextFormat cppArg0_local;
        ::QTextFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // objectForFormat(QTextFormat)const
            QTextObject * cppResult = const_cast<const ::QTextDocument *>(cppSelf)->objectForFormat(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextObject_IDX]), cppResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_pageCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pageCount()const
        int cppResult = const_cast<const ::QTextDocument *>(cppSelf)->pageCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_pageSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pageSize()const
        QSizeF cppResult = const_cast<const ::QTextDocument *>(cppSelf)->pageSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_print_(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::print(QPagedPaintDevice*)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPagedPaintDevice_IDX]), (pyArg)))) {
        overloadId = 0; // print(QPagedPaintDevice*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "print_", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPagedPaintDevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // print(QPagedPaintDevice*)const
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            const_cast<const ::QTextDocument *>(cppSelf)->print(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_redo(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "redo", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::redo()
    // 1: QTextDocument::redo(QTextCursor*)
    if (numArgs == 0) {
        overloadId = 0; // redo()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArgs[0])))) {
        overloadId = 1; // redo(QTextCursor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "redo", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // redo()
        {

            // redo()
            cppSelf->redo();
            break;
        }
        case 1: // redo(QTextCursor *cursor)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTextCursor *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // redo(QTextCursor*)
                cppSelf->redo(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_resource(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "resource", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::resource(int,QUrl)const->QVariant
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1])))) {
        overloadId = 0; // resource(int,QUrl)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "resource", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QUrl cppArg1_local;
        ::QUrl *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // resource(int,QUrl)const
            QVariant cppResult = const_cast<const ::QTextDocument *>(cppSelf)->resource(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_revision(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // revision()const
        int cppResult = const_cast<const ::QTextDocument *>(cppSelf)->revision();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_rootFrame(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rootFrame()const
        QTextFrame * cppResult = const_cast<const ::QTextDocument *>(cppSelf)->rootFrame();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextFrame_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_setBaseUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setBaseUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setBaseUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBaseUrl", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBaseUrl(QUrl)
            cppSelf->setBaseUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setBaselineOffset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setBaselineOffset(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setBaselineOffset(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBaselineOffset", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBaselineOffset(qreal)
            cppSelf->setBaselineOffset(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setDefaultCursorMoveStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setDefaultCursorMoveStyle(Qt::CursorMoveStyle)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_CursorMoveStyle_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setDefaultCursorMoveStyle(Qt::CursorMoveStyle)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDefaultCursorMoveStyle", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        ::Qt::CursorMoveStyle cppArg0{Qt::LogicalMoveStyle};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultCursorMoveStyle(Qt::CursorMoveStyle)
            cppSelf->setDefaultCursorMoveStyle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setDefaultFont(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setDefaultFont(QFont)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // setDefaultFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDefaultFont", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultFont(QFont)
            cppSelf->setDefaultFont(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setDefaultStyleSheet(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setDefaultStyleSheet(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDefaultStyleSheet(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDefaultStyleSheet", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultStyleSheet(QString)
            cppSelf->setDefaultStyleSheet(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setDefaultTextOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setDefaultTextOption(QTextOption)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_IDX]), (pyArg)))) {
        overloadId = 0; // setDefaultTextOption(QTextOption)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDefaultTextOption", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextOption cppArg0_local;
        ::QTextOption *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultTextOption(QTextOption)
            cppSelf->setDefaultTextOption(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setDocumentLayout(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setDocumentLayout(QAbstractTextDocumentLayout*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_IDX]), (pyArg)))) {
        overloadId = 0; // setDocumentLayout(QAbstractTextDocumentLayout*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDocumentLayout", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractTextDocumentLayout *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDocumentLayout(QAbstractTextDocumentLayout*)
            cppSelf->setDocumentLayout(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setDocumentMargin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setDocumentMargin(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setDocumentMargin(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDocumentMargin", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDocumentMargin(qreal)
            cppSelf->setDocumentMargin(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setHtml(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setHtml(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setHtml(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHtml", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHtml(QString)
            cppSelf->setHtml(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setIndentWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setIndentWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setIndentWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIndentWidth", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIndentWidth(qreal)
            cppSelf->setIndentWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setLayoutEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setLayoutEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setLayoutEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLayoutEnabled", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLayoutEnabled(bool)
            cppSelf->setLayoutEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setMarkdown(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setMarkdown", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::setMarkdown(QString,QFlags<QTextDocument::MarkdownFeature>=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setMarkdown(QString,QFlags<QTextDocument::MarkdownFeature>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_MarkdownFeature_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // setMarkdown(QString,QFlags<QTextDocument::MarkdownFeature>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_features = Shiboken::String::createStaticString("features");
            if (PyDict_Contains(kwds, key_features) != 0) {
                value = PyDict_GetItem(kwds, key_features);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_features);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_MarkdownFeature_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_features);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QTextDocument::MarkdownFeature> cppArg1(QTextDocument::MarkdownFeature::MarkdownDialectGitHub);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMarkdown(QString,QFlags<QTextDocument::MarkdownFeature>)
            cppSelf->setMarkdown(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setMaximumBlockCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setMaximumBlockCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMaximumBlockCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximumBlockCount", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumBlockCount(int)
            cppSelf->setMaximumBlockCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setMetaInformation(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setMetaInformation", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::setMetaInformation(QTextDocument::MetaInformation,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_MetaInformation_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // setMetaInformation(QTextDocument::MetaInformation,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setMetaInformation", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        ::QTextDocument::MetaInformation cppArg0{QTextDocument::DocumentTitle};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMetaInformation(QTextDocument::MetaInformation,QString)
            cppSelf->setMetaInformation(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setModified(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setModified", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    if (PyArg_ParseTuple(args, "|O:setModified", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::setModified(bool=)
    if (numArgs == 0) {
        overloadId = 0; // setModified(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // setModified(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setModified", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_m = Shiboken::String::createStaticString("m");
            if (PyDict_Contains(kwds, key_m) != 0) {
                value = PyDict_GetItem(kwds, key_m);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_m);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setModified", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "setModified", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_m);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setModified", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setModified(bool)
            cppSelf->setModified(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setPageSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setPageSize(QSizeF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
        overloadId = 0; // setPageSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPageSize", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSizeF cppArg0_local;
        ::QSizeF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPageSize(QSizeF)
            cppSelf->setPageSize(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setPlainText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setPlainText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPlainText", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlainText(QString)
            cppSelf->setPlainText(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setSubScriptBaseline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setSubScriptBaseline(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setSubScriptBaseline(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSubScriptBaseline", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSubScriptBaseline(qreal)
            cppSelf->setSubScriptBaseline(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setSuperScriptBaseline(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setSuperScriptBaseline(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setSuperScriptBaseline(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSuperScriptBaseline", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSuperScriptBaseline(qreal)
            cppSelf->setSuperScriptBaseline(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setTextWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setTextWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setTextWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextWidth", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextWidth(qreal)
            cppSelf->setTextWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setUndoRedoEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setUndoRedoEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUndoRedoEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUndoRedoEnabled", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUndoRedoEnabled(bool)
            cppSelf->setUndoRedoEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_setUseDesignMetrics(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QTextDocument::setUseDesignMetrics(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUseDesignMetrics(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUseDesignMetrics", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUseDesignMetrics(bool)
            cppSelf->setUseDesignMetrics(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        QSizeF cppResult = const_cast<const ::QTextDocument *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_subScriptBaseline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // subScriptBaseline()const
        qreal cppResult = const_cast<const ::QTextDocument *>(cppSelf)->subScriptBaseline();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_superScriptBaseline(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // superScriptBaseline()const
        qreal cppResult = const_cast<const ::QTextDocument *>(cppSelf)->superScriptBaseline();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_textWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textWidth()const
        qreal cppResult = const_cast<const ::QTextDocument *>(cppSelf)->textWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_toHtml(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toHtml()const
        QString cppResult = const_cast<const ::QTextDocument *>(cppSelf)->toHtml();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_toMarkdown(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "toMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    if (PyArg_ParseTuple(args, "|O:toMarkdown", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::toMarkdown(QFlags<QTextDocument::MarkdownFeature>=)const->QString
    if (numArgs == 0) {
        overloadId = 0; // toMarkdown(QFlags<QTextDocument::MarkdownFeature>)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_MarkdownFeature_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // toMarkdown(QFlags<QTextDocument::MarkdownFeature>)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_features = Shiboken::String::createStaticString("features");
            if (PyDict_Contains(kwds, key_features) != 0) {
                value = PyDict_GetItem(kwds, key_features);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_features);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "toMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_MarkdownFeature_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "toMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_features);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "toMarkdown", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);
            }
        }
        ::QFlags<QTextDocument::MarkdownFeature> cppArg0(QTextDocument::MarkdownFeature::MarkdownDialectGitHub);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toMarkdown(QFlags<QTextDocument::MarkdownFeature>)const
            QString cppResult = const_cast<const ::QTextDocument *>(cppSelf)->toMarkdown(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_toPlainText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toPlainText()const
        QString cppResult = const_cast<const ::QTextDocument *>(cppSelf)->toPlainText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_toRawText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toRawText()const
        QString cppResult = const_cast<const ::QTextDocument *>(cppSelf)->toRawText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTextDocumentFunc_undo(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "undo", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QTextDocument::undo()
    // 1: QTextDocument::undo(QTextCursor*)
    if (numArgs == 0) {
        overloadId = 0; // undo()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArgs[0])))) {
        overloadId = 1; // undo(QTextCursor*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "undo", errInfo, SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // undo()
        {

            // undo()
            cppSelf->undo();
            break;
        }
        case 1: // undo(QTextCursor *cursor)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTextCursor *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // undo(QTextCursor*)
                cppSelf->undo(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTextDocumentFunc_useDesignMetrics(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // useDesignMetrics()const
        bool cppResult = const_cast<const ::QTextDocument *>(cppSelf)->useDesignMetrics();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QTextDocument_PropertyStrings[] = {
    "baseUrl::",
    "blockCount:",
    "defaultFont::",
    "defaultStyleSheet::",
    "documentMargin::",
    "indentWidth::",
    "layoutEnabled:isLayoutEnabled:",
    "maximumBlockCount::",
    "modified:isModified:",
    "pageSize::",
    "size:",
    "textWidth::",
    "undoRedoEnabled:isUndoRedoEnabled:",
    "useDesignMetrics::",
    nullptr // Sentinel
};

static const char *Sbk_QTextDocument_EnumFlagInfo[] = {
    "FindFlag:Flag:FindFlags",
    "MarkdownFeature:Flag:MarkdownFeatures",
    "MetaInformation:Enum",
    "ResourceType:IntEnum",
    "Stacks:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTextDocument_methods[] = {
    {"addResource", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_addResource), METH_VARARGS, nullptr},
    {"adjustSize", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_adjustSize), METH_NOARGS, nullptr},
    {"allFormats", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_allFormats), METH_NOARGS, nullptr},
    {"availableRedoSteps", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_availableRedoSteps), METH_NOARGS, nullptr},
    {"availableUndoSteps", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_availableUndoSteps), METH_NOARGS, nullptr},
    {"baseUrl", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_baseUrl), METH_NOARGS, nullptr},
    {"baselineOffset", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_baselineOffset), METH_NOARGS, nullptr},
    {"begin", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_begin), METH_NOARGS, nullptr},
    {"blockCount", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_blockCount), METH_NOARGS, nullptr},
    {"characterAt", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_characterAt), METH_O, nullptr},
    {"characterCount", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_characterCount), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_clear), METH_NOARGS, nullptr},
    {"clearUndoRedoStacks", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_clearUndoRedoStacks), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"clone", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_clone), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"createObject", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_createObject), METH_O, nullptr},
    {"defaultCursorMoveStyle", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_defaultCursorMoveStyle), METH_NOARGS, nullptr},
    {"defaultFont", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_defaultFont), METH_NOARGS, nullptr},
    {"defaultStyleSheet", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_defaultStyleSheet), METH_NOARGS, nullptr},
    {"defaultTextOption", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_defaultTextOption), METH_NOARGS, nullptr},
    {"documentLayout", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_documentLayout), METH_NOARGS, nullptr},
    {"documentMargin", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_documentMargin), METH_NOARGS, nullptr},
    {"drawContents", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_drawContents), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"end", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_end), METH_NOARGS, nullptr},
    {"find", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_find), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"findBlock", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_findBlock), METH_O, nullptr},
    {"findBlockByLineNumber", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_findBlockByLineNumber), METH_O, nullptr},
    {"findBlockByNumber", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_findBlockByNumber), METH_O, nullptr},
    {"firstBlock", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_firstBlock), METH_NOARGS, nullptr},
    {"frameAt", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_frameAt), METH_O, nullptr},
    {"idealWidth", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_idealWidth), METH_NOARGS, nullptr},
    {"indentWidth", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_indentWidth), METH_NOARGS, nullptr},
    {"isEmpty", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_isEmpty), METH_NOARGS, nullptr},
    {"isLayoutEnabled", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_isLayoutEnabled), METH_NOARGS, nullptr},
    {"isModified", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_isModified), METH_NOARGS, nullptr},
    {"isRedoAvailable", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_isRedoAvailable), METH_NOARGS, nullptr},
    {"isUndoAvailable", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_isUndoAvailable), METH_NOARGS, nullptr},
    {"isUndoRedoEnabled", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_isUndoRedoEnabled), METH_NOARGS, nullptr},
    {"lastBlock", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_lastBlock), METH_NOARGS, nullptr},
    {"lineCount", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_lineCount), METH_NOARGS, nullptr},
    {"loadResource", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_loadResource), METH_VARARGS, nullptr},
    {"markContentsDirty", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_markContentsDirty), METH_VARARGS, nullptr},
    {"maximumBlockCount", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_maximumBlockCount), METH_NOARGS, nullptr},
    {"metaInformation", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_metaInformation), METH_O, nullptr},
    {"object", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_object), METH_O, nullptr},
    {"objectForFormat", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_objectForFormat), METH_O, nullptr},
    {"pageCount", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_pageCount), METH_NOARGS, nullptr},
    {"pageSize", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_pageSize), METH_NOARGS, nullptr},
    {"print_", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_print_), METH_O, nullptr},
    {"redo", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_redo), METH_VARARGS, nullptr},
    {"resource", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_resource), METH_VARARGS, nullptr},
    {"revision", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_revision), METH_NOARGS, nullptr},
    {"rootFrame", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_rootFrame), METH_NOARGS, nullptr},
    {"setBaseUrl", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setBaseUrl), METH_O, nullptr},
    {"setBaselineOffset", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setBaselineOffset), METH_O, nullptr},
    {"setDefaultCursorMoveStyle", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setDefaultCursorMoveStyle), METH_O, nullptr},
    {"setDefaultFont", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setDefaultFont), METH_O, nullptr},
    {"setDefaultStyleSheet", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setDefaultStyleSheet), METH_O, nullptr},
    {"setDefaultTextOption", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setDefaultTextOption), METH_O, nullptr},
    {"setDocumentLayout", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setDocumentLayout), METH_O, nullptr},
    {"setDocumentMargin", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setDocumentMargin), METH_O, nullptr},
    {"setHtml", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setHtml), METH_O, nullptr},
    {"setIndentWidth", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setIndentWidth), METH_O, nullptr},
    {"setLayoutEnabled", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setLayoutEnabled), METH_O, nullptr},
    {"setMarkdown", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setMarkdown), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setMaximumBlockCount", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setMaximumBlockCount), METH_O, nullptr},
    {"setMetaInformation", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setMetaInformation), METH_VARARGS, nullptr},
    {"setModified", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setModified), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setPageSize", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setPageSize), METH_O, nullptr},
    {"setPlainText", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setPlainText), METH_O, nullptr},
    {"setSubScriptBaseline", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setSubScriptBaseline), METH_O, nullptr},
    {"setSuperScriptBaseline", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setSuperScriptBaseline), METH_O, nullptr},
    {"setTextWidth", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setTextWidth), METH_O, nullptr},
    {"setUndoRedoEnabled", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setUndoRedoEnabled), METH_O, nullptr},
    {"setUseDesignMetrics", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_setUseDesignMetrics), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_size), METH_NOARGS, nullptr},
    {"subScriptBaseline", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_subScriptBaseline), METH_NOARGS, nullptr},
    {"superScriptBaseline", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_superScriptBaseline), METH_NOARGS, nullptr},
    {"textWidth", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_textWidth), METH_NOARGS, nullptr},
    {"toHtml", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_toHtml), METH_NOARGS, nullptr},
    {"toMarkdown", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_toMarkdown), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"toPlainText", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_toPlainText), METH_NOARGS, nullptr},
    {"toRawText", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_toRawText), METH_NOARGS, nullptr},
    {"undo", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_undo), METH_VARARGS, nullptr},
    {"useDesignMetrics", reinterpret_cast<PyCFunction>(Sbk_QTextDocumentFunc_useDesignMetrics), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QTextDocument_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QTextDocument *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QTextDocumentWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QTextDocument_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTextDocument_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTextDocument_Type = nullptr;
static PyTypeObject *Sbk_QTextDocument_TypeF(void)
{
    return _Sbk_QTextDocument_Type;
}

static PyType_Slot Sbk_QTextDocument_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QTextDocument_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTextDocument_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTextDocument_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTextDocument_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QTextDocument_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTextDocument_spec = {
    "2:PySide6.QtGui.QTextDocument",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTextDocument_slots
};

} //extern "C"

static void *Sbk_QTextDocument_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QTextDocument *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTextDocument_MetaInformation(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextDocument::MetaInformation>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextDocument::MetaInformation *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextDocument_MetaInformation_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_MetaInformation_IDX])))
        return Enum_PythonToCpp_QTextDocument_MetaInformation;
    return {};
}

static PyObject *QTextDocument_MetaInformation_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextDocument::MetaInformation>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextDocument::MetaInformation *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_MetaInformation_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextDocument_MarkdownFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextDocument::MarkdownFeature>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextDocument::MarkdownFeature *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextDocument_MarkdownFeature_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_MarkdownFeature_IDX])))
        return Enum_PythonToCpp_QTextDocument_MarkdownFeature;
    return {};
}

static PyObject *QTextDocument_MarkdownFeature_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextDocument::MarkdownFeature>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextDocument::MarkdownFeature *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_MarkdownFeature_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QTextDocument_MarkdownFeature(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QTextDocument::MarkdownFeature>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QTextDocument::MarkdownFeature> *>(cppOut) = value;

}

static PyObject *QTextDocument_MarkdownFeature_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QTextDocument::MarkdownFeature> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_MarkdownFeature_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QTextDocument_FindFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextDocument::FindFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextDocument::FindFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextDocument_FindFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_FindFlag_IDX])))
        return Enum_PythonToCpp_QTextDocument_FindFlag;
    return {};
}

static PyObject *QTextDocument_FindFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextDocument::FindFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextDocument::FindFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_FindFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QTextDocument_FindFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QTextDocument::FindFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QTextDocument::FindFlag> *>(cppOut) = value;

}

static PyObject *QTextDocument_FindFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QTextDocument::FindFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_FindFlag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QTextDocument_ResourceType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextDocument::ResourceType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextDocument::ResourceType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextDocument_ResourceType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_ResourceType_IDX])))
        return Enum_PythonToCpp_QTextDocument_ResourceType;
    return {};
}

static PyObject *QTextDocument_ResourceType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextDocument::ResourceType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextDocument::ResourceType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_ResourceType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTextDocument_Stacks(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTextDocument::Stacks>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTextDocument::Stacks *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTextDocument_Stacks_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_Stacks_IDX])))
        return Enum_PythonToCpp_QTextDocument_Stacks;
    return {};
}

static PyObject *QTextDocument_Stacks_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTextDocument::Stacks>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTextDocument::Stacks *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_Stacks_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QTextDocument_PythonToCpp_QTextDocument_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QTextDocument_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QTextDocument_PythonToCpp_QTextDocument_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QTextDocument_TypeF()))
        return QTextDocument_PythonToCpp_QTextDocument_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QTextDocument_PTR_CppToPython_QTextDocument(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QTextDocument *>(const_cast<void *>(cppIn)), Sbk_QTextDocument_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QTextDocument_SignatureStrings[] = {
    "1:PySide6.QtGui.QTextDocument(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,undoRedoEnabled:bool=None,modified:bool=None,pageSize:QSizeF=None,defaultFont:QFont=None,useDesignMetrics:bool=None,layoutEnabled:bool=None,size:QSizeF=None,textWidth:qreal=None,blockCount:int=None,indentWidth:qreal=None,defaultStyleSheet:QString=None,maximumBlockCount:int=None,documentMargin:qreal=None,baseUrl:QUrl=None)",
    "0:PySide6.QtGui.QTextDocument(self,text:QString,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,undoRedoEnabled:bool=None,modified:bool=None,pageSize:QSizeF=None,defaultFont:QFont=None,useDesignMetrics:bool=None,layoutEnabled:bool=None,size:QSizeF=None,textWidth:qreal=None,blockCount:int=None,indentWidth:qreal=None,defaultStyleSheet:QString=None,maximumBlockCount:int=None,documentMargin:qreal=None,baseUrl:QUrl=None)",
    "PySide6.QtGui.QTextDocument.addResource(self,type:int,name:typing.Union[PySide6.QtCore.QUrl, QString],resource:QVariant)",
    "PySide6.QtGui.QTextDocument.adjustSize(self)",
    "PySide6.QtGui.QTextDocument.allFormats(self)->QList[PySide6.QtGui.QTextFormat]",
    "PySide6.QtGui.QTextDocument.availableRedoSteps(self)->int",
    "PySide6.QtGui.QTextDocument.availableUndoSteps(self)->int",
    "PySide6.QtGui.QTextDocument.baseUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtGui.QTextDocument.baselineOffset(self)->qreal",
    "PySide6.QtGui.QTextDocument.begin(self)->PySide6.QtGui.QTextBlock",
    "PySide6.QtGui.QTextDocument.blockCount(self)->int",
    "PySide6.QtGui.QTextDocument.characterAt(self,pos:int)->QChar",
    "PySide6.QtGui.QTextDocument.characterCount(self)->int",
    "PySide6.QtGui.QTextDocument.clear(self)",
    "PySide6.QtGui.QTextDocument.clearUndoRedoStacks(self,historyToClear:PySide6.QtGui.QTextDocument.Stacks=QTextDocument.Stacks.UndoAndRedoStacks)",
    "PySide6.QtGui.QTextDocument.clone(self,parent:PySide6.QtCore.QObject=nullptr)->PySide6.QtGui.QTextDocument",
    "PySide6.QtGui.QTextDocument.createObject(self,f:PySide6.QtGui.QTextFormat)->PySide6.QtGui.QTextObject",
    "PySide6.QtGui.QTextDocument.defaultCursorMoveStyle(self)->PySide6.QtCore.Qt.CursorMoveStyle",
    "PySide6.QtGui.QTextDocument.defaultFont(self)->PySide6.QtGui.QFont",
    "PySide6.QtGui.QTextDocument.defaultStyleSheet(self)->QString",
    "PySide6.QtGui.QTextDocument.defaultTextOption(self)->PySide6.QtGui.QTextOption",
    "PySide6.QtGui.QTextDocument.documentLayout(self)->PySide6.QtGui.QAbstractTextDocumentLayout",
    "PySide6.QtGui.QTextDocument.documentMargin(self)->qreal",
    "PySide6.QtGui.QTextDocument.drawContents(self,painter:PySide6.QtGui.QPainter,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect]=QRectF())",
    "PySide6.QtGui.QTextDocument.end(self)->PySide6.QtGui.QTextBlock",
    "3:PySide6.QtGui.QTextDocument.find(self,expr:typing.Union[PySide6.QtCore.QRegularExpression, QString],cursor:PySide6.QtGui.QTextCursor,options:PySide6.QtGui.QTextDocument.FindFlag=QTextDocument.FindFlags())->PySide6.QtGui.QTextCursor",
    "2:PySide6.QtGui.QTextDocument.find(self,expr:typing.Union[PySide6.QtCore.QRegularExpression, QString],from:int=0,options:PySide6.QtGui.QTextDocument.FindFlag=QTextDocument.FindFlags())->PySide6.QtGui.QTextCursor",
    "1:PySide6.QtGui.QTextDocument.find(self,subString:QString,cursor:PySide6.QtGui.QTextCursor,options:PySide6.QtGui.QTextDocument.FindFlag=QTextDocument.FindFlags())->PySide6.QtGui.QTextCursor",
    "0:PySide6.QtGui.QTextDocument.find(self,subString:QString,from:int=0,options:PySide6.QtGui.QTextDocument.FindFlag=QTextDocument.FindFlags())->PySide6.QtGui.QTextCursor",
    "PySide6.QtGui.QTextDocument.findBlock(self,pos:int)->PySide6.QtGui.QTextBlock",
    "PySide6.QtGui.QTextDocument.findBlockByLineNumber(self,blockNumber:int)->PySide6.QtGui.QTextBlock",
    "PySide6.QtGui.QTextDocument.findBlockByNumber(self,blockNumber:int)->PySide6.QtGui.QTextBlock",
    "PySide6.QtGui.QTextDocument.firstBlock(self)->PySide6.QtGui.QTextBlock",
    "PySide6.QtGui.QTextDocument.frameAt(self,pos:int)->PySide6.QtGui.QTextFrame",
    "PySide6.QtGui.QTextDocument.idealWidth(self)->qreal",
    "PySide6.QtGui.QTextDocument.indentWidth(self)->qreal",
    "PySide6.QtGui.QTextDocument.isEmpty(self)->bool",
    "PySide6.QtGui.QTextDocument.isLayoutEnabled(self)->bool",
    "PySide6.QtGui.QTextDocument.isModified(self)->bool",
    "PySide6.QtGui.QTextDocument.isRedoAvailable(self)->bool",
    "PySide6.QtGui.QTextDocument.isUndoAvailable(self)->bool",
    "PySide6.QtGui.QTextDocument.isUndoRedoEnabled(self)->bool",
    "PySide6.QtGui.QTextDocument.lastBlock(self)->PySide6.QtGui.QTextBlock",
    "PySide6.QtGui.QTextDocument.lineCount(self)->int",
    "PySide6.QtGui.QTextDocument.loadResource(self,type:int,name:typing.Union[PySide6.QtCore.QUrl, QString])->QVariant",
    "PySide6.QtGui.QTextDocument.markContentsDirty(self,from:int,length:int)",
    "PySide6.QtGui.QTextDocument.maximumBlockCount(self)->int",
    "PySide6.QtGui.QTextDocument.metaInformation(self,info:PySide6.QtGui.QTextDocument.MetaInformation)->QString",
    "PySide6.QtGui.QTextDocument.object(self,objectIndex:int)->PySide6.QtGui.QTextObject",
    "PySide6.QtGui.QTextDocument.objectForFormat(self,arg__1:PySide6.QtGui.QTextFormat)->PySide6.QtGui.QTextObject",
    "PySide6.QtGui.QTextDocument.pageCount(self)->int",
    "PySide6.QtGui.QTextDocument.pageSize(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtGui.QTextDocument.print_(self,printer:PySide6.QtGui.QPagedPaintDevice)",
    "1:PySide6.QtGui.QTextDocument.redo(self)",
    "0:PySide6.QtGui.QTextDocument.redo(self,cursor:PySide6.QtGui.QTextCursor)",
    "PySide6.QtGui.QTextDocument.resource(self,type:int,name:typing.Union[PySide6.QtCore.QUrl, QString])->QVariant",
    "PySide6.QtGui.QTextDocument.revision(self)->int",
    "PySide6.QtGui.QTextDocument.rootFrame(self)->PySide6.QtGui.QTextFrame",
    "PySide6.QtGui.QTextDocument.setBaseUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtGui.QTextDocument.setBaselineOffset(self,baseline:qreal)",
    "PySide6.QtGui.QTextDocument.setDefaultCursorMoveStyle(self,style:PySide6.QtCore.Qt.CursorMoveStyle)",
    "PySide6.QtGui.QTextDocument.setDefaultFont(self,font:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "PySide6.QtGui.QTextDocument.setDefaultStyleSheet(self,sheet:QString)",
    "PySide6.QtGui.QTextDocument.setDefaultTextOption(self,option:typing.Union[PySide6.QtGui.QTextOption, PySide6.QtCore.Qt.AlignmentFlag])",
    "PySide6.QtGui.QTextDocument.setDocumentLayout(self,layout:PySide6.QtGui.QAbstractTextDocumentLayout)",
    "PySide6.QtGui.QTextDocument.setDocumentMargin(self,margin:qreal)",
    "PySide6.QtGui.QTextDocument.setHtml(self,html:QString)",
    "PySide6.QtGui.QTextDocument.setIndentWidth(self,width:qreal)",
    "PySide6.QtGui.QTextDocument.setLayoutEnabled(self,b:bool)",
    "PySide6.QtGui.QTextDocument.setMarkdown(self,markdown:QString,features:PySide6.QtGui.QTextDocument.MarkdownFeature=QTextDocument.MarkdownFeature.MarkdownDialectGitHub)",
    "PySide6.QtGui.QTextDocument.setMaximumBlockCount(self,maximum:int)",
    "PySide6.QtGui.QTextDocument.setMetaInformation(self,info:PySide6.QtGui.QTextDocument.MetaInformation,arg__2:QString)",
    "PySide6.QtGui.QTextDocument.setModified(self,m:bool=true)",
    "PySide6.QtGui.QTextDocument.setPageSize(self,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])",
    "PySide6.QtGui.QTextDocument.setPlainText(self,text:QString)",
    "PySide6.QtGui.QTextDocument.setSubScriptBaseline(self,baseline:qreal)",
    "PySide6.QtGui.QTextDocument.setSuperScriptBaseline(self,baseline:qreal)",
    "PySide6.QtGui.QTextDocument.setTextWidth(self,width:qreal)",
    "PySide6.QtGui.QTextDocument.setUndoRedoEnabled(self,enable:bool)",
    "PySide6.QtGui.QTextDocument.setUseDesignMetrics(self,b:bool)",
    "PySide6.QtGui.QTextDocument.size(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtGui.QTextDocument.subScriptBaseline(self)->qreal",
    "PySide6.QtGui.QTextDocument.superScriptBaseline(self)->qreal",
    "PySide6.QtGui.QTextDocument.textWidth(self)->qreal",
    "PySide6.QtGui.QTextDocument.toHtml(self)->QString",
    "PySide6.QtGui.QTextDocument.toMarkdown(self,features:PySide6.QtGui.QTextDocument.MarkdownFeature=QTextDocument.MarkdownFeature.MarkdownDialectGitHub)->QString",
    "PySide6.QtGui.QTextDocument.toPlainText(self)->QString",
    "PySide6.QtGui.QTextDocument.toRawText(self)->QString",
    "1:PySide6.QtGui.QTextDocument.undo(self)",
    "0:PySide6.QtGui.QTextDocument.undo(self,cursor:PySide6.QtGui.QTextCursor)",
    "PySide6.QtGui.QTextDocument.useDesignMetrics(self)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QTextDocument_SignatureByteSize = 1333;
static constexpr uint8_t QTextDocument_SignatureBytes[1333] = {
    0x78, 0xda, 0xed, 0x59, 0x4b, 0x6f, 0xe3, 0x36, 0x10, 0xbe, 0xef, 0xaf, 0xd8, 0xe3, 0xa6, 0x50,
    0x8d, 0x64, 0x0b, 0xf4, 0x20, 0xc0, 0x05, 0x12, 0x3b, 0xde, 0x0d, 0x9a, 0x6c, 0xe2, 0x38, 0x69,
    0x0f, 0x8b, 0x20, 0xa0, 0xa5, 0x91, 0xc3, 0x0d, 0x25, 0xba, 0x24, 0x15, 0xc7, 0xfd, 0xf5, 0x1d,
    0x8a, 0x92, 0x2c, 0x5b, 0x32, 0x49, 0x65, 0xb3, 0x69, 0x0f, 0xbd, 0x18, 0x32, 0x35, 0x0f, 0x92,
    0xf3, 0xfa, 0x66, 0x74, 0x14, 0x5e, 0xad, 0x67, 0x34, 0x86, 0x5f, 0x07, 0x53, 0xf5, 0x29, 0xa7,
    0x83, 0xe9, 0x0d, 0x3c, 0xab, 0x31, 0x8f, 0xf2, 0x14, 0x32, 0xf5, 0x41, 0x02, 0x4b, 0x82, 0x25,
    0x11, 0xf8, 0xdc, 0xa0, 0x1b, 0x71, 0x01, 0x83, 0xe9, 0xe5, 0xfc, 0x1b, 0x44, 0x6a, 0x98, 0xe5,
    0x8c, 0x2d, 0x95, 0x08, 0x7e, 0x0a, 0x7f, 0x87, 0xf5, 0x8a, 0x8b, 0xf8, 0x32, 0x63, 0xeb, 0xe1,
    0x17, 0x9e, 0x41, 0x90, 0x67, 0x31, 0xbf, 0x86, 0x98, 0x9f, 0x66, 0x64, 0xce, 0x20, 0x0e, 0xe7,
    0x9c, 0x33, 0xf3, 0x26, 0xe5, 0x31, 0x4d, 0xe8, 0xd6, 0xd2, 0x92, 0x2c, 0x60, 0x46, 0xff, 0x86,
    0x70, 0xaa, 0x7f, 0x27, 0x66, 0x31, 0x86, 0x84, 0xe4, 0x4c, 0x4d, 0x38, 0xea, 0x9f, 0xea, 0xdf,
    0x52, 0xb0, 0x84, 0x31, 0x48, 0xba, 0xc8, 0x2e, 0x40, 0x09, 0x1a, 0xc9, 0x86, 0x18, 0x46, 0xd6,
    0x3c, 0x57, 0x6d, 0x8d, 0x72, 0x57, 0xb4, 0xc2, 0x73, 0xfe, 0x49, 0x63, 0xf5, 0x10, 0xfe, 0x25,
    0x80, 0x94, 0x54, 0x73, 0xc6, 0xa3, 0xc7, 0x11, 0xcf, 0x51, 0x1d, 0xad, 0x94, 0xd1, 0x2c, 0xc6,
    0xe3, 0xb7, 0x48, 0xcb, 0xad, 0xcd, 0xd4, 0x9a, 0xc1, 0xec, 0x01, 0x00, 0x37, 0x38, 0xc3, 0xcd,
    0x64, 0x8b, 0xf2, 0x84, 0xe4, 0x99, 0xa6, 0x79, 0x7a, 0xd2, 0x21, 0x30, 0x2e, 0x6f, 0xf7, 0x82,
    0x88, 0x05, 0xcd, 0xb6, 0xd4, 0x13, 0x09, 0xb7, 0x82, 0x85, 0x53, 0xfc, 0x29, 0x56, 0x0e, 0xde,
    0x1d, 0xba, 0xed, 0xa3, 0x4f, 0x52, 0x29, 0xff, 0xdf, 0x58, 0xff, 0xa6, 0xb1, 0x2c, 0xa6, 0x1a,
    0x90, 0x38, 0xbe, 0x06, 0xc9, 0x73, 0x11, 0x41, 0x69, 0xb6, 0xf5, 0x12, 0xb4, 0x9e, 0x20, 0x23,
    0x29, 0x84, 0xf8, 0x0f, 0xb7, 0x33, 0xb8, 0xcd, 0x28, 0xcf, 0xbe, 0xee, 0x5a, 0x0f, 0x35, 0x04,
    0xef, 0xcb, 0x1d, 0xdf, 0x05, 0xa2, 0x14, 0x13, 0x4e, 0xff, 0x20, 0x82, 0x92, 0x4c, 0xb9, 0x14,
    0x7f, 0xcb, 0xa5, 0xd2, 0x97, 0x59, 0xe8, 0x75, 0x10, 0x33, 0x36, 0xe1, 0x22, 0x25, 0x4a, 0x1a,
    0xe2, 0x9f, 0x7f, 0x9b, 0x9e, 0x53, 0xa9, 0xbe, 0x76, 0xf0, 0x18, 0xba, 0x3b, 0xbb, 0xb8, 0x27,
    0x42, 0x99, 0xb6, 0xae, 0xf6, 0xac, 0x99, 0x82, 0x65, 0x2d, 0x16, 0x0f, 0xee, 0xc7, 0x79, 0x9b,
    0xf5, 0xe4, 0x2c, 0xed, 0x52, 0x91, 0x77, 0xdc, 0xa5, 0x93, 0x9d, 0xd1, 0x0c, 0x2e, 0x93, 0x44,
    0x82, 0xaa, 0xa4, 0x14, 0x76, 0xb7, 0xf3, 0x01, 0xfa, 0x47, 0x5b, 0x69, 0x4d, 0x58, 0x38, 0x97,
    0x5d, 0x42, 0xed, 0x7e, 0xbe, 0x47, 0x8d, 0x1e, 0x88, 0x20, 0x91, 0x02, 0x71, 0x5c, 0xa5, 0x6a,
    0x2e, 0xb5, 0x4b, 0x69, 0xb3, 0x8d, 0xf0, 0x9d, 0x1f, 0x73, 0x3f, 0x95, 0x0c, 0x88, 0xf0, 0x70,
    0xa4, 0x82, 0xee, 0xb6, 0xcc, 0x29, 0x33, 0x45, 0xa2, 0x47, 0x63, 0xc0, 0xe0, 0x01, 0xdd, 0x89,
    0x8b, 0xf5, 0x0d, 0x1f, 0x69, 0x0a, 0x5b, 0x76, 0x1b, 0x18, 0xb6, 0x61, 0xd7, 0xe2, 0x40, 0x8b,
    0x3e, 0xce, 0xe2, 0x8d, 0x74, 0xd7, 0x76, 0x30, 0x40, 0x7b, 0x94, 0xb3, 0x6e, 0x1b, 0x56, 0xe2,
    0xec, 0xaa, 0xd0, 0x55, 0x14, 0x18, 0x71, 0x46, 0x63, 0x12, 0xee, 0x0d, 0x9f, 0x6e, 0x3d, 0x86,
    0xd9, 0xaa, 0xa5, 0xcc, 0x68, 0xa3, 0x5c, 0x48, 0x2e, 0x2e, 0xf8, 0x13, 0x14, 0xb9, 0x6d, 0x9f,
    0xd3, 0xab, 0xc1, 0x0e, 0xa1, 0x8f, 0x6c, 0x9d, 0xc2, 0xf7, 0x38, 0xb4, 0x7e, 0xe5, 0x23, 0x62,
    0x93, 0x70, 0xeb, 0x74, 0x62, 0xb2, 0x98, 0x0f, 0x73, 0x71, 0x13, 0x4b, 0x85, 0x09, 0xd1, 0x12,
    0x56, 0x86, 0xc0, 0x2e, 0xae, 0x7c, 0x38, 0x2f, 0xaa, 0xcd, 0x1e, 0x59, 0xc7, 0x73, 0xa9, 0x74,
    0x38, 0x34, 0x39, 0x0d, 0x83, 0x97, 0x6c, 0x53, 0x1e, 0xfc, 0xb3, 0x45, 0x2c, 0xc8, 0x6a, 0x84,
    0x97, 0x88, 0xcf, 0xb2, 0x72, 0x4b, 0x0c, 0x3d, 0x68, 0x05, 0xc4, 0x95, 0x59, 0xc6, 0xa4, 0x1f,
    0x29, 0x7b, 0x91, 0xb8, 0x46, 0x8a, 0x49, 0xf0, 0xbe, 0x6b, 0xf9, 0x6e, 0x68, 0xde, 0x7e, 0x38,
    0xb0, 0x47, 0x09, 0x64, 0xb1, 0x33, 0x83, 0xfd, 0x62, 0x0d, 0xd9, 0x84, 0x96, 0x22, 0x02, 0x78,
    0x5e, 0x0a, 0xd7, 0x86, 0x17, 0x39, 0x23, 0xe2, 0x14, 0x09, 0x41, 0x4a, 0xa4, 0x68, 0xd4, 0xb8,
    0xa8, 0x70, 0xd7, 0x2e, 0x55, 0xc6, 0x91, 0x03, 0x5e, 0xd8, 0x5d, 0x5a, 0x37, 0x33, 0xc1, 0xcd,
    0x4c, 0x18, 0x59, 0x0c, 0xbb, 0x97, 0x25, 0x5e, 0x47, 0xe7, 0x41, 0x8d, 0x8a, 0x77, 0x1f, 0xdf,
    0xe4, 0xa4, 0x89, 0xe0, 0x69, 0x01, 0x37, 0x0e, 0xdf, 0xe2, 0x4c, 0x47, 0x9e, 0x67, 0x92, 0xf9,
    0xdc, 0x6c, 0xb0, 0x06, 0x96, 0xff, 0x05, 0x8b, 0x1c, 0xbe, 0x78, 0xf7, 0x6f, 0x7b, 0xcb, 0xae,
    0x5d, 0x16, 0x91, 0xb4, 0x5b, 0xb1, 0x5f, 0x84, 0x19, 0x6a, 0x69, 0x27, 0xeb, 0x73, 0x04, 0x2d,
    0x5f, 0xf2, 0x74, 0x0e, 0xa6, 0x3c, 0x1b, 0x78, 0x6c, 0x16, 0x5e, 0x49, 0xc3, 0x0f, 0x91, 0x2e,
    0xa4, 0xda, 0x5c, 0xc7, 0x8b, 0xc5, 0x08, 0xc4, 0xd0, 0x6d, 0x10, 0xd4, 0x55, 0x76, 0x35, 0xa5,
    0x55, 0x16, 0xbe, 0x20, 0xac, 0xe8, 0x20, 0xfc, 0xd3, 0x79, 0xa3, 0xed, 0xe8, 0xc1, 0x24, 0x4f,
    0xd3, 0xa5, 0x5a, 0x57, 0x0c, 0xba, 0xfd, 0x71, 0xd0, 0x9f, 0x37, 0xfb, 0xa5, 0x1e, 0x7c, 0x17,
    0x65, 0x07, 0xd7, 0x83, 0x45, 0x03, 0xab, 0xe3, 0x0a, 0x83, 0xf7, 0xe0, 0x2b, 0x70, 0xd9, 0x0b,
    0xf9, 0x1a, 0xed, 0xa7, 0x37, 0x27, 0x23, 0xaf, 0xe1, 0x3f, 0x1a, 0xf0, 0xf7, 0x82, 0xc1, 0x8c,
    0x93, 0x57, 0x6a, 0xe7, 0x34, 0x26, 0x2a, 0xfb, 0x38, 0xab, 0xc6, 0x94, 0x88, 0xc7, 0x0a, 0x31,
    0x8c, 0xa9, 0x28, 0xfd, 0xa6, 0x4e, 0x6c, 0x01, 0x83, 0x6c, 0x81, 0x4d, 0x2f, 0x75, 0xb5, 0x83,
    0xad, 0x5e, 0xd7, 0xf7, 0xc8, 0x29, 0x28, 0x72, 0x96, 0x25, 0x05, 0x6c, 0xad, 0x30, 0x19, 0xf6,
    0xdb, 0x09, 0xb7, 0x66, 0xd2, 0x8b, 0x6d, 0x2e, 0x4f, 0x04, 0xc8, 0x1b, 0xe8, 0xd9, 0x3c, 0x9f,
    0x61, 0x84, 0x3d, 0xef, 0x0f, 0x6b, 0x0f, 0xc4, 0x6c, 0xe4, 0x20, 0xec, 0x36, 0xc8, 0xdb, 0x08,
    0x47, 0xd8, 0x76, 0x7f, 0x7f, 0xf4, 0x03, 0xf0, 0xb9, 0x9e, 0x90, 0xf4, 0xba, 0xde, 0x6a, 0xa4,
    0xb2, 0x0f, 0xc2, 0x17, 0xd3, 0x10, 0xbb, 0x04, 0xbc, 0x56, 0x75, 0x5f, 0xe6, 0x40, 0xb1, 0x07,
    0x4d, 0x2e, 0x20, 0x2e, 0x20, 0xe5, 0x18, 0x9e, 0x68, 0x04, 0x07, 0x0e, 0x40, 0x20, 0x30, 0x22,
    0xcb, 0x66, 0xef, 0xd0, 0x8f, 0xd0, 0x89, 0x13, 0xec, 0xde, 0x29, 0xde, 0x34, 0xa6, 0x04, 0x5e,
    0x82, 0x6c, 0xf4, 0x17, 0x2e, 0x1b, 0x09, 0xce, 0x4d, 0x01, 0xb1, 0x24, 0x1b, 0x77, 0x81, 0x91,
    0xa0, 0x4e, 0x1a, 0x33, 0x8a, 0x20, 0x17, 0xac, 0xcf, 0xd9, 0x7c, 0x64, 0xef, 0x0c, 0x30, 0x82,
    0x6a, 0xa8, 0x61, 0xe6, 0x57, 0x4e, 0x11, 0xe3, 0xfd, 0xcd, 0x65, 0x20, 0xf5, 0x63, 0xe8, 0x6c,
    0x30, 0x7d, 0x75, 0xd4, 0x4d, 0x66, 0x90, 0xe8, 0xb9, 0xe1, 0x9e, 0x7b, 0xa8, 0x9b, 0xce, 0xfa,
    0x1e, 0xea, 0x07, 0x3d, 0x9e, 0xba, 0xf3, 0xd5, 0xb6, 0xd3, 0x8f, 0x06, 0xb2, 0x39, 0x0b, 0xf4,
    0x15, 0xb2, 0xd3, 0x97, 0x96, 0x80, 0xd2, 0xba, 0xf5, 0x0d, 0x4b, 0xbb, 0x41, 0x53, 0x83, 0x63,
    0x46, 0x17, 0x99, 0x56, 0xa2, 0xb1, 0xa5, 0xc7, 0x59, 0xda, 0xfd, 0x6c, 0x39, 0x49, 0x0d, 0xbd,
    0x9b, 0x5a, 0x6f, 0x25, 0x8d, 0xc6, 0x36, 0x48, 0x1b, 0x33, 0x50, 0xa7, 0x80, 0xcf, 0x2a, 0x2d,
    0xfd, 0xfb, 0x01, 0x9f, 0xbc, 0xef, 0xf8, 0x6c, 0x07, 0x49, 0x05, 0xab, 0xcd, 0x2c, 0xd7, 0xc9,
    0xdc, 0xc6, 0x47, 0xc1, 0xbc, 0x18, 0x2b, 0x3b, 0x39, 0xf1, 0x98, 0x8f, 0x31, 0x5f, 0x6d, 0x0e,
    0x5a, 0xfc, 0xdb, 0xb4, 0x0f, 0x40, 0x54, 0x8e, 0xb9, 0xc9, 0x5e, 0xea, 0x4a, 0xae, 0x89, 0x21,
    0x1e, 0x5a, 0xdf, 0xd6, 0xff, 0xc7, 0x94, 0x30, 0x2c, 0x26, 0x9f, 0xa8, 0xfa, 0x9c, 0xcf, 0x3d,
    0xf6, 0xd9, 0x55, 0xbd, 0xab, 0x01, 0xb6, 0xbb, 0xfa, 0x6b, 0x11, 0xaf, 0x51, 0xc7, 0x4d, 0xe1,
    0xfc, 0xe8, 0x6d, 0xd6, 0x2d, 0x04, 0x1a, 0xa4, 0x66, 0xd6, 0xaf, 0x44, 0xee, 0xce, 0x13, 0x57,
    0xcd, 0xba, 0x68, 0xbe, 0x0c, 0x58, 0x93, 0x65, 0x51, 0x27, 0xdb, 0x51, 0xa6, 0x97, 0xdd, 0xa1,
    0x75, 0xc5, 0xb0, 0x36, 0xea, 0xc5, 0xf6, 0x97, 0x15, 0x27, 0xef, 0x0c, 0x9b, 0xce, 0x48, 0xd0,
    0x65, 0x9d, 0x80, 0x5f, 0x94, 0x7a, 0x67, 0xf9, 0x12, 0xc4, 0x2b, 0xc8, 0xb9, 0xa9, 0xbe, 0x98,
    0xf4, 0x8f, 0xa2, 0x2e, 0x28, 0x1e, 0x40, 0xf1, 0xc7, 0x2f, 0x98, 0x6e, 0x77, 0xbe, 0xf8, 0xf4,
    0x88, 0xc4, 0xef, 0x02, 0x40, 0xb2, 0xd3, 0x02, 0x5e, 0xbd, 0x98, 0xdc, 0x73, 0xed, 0x5e, 0xcc,
    0x6a, 0xeb, 0xae, 0xfd, 0x58, 0x78, 0x9d, 0x1f, 0x3d, 0x21, 0xb1, 0xe2, 0xdb, 0x39, 0xea, 0xcd,
    0x52, 0x92, 0xef, 0xf6, 0xb6, 0x63, 0xc7, 0x9b, 0xed, 0x9a, 0xac, 0xba, 0x98, 0xec, 0xb8, 0x54,
    0x7f, 0xac, 0xf4, 0xc2, 0xa5, 0x35, 0xe1, 0x77, 0xe2, 0xd2, 0xbc, 0xcb, 0xa5, 0xab, 0xfe, 0xf4,
    0x1f, 0x5b, 0x69, 0x67, 0xe5
};
#endif

PyTypeObject *init_QTextDocument(PyObject *module)
{
    if (SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX].type != nullptr)
        return SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX].type;

    Shiboken::AutoDecRef Sbk_QTextDocument_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QTextDocument_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTextDocument",
        "QTextDocument*",
        &Sbk_QTextDocument_spec,
        &Shiboken::callCppDestructor< QTextDocument >,
        Sbk_QTextDocument_Type_bases.object(),
        0);
    auto *pyType = Sbk_QTextDocument_TypeF(); // references _Sbk_QTextDocument_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QTextDocument_SignatureStrings);
#else
    InitSignatureBytes(pyType, QTextDocument_SignatureBytes, QTextDocument_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTextDocument_PropertyStrings);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QTextDocument_PythonToCpp_QTextDocument_PTR,
        is_QTextDocument_PythonToCpp_QTextDocument_PTR_Convertible,
        QTextDocument_PTR_CppToPython_QTextDocument);

    Shiboken::Conversions::registerConverterName(converter, "QTextDocument");
    Shiboken::Conversions::registerConverterName(converter, "QTextDocument*");
    Shiboken::Conversions::registerConverterName(converter, "QTextDocument&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QTextDocument).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QTextDocumentWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QTextDocument_TypeF(), &Sbk_QTextDocument_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTextDocument_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'MetaInformation'.
    const char *MetaInformation_Initializer[] = {
        "DocumentTitle",
        "DocumentUrl",
        "CssMedia",
        "FrontMatter",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MetaInformation_InitializerValues[] = {
        uint8_t(QTextDocument::MetaInformation::DocumentTitle), //  0x00  0
        uint8_t(QTextDocument::MetaInformation::DocumentUrl),   //  0x01  1
        uint8_t(QTextDocument::MetaInformation::CssMedia),      //  0x02  2
        uint8_t(QTextDocument::MetaInformation::FrontMatter)    //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextDocument_TypeF(),
        "2:PySide6.QtGui.QTextDocument.MetaInformation",
        MetaInformation_Initializer, MetaInformation_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_MetaInformation_IDX].type = EType;
    // Register converter for enum 'QTextDocument::MetaInformation'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextDocument_MetaInformation_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextDocument_MetaInformation,
            is_Enum_PythonToCpp_QTextDocument_MetaInformation_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextDocument::MetaInformation");
        Shiboken::Conversions::registerConverterAlias(converter, "MetaInformation");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'MetaInformation' enum.

    // Initialization of enum 'MarkdownFeature'.
    const char *MarkdownFeature_Initializer[] = {
        "MarkdownNoHTML",
        "MarkdownDialectCommonMark",
        "MarkdownDialectGitHub",
        nullptr};
    // "uint32_t" used instead of "unsigned int"
    constexpr uint32_t MarkdownFeature_InitializerValues[] = {
        uint32_t(QTextDocument::MarkdownFeature::MarkdownNoHTML),            //  0x00000060  96
        uint32_t(QTextDocument::MarkdownFeature::MarkdownDialectCommonMark), //  0x00000000  0
        uint32_t(QTextDocument::MarkdownFeature::MarkdownDialectGitHub)      //  0x00104f0c  1068812
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextDocument_TypeF(),
        "2:PySide6.QtGui.QTextDocument.MarkdownFeature",
        MarkdownFeature_Initializer, MarkdownFeature_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_MarkdownFeature_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_MarkdownFeature_IDX].type =
        EType;
    // Register converter for enum 'QTextDocument::MarkdownFeature'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextDocument_MarkdownFeature_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextDocument_MarkdownFeature,
            is_Enum_PythonToCpp_QTextDocument_MarkdownFeature_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextDocument::MarkdownFeature");
        Shiboken::Conversions::registerConverterAlias(converter, "MarkdownFeature");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QTextDocument_MarkdownFeature_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QTextDocument_MarkdownFeature,
            is_Enum_PythonToCpp_QTextDocument_MarkdownFeature_Convertible);
        // Register converter for flag 'QFlags<QTextDocument::MarkdownFeature>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QTextDocument::MarkdownFeature>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QTextDocument::MarkdownFeatures");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'MarkdownFeature' enum/flags.

    // Initialization of enum 'FindFlag'.
    const char *FindFlag_Initializer[] = {
        "FindBackward",
        "FindCaseSensitively",
        "FindWholeWords",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FindFlag_InitializerValues[] = {
        uint8_t(QTextDocument::FindFlag::FindBackward),        //  0x01  1
        uint8_t(QTextDocument::FindFlag::FindCaseSensitively), //  0x02  2
        uint8_t(QTextDocument::FindFlag::FindWholeWords)       //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextDocument_TypeF(),
        "2:PySide6.QtGui.QTextDocument.FindFlag",
        FindFlag_Initializer, FindFlag_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_FindFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_FindFlag_IDX].type =
        EType;
    // Register converter for enum 'QTextDocument::FindFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextDocument_FindFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextDocument_FindFlag,
            is_Enum_PythonToCpp_QTextDocument_FindFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextDocument::FindFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "FindFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QTextDocument_FindFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QTextDocument_FindFlag,
            is_Enum_PythonToCpp_QTextDocument_FindFlag_Convertible);
        // Register converter for flag 'QFlags<QTextDocument::FindFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QTextDocument::FindFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QTextDocument::FindFlags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'FindFlag' enum/flags.

    // Initialization of enum 'ResourceType'.
    const char *ResourceType_Initializer[] = {
        "UnknownResource",
        "HtmlResource",
        "ImageResource",
        "StyleSheetResource",
        "MarkdownResource",
        "UserResource",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ResourceType_InitializerValues[] = {
        uint8_t(QTextDocument::ResourceType::UnknownResource),    //  0x00  0
        uint8_t(QTextDocument::ResourceType::HtmlResource),       //  0x01  1
        uint8_t(QTextDocument::ResourceType::ImageResource),      //  0x02  2
        uint8_t(QTextDocument::ResourceType::StyleSheetResource), //  0x03  3
        uint8_t(QTextDocument::ResourceType::MarkdownResource),   //  0x04  4
        uint8_t(QTextDocument::ResourceType::UserResource)        //  0x64  100
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextDocument_TypeF(),
        "2:PySide6.QtGui.QTextDocument.ResourceType",
        ResourceType_Initializer, ResourceType_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_ResourceType_IDX].type = EType;
    // Register converter for enum 'QTextDocument::ResourceType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextDocument_ResourceType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextDocument_ResourceType,
            is_Enum_PythonToCpp_QTextDocument_ResourceType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextDocument::ResourceType");
        Shiboken::Conversions::registerConverterAlias(converter, "ResourceType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ResourceType' enum.

    // Initialization of enum 'Stacks'.
    const char *Stacks_Initializer[] = {
        "UndoStack",
        "RedoStack",
        "UndoAndRedoStacks",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Stacks_InitializerValues[] = {
        uint8_t(QTextDocument::Stacks::UndoStack),        //  0x01  1
        uint8_t(QTextDocument::Stacks::RedoStack),        //  0x02  2
        uint8_t(QTextDocument::Stacks::UndoAndRedoStacks) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTextDocument_TypeF(),
        "2:PySide6.QtGui.QTextDocument.Stacks",
        Stacks_Initializer, Stacks_InitializerValues);
    SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_Stacks_IDX].type = EType;
    // Register converter for enum 'QTextDocument::Stacks'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTextDocument_Stacks_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTextDocument_Stacks,
            is_Enum_PythonToCpp_QTextDocument_Stacks_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTextDocument::Stacks");
        Shiboken::Conversions::registerConverterAlias(converter, "Stacks");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Stacks' enum.

    PySide::Signal::registerSignals(pyType, &::QTextDocument::staticMetaObject);
    qRegisterMetaType< ::QTextDocument::MetaInformation >("QTextDocument::MetaInformation");
    qRegisterMetaType< ::QTextDocument::MarkdownFeature >("QTextDocument::MarkdownFeature");
    qRegisterMetaType< ::QTextDocument::FindFlag >("QTextDocument::FindFlag");
    qRegisterMetaType< ::QTextDocument::ResourceType >("QTextDocument::ResourceType");
    qRegisterMetaType< ::QTextDocument::Stacks >("QTextDocument::Stacks");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QTextDocument::staticMetaObject, sizeof(QTextDocumentWrapper));

    return pyType;
}
