// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtnetwork_python.h"

// main header
#include "qabstractsocket_wrapper.h"

// Argument includes
#include <QString>
#include <QtNetwork/qabstractsocket.h>
#include <QtNetwork/qauthenticator.h>
#include <QtNetwork/qhostaddress.h>
#include <QtNetwork/qnetworkproxy.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QAbstractSocketWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QAbstractSocketWrapper::QAbstractSocketWrapper(::QAbstractSocket::SocketType socketType, ::QObject * parent) : QAbstractSocket(socketType, parent)
{
}

bool QAbstractSocketWrapper::atEnd() const
{
    if (m_PyMethodCache[0])
        return this->::QIODevice::atEnd();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "atEnd";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QIODevice::atEnd();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAbstractSocketWrapper::bind(const ::QHostAddress & address, quint16 port, ::QFlags<QAbstractSocket::BindFlag> mode)
{
    if (m_PyMethodCache[1])
        return this->::QAbstractSocket::bind(address, port, mode);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "bind";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QAbstractSocket::bind(address, port, mode);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &address),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &port),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_BindFlag_IDX])))->flagsConverter, &mode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NHN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &address),
        port,
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_BindFlag_IDX])))->flagsConverter, &mode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QAbstractSocketWrapper::bytesAvailable() const
{
    if (m_PyMethodCache[2])
        return this->::QAbstractSocket::bytesAvailable();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "bytesAvailable";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QAbstractSocket::bytesAvailable();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "qint64", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    qint64 cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QAbstractSocketWrapper::bytesToWrite() const
{
    if (m_PyMethodCache[3])
        return this->::QAbstractSocket::bytesToWrite();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "bytesToWrite";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QAbstractSocket::bytesToWrite();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "qint64", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    qint64 cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAbstractSocketWrapper::canReadLine() const
{
    if (m_PyMethodCache[4])
        return this->::QIODevice::canReadLine();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "canReadLine";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QIODevice::canReadLine();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractSocketWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[5]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return;
    }
}

void QAbstractSocketWrapper::close()
{
    if (m_PyMethodCache[6]) {
        return this->::QAbstractSocket::close();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "close";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QAbstractSocket::close();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return;
    }
}

void QAbstractSocketWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[7]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return;
    }
}

void QAbstractSocketWrapper::connectToHost(const ::QString & hostName, quint16 port, ::QFlags<QIODeviceBase::OpenModeFlag> mode, ::QAbstractSocket::NetworkLayerProtocol protocol)
{
    if (m_PyMethodCache[8]) {
        return this->::QAbstractSocket::connectToHost(hostName, port, mode, protocol);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectToHost";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QAbstractSocket::connectToHost(hostName, port, mode, protocol);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[4] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &hostName),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &port),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, &mode),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_NetworkLayerProtocol_IDX])))->converter, &protocol)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NHNN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &hostName),
        port,
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, &mode),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_NetworkLayerProtocol_IDX])))->converter, &protocol)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 4, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
    Py_DECREF(pyArgArray[3]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return;
    }
}

void QAbstractSocketWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[9]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return;
    }
}

void QAbstractSocketWrapper::disconnectFromHost()
{
    if (m_PyMethodCache[10]) {
        return this->::QAbstractSocket::disconnectFromHost();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectFromHost";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QAbstractSocket::disconnectFromHost();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return;
    }
}

void QAbstractSocketWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[11]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return;
    }
}

bool QAbstractSocketWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[12])
        return this->::QObject::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QObject::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAbstractSocketWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[13])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAbstractSocketWrapper::isSequential() const
{
    if (m_PyMethodCache[14])
        return this->::QAbstractSocket::isSequential();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isSequential";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QAbstractSocket::isSequential();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAbstractSocketWrapper::open(::QFlags<QIODeviceBase::OpenModeFlag> mode)
{
    if (m_PyMethodCache[15])
        return this->::QIODevice::open(mode);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "open";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[15] = true;
        gil.release();
        return this->::QIODevice::open(mode);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, &mode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, &mode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QAbstractSocketWrapper::pos() const
{
    if (m_PyMethodCache[16])
        return this->::QIODevice::pos();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "pos";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[16] = true;
        gil.release();
        return this->::QIODevice::pos();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "qint64", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    qint64 cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QAbstractSocketWrapper::readData(char * data, qint64 maxlen)
{
    if (m_PyMethodCache[17]) {
        return this->::QAbstractSocket::readData(data, maxlen);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "readData";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[17] = true;
        gil.release();
        return this->::QAbstractSocket::readData(data, maxlen);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        maxlen
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return 0;
    }

    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    qint64 cppResult = 0;
    if (PyBytes_Check(pyResult.object())) {
        cppResult = PyBytes_Size(pyResult.object());
        memcpy(data, PyBytes_AsString(pyResult.object()), cppResult);
    } else if (Shiboken::String::check(pyResult.object())) {
        cppResult = Shiboken::String::len(pyResult.object());
        memcpy(data, Shiboken::String::toCString(pyResult.object()), cppResult);
    }
    // END of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    // ========================================================================
    // End of code injection

    return cppResult;
}

qint64 QAbstractSocketWrapper::readLineData(char * data, qint64 maxlen)
{
    if (m_PyMethodCache[18]) {
        return this->::QAbstractSocket::readLineData(data, maxlen);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "readLineData";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[18] = true;
        gil.release();
        return this->::QAbstractSocket::readLineData(data, maxlen);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        maxlen
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return 0;
    }

    // Begin code injection
    // ========================================================================
    // START of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    qint64 cppResult = 0;
    if (PyBytes_Check(pyResult.object())) {
        cppResult = PyBytes_Size(pyResult.object());
        memcpy(data, PyBytes_AsString(pyResult.object()), cppResult);
    } else if (Shiboken::String::check(pyResult.object())) {
        cppResult = Shiboken::String::len(pyResult.object());
        memcpy(data, Shiboken::String::toCString(pyResult.object()), cppResult);
    }
    // END of custom code block [file: ../glue/qtcore.cpp (return-readData)]
    // ========================================================================
    // End of code injection

    return cppResult;
}

bool QAbstractSocketWrapper::reset()
{
    if (m_PyMethodCache[19])
        return this->::QIODevice::reset();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "reset";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[19] = true;
        gil.release();
        return this->::QIODevice::reset();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractSocketWrapper::resume()
{
    if (m_PyMethodCache[20]) {
        return this->::QAbstractSocket::resume();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resume";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[20] = true;
        gil.release();
        return this->::QAbstractSocket::resume();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return;
    }
}

bool QAbstractSocketWrapper::seek(qint64 pos)
{
    if (m_PyMethodCache[21])
        return this->::QIODevice::seek(pos);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "seek";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[21] = true;
        gil.release();
        return this->::QIODevice::seek(pos);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &pos)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        pos
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractSocketWrapper::setReadBufferSize(qint64 size)
{
    if (m_PyMethodCache[22]) {
        return this->::QAbstractSocket::setReadBufferSize(size);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setReadBufferSize";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[22] = true;
        gil.release();
        return this->::QAbstractSocket::setReadBufferSize(size);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &size)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        size
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return;
    }
}

bool QAbstractSocketWrapper::setSocketDescriptor(::qintptr socketDescriptor, ::QAbstractSocket::SocketState state, ::QFlags<QIODeviceBase::OpenModeFlag> openMode)
{
    if (m_PyMethodCache[23])
        return this->::QAbstractSocket::setSocketDescriptor(socketDescriptor, state, openMode);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setSocketDescriptor";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[23] = true;
        gil.release();
        return this->::QAbstractSocket::setSocketDescriptor(socketDescriptor, state, openMode);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[3] = {
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], &socketDescriptor),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketState_IDX])))->converter, &state),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, &openMode)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NNN)",
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], &socketDescriptor),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketState_IDX])))->converter, &state),
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, &openMode)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 3, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
    Py_DECREF(pyArgArray[2]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractSocketWrapper::setSocketOption(::QAbstractSocket::SocketOption option, const ::QVariant & value)
{
    if (m_PyMethodCache[24]) {
        return this->::QAbstractSocket::setSocketOption(option, value);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setSocketOption";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[24] = true;
        gil.release();
        return this->::QAbstractSocket::setSocketOption(option, value);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketOption_IDX])))->converter, &option),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketOption_IDX])))->converter, &option),
        Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return;
    }
}

qint64 QAbstractSocketWrapper::size() const
{
    if (m_PyMethodCache[25])
        return this->::QIODevice::size();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "size";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[25] = true;
        gil.release();
        return this->::QIODevice::size();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "qint64", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    qint64 cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QAbstractSocketWrapper::skipData(qint64 maxSize)
{
    if (m_PyMethodCache[26])
        return this->::QAbstractSocket::skipData(maxSize);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "skipData";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[26] = true;
        gil.release();
        return this->::QAbstractSocket::skipData(maxSize);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &maxSize)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(L)",
        maxSize
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "qint64", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    qint64 cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::qintptr QAbstractSocketWrapper::socketDescriptor() const
{
    if (m_PyMethodCache[27])
        return this->::QAbstractSocket::socketDescriptor();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::qintptr();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "socketDescriptor";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[27] = true;
        gil.release();
        return this->::QAbstractSocket::socketDescriptor();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return ::qintptr();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "qintptr", Py_TYPE(pyResult)->tp_name);
        return ::qintptr();
    }
    ::qintptr cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QVariant QAbstractSocketWrapper::socketOption(::QAbstractSocket::SocketOption option)
{
    if (m_PyMethodCache[28])
        return this->::QAbstractSocket::socketOption(option);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "socketOption";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[28] = true;
        gil.release();
        return this->::QAbstractSocket::socketOption(option);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketOption_IDX])))->converter, &option)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketOption_IDX])))->converter, &option)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QAbstractSocketWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[29]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[29] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return;
    }
}

bool QAbstractSocketWrapper::waitForBytesWritten(int msecs)
{
    if (m_PyMethodCache[30])
        return this->::QAbstractSocket::waitForBytesWritten(msecs);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "waitForBytesWritten";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[30] = true;
        gil.release();
        return this->::QAbstractSocket::waitForBytesWritten(msecs);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &msecs)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        msecs
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAbstractSocketWrapper::waitForConnected(int msecs)
{
    if (m_PyMethodCache[31])
        return this->::QAbstractSocket::waitForConnected(msecs);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "waitForConnected";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[31] = true;
        gil.release();
        return this->::QAbstractSocket::waitForConnected(msecs);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &msecs)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        msecs
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAbstractSocketWrapper::waitForDisconnected(int msecs)
{
    if (m_PyMethodCache[32])
        return this->::QAbstractSocket::waitForDisconnected(msecs);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "waitForDisconnected";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[32] = true;
        gil.release();
        return this->::QAbstractSocket::waitForDisconnected(msecs);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &msecs)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        msecs
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QAbstractSocketWrapper::waitForReadyRead(int msecs)
{
    if (m_PyMethodCache[33])
        return this->::QAbstractSocket::waitForReadyRead(msecs);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "waitForReadyRead";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[33] = true;
        gil.release();
        return this->::QAbstractSocket::waitForReadyRead(msecs);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &msecs)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        msecs
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

qint64 QAbstractSocketWrapper::writeData(const char * data, qint64 len)
{
    if (m_PyMethodCache[34])
        return this->::QAbstractSocket::writeData(data, len);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "writeData";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[34] = true;
        gil.release();
        return this->::QAbstractSocket::writeData(data, len);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), data),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &len)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NL)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), data),
        len
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QAbstractSocket", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QAbstractSocket", funcName, "qint64", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    qint64 cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

const QMetaObject *QAbstractSocketWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QAbstractSocket::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QAbstractSocketWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QAbstractSocket::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QAbstractSocketWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QAbstractSocketWrapper *>(this));
    return QAbstractSocket::qt_metacast(_clname);
}

QAbstractSocketWrapper::~QAbstractSocketWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QAbstractSocket_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QAbstractSocket >()))
        return -1;

    QAbstractSocketWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "QAbstractSocket", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QAbstractSocket::QAbstractSocket(QAbstractSocket::SocketType,QObject*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketType_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
        overloadId = 0; // QAbstractSocket(QAbstractSocket::SocketType,QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        ::QAbstractSocket::SocketType cppArg0{QAbstractSocket::TcpSocket};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return -1;
        ::QObject *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QAbstractSocket(QAbstractSocket::SocketType,QObject*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QAbstractSocketWrapper(cppArg0, cppArg1);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QAbstractSocketWrapper(cppArg0, cppArg1);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[1], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QAbstractSocket >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QAbstractSocketFunc_abort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // abort()
        cppSelf->abort();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_bind(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:bind", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractSocket::bind(QHostAddress,quint16=,QFlags<QAbstractSocket::BindFlag>=)->bool
    // 1: QAbstractSocket::bind(quint16=,QFlags<QAbstractSocket::BindFlag>=)->bool
    if (numArgs == 0) {
        overloadId = 1; // bind(quint16,QFlags<QAbstractSocket::BindFlag>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // bind(quint16,QFlags<QAbstractSocket::BindFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_BindFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 1; // bind(quint16,QFlags<QAbstractSocket::BindFlag>)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // bind(QHostAddress,quint16,QFlags<QAbstractSocket::BindFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // bind(QHostAddress,quint16,QFlags<QAbstractSocket::BindFlag>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_BindFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 0; // bind(QHostAddress,quint16,QFlags<QAbstractSocket::BindFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // bind(const QHostAddress &address, quint16 port, QFlags<QAbstractSocket::BindFlag> mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_port = Shiboken::String::createStaticString("port");
                if (PyDict_Contains(kwds, key_port) != 0) {
                    value = PyDict_GetItem(kwds, key_port);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_port);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_port);
                }
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_BindFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QHostAddress cppArg0_local;
            ::QHostAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            quint16 cppArg1 = 0;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QAbstractSocket::BindFlag> cppArg2(QAbstractSocket::BindFlag::DefaultForPlatform);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bind(QHostAddress,quint16,QFlags<QAbstractSocket::BindFlag>)
                bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QAbstractSocket::bind(*cppArg0, cppArg1, cppArg2)
                    : cppSelf->bind(*cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // bind(quint16 port, QFlags<QAbstractSocket::BindFlag> mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_port = Shiboken::String::createStaticString("port");
                if (PyDict_Contains(kwds, key_port) != 0) {
                    value = PyDict_GetItem(kwds, key_port);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_port);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_port);
                }
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_BindFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "bind", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
            }
            quint16 cppArg0 = 0;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QAbstractSocket::BindFlag> cppArg1(QAbstractSocket::BindFlag::DefaultForPlatform);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // bind(quint16,QFlags<QAbstractSocket::BindFlag>)
                bool cppResult = cppSelf->bind(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_bytesAvailable(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bytesAvailable()const
        qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QAbstractSocket *>(cppSelf)->::QAbstractSocket::bytesAvailable()
            : const_cast<const ::QAbstractSocket *>(cppSelf)->bytesAvailable();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_bytesToWrite(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bytesToWrite()const
        qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QAbstractSocket *>(cppSelf)->::QAbstractSocket::bytesToWrite()
            : const_cast<const ::QAbstractSocket *>(cppSelf)->bytesToWrite();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_close(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // close()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QAbstractSocket::close()
            : cppSelf->close();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_connectToHost(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "connectToHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:connectToHost", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractSocket::connectToHost(QString,quint16,QFlags<QIODeviceBase::OpenModeFlag>=,QAbstractSocket::NetworkLayerProtocol=)
    // 1: QAbstractSocket::connectToHost(QHostAddress,quint16,QFlags<QIODeviceBase::OpenModeFlag>=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // connectToHost(QHostAddress,quint16,QFlags<QIODeviceBase::OpenModeFlag>)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
            overloadId = 1; // connectToHost(QHostAddress,quint16,QFlags<QIODeviceBase::OpenModeFlag>)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // connectToHost(QString,quint16,QFlags<QIODeviceBase::OpenModeFlag>,QAbstractSocket::NetworkLayerProtocol)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // connectToHost(QString,quint16,QFlags<QIODeviceBase::OpenModeFlag>,QAbstractSocket::NetworkLayerProtocol)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_NetworkLayerProtocol_IDX])))->converter, (pyArgs[3])))) {
                overloadId = 0; // connectToHost(QString,quint16,QFlags<QIODeviceBase::OpenModeFlag>,QAbstractSocket::NetworkLayerProtocol)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "connectToHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // connectToHost(const QString &hostName, quint16 port, QFlags<QIODeviceBase::OpenModeFlag> mode, QAbstractSocket::NetworkLayerProtocol protocol)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "connectToHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "connectToHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                static PyObject *const key_protocol = Shiboken::String::createStaticString("protocol");
                if (PyDict_Contains(kwds, key_protocol) != 0) {
                    value = PyDict_GetItem(kwds, key_protocol);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_protocol);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "connectToHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_NetworkLayerProtocol_IDX])))->converter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "connectToHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_protocol);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "connectToHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            quint16 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QIODeviceBase::OpenModeFlag> cppArg2(QIODeviceBase::OpenModeFlag::ReadWrite);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QAbstractSocket::NetworkLayerProtocol cppArg3(QAbstractSocket::NetworkLayerProtocol::AnyIPProtocol);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connectToHost(QString,quint16,QFlags<QIODeviceBase::OpenModeFlag>,QAbstractSocket::NetworkLayerProtocol)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? cppSelf->::QAbstractSocket::connectToHost(cppArg0, cppArg1, cppArg2, cppArg3)
                    : cppSelf->connectToHost(cppArg0, cppArg1, cppArg2, cppArg3);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
        case 1: // connectToHost(const QHostAddress &address, quint16 port, QFlags<QIODeviceBase::OpenModeFlag> mode)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "connectToHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "connectToHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "connectToHost", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QHostAddress cppArg0_local;
            ::QHostAddress *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            quint16 cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<QIODeviceBase::OpenModeFlag> cppArg2(QIODeviceBase::OpenModeFlag::ReadWrite);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // connectToHost(QHostAddress,quint16,QFlags<QIODeviceBase::OpenModeFlag>)
                PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
                cppSelf->connectToHost(*cppArg0, cppArg1, cppArg2);
                PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_disconnectFromHost(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // disconnectFromHost()
        PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QAbstractSocket::disconnectFromHost()
            : cppSelf->disconnectFromHost();
        PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_error(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // error()const
        QAbstractSocket::SocketError cppResult = const_cast<const ::QAbstractSocket *>(cppSelf)->error();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketError_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_flush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flush()
        bool cppResult = cppSelf->flush();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_isSequential(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isSequential()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QAbstractSocket *>(cppSelf)->::QAbstractSocket::isSequential()
            : const_cast<const ::QAbstractSocket *>(cppSelf)->isSequential();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_isValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isValid()const
        bool cppResult = const_cast<const ::QAbstractSocket *>(cppSelf)->isValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_localAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localAddress()const
        QHostAddress cppResult = const_cast<const ::QAbstractSocket *>(cppSelf)->localAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_localPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // localPort()const
        quint16 cppResult = const_cast<const ::QAbstractSocket *>(cppSelf)->localPort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_pauseMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // pauseMode()const
        QFlags<QAbstractSocket::PauseMode> cppResult = const_cast<const ::QAbstractSocket *>(cppSelf)->pauseMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_PauseMode_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_peerAddress(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerAddress()const
        QHostAddress cppResult = const_cast<const ::QAbstractSocket *>(cppSelf)->peerAddress();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_peerName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerName()const
        QString cppResult = const_cast<const ::QAbstractSocket *>(cppSelf)->peerName();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_peerPort(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // peerPort()const
        quint16 cppResult = const_cast<const ::QAbstractSocket *>(cppSelf)->peerPort();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_protocolTag(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // protocolTag()const
        QString cppResult = const_cast<const ::QAbstractSocket *>(cppSelf)->protocolTag();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_proxy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // proxy()const
        QNetworkProxy cppResult = const_cast<const ::QAbstractSocket *>(cppSelf)->proxy();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxy_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_readBufferSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // readBufferSize()const
        qint64 cppResult = const_cast<const ::QAbstractSocket *>(cppSelf)->readBufferSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_readData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QIODevice::readData(char*,qint64)->PyObject
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // readData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readData", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readData(char*,qint64)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            QByteArray ba(1 + qsizetype(cppArg0), char(0));
            Py_BEGIN_ALLOW_THREADS
            (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QAbstractSocket::readData(ba.data(), qint64(cppArg0)) : cppSelf->readData(ba.data(), qint64(cppArg0)));
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::String::fromCString(ba.constData());
            // END of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_readLineData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QIODevice::readLineData(char*,qint64)->PyObject
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // readLineData(char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "readLineData", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // readLineData(char*,qint64)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            QByteArray ba(1 + qsizetype(cppArg0), char(0));
            Py_BEGIN_ALLOW_THREADS
            (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self)) ? cppSelf->::QAbstractSocket::readLineData(ba.data(), qint64(cppArg0)) : cppSelf->readLineData(ba.data(), qint64(cppArg0)));
            Py_END_ALLOW_THREADS
            pyResult = Shiboken::String::fromCString(ba.constData());
            // END of custom code block [file: ../glue/qtcore.cpp (qiodevice-readData)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_resume(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resume()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QAbstractSocket::resume()
            : cppSelf->resume();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_setLocalAddress(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSocket::setLocalAddress(QHostAddress)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArg)))) {
        overloadId = 0; // setLocalAddress(QHostAddress)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocalAddress", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHostAddress cppArg0_local;
        ::QHostAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocalAddress(QHostAddress)
            cppSelf->setLocalAddress(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_setLocalPort(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSocket::setLocalPort(quint16)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArg)))) {
        overloadId = 0; // setLocalPort(quint16)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLocalPort", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        quint16 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLocalPort(quint16)
            cppSelf->setLocalPort(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_setPauseMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSocket::setPauseMode(QFlags<QAbstractSocket::PauseMode>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_PauseMode_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setPauseMode(QFlags<QAbstractSocket::PauseMode>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPauseMode", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        ::QFlags<QAbstractSocket::PauseMode> cppArg0 = QFlags<QAbstractSocket::PauseMode>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPauseMode(QFlags<QAbstractSocket::PauseMode>)
            cppSelf->setPauseMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_setPeerAddress(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSocket::setPeerAddress(QHostAddress)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QHostAddress_IDX]), (pyArg)))) {
        overloadId = 0; // setPeerAddress(QHostAddress)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPeerAddress", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHostAddress cppArg0_local;
        ::QHostAddress *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPeerAddress(QHostAddress)
            cppSelf->setPeerAddress(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_setPeerName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSocket::setPeerName(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPeerName(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPeerName", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPeerName(QString)
            cppSelf->setPeerName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_setPeerPort(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSocket::setPeerPort(quint16)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<quint16>(), (pyArg)))) {
        overloadId = 0; // setPeerPort(quint16)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPeerPort", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        quint16 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPeerPort(quint16)
            cppSelf->setPeerPort(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_setProtocolTag(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSocket::setProtocolTag(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setProtocolTag(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProtocolTag", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProtocolTag(QString)
            cppSelf->setProtocolTag(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_setProxy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSocket::setProxy(QNetworkProxy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QNetworkProxy_IDX]), (pyArg)))) {
        overloadId = 0; // setProxy(QNetworkProxy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProxy", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QNetworkProxy cppArg0_local;
        ::QNetworkProxy *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setProxy(QNetworkProxy)
            cppSelf->setProxy(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_setReadBufferSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSocket::setReadBufferSize(qint64)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // setReadBufferSize(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReadBufferSize", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReadBufferSize(qint64)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSocket::setReadBufferSize(cppArg0)
                : cppSelf->setReadBufferSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_setSocketDescriptor(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setSocketDescriptor", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:setSocketDescriptor", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractSocket::setSocketDescriptor(qintptr,QAbstractSocket::SocketState=,QFlags<QIODeviceBase::OpenModeFlag>=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setSocketDescriptor(qintptr,QAbstractSocket::SocketState,QFlags<QIODeviceBase::OpenModeFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketState_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setSocketDescriptor(qintptr,QAbstractSocket::SocketState,QFlags<QIODeviceBase::OpenModeFlag>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2])))) {
                overloadId = 0; // setSocketDescriptor(qintptr,QAbstractSocket::SocketState,QFlags<QIODeviceBase::OpenModeFlag>)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSocketDescriptor", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_state = Shiboken::String::createStaticString("state");
            if (PyDict_Contains(kwds, key_state) != 0) {
                value = PyDict_GetItem(kwds, key_state);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_state);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setSocketDescriptor", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketState_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setSocketDescriptor", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_state);
            }
            static PyObject *const key_openMode = Shiboken::String::createStaticString("openMode");
            if (PyDict_Contains(kwds, key_openMode) != 0) {
                value = PyDict_GetItem(kwds, key_openMode);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_openMode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setSocketDescriptor", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QIODeviceBase_OpenModeFlag_IDX])))->flagsConverter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "setSocketDescriptor", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_openMode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setSocketDescriptor", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
            }
        }
        ::qintptr cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QAbstractSocket::SocketState cppArg1(QAbstractSocket::SocketState::ConnectedState);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFlags<QIODeviceBase::OpenModeFlag> cppArg2(QIODeviceBase::OpenModeFlag::ReadWrite);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSocketDescriptor(qintptr,QAbstractSocket::SocketState,QFlags<QIODeviceBase::OpenModeFlag>)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSocket::setSocketDescriptor(cppArg0, cppArg1, cppArg2)
                : cppSelf->setSocketDescriptor(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_setSocketError(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSocket::setSocketError(QAbstractSocket::SocketError)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketError_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSocketError(QAbstractSocket::SocketError)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSocketError", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        ::QAbstractSocket::SocketError cppArg0{QAbstractSocket::ConnectionRefusedError};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSocketError(QAbstractSocket::SocketError)
            cppSelf->setSocketError(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_setSocketOption(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setSocketOption", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractSocket::setSocketOption(QAbstractSocket::SocketOption,QVariant)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketOption_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
        overloadId = 0; // setSocketOption(QAbstractSocket::SocketOption,QVariant)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSocketOption", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        ::QAbstractSocket::SocketOption cppArg0{QAbstractSocket::LowDelayOption};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QVariant cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSocketOption(QAbstractSocket::SocketOption,QVariant)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSocket::setSocketOption(cppArg0, cppArg1)
                : cppSelf->setSocketOption(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_setSocketState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSocket::setSocketState(QAbstractSocket::SocketState)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketState_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setSocketState(QAbstractSocket::SocketState)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSocketState", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        ::QAbstractSocket::SocketState cppArg0{QAbstractSocket::UnconnectedState};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSocketState(QAbstractSocket::SocketState)
            cppSelf->setSocketState(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QAbstractSocketFunc_skipData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QIODevice::skipData(qint64)->qint64
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArg)))) {
        overloadId = 0; // skipData(qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "skipData", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        qint64 cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // skipData(qint64)
            qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSocket::skipData(cppArg0)
                : cppSelf->skipData(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_socketDescriptor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // socketDescriptor()const
        qintptr cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QAbstractSocket *>(cppSelf)->::QAbstractSocket::socketDescriptor()
            : const_cast<const ::QAbstractSocket *>(cppSelf)->socketDescriptor();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_qintptr_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_socketOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QAbstractSocket::socketOption(QAbstractSocket::SocketOption)->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketOption_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // socketOption(QAbstractSocket::SocketOption)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "socketOption", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        ::QAbstractSocket::SocketOption cppArg0{QAbstractSocket::LowDelayOption};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // socketOption(QAbstractSocket::SocketOption)
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSocket::socketOption(cppArg0)
                : cppSelf->socketOption(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_socketType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // socketType()const
        QAbstractSocket::SocketType cppResult = const_cast<const ::QAbstractSocket *>(cppSelf)->socketType();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketType_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QAbstractSocket::SocketState cppResult = const_cast<const ::QAbstractSocket *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketState_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_waitForBytesWritten(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "waitForBytesWritten", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    if (PyArg_ParseTuple(args, "|O:waitForBytesWritten", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::waitForBytesWritten(int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // waitForBytesWritten(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // waitForBytesWritten(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "waitForBytesWritten", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_msecs = Shiboken::String::createStaticString("msecs");
            if (PyDict_Contains(kwds, key_msecs) != 0) {
                value = PyDict_GetItem(kwds, key_msecs);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_msecs);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "waitForBytesWritten", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "waitForBytesWritten", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_msecs);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "waitForBytesWritten", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
            }
        }
        int cppArg0 = 30000;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForBytesWritten(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSocket::waitForBytesWritten(cppArg0)
                : cppSelf->waitForBytesWritten(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_waitForConnected(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "waitForConnected", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    if (PyArg_ParseTuple(args, "|O:waitForConnected", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractSocket::waitForConnected(int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // waitForConnected(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // waitForConnected(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "waitForConnected", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_msecs = Shiboken::String::createStaticString("msecs");
            if (PyDict_Contains(kwds, key_msecs) != 0) {
                value = PyDict_GetItem(kwds, key_msecs);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_msecs);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "waitForConnected", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "waitForConnected", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_msecs);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "waitForConnected", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
            }
        }
        int cppArg0 = 30000;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForConnected(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSocket::waitForConnected(cppArg0)
                : cppSelf->waitForConnected(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_waitForDisconnected(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "waitForDisconnected", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    if (PyArg_ParseTuple(args, "|O:waitForDisconnected", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractSocket::waitForDisconnected(int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // waitForDisconnected(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // waitForDisconnected(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "waitForDisconnected", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_msecs = Shiboken::String::createStaticString("msecs");
            if (PyDict_Contains(kwds, key_msecs) != 0) {
                value = PyDict_GetItem(kwds, key_msecs);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_msecs);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "waitForDisconnected", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "waitForDisconnected", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_msecs);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "waitForDisconnected", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
            }
        }
        int cppArg0 = 30000;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForDisconnected(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSocket::waitForDisconnected(cppArg0)
                : cppSelf->waitForDisconnected(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_waitForReadyRead(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "waitForReadyRead", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    if (PyArg_ParseTuple(args, "|O:waitForReadyRead", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::waitForReadyRead(int=)->bool
    if (numArgs == 0) {
        overloadId = 0; // waitForReadyRead(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // waitForReadyRead(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "waitForReadyRead", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_msecs = Shiboken::String::createStaticString("msecs");
            if (PyDict_Contains(kwds, key_msecs) != 0) {
                value = PyDict_GetItem(kwds, key_msecs);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_msecs);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "waitForReadyRead", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "waitForReadyRead", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_msecs);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "waitForReadyRead", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);
            }
        }
        int cppArg0 = 30000;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // waitForReadyRead(int)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSocket::waitForReadyRead(cppArg0)
                : cppSelf->waitForReadyRead(cppArg0);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QAbstractSocketFunc_writeData(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "writeData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QIODevice::writeData(const char*,qint64)->qint64
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), (pyArgs[1])))) {
        overloadId = 0; // writeData(const char*,qint64)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "writeData", errInfo, SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qint64 cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // writeData(const char*,qint64)
            qint64 cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QAbstractSocket::writeData(cppArg0, cppArg1)
                : cppSelf->writeData(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qint64>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QAbstractSocket_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QAbstractSocket_EnumFlagInfo[] = {
    "BindFlag:Flag:BindMode",
    "NetworkLayerProtocol:Enum",
    "PauseMode:Flag:PauseModes",
    "SocketError:Enum",
    "SocketOption:Enum",
    "SocketState:Enum",
    "SocketType:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QAbstractSocket_methods[] = {
    {"abort", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_abort), METH_NOARGS, nullptr},
    {"bind", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_bind), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"bytesAvailable", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_bytesAvailable), METH_NOARGS, nullptr},
    {"bytesToWrite", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_bytesToWrite), METH_NOARGS, nullptr},
    {"close", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_close), METH_NOARGS, nullptr},
    {"connectToHost", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_connectToHost), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"disconnectFromHost", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_disconnectFromHost), METH_NOARGS, nullptr},
    {"error", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_error), METH_NOARGS, nullptr},
    {"flush", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_flush), METH_NOARGS, nullptr},
    {"isSequential", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_isSequential), METH_NOARGS, nullptr},
    {"isValid", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_isValid), METH_NOARGS, nullptr},
    {"localAddress", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_localAddress), METH_NOARGS, nullptr},
    {"localPort", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_localPort), METH_NOARGS, nullptr},
    {"pauseMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_pauseMode), METH_NOARGS, nullptr},
    {"peerAddress", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_peerAddress), METH_NOARGS, nullptr},
    {"peerName", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_peerName), METH_NOARGS, nullptr},
    {"peerPort", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_peerPort), METH_NOARGS, nullptr},
    {"protocolTag", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_protocolTag), METH_NOARGS, nullptr},
    {"proxy", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_proxy), METH_NOARGS, nullptr},
    {"readBufferSize", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_readBufferSize), METH_NOARGS, nullptr},
    {"readData", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_readData), METH_O, nullptr},
    {"readLineData", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_readLineData), METH_O, nullptr},
    {"resume", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_resume), METH_NOARGS, nullptr},
    {"setLocalAddress", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_setLocalAddress), METH_O, nullptr},
    {"setLocalPort", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_setLocalPort), METH_O, nullptr},
    {"setPauseMode", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_setPauseMode), METH_O, nullptr},
    {"setPeerAddress", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_setPeerAddress), METH_O, nullptr},
    {"setPeerName", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_setPeerName), METH_O, nullptr},
    {"setPeerPort", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_setPeerPort), METH_O, nullptr},
    {"setProtocolTag", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_setProtocolTag), METH_O, nullptr},
    {"setProxy", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_setProxy), METH_O, nullptr},
    {"setReadBufferSize", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_setReadBufferSize), METH_O, nullptr},
    {"setSocketDescriptor", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_setSocketDescriptor), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setSocketError", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_setSocketError), METH_O, nullptr},
    {"setSocketOption", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_setSocketOption), METH_VARARGS, nullptr},
    {"setSocketState", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_setSocketState), METH_O, nullptr},
    {"skipData", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_skipData), METH_O, nullptr},
    {"socketDescriptor", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_socketDescriptor), METH_NOARGS, nullptr},
    {"socketOption", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_socketOption), METH_O, nullptr},
    {"socketType", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_socketType), METH_NOARGS, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_state), METH_NOARGS, nullptr},
    {"waitForBytesWritten", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_waitForBytesWritten), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"waitForConnected", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_waitForConnected), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"waitForDisconnected", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_waitForDisconnected), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"waitForReadyRead", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_waitForReadyRead), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"writeData", reinterpret_cast<PyCFunction>(Sbk_QAbstractSocketFunc_writeData), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QAbstractSocket_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QAbstractSocket *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QAbstractSocketWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QAbstractSocket_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QAbstractSocket_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QAbstractSocketSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QAbstractSocket *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]))
        return static_cast< ::QIODevice *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODeviceBase_IDX]))
        return static_cast< ::QIODeviceBase *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QAbstractSocket_Type = nullptr;
static PyTypeObject *Sbk_QAbstractSocket_TypeF(void)
{
    return _Sbk_QAbstractSocket_Type;
}

static PyType_Slot Sbk_QAbstractSocket_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QAbstractSocket_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QAbstractSocket_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QAbstractSocket_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QAbstractSocket_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QAbstractSocket_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QAbstractSocket_spec = {
    "2:PySide6.QtNetwork.QAbstractSocket",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QAbstractSocket_slots
};

} //extern "C"

static void *Sbk_QAbstractSocket_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QAbstractSocket *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QAbstractSocket_SocketType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractSocket::SocketType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractSocket::SocketType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractSocket_SocketType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketType_IDX])))
        return Enum_PythonToCpp_QAbstractSocket_SocketType;
    return {};
}

static PyObject *QAbstractSocket_SocketType_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractSocket::SocketType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractSocket::SocketType *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketType_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractSocket_NetworkLayerProtocol(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractSocket::NetworkLayerProtocol>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractSocket::NetworkLayerProtocol *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractSocket_NetworkLayerProtocol_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_NetworkLayerProtocol_IDX])))
        return Enum_PythonToCpp_QAbstractSocket_NetworkLayerProtocol;
    return {};
}

static PyObject *QAbstractSocket_NetworkLayerProtocol_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractSocket::NetworkLayerProtocol>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractSocket::NetworkLayerProtocol *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_NetworkLayerProtocol_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractSocket_SocketError(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractSocket::SocketError>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractSocket::SocketError *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractSocket_SocketError_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketError_IDX])))
        return Enum_PythonToCpp_QAbstractSocket_SocketError;
    return {};
}

static PyObject *QAbstractSocket_SocketError_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractSocket::SocketError>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractSocket::SocketError *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketError_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractSocket_SocketState(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractSocket::SocketState>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractSocket::SocketState *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractSocket_SocketState_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketState_IDX])))
        return Enum_PythonToCpp_QAbstractSocket_SocketState;
    return {};
}

static PyObject *QAbstractSocket_SocketState_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractSocket::SocketState>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractSocket::SocketState *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketState_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractSocket_SocketOption(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractSocket::SocketOption>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractSocket::SocketOption *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractSocket_SocketOption_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketOption_IDX])))
        return Enum_PythonToCpp_QAbstractSocket_SocketOption;
    return {};
}

static PyObject *QAbstractSocket_SocketOption_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractSocket::SocketOption>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractSocket::SocketOption *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketOption_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QAbstractSocket_BindFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractSocket::BindFlag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractSocket::BindFlag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractSocket_BindFlag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_BindFlag_IDX])))
        return Enum_PythonToCpp_QAbstractSocket_BindFlag;
    return {};
}

static PyObject *QAbstractSocket_BindFlag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractSocket::BindFlag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractSocket::BindFlag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_BindFlag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QAbstractSocket_BindFlag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QAbstractSocket::BindFlag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QAbstractSocket::BindFlag> *>(cppOut) = value;

}

static PyObject *QAbstractSocket_BindFlag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QAbstractSocket::BindFlag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_BindFlag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QAbstractSocket_PauseMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QAbstractSocket::PauseMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QAbstractSocket::PauseMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QAbstractSocket_PauseMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_PauseMode_IDX])))
        return Enum_PythonToCpp_QAbstractSocket_PauseMode;
    return {};
}

static PyObject *QAbstractSocket_PauseMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QAbstractSocket::PauseMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QAbstractSocket::PauseMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_PauseMode_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QAbstractSocket_PauseMode(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QAbstractSocket::PauseMode>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QAbstractSocket::PauseMode> *>(cppOut) = value;

}

static PyObject *QAbstractSocket_PauseMode_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QAbstractSocket::PauseMode> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_PauseMode_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QAbstractSocket_PythonToCpp_QAbstractSocket_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QAbstractSocket_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QAbstractSocket_PythonToCpp_QAbstractSocket_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QAbstractSocket_TypeF()))
        return QAbstractSocket_PythonToCpp_QAbstractSocket_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QAbstractSocket_PTR_CppToPython_QAbstractSocket(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QAbstractSocket *>(const_cast<void *>(cppIn)), Sbk_QAbstractSocket_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QAbstractSocket_SignatureStrings[] = {
    "PySide6.QtNetwork.QAbstractSocket(self,socketType:PySide6.QtNetwork.QAbstractSocket.SocketType,parent:PySide6.QtCore.QObject)",
    "PySide6.QtNetwork.QAbstractSocket.abort(self)",
    "1:PySide6.QtNetwork.QAbstractSocket.bind(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],port:quint16=0,mode:PySide6.QtNetwork.QAbstractSocket.BindFlag=QAbstractSocket.BindFlag.DefaultForPlatform)->bool",
    "0:PySide6.QtNetwork.QAbstractSocket.bind(self,port:quint16=0,mode:PySide6.QtNetwork.QAbstractSocket.BindFlag=QAbstractSocket.BindFlag.DefaultForPlatform)->bool",
    "PySide6.QtNetwork.QAbstractSocket.bytesAvailable(self)->qint64",
    "PySide6.QtNetwork.QAbstractSocket.bytesToWrite(self)->qint64",
    "PySide6.QtNetwork.QAbstractSocket.close(self)",
    "1:PySide6.QtNetwork.QAbstractSocket.connectToHost(self,hostName:QString,port:quint16,mode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.ReadWrite,protocol:PySide6.QtNetwork.QAbstractSocket.NetworkLayerProtocol=QAbstractSocket.NetworkLayerProtocol.AnyIPProtocol)",
    "0:PySide6.QtNetwork.QAbstractSocket.connectToHost(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress],port:quint16,mode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.ReadWrite)",
    "PySide6.QtNetwork.QAbstractSocket.disconnectFromHost(self)",
    "PySide6.QtNetwork.QAbstractSocket.error(self)->PySide6.QtNetwork.QAbstractSocket.SocketError",
    "PySide6.QtNetwork.QAbstractSocket.flush(self)->bool",
    "PySide6.QtNetwork.QAbstractSocket.isSequential(self)->bool",
    "PySide6.QtNetwork.QAbstractSocket.isValid(self)->bool",
    "PySide6.QtNetwork.QAbstractSocket.localAddress(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtNetwork.QAbstractSocket.localPort(self)->quint16",
    "PySide6.QtNetwork.QAbstractSocket.pauseMode(self)->PySide6.QtNetwork.QAbstractSocket.PauseMode",
    "PySide6.QtNetwork.QAbstractSocket.peerAddress(self)->PySide6.QtNetwork.QHostAddress",
    "PySide6.QtNetwork.QAbstractSocket.peerName(self)->QString",
    "PySide6.QtNetwork.QAbstractSocket.peerPort(self)->quint16",
    "PySide6.QtNetwork.QAbstractSocket.protocolTag(self)->QString",
    "PySide6.QtNetwork.QAbstractSocket.proxy(self)->PySide6.QtNetwork.QNetworkProxy",
    "PySide6.QtNetwork.QAbstractSocket.readBufferSize(self)->qint64",
    "PySide6.QtNetwork.QAbstractSocket.readData(self,maxlen:qint64)->PyObject",
    "PySide6.QtNetwork.QAbstractSocket.readLineData(self,maxlen:qint64)->PyObject",
    "PySide6.QtNetwork.QAbstractSocket.resume(self)",
    "PySide6.QtNetwork.QAbstractSocket.setLocalAddress(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress])",
    "PySide6.QtNetwork.QAbstractSocket.setLocalPort(self,port:quint16)",
    "PySide6.QtNetwork.QAbstractSocket.setPauseMode(self,pauseMode:PySide6.QtNetwork.QAbstractSocket.PauseMode)",
    "PySide6.QtNetwork.QAbstractSocket.setPeerAddress(self,address:typing.Union[PySide6.QtNetwork.QHostAddress, PySide6.QtNetwork.QHostAddress.SpecialAddress])",
    "PySide6.QtNetwork.QAbstractSocket.setPeerName(self,name:QString)",
    "PySide6.QtNetwork.QAbstractSocket.setPeerPort(self,port:quint16)",
    "PySide6.QtNetwork.QAbstractSocket.setProtocolTag(self,tag:QString)",
    "PySide6.QtNetwork.QAbstractSocket.setProxy(self,networkProxy:typing.Union[PySide6.QtNetwork.QNetworkProxy, PySide6.QtNetwork.QNetworkProxy.ProxyType])",
    "PySide6.QtNetwork.QAbstractSocket.setReadBufferSize(self,size:qint64)",
    "PySide6.QtNetwork.QAbstractSocket.setSocketDescriptor(self,socketDescriptor:qintptr,state:PySide6.QtNetwork.QAbstractSocket.SocketState=QAbstractSocket.SocketState.ConnectedState,openMode:PySide6.QtCore.QIODeviceBase.OpenModeFlag=QIODeviceBase.OpenModeFlag.ReadWrite)->bool",
    "PySide6.QtNetwork.QAbstractSocket.setSocketError(self,socketError:PySide6.QtNetwork.QAbstractSocket.SocketError)",
    "PySide6.QtNetwork.QAbstractSocket.setSocketOption(self,option:PySide6.QtNetwork.QAbstractSocket.SocketOption,value:QVariant)",
    "PySide6.QtNetwork.QAbstractSocket.setSocketState(self,state:PySide6.QtNetwork.QAbstractSocket.SocketState)",
    "PySide6.QtNetwork.QAbstractSocket.skipData(self,maxSize:qint64)->qint64",
    "PySide6.QtNetwork.QAbstractSocket.socketDescriptor(self)->qintptr",
    "PySide6.QtNetwork.QAbstractSocket.socketOption(self,option:PySide6.QtNetwork.QAbstractSocket.SocketOption)->QVariant",
    "PySide6.QtNetwork.QAbstractSocket.socketType(self)->PySide6.QtNetwork.QAbstractSocket.SocketType",
    "PySide6.QtNetwork.QAbstractSocket.state(self)->PySide6.QtNetwork.QAbstractSocket.SocketState",
    "PySide6.QtNetwork.QAbstractSocket.waitForBytesWritten(self,msecs:int=30000)->bool",
    "PySide6.QtNetwork.QAbstractSocket.waitForConnected(self,msecs:int=30000)->bool",
    "PySide6.QtNetwork.QAbstractSocket.waitForDisconnected(self,msecs:int=30000)->bool",
    "PySide6.QtNetwork.QAbstractSocket.waitForReadyRead(self,msecs:int=30000)->bool",
    "PySide6.QtNetwork.QAbstractSocket.writeData(self,data:char*,len:qint64)->qint64",
    nullptr}; // Sentinel
#else
static constexpr size_t QAbstractSocket_SignatureByteSize = 805;
static constexpr uint8_t QAbstractSocket_SignatureBytes[805] = {
    0x78, 0xda, 0xcd, 0x57, 0x51, 0x4f, 0xdb, 0x30, 0x10, 0x7e, 0xe7, 0x57, 0xec, 0x71, 0x9d, 0xb2,
    0x08, 0xb4, 0x89, 0x87, 0x48, 0x45, 0x6a, 0x29, 0x68, 0x48, 0x8c, 0xa6, 0xa4, 0x63, 0x0f, 0xd3,
    0x1e, 0xdc, 0xe4, 0x5a, 0x3c, 0xdc, 0x38, 0xd8, 0x0e, 0x90, 0xfd, 0xfa, 0xd9, 0xb1, 0x13, 0xd2,
    0xae, 0x94, 0x33, 0x74, 0x68, 0x7d, 0xa8, 0x9c, 0xc4, 0xf7, 0xdd, 0xf9, 0xf3, 0x7d, 0xe7, 0x73,
    0x5c, 0x25, 0x34, 0x83, 0xc3, 0x70, 0xa2, 0x2e, 0x40, 0xdd, 0x73, 0x71, 0x13, 0x4e, 0x06, 0x33,
    0xa9, 0x04, 0x49, 0x55, 0xc2, 0xd3, 0x1b, 0x50, 0xef, 0x25, 0xb0, 0x79, 0x20, 0xeb, 0xf1, 0xb4,
    0x2a, 0x20, 0x8a, 0x9f, 0xb3, 0x08, 0x93, 0x76, 0x72, 0x50, 0x10, 0x01, 0xb9, 0xea, 0xd8, 0x1c,
    0x73, 0x01, 0xe1, 0x64, 0x3c, 0xfb, 0x05, 0xa9, 0xea, 0xed, 0x3d, 0x8f, 0x45, 0x66, 0x5c, 0xd8,
    0x18, 0x7a, 0x7b, 0x07, 0x08, 0xdf, 0x33, 0x9a, 0x67, 0x36, 0x64, 0x92, 0x65, 0x02, 0xa4, 0x8c,
    0x54, 0x55, 0xd0, 0x7c, 0x11, 0x7e, 0xcb, 0x29, 0xcf, 0x7f, 0x6c, 0x00, 0xf8, 0xc2, 0xa5, 0x1a,
    0xd8, 0xb9, 0xc1, 0xbb, 0xed, 0xdf, 0xc3, 0xa4, 0x80, 0x94, 0x12, 0xe6, 0x1e, 0x7f, 0x06, 0x85,
    0x0e, 0x2e, 0xba, 0x2d, 0x69, 0xae, 0x0e, 0x0e, 0xfb, 0xfb, 0xc1, 0x92, 0x67, 0x18, 0x7e, 0x86,
    0x3a, 0xc6, 0x53, 0x46, 0x16, 0xfd, 0xa7, 0x3e, 0x84, 0x23, 0x98, 0x93, 0x92, 0xa9, 0x53, 0x2e,
    0x62, 0x46, 0xd4, 0x9c, 0x8b, 0x65, 0xef, 0xe3, 0xd1, 0x8c, 0x73, 0xb6, 0xb7, 0xef, 0xc5, 0xc1,
    0xdb, 0xc7, 0x87, 0x88, 0xae, 0x52, 0x20, 0x07, 0x77, 0x84, 0x32, 0x32, 0x63, 0x60, 0xb7, 0xf6,
    0xe3, 0xd1, 0xad, 0x8e, 0xf1, 0xf0, 0x33, 0xd6, 0x7c, 0xca, 0xbf, 0x0b, 0xaa, 0xfc, 0x8d, 0x53,
    0xc6, 0x25, 0x78, 0x64, 0x53, 0xca, 0xf3, 0x5c, 0x27, 0xea, 0x94, 0x9b, 0x24, 0xb0, 0x94, 0x5e,
    0xeb, 0xd1, 0x05, 0x59, 0x42, 0x34, 0x49, 0x94, 0xd0, 0x89, 0xb5, 0xc2, 0xf1, 0x3a, 0xc3, 0x36,
    0xdb, 0xcf, 0xc6, 0x23, 0xb8, 0xa3, 0x29, 0x0c, 0x89, 0x84, 0x70, 0x5c, 0x40, 0xfe, 0x55, 0xcf,
    0xb2, 0x04, 0x3f, 0xf9, 0x29, 0xbc, 0x04, 0x92, 0xd5, 0x8b, 0x0c, 0x0a, 0xc1, 0x15, 0x4f, 0x39,
    0x43, 0xc4, 0xeb, 0xde, 0x9f, 0x93, 0x0a, 0x44, 0xec, 0xcc, 0xfa, 0x98, 0x49, 0xe1, 0x20, 0xaf,
    0xce, 0xe2, 0xe6, 0xa9, 0x87, 0x4a, 0xb3, 0x0d, 0xe4, 0xbc, 0xb5, 0xe6, 0xfe, 0x05, 0xdf, 0x98,
    0xaa, 0x94, 0x51, 0xe9, 0x56, 0x7f, 0x2a, 0xf8, 0xb2, 0x5d, 0x3f, 0xc6, 0x14, 0x84, 0xe0, 0xa2,
    0x49, 0x5c, 0x6c, 0x2d, 0x3d, 0x31, 0x46, 0x08, 0xf0, 0x39, 0x2b, 0xe5, 0x75, 0x03, 0x8e, 0xd4,
    0x23, 0x95, 0x09, 0xdc, 0x96, 0xba, 0x4a, 0x6b, 0x92, 0xbd, 0x4d, 0xaf, 0x08, 0xa3, 0x99, 0xa7,
    0x15, 0xe3, 0x69, 0xbb, 0x9d, 0x5b, 0x88, 0xe8, 0xe4, 0x00, 0x16, 0x34, 0x6e, 0xcf, 0x0a, 0x5d,
    0x13, 0x6c, 0x86, 0x20, 0x4c, 0x0b, 0x52, 0x4a, 0x30, 0x79, 0x80, 0xdf, 0x95, 0xb8, 0x31, 0xc1,
    0xc0, 0x03, 0x88, 0x5d, 0xaf, 0xd6, 0x60, 0x9a, 0x22, 0xd4, 0x00, 0xba, 0x5a, 0x84, 0xb4, 0x7c,
    0x21, 0x4d, 0xae, 0x38, 0x4c, 0xc9, 0xe2, 0x05, 0x6e, 0x05, 0x7f, 0xa8, 0xb6, 0x2c, 0xdf, 0x0d,
    0x62, 0x33, 0x0d, 0x01, 0x27, 0xb4, 0x58, 0x87, 0xe5, 0x7c, 0x0e, 0x22, 0xa1, 0xbf, 0xfd, 0x8f,
    0x01, 0x63, 0x3e, 0x22, 0x8a, 0xd8, 0xa2, 0xb5, 0x24, 0x0f, 0x0c, 0xf2, 0xc8, 0x5a, 0xd7, 0xe1,
    0xd9, 0xf6, 0x04, 0x09, 0x74, 0x4e, 0x73, 0xd8, 0x11, 0x98, 0x2c, 0x9b, 0x2d, 0x45, 0x4c, 0x97,
    0xa0, 0xce, 0xd7, 0x95, 0xf4, 0x16, 0x05, 0xd8, 0x27, 0xb6, 0x36, 0xd3, 0x56, 0xaa, 0x36, 0x12,
    0x21, 0x5e, 0xd1, 0x65, 0xd0, 0xca, 0x34, 0xf2, 0xd0, 0x27, 0xd6, 0xd5, 0x9a, 0x46, 0xff, 0x23,
    0x1e, 0xe3, 0xae, 0xd4, 0x83, 0xbc, 0xd3, 0x79, 0x78, 0x00, 0xbc, 0x6e, 0x1f, 0xd6, 0x84, 0x1f,
    0x28, 0xb2, 0xf0, 0x8d, 0xa1, 0x95, 0x7f, 0x90, 0x77, 0x94, 0xfe, 0x2c, 0xbd, 0xdd, 0xb2, 0xb0,
    0x91, 0xdf, 0xee, 0x84, 0xb0, 0xfe, 0x37, 0xd7, 0x0e, 0x2c, 0xb7, 0x97, 0x7f, 0x97, 0x91, 0x40,
    0xea, 0x51, 0x23, 0x5f, 0x1c, 0x8a, 0x1d, 0x8d, 0x40, 0xa6, 0x82, 0x16, 0xca, 0x1d, 0xee, 0xee,
    0xc6, 0xf4, 0xf8, 0xb6, 0xc6, 0x2c, 0x94, 0x08, 0xa4, 0x22, 0x0a, 0x7f, 0x8b, 0x4a, 0xcc, 0xec,
    0xfe, 0x96, 0x6f, 0xe1, 0xb1, 0x6d, 0x44, 0x20, 0xab, 0x1f, 0x03, 0xee, 0x9a, 0x9a, 0x5d, 0x77,
    0x45, 0xe8, 0xe3, 0xbd, 0x65, 0xe4, 0xa4, 0xed, 0x74, 0x1c, 0x19, 0xf5, 0x8b, 0xc8, 0xab, 0xe7,
    0xf1, 0xda, 0x82, 0x71, 0xa1, 0x74, 0x1e, 0x59, 0x8f, 0xbc, 0x1e, 0xa3, 0x9d, 0x59, 0xd3, 0xe0,
    0x8e, 0xb0, 0x52, 0xeb, 0xeb, 0x8a, 0x08, 0x4a, 0x72, 0xe5, 0xe5, 0xbc, 0x66, 0xdf, 0xad, 0xd6,
    0x7f, 0x87, 0x51, 0xae, 0x6e, 0x68, 0xb1, 0x72, 0xd0, 0x24, 0x9d, 0x54, 0xf5, 0x38, 0xfd, 0xe4,
    0xa6, 0x7c, 0x75, 0x00, 0x3a, 0x41, 0xd1, 0x08, 0xaf, 0xa6, 0xdb, 0x74, 0x10, 0x8e, 0x6a, 0xb4,
    0x53, 0x23, 0x6f, 0xdf, 0xee, 0xd9, 0xd8, 0x60, 0x1c, 0xb4, 0x3b, 0xe8, 0x81, 0x5d, 0xef, 0x1e,
    0x02, 0xfc, 0x9e, 0x50, 0x73, 0x5d, 0x1e, 0x9a, 0xdb, 0xab, 0x11, 0x94, 0x02, 0xc7, 0xdc, 0x52,
    0x42, 0x2a, 0x23, 0x4d, 0x7d, 0xff, 0xd3, 0xbe, 0xfe, 0xe1, 0x75, 0xe6, 0x10, 0x5b, 0xf9, 0xef,
    0x06, 0x6e, 0xd4, 0xde, 0x6c, 0x76, 0x85, 0x68, 0x4a, 0x48, 0x65, 0xfe, 0x5e, 0x0b, 0x67, 0xca,
    0xd0, 0x63, 0xfe, 0x67, 0x7a, 0x14, 0xa5, 0xd7, 0x44, 0x7c, 0x08, 0x56, 0x1a, 0x2e, 0x27, 0x83,
    0x3f, 0x71, 0xa8, 0xf1, 0xa7
};
#endif

PyTypeObject *init_QAbstractSocket(PyObject *module)
{
    if (SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX].type != nullptr)
        return SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX].type;

    Shiboken::AutoDecRef Sbk_QAbstractSocket_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]))));

    _Sbk_QAbstractSocket_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QAbstractSocket",
        "QAbstractSocket*",
        &Sbk_QAbstractSocket_spec,
        &Shiboken::callCppDestructor< QAbstractSocket >,
        Sbk_QAbstractSocket_Type_bases.object(),
        0);
    auto *pyType = Sbk_QAbstractSocket_TypeF(); // references _Sbk_QAbstractSocket_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QAbstractSocket_SignatureStrings);
#else
    InitSignatureBytes(pyType, QAbstractSocket_SignatureBytes, QAbstractSocket_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QAbstractSocket_PropertyStrings);
    SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QAbstractSocket_PythonToCpp_QAbstractSocket_PTR,
        is_QAbstractSocket_PythonToCpp_QAbstractSocket_PTR_Convertible,
        QAbstractSocket_PTR_CppToPython_QAbstractSocket);

    Shiboken::Conversions::registerConverterName(converter, "QAbstractSocket");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractSocket*");
    Shiboken::Conversions::registerConverterName(converter, "QAbstractSocket&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QAbstractSocket).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QAbstractSocketWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QIODevice_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QAbstractSocket_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QAbstractSocket_TypeF(), &Sbk_QAbstractSocketSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QAbstractSocket_TypeF(), &Sbk_QAbstractSocket_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QAbstractSocket_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'SocketType'.
    const char *SocketType_Initializer[] = {
        "TcpSocket",
        "UdpSocket",
        "SctpSocket",
        "UnknownSocketType",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t SocketType_InitializerValues[] = {
        int8_t(QAbstractSocket::SocketType::TcpSocket),        //  0x00  0
        int8_t(QAbstractSocket::SocketType::UdpSocket),        //  0x01  1
        int8_t(QAbstractSocket::SocketType::SctpSocket),       //  0x02  2
        int8_t(QAbstractSocket::SocketType::UnknownSocketType) // -0x01 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractSocket_TypeF(),
        "2:PySide6.QtNetwork.QAbstractSocket.SocketType",
        SocketType_Initializer, SocketType_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketType_IDX].type = EType;
    // Register converter for enum 'QAbstractSocket::SocketType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractSocket_SocketType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractSocket_SocketType,
            is_Enum_PythonToCpp_QAbstractSocket_SocketType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractSocket::SocketType");
        Shiboken::Conversions::registerConverterAlias(converter, "SocketType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SocketType' enum.

    // Initialization of enum 'NetworkLayerProtocol'.
    const char *NetworkLayerProtocol_Initializer[] = {
        "IPv4Protocol",
        "IPv6Protocol",
        "AnyIPProtocol",
        "UnknownNetworkLayerProtocol",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t NetworkLayerProtocol_InitializerValues[] = {
        int8_t(QAbstractSocket::NetworkLayerProtocol::IPv4Protocol),               //  0x00  0
        int8_t(QAbstractSocket::NetworkLayerProtocol::IPv6Protocol),               //  0x01  1
        int8_t(QAbstractSocket::NetworkLayerProtocol::AnyIPProtocol),              //  0x02  2
        int8_t(QAbstractSocket::NetworkLayerProtocol::UnknownNetworkLayerProtocol) // -0x01 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractSocket_TypeF(),
        "2:PySide6.QtNetwork.QAbstractSocket.NetworkLayerProtocol",
        NetworkLayerProtocol_Initializer, NetworkLayerProtocol_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_NetworkLayerProtocol_IDX].type = EType;
    // Register converter for enum 'QAbstractSocket::NetworkLayerProtocol'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractSocket_NetworkLayerProtocol_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractSocket_NetworkLayerProtocol,
            is_Enum_PythonToCpp_QAbstractSocket_NetworkLayerProtocol_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractSocket::NetworkLayerProtocol");
        Shiboken::Conversions::registerConverterAlias(converter, "NetworkLayerProtocol");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'NetworkLayerProtocol' enum.

    // Initialization of enum 'SocketError'.
    const char *SocketError_Initializer[] = {
        "ConnectionRefusedError",
        "RemoteHostClosedError",
        "HostNotFoundError",
        "SocketAccessError",
        "SocketResourceError",
        "SocketTimeoutError",
        "DatagramTooLargeError",
        "NetworkError",
        "AddressInUseError",
        "SocketAddressNotAvailableError",
        "UnsupportedSocketOperationError",
        "UnfinishedSocketOperationError",
        "ProxyAuthenticationRequiredError",
        "SslHandshakeFailedError",
        "ProxyConnectionRefusedError",
        "ProxyConnectionClosedError",
        "ProxyConnectionTimeoutError",
        "ProxyNotFoundError",
        "ProxyProtocolError",
        "OperationError",
        "SslInternalError",
        "SslInvalidUserDataError",
        "TemporaryError",
        "UnknownSocketError",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t SocketError_InitializerValues[] = {
        int8_t(QAbstractSocket::SocketError::ConnectionRefusedError),           //  0x00  0
        int8_t(QAbstractSocket::SocketError::RemoteHostClosedError),            //  0x01  1
        int8_t(QAbstractSocket::SocketError::HostNotFoundError),                //  0x02  2
        int8_t(QAbstractSocket::SocketError::SocketAccessError),                //  0x03  3
        int8_t(QAbstractSocket::SocketError::SocketResourceError),              //  0x04  4
        int8_t(QAbstractSocket::SocketError::SocketTimeoutError),               //  0x05  5
        int8_t(QAbstractSocket::SocketError::DatagramTooLargeError),            //  0x06  6
        int8_t(QAbstractSocket::SocketError::NetworkError),                     //  0x07  7
        int8_t(QAbstractSocket::SocketError::AddressInUseError),                //  0x08  8
        int8_t(QAbstractSocket::SocketError::SocketAddressNotAvailableError),   //  0x09  9
        int8_t(QAbstractSocket::SocketError::UnsupportedSocketOperationError),  //  0x0a  10
        int8_t(QAbstractSocket::SocketError::UnfinishedSocketOperationError),   //  0x0b  11
        int8_t(QAbstractSocket::SocketError::ProxyAuthenticationRequiredError), //  0x0c  12
        int8_t(QAbstractSocket::SocketError::SslHandshakeFailedError),          //  0x0d  13
        int8_t(QAbstractSocket::SocketError::ProxyConnectionRefusedError),      //  0x0e  14
        int8_t(QAbstractSocket::SocketError::ProxyConnectionClosedError),       //  0x0f  15
        int8_t(QAbstractSocket::SocketError::ProxyConnectionTimeoutError),      //  0x10  16
        int8_t(QAbstractSocket::SocketError::ProxyNotFoundError),               //  0x11  17
        int8_t(QAbstractSocket::SocketError::ProxyProtocolError),               //  0x12  18
        int8_t(QAbstractSocket::SocketError::OperationError),                   //  0x13  19
        int8_t(QAbstractSocket::SocketError::SslInternalError),                 //  0x14  20
        int8_t(QAbstractSocket::SocketError::SslInvalidUserDataError),          //  0x15  21
        int8_t(QAbstractSocket::SocketError::TemporaryError),                   //  0x16  22
        int8_t(QAbstractSocket::SocketError::UnknownSocketError)                // -0x01 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractSocket_TypeF(),
        "2:PySide6.QtNetwork.QAbstractSocket.SocketError",
        SocketError_Initializer, SocketError_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketError_IDX].type = EType;
    // Register converter for enum 'QAbstractSocket::SocketError'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractSocket_SocketError_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractSocket_SocketError,
            is_Enum_PythonToCpp_QAbstractSocket_SocketError_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractSocket::SocketError");
        Shiboken::Conversions::registerConverterAlias(converter, "SocketError");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SocketError' enum.

    // Initialization of enum 'SocketState'.
    const char *SocketState_Initializer[] = {
        "UnconnectedState",
        "HostLookupState",
        "ConnectingState",
        "ConnectedState",
        "BoundState",
        "ListeningState",
        "ClosingState",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SocketState_InitializerValues[] = {
        uint8_t(QAbstractSocket::SocketState::UnconnectedState), //  0x00  0
        uint8_t(QAbstractSocket::SocketState::HostLookupState),  //  0x01  1
        uint8_t(QAbstractSocket::SocketState::ConnectingState),  //  0x02  2
        uint8_t(QAbstractSocket::SocketState::ConnectedState),   //  0x03  3
        uint8_t(QAbstractSocket::SocketState::BoundState),       //  0x04  4
        uint8_t(QAbstractSocket::SocketState::ListeningState),   //  0x05  5
        uint8_t(QAbstractSocket::SocketState::ClosingState)      //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractSocket_TypeF(),
        "2:PySide6.QtNetwork.QAbstractSocket.SocketState",
        SocketState_Initializer, SocketState_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketState_IDX].type = EType;
    // Register converter for enum 'QAbstractSocket::SocketState'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractSocket_SocketState_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractSocket_SocketState,
            is_Enum_PythonToCpp_QAbstractSocket_SocketState_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractSocket::SocketState");
        Shiboken::Conversions::registerConverterAlias(converter, "SocketState");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SocketState' enum.

    // Initialization of enum 'SocketOption'.
    const char *SocketOption_Initializer[] = {
        "LowDelayOption",
        "KeepAliveOption",
        "MulticastTtlOption",
        "MulticastLoopbackOption",
        "TypeOfServiceOption",
        "SendBufferSizeSocketOption",
        "ReceiveBufferSizeSocketOption",
        "PathMtuSocketOption",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t SocketOption_InitializerValues[] = {
        uint8_t(QAbstractSocket::SocketOption::LowDelayOption),                //  0x00  0
        uint8_t(QAbstractSocket::SocketOption::KeepAliveOption),               //  0x01  1
        uint8_t(QAbstractSocket::SocketOption::MulticastTtlOption),            //  0x02  2
        uint8_t(QAbstractSocket::SocketOption::MulticastLoopbackOption),       //  0x03  3
        uint8_t(QAbstractSocket::SocketOption::TypeOfServiceOption),           //  0x04  4
        uint8_t(QAbstractSocket::SocketOption::SendBufferSizeSocketOption),    //  0x05  5
        uint8_t(QAbstractSocket::SocketOption::ReceiveBufferSizeSocketOption), //  0x06  6
        uint8_t(QAbstractSocket::SocketOption::PathMtuSocketOption)            //  0x07  7
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractSocket_TypeF(),
        "2:PySide6.QtNetwork.QAbstractSocket.SocketOption",
        SocketOption_Initializer, SocketOption_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_SocketOption_IDX].type = EType;
    // Register converter for enum 'QAbstractSocket::SocketOption'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractSocket_SocketOption_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractSocket_SocketOption,
            is_Enum_PythonToCpp_QAbstractSocket_SocketOption_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractSocket::SocketOption");
        Shiboken::Conversions::registerConverterAlias(converter, "SocketOption");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'SocketOption' enum.

    // Initialization of enum 'BindFlag'.
    const char *BindFlag_Initializer[] = {
        "DefaultForPlatform",
        "ShareAddress",
        "DontShareAddress",
        "ReuseAddressHint",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t BindFlag_InitializerValues[] = {
        uint8_t(QAbstractSocket::BindFlag::DefaultForPlatform), //  0x00  0
        uint8_t(QAbstractSocket::BindFlag::ShareAddress),       //  0x01  1
        uint8_t(QAbstractSocket::BindFlag::DontShareAddress),   //  0x02  2
        uint8_t(QAbstractSocket::BindFlag::ReuseAddressHint)    //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractSocket_TypeF(),
        "2:PySide6.QtNetwork.QAbstractSocket.BindFlag",
        BindFlag_Initializer, BindFlag_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_BindFlag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_BindFlag_IDX].type =
        EType;
    // Register converter for enum 'QAbstractSocket::BindFlag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractSocket_BindFlag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractSocket_BindFlag,
            is_Enum_PythonToCpp_QAbstractSocket_BindFlag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractSocket::BindFlag");
        Shiboken::Conversions::registerConverterAlias(converter, "BindFlag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QAbstractSocket_BindFlag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QAbstractSocket_BindFlag,
            is_Enum_PythonToCpp_QAbstractSocket_BindFlag_Convertible);
        // Register converter for flag 'QFlags<QAbstractSocket::BindFlag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QAbstractSocket::BindFlag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QAbstractSocket::BindMode");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'BindFlag' enum/flags.

    // Initialization of enum 'PauseMode'.
    const char *PauseMode_Initializer[] = {
        "PauseNever",
        "PauseOnSslErrors",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t PauseMode_InitializerValues[] = {
        uint8_t(QAbstractSocket::PauseMode::PauseNever),      //  0x00  0
        uint8_t(QAbstractSocket::PauseMode::PauseOnSslErrors) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QAbstractSocket_TypeF(),
        "2:PySide6.QtNetwork.QAbstractSocket.PauseMode",
        PauseMode_Initializer, PauseMode_InitializerValues);
    SbkPySide6_QtNetworkTypeStructs[SBK_QAbstractSocket_PauseMode_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtNetworkTypeStructs[SBK_QFlags_QAbstractSocket_PauseMode_IDX].type =
        EType;
    // Register converter for enum 'QAbstractSocket::PauseMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QAbstractSocket_PauseMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QAbstractSocket_PauseMode,
            is_Enum_PythonToCpp_QAbstractSocket_PauseMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QAbstractSocket::PauseMode");
        Shiboken::Conversions::registerConverterAlias(converter, "PauseMode");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QAbstractSocket_PauseMode_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QAbstractSocket_PauseMode,
            is_Enum_PythonToCpp_QAbstractSocket_PauseMode_Convertible);
        // Register converter for flag 'QFlags<QAbstractSocket::PauseMode>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QAbstractSocket::PauseMode>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QAbstractSocket::PauseModes");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'PauseMode' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QAbstractSocket::staticMetaObject);
    qRegisterMetaType< ::QAbstractSocket::SocketType >("QAbstractSocket::SocketType");
    qRegisterMetaType< ::QAbstractSocket::NetworkLayerProtocol >("QAbstractSocket::NetworkLayerProtocol");
    qRegisterMetaType< ::QAbstractSocket::SocketError >("QAbstractSocket::SocketError");
    qRegisterMetaType< ::QAbstractSocket::SocketState >("QAbstractSocket::SocketState");
    qRegisterMetaType< ::QAbstractSocket::SocketOption >("QAbstractSocket::SocketOption");
    qRegisterMetaType< ::QAbstractSocket::BindFlag >("QAbstractSocket::BindFlag");
    qRegisterMetaType< ::QAbstractSocket::PauseMode >("QAbstractSocket::PauseMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QAbstractSocket::staticMetaObject, sizeof(QAbstractSocketWrapper));

    return pyType;
}
