// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtopengl_python.h"

// main header
#include "qopenglfunctions_1_2_wrapper.h"

// Extra includes
#include <QtCore/QVarLengthArray>
#include <sbkcpptonumpy.h>

// Argument includes
#include <QtGui/qopenglcontext.h>
#include <QtOpenGL/qopenglversionprofile.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Begin code injection
// ========================================================================
// START of custom code block [file: ../glue/qtopengl.cpp (glgetvreturnsize_declaration)]
int glGetVReturnSize(GLenum pname);
// END of custom code block [file: ../glue/qtopengl.cpp (glgetvreturnsize_declaration)]
// ========================================================================
// End of code injection


// Native ---------------------------------------------------------

void QOpenGLFunctions_1_2Wrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QOpenGLFunctions_1_2Wrapper::QOpenGLFunctions_1_2Wrapper()
{
}

bool QOpenGLFunctions_1_2Wrapper::initializeOpenGLFunctions()
{
    if (m_PyMethodCache[0])
        return this->::QOpenGLFunctions_1_2::initializeOpenGLFunctions();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "initializeOpenGLFunctions";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QOpenGLFunctions_1_2::initializeOpenGLFunctions();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QOpenGLFunctions_1_2", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QOpenGLFunctions_1_2", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

QOpenGLFunctions_1_2Wrapper::~QOpenGLFunctions_1_2Wrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QOpenGLFunctions_1_2_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(args)
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QOpenGLFunctions_1_2 >()))
        return -1;

    QOpenGLFunctions_1_2Wrapper *cptr{};
    Shiboken::PythonContextMarker pcm;


    // PyMI support
    Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {

        // QOpenGLFunctions_1_2()
        cptr = new QOpenGLFunctions_1_2Wrapper();
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QOpenGLFunctions_1_2 >(), cptr)) {
        delete cptr;
        return -1;
    }
    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);


    return 1;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glAccum(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glAccum", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glAccum(uint,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // glAccum(uint,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glAccum", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glAccum(uint,float)
            cppSelf->glAccum(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glAlphaFunc(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glAlphaFunc", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glAlphaFunc(uint,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // glAlphaFunc(uint,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glAlphaFunc", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glAlphaFunc(uint,float)
            cppSelf->glAlphaFunc(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glArrayElement(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glArrayElement(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // glArrayElement(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glArrayElement", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glArrayElement(int)
            cppSelf->glArrayElement(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glBegin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glBegin(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glBegin(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glBegin", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glBegin(uint)
            cppSelf->glBegin(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glBindTexture(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glBindTexture", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glBindTexture(uint,uint)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))) {
        overloadId = 0; // glBindTexture(uint,uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glBindTexture", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glBindTexture(uint,uint)
            cppSelf->glBindTexture(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glBlendColor(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glBlendColor", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glBlendColor(float,float,float,float)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 0; // glBlendColor(float,float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glBlendColor", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glBlendColor(float,float,float,float)
            cppSelf->glBlendColor(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glBlendEquation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glBlendEquation(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glBlendEquation(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glBlendEquation", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glBlendEquation(uint)
            cppSelf->glBlendEquation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glBlendFunc(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glBlendFunc", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glBlendFunc(uint,uint)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))) {
        overloadId = 0; // glBlendFunc(uint,uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glBlendFunc", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glBlendFunc(uint,uint)
            cppSelf->glBlendFunc(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glCallList(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glCallList(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glCallList(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glCallList", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glCallList(uint)
            cppSelf->glCallList(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glCallLists(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glCallLists", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glCallLists(int,uint,const void*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))) {
        overloadId = 0; // glCallLists(int,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glCallLists", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        void* cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glCallLists(int,uint,const void*)
            cppSelf->glCallLists(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glClear(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glClear(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glClear(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glClear", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glClear(uint)
            cppSelf->glClear(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glClearAccum(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glClearAccum", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glClearAccum(float,float,float,float)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 0; // glClearAccum(float,float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glClearAccum", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glClearAccum(float,float,float,float)
            cppSelf->glClearAccum(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glClearColor(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glClearColor", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glClearColor(float,float,float,float)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 0; // glClearColor(float,float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glClearColor", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glClearColor(float,float,float,float)
            cppSelf->glClearColor(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glClearDepth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glClearDepth(double)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // glClearDepth(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glClearDepth", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glClearDepth(double)
            cppSelf->glClearDepth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glClearIndex(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glClearIndex(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // glClearIndex(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glClearIndex", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glClearIndex(float)
            cppSelf->glClearIndex(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glClearStencil(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glClearStencil(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // glClearStencil(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glClearStencil", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glClearStencil(int)
            cppSelf->glClearStencil(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glClipPlane(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glClipPlane", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glClipPlane(uint,const double*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && PyFloat_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArgs[1])))) {
        overloadId = 0; // glClipPlane(uint,const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glClipPlane", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        Shiboken::Conversions::ArrayHandle<double> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glClipPlane(uint,const double*)
            cppSelf->glClipPlane(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3b(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor3b", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3b(signed char,signed char,signed char)
    if (numArgs == 3
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), (pyArgs[1])))
        && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), (pyArgs[2])))) {
        overloadId = 0; // glColor3b(signed char,signed char,signed char)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor3b", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        signed char cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        signed char cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        signed char cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3b(signed char,signed char,signed char)
            cppSelf->glColor3b(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3bv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3bv(const signed char*)
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<signed char>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor3bv(const signed char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor3bv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<signed char> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3bv(const signed char*)
            cppSelf->glColor3bv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor3d", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3d(double,double,double)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))) {
        overloadId = 0; // glColor3d(double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor3d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3d(double,double,double)
            cppSelf->glColor3d(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor3dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor3dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3dv(const double*)
            cppSelf->glColor3dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor3f", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3f(float,float,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glColor3f(float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor3f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3f(float,float,float)
            cppSelf->glColor3f(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor3fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor3fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3fv(const float*)
            cppSelf->glColor3fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3i(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor3i", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3i(int,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // glColor3i(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor3i", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3i(int,int,int)
            cppSelf->glColor3i(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3iv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3iv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor3iv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor3iv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3iv(const int*)
            cppSelf->glColor3iv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3s(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor3s", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3s(short,short,short)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[2])))) {
        overloadId = 0; // glColor3s(short,short,short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor3s", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        short cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3s(short,short,short)
            cppSelf->glColor3s(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3sv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3sv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor3sv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor3sv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3sv(const short*)
            cppSelf->glColor3sv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3ub(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor3ub", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3ub(uchar,uchar,uchar)
    if (numArgs == 3
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[1])))
        && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[2])))) {
        overloadId = 0; // glColor3ub(uchar,uchar,uchar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor3ub", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned char cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned char cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned char cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3ub(uchar,uchar,uchar)
            cppSelf->glColor3ub(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3ubv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3ubv(const uchar*)
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<unsigned char>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor3ubv(const uchar*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor3ubv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<unsigned char> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3ubv(const uchar*)
            cppSelf->glColor3ubv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3ui(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor3ui", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3ui(uint,uint,uint)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))) {
        overloadId = 0; // glColor3ui(uint,uint,uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor3ui", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3ui(uint,uint,uint)
            cppSelf->glColor3ui(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3uiv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3uiv(const uint*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<unsigned int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor3uiv(const uint*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor3uiv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<unsigned int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3uiv(const uint*)
            cppSelf->glColor3uiv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3us(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor3us", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3us(ushort,ushort,ushort)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), (pyArgs[2])))) {
        overloadId = 0; // glColor3us(ushort,ushort,ushort)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor3us", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned short cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3us(ushort,ushort,ushort)
            cppSelf->glColor3us(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor3usv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor3usv(const ushort*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<unsigned short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor3usv(const ushort*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor3usv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<unsigned short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor3usv(const ushort*)
            cppSelf->glColor3usv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4b(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor4b", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4b(signed char,signed char,signed char,signed char)
    if (numArgs == 4
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), (pyArgs[1])))
        && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), (pyArgs[2])))
        && SbkChar_Check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), (pyArgs[3])))) {
        overloadId = 0; // glColor4b(signed char,signed char,signed char,signed char)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor4b", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        signed char cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        signed char cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        signed char cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        signed char cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4b(signed char,signed char,signed char,signed char)
            cppSelf->glColor4b(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4bv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4bv(const signed char*)
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<signed char>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor4bv(const signed char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor4bv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<signed char> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4bv(const signed char*)
            cppSelf->glColor4bv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor4d", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4d(double,double,double,double)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[3])))) {
        overloadId = 0; // glColor4d(double,double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor4d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        double cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4d(double,double,double,double)
            cppSelf->glColor4d(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor4dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor4dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4dv(const double*)
            cppSelf->glColor4dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor4f", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4f(float,float,float,float)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 0; // glColor4f(float,float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor4f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4f(float,float,float,float)
            cppSelf->glColor4f(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor4fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor4fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4fv(const float*)
            cppSelf->glColor4fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4i(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor4i", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4i(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // glColor4i(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor4i", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4i(int,int,int,int)
            cppSelf->glColor4i(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4iv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4iv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor4iv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor4iv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4iv(const int*)
            cppSelf->glColor4iv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4s(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor4s", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4s(short,short,short,short)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[3])))) {
        overloadId = 0; // glColor4s(short,short,short,short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor4s", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        short cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        short cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4s(short,short,short,short)
            cppSelf->glColor4s(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4sv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4sv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor4sv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor4sv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4sv(const short*)
            cppSelf->glColor4sv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4ub(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor4ub", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4ub(uchar,uchar,uchar,uchar)
    if (numArgs == 4
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[1])))
        && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[2])))
        && SbkChar_Check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[3])))) {
        overloadId = 0; // glColor4ub(uchar,uchar,uchar,uchar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor4ub", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned char cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned char cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned char cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        unsigned char cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4ub(uchar,uchar,uchar,uchar)
            cppSelf->glColor4ub(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4ubv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4ubv(const uchar*)
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<unsigned char>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor4ubv(const uchar*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor4ubv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<unsigned char> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4ubv(const uchar*)
            cppSelf->glColor4ubv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4ui(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor4ui", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4ui(uint,uint,uint,uint)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3])))) {
        overloadId = 0; // glColor4ui(uint,uint,uint,uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor4ui", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        unsigned int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4ui(uint,uint,uint,uint)
            cppSelf->glColor4ui(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4uiv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4uiv(const uint*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<unsigned int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor4uiv(const uint*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor4uiv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<unsigned int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4uiv(const uint*)
            cppSelf->glColor4uiv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4us(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColor4us", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4us(ushort,ushort,ushort,ushort)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), (pyArgs[3])))) {
        overloadId = 0; // glColor4us(ushort,ushort,ushort,ushort)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColor4us", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned short cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        unsigned short cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4us(ushort,ushort,ushort,ushort)
            cppSelf->glColor4us(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColor4usv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColor4usv(const ushort*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<unsigned short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glColor4usv(const ushort*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glColor4usv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<unsigned short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColor4usv(const ushort*)
            cppSelf->glColor4usv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColorMask(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColorMask", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColorMask(uchar,uchar,uchar,uchar)
    if (numArgs == 4
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[1])))
        && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[2])))
        && SbkChar_Check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[3])))) {
        overloadId = 0; // glColorMask(uchar,uchar,uchar,uchar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColorMask", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned char cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned char cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned char cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        unsigned char cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColorMask(uchar,uchar,uchar,uchar)
            cppSelf->glColorMask(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColorMaterial(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColorMaterial", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColorMaterial(uint,uint)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))) {
        overloadId = 0; // glColorMaterial(uint,uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColorMaterial", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColorMaterial(uint,uint)
            cppSelf->glColorMaterial(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColorPointer(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColorPointer", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColorPointer(int,uint,int,const void*)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[3])))) {
        overloadId = 0; // glColorPointer(int,uint,int,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColorPointer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        void* cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColorPointer(int,uint,int,const void*)
            cppSelf->glColorPointer(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColorSubTable(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColorSubTable", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColorSubTable(uint,int,int,uint,uint,const void*)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[5])))) {
        overloadId = 0; // glColorSubTable(uint,int,int,uint,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColorSubTable", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        unsigned int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        unsigned int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        void* cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColorSubTable(uint,int,int,uint,uint,const void*)
            cppSelf->glColorSubTable(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColorTable(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColorTable", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColorTable(uint,uint,int,uint,uint,const void*)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[5])))) {
        overloadId = 0; // glColorTable(uint,uint,int,uint,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColorTable", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        unsigned int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        unsigned int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        void* cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColorTable(uint,uint,int,uint,uint,const void*)
            cppSelf->glColorTable(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColorTableParameterfv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColorTableParameterfv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColorTableParameterfv(uint,uint,const float*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && PyFloat_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glColorTableParameterfv(uint,uint,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColorTableParameterfv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<float> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColorTableParameterfv(uint,uint,const float*)
            cppSelf->glColorTableParameterfv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glColorTableParameteriv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glColorTableParameteriv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glColorTableParameteriv(uint,uint,const int*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glColorTableParameteriv(uint,uint,const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glColorTableParameteriv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<int> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glColorTableParameteriv(uint,uint,const int*)
            cppSelf->glColorTableParameteriv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glConvolutionFilter1D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glConvolutionFilter1D", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glConvolutionFilter1D(uint,uint,int,uint,uint,const void*)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[5])))) {
        overloadId = 0; // glConvolutionFilter1D(uint,uint,int,uint,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glConvolutionFilter1D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        unsigned int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        unsigned int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        void* cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glConvolutionFilter1D(uint,uint,int,uint,uint,const void*)
            cppSelf->glConvolutionFilter1D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glConvolutionFilter2D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glConvolutionFilter2D", 7, 7, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glConvolutionFilter2D(uint,uint,int,int,uint,uint,const void*)
    if (numArgs == 7
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[6])))) {
        overloadId = 0; // glConvolutionFilter2D(uint,uint,int,int,uint,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glConvolutionFilter2D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        unsigned int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        unsigned int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        void* cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glConvolutionFilter2D(uint,uint,int,int,uint,uint,const void*)
            cppSelf->glConvolutionFilter2D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glConvolutionParameterf(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glConvolutionParameterf", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glConvolutionParameterf(uint,uint,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glConvolutionParameterf(uint,uint,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glConvolutionParameterf", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glConvolutionParameterf(uint,uint,float)
            cppSelf->glConvolutionParameterf(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glConvolutionParameterfv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glConvolutionParameterfv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glConvolutionParameterfv(uint,uint,const float*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && PyFloat_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glConvolutionParameterfv(uint,uint,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glConvolutionParameterfv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<float> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glConvolutionParameterfv(uint,uint,const float*)
            cppSelf->glConvolutionParameterfv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glConvolutionParameteri(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glConvolutionParameteri", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glConvolutionParameteri(uint,uint,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // glConvolutionParameteri(uint,uint,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glConvolutionParameteri", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glConvolutionParameteri(uint,uint,int)
            cppSelf->glConvolutionParameteri(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glConvolutionParameteriv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glConvolutionParameteriv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glConvolutionParameteriv(uint,uint,const int*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glConvolutionParameteriv(uint,uint,const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glConvolutionParameteriv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<int> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glConvolutionParameteriv(uint,uint,const int*)
            cppSelf->glConvolutionParameteriv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glCopyColorSubTable(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glCopyColorSubTable", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glCopyColorSubTable(uint,int,int,int,int)
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
        overloadId = 0; // glCopyColorSubTable(uint,int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glCopyColorSubTable", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glCopyColorSubTable(uint,int,int,int,int)
            cppSelf->glCopyColorSubTable(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glCopyColorTable(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glCopyColorTable", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glCopyColorTable(uint,uint,int,int,int)
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
        overloadId = 0; // glCopyColorTable(uint,uint,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glCopyColorTable", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glCopyColorTable(uint,uint,int,int,int)
            cppSelf->glCopyColorTable(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glCopyConvolutionFilter1D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glCopyConvolutionFilter1D", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glCopyConvolutionFilter1D(uint,uint,int,int,int)
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
        overloadId = 0; // glCopyConvolutionFilter1D(uint,uint,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glCopyConvolutionFilter1D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glCopyConvolutionFilter1D(uint,uint,int,int,int)
            cppSelf->glCopyConvolutionFilter1D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glCopyConvolutionFilter2D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glCopyConvolutionFilter2D", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glCopyConvolutionFilter2D(uint,uint,int,int,int,int)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
        overloadId = 0; // glCopyConvolutionFilter2D(uint,uint,int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glCopyConvolutionFilter2D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glCopyConvolutionFilter2D(uint,uint,int,int,int,int)
            cppSelf->glCopyConvolutionFilter2D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glCopyPixels(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glCopyPixels", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glCopyPixels(int,int,int,int,uint)
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[4])))) {
        overloadId = 0; // glCopyPixels(int,int,int,int,uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glCopyPixels", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        unsigned int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glCopyPixels(int,int,int,int,uint)
            cppSelf->glCopyPixels(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glCopyTexImage1D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glCopyTexImage1D", 7, 7, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glCopyTexImage1D(uint,int,uint,int,int,int,int)
    if (numArgs == 7
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))) {
        overloadId = 0; // glCopyTexImage1D(uint,int,uint,int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glCopyTexImage1D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        int cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glCopyTexImage1D(uint,int,uint,int,int,int,int)
            cppSelf->glCopyTexImage1D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glCopyTexImage2D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glCopyTexImage2D", 8, 8, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glCopyTexImage2D(uint,int,uint,int,int,int,int,int)
    if (numArgs == 8
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))) {
        overloadId = 0; // glCopyTexImage2D(uint,int,uint,int,int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glCopyTexImage2D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        int cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);
        int cppArg7;
        pythonToCpp[7](pyArgs[7], &cppArg7);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glCopyTexImage2D(uint,int,uint,int,int,int,int,int)
            cppSelf->glCopyTexImage2D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glCopyTexSubImage1D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glCopyTexSubImage1D", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glCopyTexSubImage1D(uint,int,int,int,int,int)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
        overloadId = 0; // glCopyTexSubImage1D(uint,int,int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glCopyTexSubImage1D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glCopyTexSubImage1D(uint,int,int,int,int,int)
            cppSelf->glCopyTexSubImage1D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glCopyTexSubImage2D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glCopyTexSubImage2D", 8, 8, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glCopyTexSubImage2D(uint,int,int,int,int,int,int,int)
    if (numArgs == 8
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))) {
        overloadId = 0; // glCopyTexSubImage2D(uint,int,int,int,int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glCopyTexSubImage2D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        int cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);
        int cppArg7;
        pythonToCpp[7](pyArgs[7], &cppArg7);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glCopyTexSubImage2D(uint,int,int,int,int,int,int,int)
            cppSelf->glCopyTexSubImage2D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glCopyTexSubImage3D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glCopyTexSubImage3D", 9, 9, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glCopyTexSubImage3D(uint,int,int,int,int,int,int,int,int)
    if (numArgs == 9
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))
        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8])))) {
        overloadId = 0; // glCopyTexSubImage3D(uint,int,int,int,int,int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glCopyTexSubImage3D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        int cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);
        int cppArg7;
        pythonToCpp[7](pyArgs[7], &cppArg7);
        int cppArg8;
        pythonToCpp[8](pyArgs[8], &cppArg8);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glCopyTexSubImage3D(uint,int,int,int,int,int,int,int,int)
            cppSelf->glCopyTexSubImage3D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glCullFace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glCullFace(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glCullFace(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glCullFace", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glCullFace(uint)
            cppSelf->glCullFace(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glDeleteLists(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glDeleteLists", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glDeleteLists(uint,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // glDeleteLists(uint,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glDeleteLists", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glDeleteLists(uint,int)
            cppSelf->glDeleteLists(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glDeleteTextures(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glDeleteTextures", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glDeleteTextures(int,const uint*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<unsigned int>(1), -1, -1, (pyArgs[1])))) {
        overloadId = 0; // glDeleteTextures(int,const uint*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glDeleteTextures", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        Shiboken::Conversions::ArrayHandle<unsigned int> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glDeleteTextures(int,const uint*)
            cppSelf->glDeleteTextures(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glDepthFunc(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glDepthFunc(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glDepthFunc(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glDepthFunc", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glDepthFunc(uint)
            cppSelf->glDepthFunc(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glDepthMask(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glDepthMask(uchar)
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArg)))) {
        overloadId = 0; // glDepthMask(uchar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glDepthMask", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned char cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glDepthMask(uchar)
            cppSelf->glDepthMask(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glDepthRange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glDepthRange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glDepthRange(double,double)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))) {
        overloadId = 0; // glDepthRange(double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glDepthRange", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glDepthRange(double,double)
            cppSelf->glDepthRange(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glDisable(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glDisable(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glDisable(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glDisable", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glDisable(uint)
            cppSelf->glDisable(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glDisableClientState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glDisableClientState(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glDisableClientState(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glDisableClientState", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glDisableClientState(uint)
            cppSelf->glDisableClientState(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glDrawArrays(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glDrawArrays", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glDrawArrays(uint,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // glDrawArrays(uint,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glDrawArrays", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glDrawArrays(uint,int,int)
            cppSelf->glDrawArrays(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glDrawBuffer(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glDrawBuffer(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glDrawBuffer(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glDrawBuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glDrawBuffer(uint)
            cppSelf->glDrawBuffer(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glDrawElements(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glDrawElements", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glDrawElements(uint,int,uint,const void*)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[3])))) {
        overloadId = 0; // glDrawElements(uint,int,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glDrawElements", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        void* cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glDrawElements(uint,int,uint,const void*)
            cppSelf->glDrawElements(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glDrawPixels(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glDrawPixels", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glDrawPixels(int,int,uint,uint,const void*)
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[4])))) {
        overloadId = 0; // glDrawPixels(int,int,uint,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glDrawPixels", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        unsigned int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        void* cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glDrawPixels(int,int,uint,uint,const void*)
            cppSelf->glDrawPixels(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glDrawRangeElements(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glDrawRangeElements", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glDrawRangeElements(uint,uint,uint,int,uint,const void*)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[5])))) {
        overloadId = 0; // glDrawRangeElements(uint,uint,uint,int,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glDrawRangeElements", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        unsigned int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        void* cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glDrawRangeElements(uint,uint,uint,int,uint,const void*)
            cppSelf->glDrawRangeElements(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEdgeFlag(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEdgeFlag(uchar)
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArg)))) {
        overloadId = 0; // glEdgeFlag(uchar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glEdgeFlag", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned char cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEdgeFlag(uchar)
            cppSelf->glEdgeFlag(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEdgeFlagPointer(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glEdgeFlagPointer", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEdgeFlagPointer(int,const void*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
        overloadId = 0; // glEdgeFlagPointer(int,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glEdgeFlagPointer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        void* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEdgeFlagPointer(int,const void*)
            cppSelf->glEdgeFlagPointer(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEnable(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEnable(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glEnable(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glEnable", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEnable(uint)
            cppSelf->glEnable(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEnableClientState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEnableClientState(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glEnableClientState(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glEnableClientState", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEnableClientState(uint)
            cppSelf->glEnableClientState(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEnd(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glEnd()
        cppSelf->glEnd();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEndList(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glEndList()
        cppSelf->glEndList();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEvalCoord1d(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEvalCoord1d(double)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // glEvalCoord1d(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glEvalCoord1d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEvalCoord1d(double)
            cppSelf->glEvalCoord1d(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEvalCoord1dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEvalCoord1dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glEvalCoord1dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glEvalCoord1dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEvalCoord1dv(const double*)
            cppSelf->glEvalCoord1dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEvalCoord1f(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEvalCoord1f(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // glEvalCoord1f(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glEvalCoord1f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEvalCoord1f(float)
            cppSelf->glEvalCoord1f(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEvalCoord1fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEvalCoord1fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glEvalCoord1fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glEvalCoord1fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEvalCoord1fv(const float*)
            cppSelf->glEvalCoord1fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEvalCoord2d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glEvalCoord2d", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEvalCoord2d(double,double)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))) {
        overloadId = 0; // glEvalCoord2d(double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glEvalCoord2d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEvalCoord2d(double,double)
            cppSelf->glEvalCoord2d(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEvalCoord2dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEvalCoord2dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glEvalCoord2dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glEvalCoord2dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEvalCoord2dv(const double*)
            cppSelf->glEvalCoord2dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEvalCoord2f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glEvalCoord2f", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEvalCoord2f(float,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // glEvalCoord2f(float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glEvalCoord2f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEvalCoord2f(float,float)
            cppSelf->glEvalCoord2f(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEvalCoord2fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEvalCoord2fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glEvalCoord2fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glEvalCoord2fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEvalCoord2fv(const float*)
            cppSelf->glEvalCoord2fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEvalMesh1(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glEvalMesh1", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEvalMesh1(uint,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // glEvalMesh1(uint,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glEvalMesh1", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEvalMesh1(uint,int,int)
            cppSelf->glEvalMesh1(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEvalMesh2(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glEvalMesh2", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEvalMesh2(uint,int,int,int,int)
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
        overloadId = 0; // glEvalMesh2(uint,int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glEvalMesh2", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEvalMesh2(uint,int,int,int,int)
            cppSelf->glEvalMesh2(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEvalPoint1(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEvalPoint1(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // glEvalPoint1(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glEvalPoint1", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEvalPoint1(int)
            cppSelf->glEvalPoint1(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glEvalPoint2(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glEvalPoint2", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glEvalPoint2(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // glEvalPoint2(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glEvalPoint2", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glEvalPoint2(int,int)
            cppSelf->glEvalPoint2(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glFinish(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glFinish()
        cppSelf->glFinish();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glFlush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glFlush()
        cppSelf->glFlush();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glFogf(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glFogf", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glFogf(uint,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // glFogf(uint,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glFogf", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glFogf(uint,float)
            cppSelf->glFogf(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glFogfv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glFogfv", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glFogfv(uint,const float*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && PyFloat_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[1])))) {
        overloadId = 0; // glFogfv(uint,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glFogfv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        Shiboken::Conversions::ArrayHandle<float> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glFogfv(uint,const float*)
            cppSelf->glFogfv(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glFogi(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glFogi", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glFogi(uint,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // glFogi(uint,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glFogi", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glFogi(uint,int)
            cppSelf->glFogi(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glFogiv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glFogiv", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glFogiv(uint,const int*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArgs[1])))) {
        overloadId = 0; // glFogiv(uint,const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glFogiv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        Shiboken::Conversions::ArrayHandle<int> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glFogiv(uint,const int*)
            cppSelf->glFogiv(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glFrontFace(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glFrontFace(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glFrontFace(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glFrontFace", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glFrontFace(uint)
            cppSelf->glFrontFace(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glFrustum(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glFrustum", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glFrustum(double,double,double,double,double,double)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[5])))) {
        overloadId = 0; // glFrustum(double,double,double,double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glFrustum", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        double cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        double cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        double cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glFrustum(double,double,double,double,double,double)
            cppSelf->glFrustum(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glGenLists(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glGenLists(int)->unsigned int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // glGenLists(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glGenLists", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glGenLists(int)
            unsigned int cppResult = cppSelf->glGenLists(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glGetBooleanv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glGetBooleanv(uint,uchar*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glGetBooleanv(uint,uchar*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glGetBooleanv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glGetBooleanv(uint,uchar*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qopenglfunctions-glgetbooleanv)]
            const int size = glGetVReturnSize(cppArg0);
            QVarLengthArray<GLboolean> result(size, GL_FALSE);
            cppSelf->glGetBooleanv(cppArg0, result.data());
            if (size == 1) {
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &result[0]);
            } else {
                pyResult = Shiboken::Numpy::createByteArray1(size, result.constData());
            }
            // END of custom code block [file: ../glue/qtgui.cpp (qopenglfunctions-glgetbooleanv)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glGetColorTable(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glGetColorTable", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glGetColorTable(uint,uint,uint,void*)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[3])))) {
        overloadId = 0; // glGetColorTable(uint,uint,uint,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glGetColorTable", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        void* cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glGetColorTable(uint,uint,uint,void*)
            cppSelf->glGetColorTable(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glGetConvolutionFilter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glGetConvolutionFilter", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glGetConvolutionFilter(uint,uint,uint,void*)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[3])))) {
        overloadId = 0; // glGetConvolutionFilter(uint,uint,uint,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glGetConvolutionFilter", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        void* cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glGetConvolutionFilter(uint,uint,uint,void*)
            cppSelf->glGetConvolutionFilter(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glGetDoublev(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glGetDoublev(uint,double*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glGetDoublev(uint,double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glGetDoublev", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glGetDoublev(uint,double*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qopenglfunctions-glgetdoublev)]
            const int size = glGetVReturnSize(cppArg0);
            QVarLengthArray<GLdouble> result(size, 0);
            cppSelf->glGetDoublev(cppArg0, result.data());
            if (size == 1) {
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<double>(), &result[0]);
            } else {
                pyResult = Shiboken::Numpy::createDoubleArray1(size, result.constData());
            }
            // END of custom code block [file: ../glue/qtgui.cpp (qopenglfunctions-glgetdoublev)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glGetError(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glGetError()
        unsigned int cppResult = cppSelf->glGetError();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glGetFloatv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glGetFloatv(uint,float*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glGetFloatv(uint,float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glGetFloatv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glGetFloatv(uint,float*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qopenglfunctions-glgetfloatv)]
            const int size = glGetVReturnSize(cppArg0);
            QVarLengthArray<GLfloat> result(size, 0);
            cppSelf->glGetFloatv(cppArg0, result.data());
            if (size == 1) {
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<float>(), &result[0]);
            } else {
                pyResult = Shiboken::Numpy::createFloatArray1(size, result.constData());
            }
            // END of custom code block [file: ../glue/qtgui.cpp (qopenglfunctions-glgetfloatv)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glGetHistogram(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glGetHistogram", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glGetHistogram(uint,uchar,uint,uint,void*)
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[4])))) {
        overloadId = 0; // glGetHistogram(uint,uchar,uint,uint,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glGetHistogram", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned char cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        unsigned int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        void* cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glGetHistogram(uint,uchar,uint,uint,void*)
            cppSelf->glGetHistogram(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glGetIntegerv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glGetIntegerv(uint,int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glGetIntegerv(uint,int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glGetIntegerv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glGetIntegerv(uint,int*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtgui.cpp (qopenglfunctions-glgetintegerv)]
            const int size = glGetVReturnSize(cppArg0);
            QVarLengthArray<GLint> result(size, 0);
            cppSelf->glGetIntegerv(cppArg0, result.data());
            if (size == 1) {
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &result[0]);
            } else {
                pyResult = Shiboken::Numpy::createIntArray1(size, result.constData());
            }
            // END of custom code block [file: ../glue/qtgui.cpp (qopenglfunctions-glgetintegerv)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glGetMinmax(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glGetMinmax", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glGetMinmax(uint,uchar,uint,uint,void*)
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[4])))) {
        overloadId = 0; // glGetMinmax(uint,uchar,uint,uint,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glGetMinmax", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned char cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        unsigned int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        void* cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glGetMinmax(uint,uchar,uint,uint,void*)
            cppSelf->glGetMinmax(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glGetSeparableFilter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glGetSeparableFilter", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glGetSeparableFilter(uint,uint,uint,void*,void*,void*)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[5])))) {
        overloadId = 0; // glGetSeparableFilter(uint,uint,uint,void*,void*,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glGetSeparableFilter", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        void* cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        void* cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        void* cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glGetSeparableFilter(uint,uint,uint,void*,void*,void*)
            cppSelf->glGetSeparableFilter(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glGetString(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glGetString(uint)->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glGetString(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glGetString", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glGetString(uint)
            // Begin code injection
            // TEMPLATE - glGetString_return_QString - START
            const GLubyte *us = cppSelf->glGetString(cppArg0);
            const QString s = QString::fromLocal8Bit(reinterpret_cast<const char *>(us));
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &s);
            // TEMPLATE - glGetString_return_QString - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glGetTexImage(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glGetTexImage", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glGetTexImage(uint,int,uint,uint,void*)
    if (numArgs == 5
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[4])))) {
        overloadId = 0; // glGetTexImage(uint,int,uint,uint,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glGetTexImage", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        unsigned int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        void* cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glGetTexImage(uint,int,uint,uint,void*)
            cppSelf->glGetTexImage(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glHint(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glHint", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glHint(uint,uint)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))) {
        overloadId = 0; // glHint(uint,uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glHint", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glHint(uint,uint)
            cppSelf->glHint(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glHistogram(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glHistogram", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glHistogram(uint,int,uint,uchar)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))
        && SbkChar_Check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[3])))) {
        overloadId = 0; // glHistogram(uint,int,uint,uchar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glHistogram", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        unsigned char cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glHistogram(uint,int,uint,uchar)
            cppSelf->glHistogram(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIndexMask(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIndexMask(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glIndexMask(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIndexMask", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIndexMask(uint)
            cppSelf->glIndexMask(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIndexPointer(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glIndexPointer", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIndexPointer(uint,int,const void*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))) {
        overloadId = 0; // glIndexPointer(uint,int,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glIndexPointer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        void* cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIndexPointer(uint,int,const void*)
            cppSelf->glIndexPointer(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIndexd(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIndexd(double)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // glIndexd(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIndexd", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIndexd(double)
            cppSelf->glIndexd(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIndexdv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIndexdv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glIndexdv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIndexdv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIndexdv(const double*)
            cppSelf->glIndexdv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIndexf(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIndexf(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // glIndexf(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIndexf", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIndexf(float)
            cppSelf->glIndexf(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIndexfv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIndexfv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glIndexfv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIndexfv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIndexfv(const float*)
            cppSelf->glIndexfv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIndexi(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIndexi(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // glIndexi(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIndexi", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIndexi(int)
            cppSelf->glIndexi(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIndexiv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIndexiv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glIndexiv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIndexiv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIndexiv(const int*)
            cppSelf->glIndexiv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIndexs(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIndexs(short)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArg)))) {
        overloadId = 0; // glIndexs(short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIndexs", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIndexs(short)
            cppSelf->glIndexs(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIndexsv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIndexsv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glIndexsv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIndexsv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIndexsv(const short*)
            cppSelf->glIndexsv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIndexub(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIndexub(uchar)
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArg)))) {
        overloadId = 0; // glIndexub(uchar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIndexub", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned char cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIndexub(uchar)
            cppSelf->glIndexub(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIndexubv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIndexubv(const uchar*)
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<unsigned char>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glIndexubv(const uchar*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIndexubv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<unsigned char> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIndexubv(const uchar*)
            cppSelf->glIndexubv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glInitNames(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glInitNames()
        cppSelf->glInitNames();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glInterleavedArrays(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glInterleavedArrays", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glInterleavedArrays(uint,int,const void*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))) {
        overloadId = 0; // glInterleavedArrays(uint,int,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glInterleavedArrays", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        void* cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glInterleavedArrays(uint,int,const void*)
            cppSelf->glInterleavedArrays(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIsEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIsEnabled(uint)->unsigned char
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glIsEnabled(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIsEnabled", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIsEnabled(uint)
            unsigned char cppResult = cppSelf->glIsEnabled(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIsList(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIsList(uint)->unsigned char
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glIsList(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIsList", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIsList(uint)
            unsigned char cppResult = cppSelf->glIsList(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glIsTexture(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glIsTexture(uint)->unsigned char
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glIsTexture(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glIsTexture", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glIsTexture(uint)
            unsigned char cppResult = cppSelf->glIsTexture(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLightModelf(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glLightModelf", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLightModelf(uint,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // glLightModelf(uint,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glLightModelf", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLightModelf(uint,float)
            cppSelf->glLightModelf(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLightModelfv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glLightModelfv", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLightModelfv(uint,const float*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && PyFloat_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[1])))) {
        overloadId = 0; // glLightModelfv(uint,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glLightModelfv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        Shiboken::Conversions::ArrayHandle<float> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLightModelfv(uint,const float*)
            cppSelf->glLightModelfv(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLightModeli(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glLightModeli", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLightModeli(uint,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // glLightModeli(uint,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glLightModeli", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLightModeli(uint,int)
            cppSelf->glLightModeli(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLightModeliv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glLightModeliv", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLightModeliv(uint,const int*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArgs[1])))) {
        overloadId = 0; // glLightModeliv(uint,const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glLightModeliv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        Shiboken::Conversions::ArrayHandle<int> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLightModeliv(uint,const int*)
            cppSelf->glLightModeliv(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLightf(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glLightf", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLightf(uint,uint,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glLightf(uint,uint,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glLightf", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLightf(uint,uint,float)
            cppSelf->glLightf(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLightfv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glLightfv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLightfv(uint,uint,const float*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && PyFloat_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glLightfv(uint,uint,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glLightfv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<float> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLightfv(uint,uint,const float*)
            cppSelf->glLightfv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLighti(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glLighti", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLighti(uint,uint,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // glLighti(uint,uint,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glLighti", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLighti(uint,uint,int)
            cppSelf->glLighti(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLightiv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glLightiv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLightiv(uint,uint,const int*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glLightiv(uint,uint,const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glLightiv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<int> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLightiv(uint,uint,const int*)
            cppSelf->glLightiv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLineStipple(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glLineStipple", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLineStipple(int,ushort)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), (pyArgs[1])))) {
        overloadId = 0; // glLineStipple(int,ushort)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glLineStipple", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLineStipple(int,ushort)
            cppSelf->glLineStipple(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLineWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLineWidth(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // glLineWidth(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glLineWidth", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLineWidth(float)
            cppSelf->glLineWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glListBase(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glListBase(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glListBase(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glListBase", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glListBase(uint)
            cppSelf->glListBase(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLoadIdentity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glLoadIdentity()
        cppSelf->glLoadIdentity();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLoadMatrixd(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLoadMatrixd(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glLoadMatrixd(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glLoadMatrixd", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLoadMatrixd(const double*)
            cppSelf->glLoadMatrixd(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLoadMatrixf(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLoadMatrixf(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glLoadMatrixf(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glLoadMatrixf", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLoadMatrixf(const float*)
            cppSelf->glLoadMatrixf(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLoadName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLoadName(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glLoadName(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glLoadName", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLoadName(uint)
            cppSelf->glLoadName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glLogicOp(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glLogicOp(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glLogicOp(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glLogicOp", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glLogicOp(uint)
            cppSelf->glLogicOp(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMap1d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glMap1d", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMap1d(uint,double,double,int,int,const double*)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && PyFloat_Check(pyArgs[5]) && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArgs[5])))) {
        overloadId = 0; // glMap1d(uint,double,double,int,int,const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glMap1d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        Shiboken::Conversions::ArrayHandle<double> cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMap1d(uint,double,double,int,int,const double*)
            cppSelf->glMap1d(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMap1f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glMap1f", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMap1f(uint,float,float,int,int,const float*)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && PyFloat_Check(pyArgs[5]) && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[5])))) {
        overloadId = 0; // glMap1f(uint,float,float,int,int,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glMap1f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        Shiboken::Conversions::ArrayHandle<float> cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMap1f(uint,float,float,int,int,const float*)
            cppSelf->glMap1f(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMap2d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[10];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glMap2d", 10, 10, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMap2d(uint,double,double,int,int,double,double,int,int,const double*)
    if (numArgs == 10
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))
        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8])))
        && PyFloat_Check(pyArgs[9]) && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArgs[9])))) {
        overloadId = 0; // glMap2d(uint,double,double,int,int,double,double,int,int,const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glMap2d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        double cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        double cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);
        int cppArg7;
        pythonToCpp[7](pyArgs[7], &cppArg7);
        int cppArg8;
        pythonToCpp[8](pyArgs[8], &cppArg8);
        Shiboken::Conversions::ArrayHandle<double> cppArg9;
        pythonToCpp[9](pyArgs[9], &cppArg9);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMap2d(uint,double,double,int,int,double,double,int,int,const double*)
            cppSelf->glMap2d(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMap2f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[10];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glMap2f", 10, 10, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMap2f(uint,float,float,int,int,float,float,int,int,const float*)
    if (numArgs == 10
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))
        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8])))
        && PyFloat_Check(pyArgs[9]) && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[9])))) {
        overloadId = 0; // glMap2f(uint,float,float,int,int,float,float,int,int,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glMap2f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        float cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        float cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);
        int cppArg7;
        pythonToCpp[7](pyArgs[7], &cppArg7);
        int cppArg8;
        pythonToCpp[8](pyArgs[8], &cppArg8);
        Shiboken::Conversions::ArrayHandle<float> cppArg9;
        pythonToCpp[9](pyArgs[9], &cppArg9);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMap2f(uint,float,float,int,int,float,float,int,int,const float*)
            cppSelf->glMap2f(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMapGrid1d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glMapGrid1d", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMapGrid1d(int,double,double)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))) {
        overloadId = 0; // glMapGrid1d(int,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glMapGrid1d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMapGrid1d(int,double,double)
            cppSelf->glMapGrid1d(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMapGrid1f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glMapGrid1f", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMapGrid1f(int,float,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glMapGrid1f(int,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glMapGrid1f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMapGrid1f(int,float,float)
            cppSelf->glMapGrid1f(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMapGrid2d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glMapGrid2d", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMapGrid2d(int,double,double,int,double,double)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[5])))) {
        overloadId = 0; // glMapGrid2d(int,double,double,int,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glMapGrid2d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        double cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        double cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMapGrid2d(int,double,double,int,double,double)
            cppSelf->glMapGrid2d(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMapGrid2f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glMapGrid2f", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMapGrid2f(int,float,float,int,float,float)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[5])))) {
        overloadId = 0; // glMapGrid2f(int,float,float,int,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glMapGrid2f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        float cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        float cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMapGrid2f(int,float,float,int,float,float)
            cppSelf->glMapGrid2f(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMaterialf(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glMaterialf", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMaterialf(uint,uint,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glMaterialf(uint,uint,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glMaterialf", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMaterialf(uint,uint,float)
            cppSelf->glMaterialf(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMaterialfv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glMaterialfv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMaterialfv(uint,uint,const float*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && PyFloat_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glMaterialfv(uint,uint,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glMaterialfv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<float> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMaterialfv(uint,uint,const float*)
            cppSelf->glMaterialfv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMateriali(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glMateriali", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMateriali(uint,uint,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // glMateriali(uint,uint,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glMateriali", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMateriali(uint,uint,int)
            cppSelf->glMateriali(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMaterialiv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glMaterialiv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMaterialiv(uint,uint,const int*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glMaterialiv(uint,uint,const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glMaterialiv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<int> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMaterialiv(uint,uint,const int*)
            cppSelf->glMaterialiv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMatrixMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMatrixMode(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glMatrixMode(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glMatrixMode", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMatrixMode(uint)
            cppSelf->glMatrixMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMinmax(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glMinmax", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMinmax(uint,uint,uchar)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), (pyArgs[2])))) {
        overloadId = 0; // glMinmax(uint,uint,uchar)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glMinmax", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned char cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMinmax(uint,uint,uchar)
            cppSelf->glMinmax(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMultMatrixd(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMultMatrixd(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glMultMatrixd(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glMultMatrixd", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMultMatrixd(const double*)
            cppSelf->glMultMatrixd(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glMultMatrixf(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glMultMatrixf(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glMultMatrixf(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glMultMatrixf", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glMultMatrixf(const float*)
            cppSelf->glMultMatrixf(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glNewList(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glNewList", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glNewList(uint,uint)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))) {
        overloadId = 0; // glNewList(uint,uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glNewList", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glNewList(uint,uint)
            cppSelf->glNewList(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glNormal3b(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glNormal3b", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glNormal3b(signed char,signed char,signed char)
    if (numArgs == 3
        && SbkChar_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), (pyArgs[0])))
        && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), (pyArgs[1])))
        && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), (pyArgs[2])))) {
        overloadId = 0; // glNormal3b(signed char,signed char,signed char)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glNormal3b", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        signed char cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        signed char cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        signed char cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glNormal3b(signed char,signed char,signed char)
            cppSelf->glNormal3b(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glNormal3bv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glNormal3bv(const signed char*)
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<signed char>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glNormal3bv(const signed char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glNormal3bv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<signed char> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glNormal3bv(const signed char*)
            cppSelf->glNormal3bv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glNormal3d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glNormal3d", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glNormal3d(double,double,double)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))) {
        overloadId = 0; // glNormal3d(double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glNormal3d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glNormal3d(double,double,double)
            cppSelf->glNormal3d(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glNormal3dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glNormal3dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glNormal3dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glNormal3dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glNormal3dv(const double*)
            cppSelf->glNormal3dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glNormal3f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glNormal3f", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glNormal3f(float,float,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glNormal3f(float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glNormal3f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glNormal3f(float,float,float)
            cppSelf->glNormal3f(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glNormal3fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glNormal3fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glNormal3fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glNormal3fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glNormal3fv(const float*)
            cppSelf->glNormal3fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glNormal3i(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glNormal3i", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glNormal3i(int,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // glNormal3i(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glNormal3i", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glNormal3i(int,int,int)
            cppSelf->glNormal3i(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glNormal3iv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glNormal3iv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glNormal3iv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glNormal3iv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glNormal3iv(const int*)
            cppSelf->glNormal3iv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glNormal3s(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glNormal3s", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glNormal3s(short,short,short)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[2])))) {
        overloadId = 0; // glNormal3s(short,short,short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glNormal3s", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        short cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glNormal3s(short,short,short)
            cppSelf->glNormal3s(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glNormal3sv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glNormal3sv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glNormal3sv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glNormal3sv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glNormal3sv(const short*)
            cppSelf->glNormal3sv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glNormalPointer(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glNormalPointer", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glNormalPointer(uint,int,const void*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[2])))) {
        overloadId = 0; // glNormalPointer(uint,int,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glNormalPointer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        void* cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glNormalPointer(uint,int,const void*)
            cppSelf->glNormalPointer(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glOrtho(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glOrtho", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glOrtho(double,double,double,double,double,double)
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[5])))) {
        overloadId = 0; // glOrtho(double,double,double,double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glOrtho", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        double cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        double cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        double cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glOrtho(double,double,double,double,double,double)
            cppSelf->glOrtho(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPassThrough(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPassThrough(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // glPassThrough(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glPassThrough", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPassThrough(float)
            cppSelf->glPassThrough(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPixelMapfv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glPixelMapfv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPixelMapfv(uint,int,const float*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && PyFloat_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glPixelMapfv(uint,int,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glPixelMapfv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<float> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPixelMapfv(uint,int,const float*)
            cppSelf->glPixelMapfv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPixelMapuiv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glPixelMapuiv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPixelMapuiv(uint,int,const uint*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<unsigned int>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glPixelMapuiv(uint,int,const uint*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glPixelMapuiv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<unsigned int> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPixelMapuiv(uint,int,const uint*)
            cppSelf->glPixelMapuiv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPixelMapusv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glPixelMapusv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPixelMapusv(uint,int,const ushort*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<unsigned short>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glPixelMapusv(uint,int,const ushort*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glPixelMapusv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<unsigned short> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPixelMapusv(uint,int,const ushort*)
            cppSelf->glPixelMapusv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPixelStoref(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glPixelStoref", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPixelStoref(uint,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // glPixelStoref(uint,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glPixelStoref", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPixelStoref(uint,float)
            cppSelf->glPixelStoref(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPixelStorei(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glPixelStorei", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPixelStorei(uint,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // glPixelStorei(uint,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glPixelStorei", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPixelStorei(uint,int)
            cppSelf->glPixelStorei(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPixelTransferf(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glPixelTransferf", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPixelTransferf(uint,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // glPixelTransferf(uint,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glPixelTransferf", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPixelTransferf(uint,float)
            cppSelf->glPixelTransferf(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPixelTransferi(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glPixelTransferi", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPixelTransferi(uint,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // glPixelTransferi(uint,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glPixelTransferi", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPixelTransferi(uint,int)
            cppSelf->glPixelTransferi(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPixelZoom(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glPixelZoom", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPixelZoom(float,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // glPixelZoom(float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glPixelZoom", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPixelZoom(float,float)
            cppSelf->glPixelZoom(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPointSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPointSize(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // glPointSize(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glPointSize", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPointSize(float)
            cppSelf->glPointSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPolygonMode(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glPolygonMode", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPolygonMode(uint,uint)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))) {
        overloadId = 0; // glPolygonMode(uint,uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glPolygonMode", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPolygonMode(uint,uint)
            cppSelf->glPolygonMode(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPolygonOffset(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glPolygonOffset", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPolygonOffset(float,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // glPolygonOffset(float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glPolygonOffset", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPolygonOffset(float,float)
            cppSelf->glPolygonOffset(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPopAttrib(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glPopAttrib()
        cppSelf->glPopAttrib();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPopClientAttrib(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glPopClientAttrib()
        cppSelf->glPopClientAttrib();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPopMatrix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glPopMatrix()
        cppSelf->glPopMatrix();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPopName(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glPopName()
        cppSelf->glPopName();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPrioritizeTextures(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glPrioritizeTextures", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPrioritizeTextures(int,const uint*,const float*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<unsigned int>(1), -1, -1, (pyArgs[1])))
        && PyFloat_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glPrioritizeTextures(int,const uint*,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glPrioritizeTextures", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        Shiboken::Conversions::ArrayHandle<unsigned int> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<float> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPrioritizeTextures(int,const uint*,const float*)
            cppSelf->glPrioritizeTextures(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPushAttrib(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPushAttrib(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glPushAttrib(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glPushAttrib", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPushAttrib(uint)
            cppSelf->glPushAttrib(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPushClientAttrib(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPushClientAttrib(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glPushClientAttrib(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glPushClientAttrib", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPushClientAttrib(uint)
            cppSelf->glPushClientAttrib(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPushMatrix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // glPushMatrix()
        cppSelf->glPushMatrix();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glPushName(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glPushName(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glPushName(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glPushName", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glPushName(uint)
            cppSelf->glPushName(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos2d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRasterPos2d", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos2d(double,double)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))) {
        overloadId = 0; // glRasterPos2d(double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRasterPos2d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos2d(double,double)
            cppSelf->glRasterPos2d(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos2dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos2dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glRasterPos2dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glRasterPos2dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos2dv(const double*)
            cppSelf->glRasterPos2dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos2f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRasterPos2f", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos2f(float,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // glRasterPos2f(float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRasterPos2f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos2f(float,float)
            cppSelf->glRasterPos2f(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos2fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos2fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glRasterPos2fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glRasterPos2fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos2fv(const float*)
            cppSelf->glRasterPos2fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos2i(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRasterPos2i", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos2i(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // glRasterPos2i(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRasterPos2i", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos2i(int,int)
            cppSelf->glRasterPos2i(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos2iv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos2iv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glRasterPos2iv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glRasterPos2iv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos2iv(const int*)
            cppSelf->glRasterPos2iv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos2s(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRasterPos2s", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos2s(short,short)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[1])))) {
        overloadId = 0; // glRasterPos2s(short,short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRasterPos2s", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos2s(short,short)
            cppSelf->glRasterPos2s(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos2sv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos2sv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glRasterPos2sv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glRasterPos2sv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos2sv(const short*)
            cppSelf->glRasterPos2sv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos3d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRasterPos3d", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos3d(double,double,double)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))) {
        overloadId = 0; // glRasterPos3d(double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRasterPos3d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos3d(double,double,double)
            cppSelf->glRasterPos3d(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos3dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos3dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glRasterPos3dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glRasterPos3dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos3dv(const double*)
            cppSelf->glRasterPos3dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos3f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRasterPos3f", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos3f(float,float,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glRasterPos3f(float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRasterPos3f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos3f(float,float,float)
            cppSelf->glRasterPos3f(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos3fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos3fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glRasterPos3fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glRasterPos3fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos3fv(const float*)
            cppSelf->glRasterPos3fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos3i(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRasterPos3i", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos3i(int,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // glRasterPos3i(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRasterPos3i", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos3i(int,int,int)
            cppSelf->glRasterPos3i(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos3iv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos3iv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glRasterPos3iv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glRasterPos3iv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos3iv(const int*)
            cppSelf->glRasterPos3iv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos3s(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRasterPos3s", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos3s(short,short,short)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[2])))) {
        overloadId = 0; // glRasterPos3s(short,short,short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRasterPos3s", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        short cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos3s(short,short,short)
            cppSelf->glRasterPos3s(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos3sv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos3sv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glRasterPos3sv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glRasterPos3sv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos3sv(const short*)
            cppSelf->glRasterPos3sv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos4d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRasterPos4d", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos4d(double,double,double,double)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[3])))) {
        overloadId = 0; // glRasterPos4d(double,double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRasterPos4d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        double cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos4d(double,double,double,double)
            cppSelf->glRasterPos4d(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos4dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos4dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glRasterPos4dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glRasterPos4dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos4dv(const double*)
            cppSelf->glRasterPos4dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos4f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRasterPos4f", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos4f(float,float,float,float)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 0; // glRasterPos4f(float,float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRasterPos4f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos4f(float,float,float,float)
            cppSelf->glRasterPos4f(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos4fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos4fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glRasterPos4fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glRasterPos4fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos4fv(const float*)
            cppSelf->glRasterPos4fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos4i(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRasterPos4i", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos4i(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // glRasterPos4i(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRasterPos4i", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos4i(int,int,int,int)
            cppSelf->glRasterPos4i(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos4iv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos4iv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glRasterPos4iv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glRasterPos4iv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos4iv(const int*)
            cppSelf->glRasterPos4iv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos4s(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRasterPos4s", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos4s(short,short,short,short)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[3])))) {
        overloadId = 0; // glRasterPos4s(short,short,short,short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRasterPos4s", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        short cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        short cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos4s(short,short,short,short)
            cppSelf->glRasterPos4s(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRasterPos4sv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRasterPos4sv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glRasterPos4sv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glRasterPos4sv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRasterPos4sv(const short*)
            cppSelf->glRasterPos4sv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glReadBuffer(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glReadBuffer(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glReadBuffer(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glReadBuffer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glReadBuffer(uint)
            cppSelf->glReadBuffer(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glReadPixels(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glReadPixels", 7, 7, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glReadPixels(int,int,int,int,uint,uint,void*)
    if (numArgs == 7
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[6])))) {
        overloadId = 0; // glReadPixels(int,int,int,int,uint,uint,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glReadPixels", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        unsigned int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        unsigned int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        void* cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glReadPixels(int,int,int,int,uint,uint,void*)
            cppSelf->glReadPixels(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRectd(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRectd", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRectd(double,double,double,double)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[3])))) {
        overloadId = 0; // glRectd(double,double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRectd", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        double cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRectd(double,double,double,double)
            cppSelf->glRectd(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRectdv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRectdv", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRectdv(const double*,const double*)
    if (numArgs == 2
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArgs[0])))
        && PyFloat_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArgs[1])))) {
        overloadId = 0; // glRectdv(const double*,const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRectdv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        Shiboken::Conversions::ArrayHandle<double> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRectdv(const double*,const double*)
            cppSelf->glRectdv(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRectf(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRectf", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRectf(float,float,float,float)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 0; // glRectf(float,float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRectf", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRectf(float,float,float,float)
            cppSelf->glRectf(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRectfv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRectfv", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRectfv(const float*,const float*)
    if (numArgs == 2
        && PyFloat_Check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[0])))
        && PyFloat_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[1])))) {
        overloadId = 0; // glRectfv(const float*,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRectfv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        Shiboken::Conversions::ArrayHandle<float> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRectfv(const float*,const float*)
            cppSelf->glRectfv(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRecti(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRecti", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRecti(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // glRecti(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRecti", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRecti(int,int,int,int)
            cppSelf->glRecti(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRectiv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRectiv", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRectiv(const int*,const int*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArgs[1])))) {
        overloadId = 0; // glRectiv(const int*,const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRectiv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        Shiboken::Conversions::ArrayHandle<int> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRectiv(const int*,const int*)
            cppSelf->glRectiv(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRects(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRects", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRects(short,short,short,short)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[3])))) {
        overloadId = 0; // glRects(short,short,short,short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRects", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        short cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        short cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRects(short,short,short,short)
            cppSelf->glRects(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRectsv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRectsv", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRectsv(const short*,const short*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArgs[1])))) {
        overloadId = 0; // glRectsv(const short*,const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRectsv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        Shiboken::Conversions::ArrayHandle<short> cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRectsv(const short*,const short*)
            cppSelf->glRectsv(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRenderMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRenderMode(uint)->int
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glRenderMode(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glRenderMode", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRenderMode(uint)
            int cppResult = cppSelf->glRenderMode(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glResetHistogram(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glResetHistogram(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glResetHistogram(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glResetHistogram", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glResetHistogram(uint)
            cppSelf->glResetHistogram(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glResetMinmax(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glResetMinmax(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glResetMinmax(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glResetMinmax", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glResetMinmax(uint)
            cppSelf->glResetMinmax(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRotated(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRotated", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRotated(double,double,double,double)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[3])))) {
        overloadId = 0; // glRotated(double,double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRotated", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        double cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRotated(double,double,double,double)
            cppSelf->glRotated(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glRotatef(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glRotatef", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glRotatef(float,float,float,float)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 0; // glRotatef(float,float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glRotatef", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glRotatef(float,float,float,float)
            cppSelf->glRotatef(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glScaled(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glScaled", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glScaled(double,double,double)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))) {
        overloadId = 0; // glScaled(double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glScaled", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glScaled(double,double,double)
            cppSelf->glScaled(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glScalef(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glScalef", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glScalef(float,float,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glScalef(float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glScalef", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glScalef(float,float,float)
            cppSelf->glScalef(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glScissor(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glScissor", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glScissor(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // glScissor(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glScissor", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glScissor(int,int,int,int)
            cppSelf->glScissor(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glSeparableFilter2D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glSeparableFilter2D", 8, 8, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glSeparableFilter2D(uint,uint,int,int,uint,uint,const void*,const void*)
    if (numArgs == 8
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[7])))) {
        overloadId = 0; // glSeparableFilter2D(uint,uint,int,int,uint,uint,const void*,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glSeparableFilter2D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        unsigned int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        unsigned int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        void* cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);
        void* cppArg7;
        pythonToCpp[7](pyArgs[7], &cppArg7);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glSeparableFilter2D(uint,uint,int,int,uint,uint,const void*,const void*)
            cppSelf->glSeparableFilter2D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glShadeModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glShadeModel(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glShadeModel(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glShadeModel", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glShadeModel(uint)
            cppSelf->glShadeModel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glStencilFunc(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glStencilFunc", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glStencilFunc(uint,int,uint)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))) {
        overloadId = 0; // glStencilFunc(uint,int,uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glStencilFunc", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glStencilFunc(uint,int,uint)
            cppSelf->glStencilFunc(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glStencilMask(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glStencilMask(uint)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArg)))) {
        overloadId = 0; // glStencilMask(uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glStencilMask", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glStencilMask(uint)
            cppSelf->glStencilMask(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glStencilOp(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glStencilOp", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glStencilOp(uint,uint,uint)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[2])))) {
        overloadId = 0; // glStencilOp(uint,uint,uint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glStencilOp", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        unsigned int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glStencilOp(uint,uint,uint)
            cppSelf->glStencilOp(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord1d(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord1d(double)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArg)))) {
        overloadId = 0; // glTexCoord1d(double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord1d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord1d(double)
            cppSelf->glTexCoord1d(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord1dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord1dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord1dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord1dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord1dv(const double*)
            cppSelf->glTexCoord1dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord1f(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord1f(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // glTexCoord1f(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord1f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord1f(float)
            cppSelf->glTexCoord1f(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord1fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord1fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord1fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord1fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord1fv(const float*)
            cppSelf->glTexCoord1fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord1i(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord1i(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // glTexCoord1i(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord1i", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord1i(int)
            cppSelf->glTexCoord1i(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord1iv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord1iv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord1iv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord1iv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord1iv(const int*)
            cppSelf->glTexCoord1iv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord1s(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord1s(short)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArg)))) {
        overloadId = 0; // glTexCoord1s(short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord1s", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord1s(short)
            cppSelf->glTexCoord1s(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord1sv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord1sv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord1sv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord1sv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord1sv(const short*)
            cppSelf->glTexCoord1sv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord2d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexCoord2d", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord2d(double,double)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))) {
        overloadId = 0; // glTexCoord2d(double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexCoord2d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord2d(double,double)
            cppSelf->glTexCoord2d(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord2dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord2dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord2dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord2dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord2dv(const double*)
            cppSelf->glTexCoord2dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord2f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexCoord2f", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord2f(float,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // glTexCoord2f(float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexCoord2f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord2f(float,float)
            cppSelf->glTexCoord2f(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord2fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord2fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord2fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord2fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord2fv(const float*)
            cppSelf->glTexCoord2fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord2i(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexCoord2i", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord2i(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // glTexCoord2i(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexCoord2i", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord2i(int,int)
            cppSelf->glTexCoord2i(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord2iv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord2iv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord2iv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord2iv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord2iv(const int*)
            cppSelf->glTexCoord2iv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord2s(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexCoord2s", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord2s(short,short)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[1])))) {
        overloadId = 0; // glTexCoord2s(short,short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexCoord2s", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord2s(short,short)
            cppSelf->glTexCoord2s(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord2sv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord2sv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord2sv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord2sv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord2sv(const short*)
            cppSelf->glTexCoord2sv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord3d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexCoord3d", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord3d(double,double,double)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))) {
        overloadId = 0; // glTexCoord3d(double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexCoord3d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord3d(double,double,double)
            cppSelf->glTexCoord3d(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord3dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord3dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord3dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord3dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord3dv(const double*)
            cppSelf->glTexCoord3dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord3f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexCoord3f", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord3f(float,float,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glTexCoord3f(float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexCoord3f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord3f(float,float,float)
            cppSelf->glTexCoord3f(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord3fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord3fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord3fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord3fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord3fv(const float*)
            cppSelf->glTexCoord3fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord3i(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexCoord3i", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord3i(int,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // glTexCoord3i(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexCoord3i", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord3i(int,int,int)
            cppSelf->glTexCoord3i(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord3iv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord3iv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord3iv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord3iv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord3iv(const int*)
            cppSelf->glTexCoord3iv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord3s(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexCoord3s", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord3s(short,short,short)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[2])))) {
        overloadId = 0; // glTexCoord3s(short,short,short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexCoord3s", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        short cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord3s(short,short,short)
            cppSelf->glTexCoord3s(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord3sv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord3sv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord3sv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord3sv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord3sv(const short*)
            cppSelf->glTexCoord3sv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord4d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexCoord4d", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord4d(double,double,double,double)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[3])))) {
        overloadId = 0; // glTexCoord4d(double,double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexCoord4d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        double cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord4d(double,double,double,double)
            cppSelf->glTexCoord4d(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord4dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord4dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord4dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord4dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord4dv(const double*)
            cppSelf->glTexCoord4dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord4f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexCoord4f", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord4f(float,float,float,float)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 0; // glTexCoord4f(float,float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexCoord4f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord4f(float,float,float,float)
            cppSelf->glTexCoord4f(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord4fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord4fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord4fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord4fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord4fv(const float*)
            cppSelf->glTexCoord4fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord4i(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexCoord4i", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord4i(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // glTexCoord4i(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexCoord4i", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord4i(int,int,int,int)
            cppSelf->glTexCoord4i(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord4iv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord4iv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord4iv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord4iv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord4iv(const int*)
            cppSelf->glTexCoord4iv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord4s(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexCoord4s", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord4s(short,short,short,short)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[3])))) {
        overloadId = 0; // glTexCoord4s(short,short,short,short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexCoord4s", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        short cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        short cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord4s(short,short,short,short)
            cppSelf->glTexCoord4s(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoord4sv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoord4sv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glTexCoord4sv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glTexCoord4sv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoord4sv(const short*)
            cppSelf->glTexCoord4sv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexCoordPointer(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexCoordPointer", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexCoordPointer(int,uint,int,const void*)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[3])))) {
        overloadId = 0; // glTexCoordPointer(int,uint,int,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexCoordPointer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        void* cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexCoordPointer(int,uint,int,const void*)
            cppSelf->glTexCoordPointer(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexEnvf(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexEnvf", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexEnvf(uint,uint,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glTexEnvf(uint,uint,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexEnvf", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexEnvf(uint,uint,float)
            cppSelf->glTexEnvf(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexEnvfv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexEnvfv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexEnvfv(uint,uint,const float*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && PyFloat_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glTexEnvfv(uint,uint,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexEnvfv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<float> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexEnvfv(uint,uint,const float*)
            cppSelf->glTexEnvfv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexEnvi(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexEnvi", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexEnvi(uint,uint,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // glTexEnvi(uint,uint,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexEnvi", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexEnvi(uint,uint,int)
            cppSelf->glTexEnvi(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexEnviv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexEnviv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexEnviv(uint,uint,const int*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glTexEnviv(uint,uint,const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexEnviv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<int> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexEnviv(uint,uint,const int*)
            cppSelf->glTexEnviv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexGend(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexGend", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexGend(uint,uint,double)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))) {
        overloadId = 0; // glTexGend(uint,uint,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexGend", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexGend(uint,uint,double)
            cppSelf->glTexGend(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexGendv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexGendv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexGendv(uint,uint,const double*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && PyFloat_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glTexGendv(uint,uint,const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexGendv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<double> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexGendv(uint,uint,const double*)
            cppSelf->glTexGendv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexGenf(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexGenf", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexGenf(uint,uint,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glTexGenf(uint,uint,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexGenf", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexGenf(uint,uint,float)
            cppSelf->glTexGenf(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexGenfv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexGenfv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexGenfv(uint,uint,const float*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && PyFloat_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glTexGenfv(uint,uint,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexGenfv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<float> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexGenfv(uint,uint,const float*)
            cppSelf->glTexGenfv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexGeni(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexGeni", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexGeni(uint,uint,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // glTexGeni(uint,uint,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexGeni", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexGeni(uint,uint,int)
            cppSelf->glTexGeni(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexGeniv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexGeniv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexGeniv(uint,uint,const int*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glTexGeniv(uint,uint,const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexGeniv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<int> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexGeniv(uint,uint,const int*)
            cppSelf->glTexGeniv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexImage1D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexImage1D", 8, 8, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexImage1D(uint,int,int,int,int,uint,uint,const void*)
    if (numArgs == 8
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[7])))) {
        overloadId = 0; // glTexImage1D(uint,int,int,int,int,uint,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexImage1D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        unsigned int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        unsigned int cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);
        void* cppArg7;
        pythonToCpp[7](pyArgs[7], &cppArg7);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexImage1D(uint,int,int,int,int,uint,uint,const void*)
            cppSelf->glTexImage1D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexImage2D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexImage2D", 9, 9, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexImage2D(uint,int,int,int,int,int,uint,uint,const void*)
    if (numArgs == 9
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[7])))
        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[8])))) {
        overloadId = 0; // glTexImage2D(uint,int,int,int,int,int,uint,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexImage2D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        unsigned int cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);
        unsigned int cppArg7;
        pythonToCpp[7](pyArgs[7], &cppArg7);
        void* cppArg8;
        pythonToCpp[8](pyArgs[8], &cppArg8);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexImage2D(uint,int,int,int,int,int,uint,uint,const void*)
            cppSelf->glTexImage2D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexImage3D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[10];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexImage3D", 10, 10, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexImage3D(uint,int,int,int,int,int,int,uint,uint,const void*)
    if (numArgs == 10
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[7])))
        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[8])))
        && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[9])))) {
        overloadId = 0; // glTexImage3D(uint,int,int,int,int,int,int,uint,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexImage3D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        int cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);
        unsigned int cppArg7;
        pythonToCpp[7](pyArgs[7], &cppArg7);
        unsigned int cppArg8;
        pythonToCpp[8](pyArgs[8], &cppArg8);
        void* cppArg9;
        pythonToCpp[9](pyArgs[9], &cppArg9);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexImage3D(uint,int,int,int,int,int,int,uint,uint,const void*)
            cppSelf->glTexImage3D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexParameterf(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexParameterf", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexParameterf(uint,uint,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glTexParameterf(uint,uint,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexParameterf", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexParameterf(uint,uint,float)
            cppSelf->glTexParameterf(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexParameterfv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexParameterfv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexParameterfv(uint,uint,const float*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && PyFloat_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glTexParameterfv(uint,uint,const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexParameterfv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<float> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexParameterfv(uint,uint,const float*)
            cppSelf->glTexParameterfv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexParameteri(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexParameteri", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexParameteri(uint,uint,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // glTexParameteri(uint,uint,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexParameteri", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexParameteri(uint,uint,int)
            cppSelf->glTexParameteri(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexParameteriv(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexParameteriv", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexParameteriv(uint,uint,const int*)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArgs[2])))) {
        overloadId = 0; // glTexParameteriv(uint,uint,const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexParameteriv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        Shiboken::Conversions::ArrayHandle<int> cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexParameteriv(uint,uint,const int*)
            cppSelf->glTexParameteriv(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexSubImage1D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexSubImage1D", 7, 7, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexSubImage1D(uint,int,int,int,uint,uint,const void*)
    if (numArgs == 7
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[6])))) {
        overloadId = 0; // glTexSubImage1D(uint,int,int,int,uint,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexSubImage1D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        unsigned int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        unsigned int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        void* cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexSubImage1D(uint,int,int,int,uint,uint,const void*)
            cppSelf->glTexSubImage1D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexSubImage2D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexSubImage2D", 9, 9, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexSubImage2D(uint,int,int,int,int,int,uint,uint,const void*)
    if (numArgs == 9
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[7])))
        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[8])))) {
        overloadId = 0; // glTexSubImage2D(uint,int,int,int,int,int,uint,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexSubImage2D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        unsigned int cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);
        unsigned int cppArg7;
        pythonToCpp[7](pyArgs[7], &cppArg7);
        void* cppArg8;
        pythonToCpp[8](pyArgs[8], &cppArg8);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexSubImage2D(uint,int,int,int,int,int,uint,uint,const void*)
            cppSelf->glTexSubImage2D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTexSubImage3D(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[11];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTexSubImage3D", 11, 11, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9]), &(pyArgs[10])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTexSubImage3D(uint,int,int,int,int,int,int,int,uint,uint,const void*)
    if (numArgs == 11
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))
        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))
        && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))
        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[8])))
        && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[9])))
        && (pythonToCpp[10] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[10])))) {
        overloadId = 0; // glTexSubImage3D(uint,int,int,int,int,int,int,int,uint,uint,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTexSubImage3D", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        unsigned int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);
        int cppArg6;
        pythonToCpp[6](pyArgs[6], &cppArg6);
        int cppArg7;
        pythonToCpp[7](pyArgs[7], &cppArg7);
        unsigned int cppArg8;
        pythonToCpp[8](pyArgs[8], &cppArg8);
        unsigned int cppArg9;
        pythonToCpp[9](pyArgs[9], &cppArg9);
        void* cppArg10;
        pythonToCpp[10](pyArgs[10], &cppArg10);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTexSubImage3D(uint,int,int,int,int,int,int,int,uint,uint,const void*)
            cppSelf->glTexSubImage3D(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, cppArg7, cppArg8, cppArg9, cppArg10);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTranslated(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTranslated", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTranslated(double,double,double)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))) {
        overloadId = 0; // glTranslated(double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTranslated", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTranslated(double,double,double)
            cppSelf->glTranslated(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glTranslatef(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glTranslatef", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glTranslatef(float,float,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glTranslatef(float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glTranslatef", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glTranslatef(float,float,float)
            cppSelf->glTranslatef(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex2d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glVertex2d", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex2d(double,double)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))) {
        overloadId = 0; // glVertex2d(double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glVertex2d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex2d(double,double)
            cppSelf->glVertex2d(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex2dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex2dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glVertex2dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glVertex2dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex2dv(const double*)
            cppSelf->glVertex2dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex2f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glVertex2f", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex2f(float,float)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))) {
        overloadId = 0; // glVertex2f(float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glVertex2f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex2f(float,float)
            cppSelf->glVertex2f(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex2fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex2fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glVertex2fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glVertex2fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex2fv(const float*)
            cppSelf->glVertex2fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex2i(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glVertex2i", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex2i(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // glVertex2i(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glVertex2i", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex2i(int,int)
            cppSelf->glVertex2i(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex2iv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex2iv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glVertex2iv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glVertex2iv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex2iv(const int*)
            cppSelf->glVertex2iv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex2s(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glVertex2s", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex2s(short,short)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[1])))) {
        overloadId = 0; // glVertex2s(short,short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glVertex2s", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex2s(short,short)
            cppSelf->glVertex2s(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex2sv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex2sv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glVertex2sv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glVertex2sv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex2sv(const short*)
            cppSelf->glVertex2sv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex3d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glVertex3d", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex3d(double,double,double)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))) {
        overloadId = 0; // glVertex3d(double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glVertex3d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex3d(double,double,double)
            cppSelf->glVertex3d(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex3dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex3dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glVertex3dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glVertex3dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex3dv(const double*)
            cppSelf->glVertex3dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex3f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glVertex3f", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex3f(float,float,float)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))) {
        overloadId = 0; // glVertex3f(float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glVertex3f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex3f(float,float,float)
            cppSelf->glVertex3f(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex3fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex3fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glVertex3fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glVertex3fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex3fv(const float*)
            cppSelf->glVertex3fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex3i(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glVertex3i", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex3i(int,int,int)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // glVertex3i(int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glVertex3i", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex3i(int,int,int)
            cppSelf->glVertex3i(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex3iv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex3iv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glVertex3iv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glVertex3iv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex3iv(const int*)
            cppSelf->glVertex3iv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex3s(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glVertex3s", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex3s(short,short,short)
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[2])))) {
        overloadId = 0; // glVertex3s(short,short,short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glVertex3s", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        short cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex3s(short,short,short)
            cppSelf->glVertex3s(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex3sv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex3sv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glVertex3sv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glVertex3sv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex3sv(const short*)
            cppSelf->glVertex3sv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex4d(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glVertex4d", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex4d(double,double,double,double)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<double>(), (pyArgs[3])))) {
        overloadId = 0; // glVertex4d(double,double,double,double)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glVertex4d", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        double cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        double cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        double cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        double cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex4d(double,double,double,double)
            cppSelf->glVertex4d(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex4dv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex4dv(const double*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<double>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glVertex4dv(const double*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glVertex4dv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<double> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex4dv(const double*)
            cppSelf->glVertex4dv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex4f(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glVertex4f", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex4f(float,float,float,float)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArgs[3])))) {
        overloadId = 0; // glVertex4f(float,float,float,float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glVertex4f", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        float cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        float cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        float cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex4f(float,float,float,float)
            cppSelf->glVertex4f(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex4fv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex4fv(const float*)
    if (PyFloat_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<float>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glVertex4fv(const float*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glVertex4fv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<float> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex4fv(const float*)
            cppSelf->glVertex4fv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex4i(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glVertex4i", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex4i(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // glVertex4i(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glVertex4i", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex4i(int,int,int,int)
            cppSelf->glVertex4i(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex4iv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex4iv(const int*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<int>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glVertex4iv(const int*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glVertex4iv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<int> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex4iv(const int*)
            cppSelf->glVertex4iv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex4s(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glVertex4s", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex4s(short,short,short,short)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<short>(), (pyArgs[3])))) {
        overloadId = 0; // glVertex4s(short,short,short,short)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glVertex4s", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        short cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        short cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        short cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        short cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex4s(short,short,short,short)
            cppSelf->glVertex4s(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertex4sv(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertex4sv(const short*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::ArrayTypeConverter<short>(1), -1, -1, (pyArg)))) {
        overloadId = 0; // glVertex4sv(const short*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "glVertex4sv", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        Shiboken::Conversions::ArrayHandle<short> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertex4sv(const short*)
            cppSelf->glVertex4sv(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glVertexPointer(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glVertexPointer", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glVertexPointer(int,uint,int,const void*)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[3])))) {
        overloadId = 0; // glVertexPointer(int,uint,int,const void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glVertexPointer", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        unsigned int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        void* cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glVertexPointer(int,uint,int,const void*)
            cppSelf->glVertexPointer(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_glViewport(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "glViewport", 4, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QOpenGLFunctions_1_2::glViewport(int,int,int,int)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
        overloadId = 0; // glViewport(int,int,int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "glViewport", errInfo, SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // glViewport(int,int,int,int)
            cppSelf->glViewport(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QOpenGLFunctions_1_2Func_initializeOpenGLFunctions(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // initializeOpenGLFunctions()
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QOpenGLFunctions_1_2::initializeOpenGLFunctions()
            : cppSelf->initializeOpenGLFunctions();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QOpenGLFunctions_1_2_PropertyStrings[] = {
    nullptr // Sentinel
};

static PyMethodDef Sbk_QOpenGLFunctions_1_2_methods[] = {
    {"glAccum", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glAccum), METH_VARARGS, nullptr},
    {"glAlphaFunc", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glAlphaFunc), METH_VARARGS, nullptr},
    {"glArrayElement", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glArrayElement), METH_O, nullptr},
    {"glBegin", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glBegin), METH_O, nullptr},
    {"glBindTexture", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glBindTexture), METH_VARARGS, nullptr},
    {"glBlendColor", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glBlendColor), METH_VARARGS, nullptr},
    {"glBlendEquation", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glBlendEquation), METH_O, nullptr},
    {"glBlendFunc", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glBlendFunc), METH_VARARGS, nullptr},
    {"glCallList", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glCallList), METH_O, nullptr},
    {"glCallLists", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glCallLists), METH_VARARGS, nullptr},
    {"glClear", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glClear), METH_O, nullptr},
    {"glClearAccum", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glClearAccum), METH_VARARGS, nullptr},
    {"glClearColor", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glClearColor), METH_VARARGS, nullptr},
    {"glClearDepth", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glClearDepth), METH_O, nullptr},
    {"glClearIndex", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glClearIndex), METH_O, nullptr},
    {"glClearStencil", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glClearStencil), METH_O, nullptr},
    {"glClipPlane", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glClipPlane), METH_VARARGS, nullptr},
    {"glColor3b", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3b), METH_VARARGS, nullptr},
    {"glColor3bv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3bv), METH_O, nullptr},
    {"glColor3d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3d), METH_VARARGS, nullptr},
    {"glColor3dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3dv), METH_O, nullptr},
    {"glColor3f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3f), METH_VARARGS, nullptr},
    {"glColor3fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3fv), METH_O, nullptr},
    {"glColor3i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3i), METH_VARARGS, nullptr},
    {"glColor3iv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3iv), METH_O, nullptr},
    {"glColor3s", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3s), METH_VARARGS, nullptr},
    {"glColor3sv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3sv), METH_O, nullptr},
    {"glColor3ub", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3ub), METH_VARARGS, nullptr},
    {"glColor3ubv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3ubv), METH_O, nullptr},
    {"glColor3ui", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3ui), METH_VARARGS, nullptr},
    {"glColor3uiv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3uiv), METH_O, nullptr},
    {"glColor3us", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3us), METH_VARARGS, nullptr},
    {"glColor3usv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor3usv), METH_O, nullptr},
    {"glColor4b", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4b), METH_VARARGS, nullptr},
    {"glColor4bv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4bv), METH_O, nullptr},
    {"glColor4d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4d), METH_VARARGS, nullptr},
    {"glColor4dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4dv), METH_O, nullptr},
    {"glColor4f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4f), METH_VARARGS, nullptr},
    {"glColor4fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4fv), METH_O, nullptr},
    {"glColor4i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4i), METH_VARARGS, nullptr},
    {"glColor4iv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4iv), METH_O, nullptr},
    {"glColor4s", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4s), METH_VARARGS, nullptr},
    {"glColor4sv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4sv), METH_O, nullptr},
    {"glColor4ub", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4ub), METH_VARARGS, nullptr},
    {"glColor4ubv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4ubv), METH_O, nullptr},
    {"glColor4ui", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4ui), METH_VARARGS, nullptr},
    {"glColor4uiv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4uiv), METH_O, nullptr},
    {"glColor4us", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4us), METH_VARARGS, nullptr},
    {"glColor4usv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColor4usv), METH_O, nullptr},
    {"glColorMask", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColorMask), METH_VARARGS, nullptr},
    {"glColorMaterial", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColorMaterial), METH_VARARGS, nullptr},
    {"glColorPointer", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColorPointer), METH_VARARGS, nullptr},
    {"glColorSubTable", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColorSubTable), METH_VARARGS, nullptr},
    {"glColorTable", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColorTable), METH_VARARGS, nullptr},
    {"glColorTableParameterfv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColorTableParameterfv), METH_VARARGS, nullptr},
    {"glColorTableParameteriv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glColorTableParameteriv), METH_VARARGS, nullptr},
    {"glConvolutionFilter1D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glConvolutionFilter1D), METH_VARARGS, nullptr},
    {"glConvolutionFilter2D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glConvolutionFilter2D), METH_VARARGS, nullptr},
    {"glConvolutionParameterf", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glConvolutionParameterf), METH_VARARGS, nullptr},
    {"glConvolutionParameterfv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glConvolutionParameterfv), METH_VARARGS, nullptr},
    {"glConvolutionParameteri", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glConvolutionParameteri), METH_VARARGS, nullptr},
    {"glConvolutionParameteriv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glConvolutionParameteriv), METH_VARARGS, nullptr},
    {"glCopyColorSubTable", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glCopyColorSubTable), METH_VARARGS, nullptr},
    {"glCopyColorTable", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glCopyColorTable), METH_VARARGS, nullptr},
    {"glCopyConvolutionFilter1D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glCopyConvolutionFilter1D), METH_VARARGS, nullptr},
    {"glCopyConvolutionFilter2D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glCopyConvolutionFilter2D), METH_VARARGS, nullptr},
    {"glCopyPixels", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glCopyPixels), METH_VARARGS, nullptr},
    {"glCopyTexImage1D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glCopyTexImage1D), METH_VARARGS, nullptr},
    {"glCopyTexImage2D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glCopyTexImage2D), METH_VARARGS, nullptr},
    {"glCopyTexSubImage1D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glCopyTexSubImage1D), METH_VARARGS, nullptr},
    {"glCopyTexSubImage2D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glCopyTexSubImage2D), METH_VARARGS, nullptr},
    {"glCopyTexSubImage3D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glCopyTexSubImage3D), METH_VARARGS, nullptr},
    {"glCullFace", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glCullFace), METH_O, nullptr},
    {"glDeleteLists", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glDeleteLists), METH_VARARGS, nullptr},
    {"glDeleteTextures", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glDeleteTextures), METH_VARARGS, nullptr},
    {"glDepthFunc", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glDepthFunc), METH_O, nullptr},
    {"glDepthMask", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glDepthMask), METH_O, nullptr},
    {"glDepthRange", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glDepthRange), METH_VARARGS, nullptr},
    {"glDisable", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glDisable), METH_O, nullptr},
    {"glDisableClientState", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glDisableClientState), METH_O, nullptr},
    {"glDrawArrays", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glDrawArrays), METH_VARARGS, nullptr},
    {"glDrawBuffer", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glDrawBuffer), METH_O, nullptr},
    {"glDrawElements", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glDrawElements), METH_VARARGS, nullptr},
    {"glDrawPixels", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glDrawPixels), METH_VARARGS, nullptr},
    {"glDrawRangeElements", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glDrawRangeElements), METH_VARARGS, nullptr},
    {"glEdgeFlag", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEdgeFlag), METH_O, nullptr},
    {"glEdgeFlagPointer", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEdgeFlagPointer), METH_VARARGS, nullptr},
    {"glEnable", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEnable), METH_O, nullptr},
    {"glEnableClientState", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEnableClientState), METH_O, nullptr},
    {"glEnd", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEnd), METH_NOARGS, nullptr},
    {"glEndList", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEndList), METH_NOARGS, nullptr},
    {"glEvalCoord1d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEvalCoord1d), METH_O, nullptr},
    {"glEvalCoord1dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEvalCoord1dv), METH_O, nullptr},
    {"glEvalCoord1f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEvalCoord1f), METH_O, nullptr},
    {"glEvalCoord1fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEvalCoord1fv), METH_O, nullptr},
    {"glEvalCoord2d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEvalCoord2d), METH_VARARGS, nullptr},
    {"glEvalCoord2dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEvalCoord2dv), METH_O, nullptr},
    {"glEvalCoord2f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEvalCoord2f), METH_VARARGS, nullptr},
    {"glEvalCoord2fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEvalCoord2fv), METH_O, nullptr},
    {"glEvalMesh1", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEvalMesh1), METH_VARARGS, nullptr},
    {"glEvalMesh2", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEvalMesh2), METH_VARARGS, nullptr},
    {"glEvalPoint1", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEvalPoint1), METH_O, nullptr},
    {"glEvalPoint2", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glEvalPoint2), METH_VARARGS, nullptr},
    {"glFinish", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glFinish), METH_NOARGS, nullptr},
    {"glFlush", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glFlush), METH_NOARGS, nullptr},
    {"glFogf", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glFogf), METH_VARARGS, nullptr},
    {"glFogfv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glFogfv), METH_VARARGS, nullptr},
    {"glFogi", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glFogi), METH_VARARGS, nullptr},
    {"glFogiv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glFogiv), METH_VARARGS, nullptr},
    {"glFrontFace", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glFrontFace), METH_O, nullptr},
    {"glFrustum", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glFrustum), METH_VARARGS, nullptr},
    {"glGenLists", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glGenLists), METH_O, nullptr},
    {"glGetBooleanv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glGetBooleanv), METH_O, nullptr},
    {"glGetColorTable", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glGetColorTable), METH_VARARGS, nullptr},
    {"glGetConvolutionFilter", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glGetConvolutionFilter), METH_VARARGS, nullptr},
    {"glGetDoublev", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glGetDoublev), METH_O, nullptr},
    {"glGetError", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glGetError), METH_NOARGS, nullptr},
    {"glGetFloatv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glGetFloatv), METH_O, nullptr},
    {"glGetHistogram", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glGetHistogram), METH_VARARGS, nullptr},
    {"glGetIntegerv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glGetIntegerv), METH_O, nullptr},
    {"glGetMinmax", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glGetMinmax), METH_VARARGS, nullptr},
    {"glGetSeparableFilter", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glGetSeparableFilter), METH_VARARGS, nullptr},
    {"glGetString", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glGetString), METH_O, nullptr},
    {"glGetTexImage", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glGetTexImage), METH_VARARGS, nullptr},
    {"glHint", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glHint), METH_VARARGS, nullptr},
    {"glHistogram", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glHistogram), METH_VARARGS, nullptr},
    {"glIndexMask", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIndexMask), METH_O, nullptr},
    {"glIndexPointer", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIndexPointer), METH_VARARGS, nullptr},
    {"glIndexd", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIndexd), METH_O, nullptr},
    {"glIndexdv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIndexdv), METH_O, nullptr},
    {"glIndexf", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIndexf), METH_O, nullptr},
    {"glIndexfv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIndexfv), METH_O, nullptr},
    {"glIndexi", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIndexi), METH_O, nullptr},
    {"glIndexiv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIndexiv), METH_O, nullptr},
    {"glIndexs", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIndexs), METH_O, nullptr},
    {"glIndexsv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIndexsv), METH_O, nullptr},
    {"glIndexub", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIndexub), METH_O, nullptr},
    {"glIndexubv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIndexubv), METH_O, nullptr},
    {"glInitNames", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glInitNames), METH_NOARGS, nullptr},
    {"glInterleavedArrays", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glInterleavedArrays), METH_VARARGS, nullptr},
    {"glIsEnabled", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIsEnabled), METH_O, nullptr},
    {"glIsList", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIsList), METH_O, nullptr},
    {"glIsTexture", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glIsTexture), METH_O, nullptr},
    {"glLightModelf", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLightModelf), METH_VARARGS, nullptr},
    {"glLightModelfv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLightModelfv), METH_VARARGS, nullptr},
    {"glLightModeli", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLightModeli), METH_VARARGS, nullptr},
    {"glLightModeliv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLightModeliv), METH_VARARGS, nullptr},
    {"glLightf", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLightf), METH_VARARGS, nullptr},
    {"glLightfv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLightfv), METH_VARARGS, nullptr},
    {"glLighti", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLighti), METH_VARARGS, nullptr},
    {"glLightiv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLightiv), METH_VARARGS, nullptr},
    {"glLineStipple", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLineStipple), METH_VARARGS, nullptr},
    {"glLineWidth", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLineWidth), METH_O, nullptr},
    {"glListBase", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glListBase), METH_O, nullptr},
    {"glLoadIdentity", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLoadIdentity), METH_NOARGS, nullptr},
    {"glLoadMatrixd", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLoadMatrixd), METH_O, nullptr},
    {"glLoadMatrixf", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLoadMatrixf), METH_O, nullptr},
    {"glLoadName", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLoadName), METH_O, nullptr},
    {"glLogicOp", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glLogicOp), METH_O, nullptr},
    {"glMap1d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMap1d), METH_VARARGS, nullptr},
    {"glMap1f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMap1f), METH_VARARGS, nullptr},
    {"glMap2d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMap2d), METH_VARARGS, nullptr},
    {"glMap2f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMap2f), METH_VARARGS, nullptr},
    {"glMapGrid1d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMapGrid1d), METH_VARARGS, nullptr},
    {"glMapGrid1f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMapGrid1f), METH_VARARGS, nullptr},
    {"glMapGrid2d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMapGrid2d), METH_VARARGS, nullptr},
    {"glMapGrid2f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMapGrid2f), METH_VARARGS, nullptr},
    {"glMaterialf", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMaterialf), METH_VARARGS, nullptr},
    {"glMaterialfv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMaterialfv), METH_VARARGS, nullptr},
    {"glMateriali", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMateriali), METH_VARARGS, nullptr},
    {"glMaterialiv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMaterialiv), METH_VARARGS, nullptr},
    {"glMatrixMode", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMatrixMode), METH_O, nullptr},
    {"glMinmax", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMinmax), METH_VARARGS, nullptr},
    {"glMultMatrixd", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMultMatrixd), METH_O, nullptr},
    {"glMultMatrixf", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glMultMatrixf), METH_O, nullptr},
    {"glNewList", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glNewList), METH_VARARGS, nullptr},
    {"glNormal3b", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glNormal3b), METH_VARARGS, nullptr},
    {"glNormal3bv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glNormal3bv), METH_O, nullptr},
    {"glNormal3d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glNormal3d), METH_VARARGS, nullptr},
    {"glNormal3dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glNormal3dv), METH_O, nullptr},
    {"glNormal3f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glNormal3f), METH_VARARGS, nullptr},
    {"glNormal3fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glNormal3fv), METH_O, nullptr},
    {"glNormal3i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glNormal3i), METH_VARARGS, nullptr},
    {"glNormal3iv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glNormal3iv), METH_O, nullptr},
    {"glNormal3s", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glNormal3s), METH_VARARGS, nullptr},
    {"glNormal3sv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glNormal3sv), METH_O, nullptr},
    {"glNormalPointer", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glNormalPointer), METH_VARARGS, nullptr},
    {"glOrtho", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glOrtho), METH_VARARGS, nullptr},
    {"glPassThrough", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPassThrough), METH_O, nullptr},
    {"glPixelMapfv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPixelMapfv), METH_VARARGS, nullptr},
    {"glPixelMapuiv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPixelMapuiv), METH_VARARGS, nullptr},
    {"glPixelMapusv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPixelMapusv), METH_VARARGS, nullptr},
    {"glPixelStoref", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPixelStoref), METH_VARARGS, nullptr},
    {"glPixelStorei", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPixelStorei), METH_VARARGS, nullptr},
    {"glPixelTransferf", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPixelTransferf), METH_VARARGS, nullptr},
    {"glPixelTransferi", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPixelTransferi), METH_VARARGS, nullptr},
    {"glPixelZoom", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPixelZoom), METH_VARARGS, nullptr},
    {"glPointSize", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPointSize), METH_O, nullptr},
    {"glPolygonMode", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPolygonMode), METH_VARARGS, nullptr},
    {"glPolygonOffset", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPolygonOffset), METH_VARARGS, nullptr},
    {"glPopAttrib", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPopAttrib), METH_NOARGS, nullptr},
    {"glPopClientAttrib", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPopClientAttrib), METH_NOARGS, nullptr},
    {"glPopMatrix", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPopMatrix), METH_NOARGS, nullptr},
    {"glPopName", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPopName), METH_NOARGS, nullptr},
    {"glPrioritizeTextures", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPrioritizeTextures), METH_VARARGS, nullptr},
    {"glPushAttrib", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPushAttrib), METH_O, nullptr},
    {"glPushClientAttrib", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPushClientAttrib), METH_O, nullptr},
    {"glPushMatrix", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPushMatrix), METH_NOARGS, nullptr},
    {"glPushName", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glPushName), METH_O, nullptr},
    {"glRasterPos2d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos2d), METH_VARARGS, nullptr},
    {"glRasterPos2dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos2dv), METH_O, nullptr},
    {"glRasterPos2f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos2f), METH_VARARGS, nullptr},
    {"glRasterPos2fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos2fv), METH_O, nullptr},
    {"glRasterPos2i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos2i), METH_VARARGS, nullptr},
    {"glRasterPos2iv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos2iv), METH_O, nullptr},
    {"glRasterPos2s", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos2s), METH_VARARGS, nullptr},
    {"glRasterPos2sv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos2sv), METH_O, nullptr},
    {"glRasterPos3d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos3d), METH_VARARGS, nullptr},
    {"glRasterPos3dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos3dv), METH_O, nullptr},
    {"glRasterPos3f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos3f), METH_VARARGS, nullptr},
    {"glRasterPos3fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos3fv), METH_O, nullptr},
    {"glRasterPos3i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos3i), METH_VARARGS, nullptr},
    {"glRasterPos3iv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos3iv), METH_O, nullptr},
    {"glRasterPos3s", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos3s), METH_VARARGS, nullptr},
    {"glRasterPos3sv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos3sv), METH_O, nullptr},
    {"glRasterPos4d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos4d), METH_VARARGS, nullptr},
    {"glRasterPos4dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos4dv), METH_O, nullptr},
    {"glRasterPos4f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos4f), METH_VARARGS, nullptr},
    {"glRasterPos4fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos4fv), METH_O, nullptr},
    {"glRasterPos4i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos4i), METH_VARARGS, nullptr},
    {"glRasterPos4iv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos4iv), METH_O, nullptr},
    {"glRasterPos4s", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos4s), METH_VARARGS, nullptr},
    {"glRasterPos4sv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRasterPos4sv), METH_O, nullptr},
    {"glReadBuffer", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glReadBuffer), METH_O, nullptr},
    {"glReadPixels", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glReadPixels), METH_VARARGS, nullptr},
    {"glRectd", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRectd), METH_VARARGS, nullptr},
    {"glRectdv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRectdv), METH_VARARGS, nullptr},
    {"glRectf", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRectf), METH_VARARGS, nullptr},
    {"glRectfv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRectfv), METH_VARARGS, nullptr},
    {"glRecti", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRecti), METH_VARARGS, nullptr},
    {"glRectiv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRectiv), METH_VARARGS, nullptr},
    {"glRects", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRects), METH_VARARGS, nullptr},
    {"glRectsv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRectsv), METH_VARARGS, nullptr},
    {"glRenderMode", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRenderMode), METH_O, nullptr},
    {"glResetHistogram", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glResetHistogram), METH_O, nullptr},
    {"glResetMinmax", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glResetMinmax), METH_O, nullptr},
    {"glRotated", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRotated), METH_VARARGS, nullptr},
    {"glRotatef", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glRotatef), METH_VARARGS, nullptr},
    {"glScaled", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glScaled), METH_VARARGS, nullptr},
    {"glScalef", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glScalef), METH_VARARGS, nullptr},
    {"glScissor", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glScissor), METH_VARARGS, nullptr},
    {"glSeparableFilter2D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glSeparableFilter2D), METH_VARARGS, nullptr},
    {"glShadeModel", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glShadeModel), METH_O, nullptr},
    {"glStencilFunc", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glStencilFunc), METH_VARARGS, nullptr},
    {"glStencilMask", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glStencilMask), METH_O, nullptr},
    {"glStencilOp", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glStencilOp), METH_VARARGS, nullptr},
    {"glTexCoord1d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord1d), METH_O, nullptr},
    {"glTexCoord1dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord1dv), METH_O, nullptr},
    {"glTexCoord1f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord1f), METH_O, nullptr},
    {"glTexCoord1fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord1fv), METH_O, nullptr},
    {"glTexCoord1i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord1i), METH_O, nullptr},
    {"glTexCoord1iv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord1iv), METH_O, nullptr},
    {"glTexCoord1s", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord1s), METH_O, nullptr},
    {"glTexCoord1sv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord1sv), METH_O, nullptr},
    {"glTexCoord2d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord2d), METH_VARARGS, nullptr},
    {"glTexCoord2dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord2dv), METH_O, nullptr},
    {"glTexCoord2f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord2f), METH_VARARGS, nullptr},
    {"glTexCoord2fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord2fv), METH_O, nullptr},
    {"glTexCoord2i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord2i), METH_VARARGS, nullptr},
    {"glTexCoord2iv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord2iv), METH_O, nullptr},
    {"glTexCoord2s", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord2s), METH_VARARGS, nullptr},
    {"glTexCoord2sv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord2sv), METH_O, nullptr},
    {"glTexCoord3d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord3d), METH_VARARGS, nullptr},
    {"glTexCoord3dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord3dv), METH_O, nullptr},
    {"glTexCoord3f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord3f), METH_VARARGS, nullptr},
    {"glTexCoord3fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord3fv), METH_O, nullptr},
    {"glTexCoord3i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord3i), METH_VARARGS, nullptr},
    {"glTexCoord3iv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord3iv), METH_O, nullptr},
    {"glTexCoord3s", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord3s), METH_VARARGS, nullptr},
    {"glTexCoord3sv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord3sv), METH_O, nullptr},
    {"glTexCoord4d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord4d), METH_VARARGS, nullptr},
    {"glTexCoord4dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord4dv), METH_O, nullptr},
    {"glTexCoord4f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord4f), METH_VARARGS, nullptr},
    {"glTexCoord4fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord4fv), METH_O, nullptr},
    {"glTexCoord4i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord4i), METH_VARARGS, nullptr},
    {"glTexCoord4iv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord4iv), METH_O, nullptr},
    {"glTexCoord4s", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord4s), METH_VARARGS, nullptr},
    {"glTexCoord4sv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoord4sv), METH_O, nullptr},
    {"glTexCoordPointer", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexCoordPointer), METH_VARARGS, nullptr},
    {"glTexEnvf", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexEnvf), METH_VARARGS, nullptr},
    {"glTexEnvfv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexEnvfv), METH_VARARGS, nullptr},
    {"glTexEnvi", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexEnvi), METH_VARARGS, nullptr},
    {"glTexEnviv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexEnviv), METH_VARARGS, nullptr},
    {"glTexGend", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexGend), METH_VARARGS, nullptr},
    {"glTexGendv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexGendv), METH_VARARGS, nullptr},
    {"glTexGenf", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexGenf), METH_VARARGS, nullptr},
    {"glTexGenfv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexGenfv), METH_VARARGS, nullptr},
    {"glTexGeni", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexGeni), METH_VARARGS, nullptr},
    {"glTexGeniv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexGeniv), METH_VARARGS, nullptr},
    {"glTexImage1D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexImage1D), METH_VARARGS, nullptr},
    {"glTexImage2D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexImage2D), METH_VARARGS, nullptr},
    {"glTexImage3D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexImage3D), METH_VARARGS, nullptr},
    {"glTexParameterf", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexParameterf), METH_VARARGS, nullptr},
    {"glTexParameterfv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexParameterfv), METH_VARARGS, nullptr},
    {"glTexParameteri", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexParameteri), METH_VARARGS, nullptr},
    {"glTexParameteriv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexParameteriv), METH_VARARGS, nullptr},
    {"glTexSubImage1D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexSubImage1D), METH_VARARGS, nullptr},
    {"glTexSubImage2D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexSubImage2D), METH_VARARGS, nullptr},
    {"glTexSubImage3D", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTexSubImage3D), METH_VARARGS, nullptr},
    {"glTranslated", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTranslated), METH_VARARGS, nullptr},
    {"glTranslatef", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glTranslatef), METH_VARARGS, nullptr},
    {"glVertex2d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex2d), METH_VARARGS, nullptr},
    {"glVertex2dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex2dv), METH_O, nullptr},
    {"glVertex2f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex2f), METH_VARARGS, nullptr},
    {"glVertex2fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex2fv), METH_O, nullptr},
    {"glVertex2i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex2i), METH_VARARGS, nullptr},
    {"glVertex2iv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex2iv), METH_O, nullptr},
    {"glVertex2s", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex2s), METH_VARARGS, nullptr},
    {"glVertex2sv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex2sv), METH_O, nullptr},
    {"glVertex3d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex3d), METH_VARARGS, nullptr},
    {"glVertex3dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex3dv), METH_O, nullptr},
    {"glVertex3f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex3f), METH_VARARGS, nullptr},
    {"glVertex3fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex3fv), METH_O, nullptr},
    {"glVertex3i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex3i), METH_VARARGS, nullptr},
    {"glVertex3iv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex3iv), METH_O, nullptr},
    {"glVertex3s", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex3s), METH_VARARGS, nullptr},
    {"glVertex3sv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex3sv), METH_O, nullptr},
    {"glVertex4d", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex4d), METH_VARARGS, nullptr},
    {"glVertex4dv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex4dv), METH_O, nullptr},
    {"glVertex4f", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex4f), METH_VARARGS, nullptr},
    {"glVertex4fv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex4fv), METH_O, nullptr},
    {"glVertex4i", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex4i), METH_VARARGS, nullptr},
    {"glVertex4iv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex4iv), METH_O, nullptr},
    {"glVertex4s", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex4s), METH_VARARGS, nullptr},
    {"glVertex4sv", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertex4sv), METH_O, nullptr},
    {"glVertexPointer", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glVertexPointer), METH_VARARGS, nullptr},
    {"glViewport", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_glViewport), METH_VARARGS, nullptr},
    {"initializeOpenGLFunctions", reinterpret_cast<PyCFunction>(Sbk_QOpenGLFunctions_1_2Func_initializeOpenGLFunctions), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QOpenGLFunctions_1_2_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QOpenGLFunctions_1_2 *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QOpenGLFunctions_1_2Wrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QOpenGLFunctions_1_2_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QOpenGLFunctions_1_2_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QOpenGLFunctions_1_2_Type = nullptr;
static PyTypeObject *Sbk_QOpenGLFunctions_1_2_TypeF(void)
{
    return _Sbk_QOpenGLFunctions_1_2_Type;
}

static PyType_Slot Sbk_QOpenGLFunctions_1_2_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QOpenGLFunctions_1_2_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QOpenGLFunctions_1_2_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QOpenGLFunctions_1_2_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QOpenGLFunctions_1_2_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QOpenGLFunctions_1_2_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QOpenGLFunctions_1_2_spec = {
    "2:PySide6.QtOpenGL.QOpenGLFunctions_1_2",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QOpenGLFunctions_1_2_slots
};

} //extern "C"

static void *Sbk_QOpenGLFunctions_1_2_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QAbstractOpenGLFunctions >())
        return dynamic_cast< ::QOpenGLFunctions_1_2 *>(reinterpret_cast< ::QAbstractOpenGLFunctions *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QOpenGLFunctions_1_2_PythonToCpp_QOpenGLFunctions_1_2_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QOpenGLFunctions_1_2_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QOpenGLFunctions_1_2_PythonToCpp_QOpenGLFunctions_1_2_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QOpenGLFunctions_1_2_TypeF()))
        return QOpenGLFunctions_1_2_PythonToCpp_QOpenGLFunctions_1_2_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QOpenGLFunctions_1_2_PTR_CppToPython_QOpenGLFunctions_1_2(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::QOpenGLFunctions_1_2 *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_QOpenGLFunctions_1_2_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QOpenGLFunctions_1_2_SignatureStrings[] = {
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2(self)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glAccum(self,op:unsigned int,value:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glAlphaFunc(self,func:unsigned int,ref:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glArrayElement(self,i:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glBegin(self,mode:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glBindTexture(self,target:unsigned int,texture:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glBlendColor(self,red:float,green:float,blue:float,alpha:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glBlendEquation(self,mode:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glBlendFunc(self,sfactor:unsigned int,dfactor:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glCallList(self,list:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glCallLists(self,n:int,type:unsigned int,lists:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glClear(self,mask:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glClearAccum(self,red:float,green:float,blue:float,alpha:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glClearColor(self,red:float,green:float,blue:float,alpha:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glClearDepth(self,depth:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glClearIndex(self,c:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glClearStencil(self,s:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glClipPlane(self,plane:unsigned int,equation:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3b(self,red:signed char,green:signed char,blue:signed char)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3bv(self,v:array signed char*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3d(self,red:double,green:double,blue:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3dv(self,v:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3f(self,red:float,green:float,blue:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3fv(self,v:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3i(self,red:int,green:int,blue:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3iv(self,v:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3s(self,red:short,green:short,blue:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3sv(self,v:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3ub(self,red:unsigned char,green:unsigned char,blue:unsigned char)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3ubv(self,v:array unsigned char*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3ui(self,red:unsigned int,green:unsigned int,blue:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3uiv(self,v:array unsigned int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3us(self,red:unsigned short,green:unsigned short,blue:unsigned short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor3usv(self,v:array unsigned short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4b(self,red:signed char,green:signed char,blue:signed char,alpha:signed char)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4bv(self,v:array signed char*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4d(self,red:double,green:double,blue:double,alpha:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4dv(self,v:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4f(self,red:float,green:float,blue:float,alpha:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4fv(self,v:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4i(self,red:int,green:int,blue:int,alpha:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4iv(self,v:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4s(self,red:short,green:short,blue:short,alpha:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4sv(self,v:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4ub(self,red:unsigned char,green:unsigned char,blue:unsigned char,alpha:unsigned char)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4ubv(self,v:array unsigned char*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4ui(self,red:unsigned int,green:unsigned int,blue:unsigned int,alpha:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4uiv(self,v:array unsigned int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4us(self,red:unsigned short,green:unsigned short,blue:unsigned short,alpha:unsigned short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColor4usv(self,v:array unsigned short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColorMask(self,red:unsigned char,green:unsigned char,blue:unsigned char,alpha:unsigned char)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColorMaterial(self,face:unsigned int,mode:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColorPointer(self,size:int,type:unsigned int,stride:int,pointer:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColorSubTable(self,target:unsigned int,start:int,count:int,format:unsigned int,type:unsigned int,data:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColorTable(self,target:unsigned int,internalformat:unsigned int,width:int,format:unsigned int,type:unsigned int,table:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColorTableParameterfv(self,target:unsigned int,pname:unsigned int,params:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glColorTableParameteriv(self,target:unsigned int,pname:unsigned int,params:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glConvolutionFilter1D(self,target:unsigned int,internalformat:unsigned int,width:int,format:unsigned int,type:unsigned int,image:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glConvolutionFilter2D(self,target:unsigned int,internalformat:unsigned int,width:int,height:int,format:unsigned int,type:unsigned int,image:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glConvolutionParameterf(self,target:unsigned int,pname:unsigned int,params:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glConvolutionParameterfv(self,target:unsigned int,pname:unsigned int,params:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glConvolutionParameteri(self,target:unsigned int,pname:unsigned int,params:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glConvolutionParameteriv(self,target:unsigned int,pname:unsigned int,params:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glCopyColorSubTable(self,target:unsigned int,start:int,x:int,y:int,width:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glCopyColorTable(self,target:unsigned int,internalformat:unsigned int,x:int,y:int,width:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glCopyConvolutionFilter1D(self,target:unsigned int,internalformat:unsigned int,x:int,y:int,width:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glCopyConvolutionFilter2D(self,target:unsigned int,internalformat:unsigned int,x:int,y:int,width:int,height:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glCopyPixels(self,x:int,y:int,width:int,height:int,type:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glCopyTexImage1D(self,target:unsigned int,level:int,internalformat:unsigned int,x:int,y:int,width:int,border:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glCopyTexImage2D(self,target:unsigned int,level:int,internalformat:unsigned int,x:int,y:int,width:int,height:int,border:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glCopyTexSubImage1D(self,target:unsigned int,level:int,xoffset:int,x:int,y:int,width:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glCopyTexSubImage2D(self,target:unsigned int,level:int,xoffset:int,yoffset:int,x:int,y:int,width:int,height:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glCopyTexSubImage3D(self,target:unsigned int,level:int,xoffset:int,yoffset:int,zoffset:int,x:int,y:int,width:int,height:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glCullFace(self,mode:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glDeleteLists(self,list:unsigned int,range:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glDeleteTextures(self,n:int,textures:array unsigned int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glDepthFunc(self,func:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glDepthMask(self,flag:unsigned char)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glDepthRange(self,nearVal:double,farVal:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glDisable(self,cap:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glDisableClientState(self,array:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glDrawArrays(self,mode:unsigned int,first:int,count:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glDrawBuffer(self,mode:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glDrawElements(self,mode:unsigned int,count:int,type:unsigned int,indices:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glDrawPixels(self,width:int,height:int,format:unsigned int,type:unsigned int,pixels:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glDrawRangeElements(self,mode:unsigned int,start:unsigned int,end:unsigned int,count:int,type:unsigned int,indices:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEdgeFlag(self,flag:unsigned char)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEdgeFlagPointer(self,stride:int,pointer:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEnable(self,cap:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEnableClientState(self,array:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEnd(self)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEndList(self)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEvalCoord1d(self,u:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEvalCoord1dv(self,u:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEvalCoord1f(self,u:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEvalCoord1fv(self,u:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEvalCoord2d(self,u:double,v:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEvalCoord2dv(self,u:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEvalCoord2f(self,u:float,v:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEvalCoord2fv(self,u:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEvalMesh1(self,mode:unsigned int,i1:int,i2:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEvalMesh2(self,mode:unsigned int,i1:int,i2:int,j1:int,j2:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEvalPoint1(self,i:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glEvalPoint2(self,i:int,j:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glFinish(self)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glFlush(self)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glFogf(self,pname:unsigned int,param:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glFogfv(self,pname:unsigned int,params:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glFogi(self,pname:unsigned int,param:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glFogiv(self,pname:unsigned int,params:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glFrontFace(self,mode:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glFrustum(self,left:double,right:double,bottom:double,top:double,zNear:double,zFar:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glGenLists(self,range:int)->unsigned int",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glGetBooleanv(self,pname:unsigned int)->Union[bool,numpy.ndarray]",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glGetColorTable(self,target:unsigned int,format:unsigned int,type:unsigned int,table:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glGetConvolutionFilter(self,target:unsigned int,format:unsigned int,type:unsigned int,image:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glGetDoublev(self,pname:unsigned int)->Union[float,numpy.ndarray]",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glGetError(self)->unsigned int",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glGetFloatv(self,pname:unsigned int)->Union[float,numpy.ndarray]",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glGetHistogram(self,target:unsigned int,reset:unsigned char,format:unsigned int,type:unsigned int,values:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glGetIntegerv(self,pname:unsigned int)->Union[int,numpy.ndarray]",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glGetMinmax(self,target:unsigned int,reset:unsigned char,format:unsigned int,type:unsigned int,values:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glGetSeparableFilter(self,target:unsigned int,format:unsigned int,type:unsigned int,row:void,column:void,span:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glGetString(self,name:unsigned int)->QString",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glGetTexImage(self,target:unsigned int,level:int,format:unsigned int,type:unsigned int,pixels:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glHint(self,target:unsigned int,mode:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glHistogram(self,target:unsigned int,width:int,internalformat:unsigned int,sink:unsigned char)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIndexMask(self,mask:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIndexPointer(self,type:unsigned int,stride:int,pointer:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIndexd(self,c:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIndexdv(self,c:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIndexf(self,c:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIndexfv(self,c:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIndexi(self,c:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIndexiv(self,c:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIndexs(self,c:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIndexsv(self,c:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIndexub(self,c:unsigned char)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIndexubv(self,c:array unsigned char*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glInitNames(self)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glInterleavedArrays(self,format:unsigned int,stride:int,pointer:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIsEnabled(self,cap:unsigned int)->unsigned char",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIsList(self,list:unsigned int)->unsigned char",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glIsTexture(self,texture:unsigned int)->unsigned char",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLightModelf(self,pname:unsigned int,param:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLightModelfv(self,pname:unsigned int,params:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLightModeli(self,pname:unsigned int,param:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLightModeliv(self,pname:unsigned int,params:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLightf(self,light:unsigned int,pname:unsigned int,param:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLightfv(self,light:unsigned int,pname:unsigned int,params:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLighti(self,light:unsigned int,pname:unsigned int,param:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLightiv(self,light:unsigned int,pname:unsigned int,params:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLineStipple(self,factor:int,pattern:unsigned short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLineWidth(self,width:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glListBase(self,base:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLoadIdentity(self)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLoadMatrixd(self,m:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLoadMatrixf(self,m:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLoadName(self,name:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glLogicOp(self,opcode:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMap1d(self,target:unsigned int,u1:double,u2:double,stride:int,order:int,points:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMap1f(self,target:unsigned int,u1:float,u2:float,stride:int,order:int,points:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMap2d(self,target:unsigned int,u1:double,u2:double,ustride:int,uorder:int,v1:double,v2:double,vstride:int,vorder:int,points:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMap2f(self,target:unsigned int,u1:float,u2:float,ustride:int,uorder:int,v1:float,v2:float,vstride:int,vorder:int,points:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMapGrid1d(self,un:int,u1:double,u2:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMapGrid1f(self,un:int,u1:float,u2:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMapGrid2d(self,un:int,u1:double,u2:double,vn:int,v1:double,v2:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMapGrid2f(self,un:int,u1:float,u2:float,vn:int,v1:float,v2:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMaterialf(self,face:unsigned int,pname:unsigned int,param:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMaterialfv(self,face:unsigned int,pname:unsigned int,params:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMateriali(self,face:unsigned int,pname:unsigned int,param:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMaterialiv(self,face:unsigned int,pname:unsigned int,params:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMatrixMode(self,mode:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMinmax(self,target:unsigned int,internalformat:unsigned int,sink:unsigned char)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMultMatrixd(self,m:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glMultMatrixf(self,m:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glNewList(self,list:unsigned int,mode:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glNormal3b(self,nx:signed char,ny:signed char,nz:signed char)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glNormal3bv(self,v:array signed char*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glNormal3d(self,nx:double,ny:double,nz:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glNormal3dv(self,v:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glNormal3f(self,nx:float,ny:float,nz:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glNormal3fv(self,v:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glNormal3i(self,nx:int,ny:int,nz:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glNormal3iv(self,v:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glNormal3s(self,nx:short,ny:short,nz:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glNormal3sv(self,v:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glNormalPointer(self,type:unsigned int,stride:int,pointer:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glOrtho(self,left:double,right:double,bottom:double,top:double,zNear:double,zFar:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPassThrough(self,token:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPixelMapfv(self,map:unsigned int,mapsize:int,values:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPixelMapuiv(self,map:unsigned int,mapsize:int,values:array unsigned int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPixelMapusv(self,map:unsigned int,mapsize:int,values:array unsigned short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPixelStoref(self,pname:unsigned int,param:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPixelStorei(self,pname:unsigned int,param:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPixelTransferf(self,pname:unsigned int,param:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPixelTransferi(self,pname:unsigned int,param:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPixelZoom(self,xfactor:float,yfactor:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPointSize(self,size:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPolygonMode(self,face:unsigned int,mode:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPolygonOffset(self,factor:float,units:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPopAttrib(self)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPopClientAttrib(self)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPopMatrix(self)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPopName(self)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPrioritizeTextures(self,n:int,textures:array unsigned int*,priorities:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPushAttrib(self,mask:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPushClientAttrib(self,mask:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPushMatrix(self)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glPushName(self,name:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos2d(self,x:double,y:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos2dv(self,v:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos2f(self,x:float,y:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos2fv(self,v:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos2i(self,x:int,y:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos2iv(self,v:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos2s(self,x:short,y:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos2sv(self,v:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos3d(self,x:double,y:double,z:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos3dv(self,v:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos3f(self,x:float,y:float,z:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos3fv(self,v:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos3i(self,x:int,y:int,z:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos3iv(self,v:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos3s(self,x:short,y:short,z:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos3sv(self,v:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos4d(self,x:double,y:double,z:double,w:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos4dv(self,v:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos4f(self,x:float,y:float,z:float,w:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos4fv(self,v:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos4i(self,x:int,y:int,z:int,w:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos4iv(self,v:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos4s(self,x:short,y:short,z:short,w:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRasterPos4sv(self,v:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glReadBuffer(self,mode:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glReadPixels(self,x:int,y:int,width:int,height:int,format:unsigned int,type:unsigned int,pixels:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRectd(self,x1:double,y1:double,x2:double,y2:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRectdv(self,v1:array double*,v2:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRectf(self,x1:float,y1:float,x2:float,y2:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRectfv(self,v1:array float*,v2:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRecti(self,x1:int,y1:int,x2:int,y2:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRectiv(self,v1:array int*,v2:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRects(self,x1:short,y1:short,x2:short,y2:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRectsv(self,v1:array short*,v2:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRenderMode(self,mode:unsigned int)->int",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glResetHistogram(self,target:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glResetMinmax(self,target:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRotated(self,angle:double,x:double,y:double,z:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glRotatef(self,angle:float,x:float,y:float,z:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glScaled(self,x:double,y:double,z:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glScalef(self,x:float,y:float,z:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glScissor(self,x:int,y:int,width:int,height:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glSeparableFilter2D(self,target:unsigned int,internalformat:unsigned int,width:int,height:int,format:unsigned int,type:unsigned int,row:void,column:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glShadeModel(self,mode:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glStencilFunc(self,func:unsigned int,ref:int,mask:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glStencilMask(self,mask:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glStencilOp(self,fail:unsigned int,zfail:unsigned int,zpass:unsigned int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord1d(self,s:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord1dv(self,v:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord1f(self,s:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord1fv(self,v:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord1i(self,s:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord1iv(self,v:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord1s(self,s:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord1sv(self,v:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord2d(self,s:double,t:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord2dv(self,v:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord2f(self,s:float,t:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord2fv(self,v:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord2i(self,s:int,t:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord2iv(self,v:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord2s(self,s:short,t:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord2sv(self,v:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord3d(self,s:double,t:double,r:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord3dv(self,v:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord3f(self,s:float,t:float,r:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord3fv(self,v:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord3i(self,s:int,t:int,r:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord3iv(self,v:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord3s(self,s:short,t:short,r:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord3sv(self,v:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord4d(self,s:double,t:double,r:double,q:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord4dv(self,v:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord4f(self,s:float,t:float,r:float,q:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord4fv(self,v:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord4i(self,s:int,t:int,r:int,q:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord4iv(self,v:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord4s(self,s:short,t:short,r:short,q:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoord4sv(self,v:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexCoordPointer(self,size:int,type:unsigned int,stride:int,pointer:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexEnvf(self,target:unsigned int,pname:unsigned int,param:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexEnvfv(self,target:unsigned int,pname:unsigned int,params:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexEnvi(self,target:unsigned int,pname:unsigned int,param:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexEnviv(self,target:unsigned int,pname:unsigned int,params:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexGend(self,coord:unsigned int,pname:unsigned int,param:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexGendv(self,coord:unsigned int,pname:unsigned int,params:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexGenf(self,coord:unsigned int,pname:unsigned int,param:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexGenfv(self,coord:unsigned int,pname:unsigned int,params:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexGeni(self,coord:unsigned int,pname:unsigned int,param:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexGeniv(self,coord:unsigned int,pname:unsigned int,params:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexImage1D(self,target:unsigned int,level:int,internalformat:int,width:int,border:int,format:unsigned int,type:unsigned int,pixels:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexImage2D(self,target:unsigned int,level:int,internalformat:int,width:int,height:int,border:int,format:unsigned int,type:unsigned int,pixels:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexImage3D(self,target:unsigned int,level:int,internalformat:int,width:int,height:int,depth:int,border:int,format:unsigned int,type:unsigned int,pixels:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexParameterf(self,target:unsigned int,pname:unsigned int,param:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexParameterfv(self,target:unsigned int,pname:unsigned int,params:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexParameteri(self,target:unsigned int,pname:unsigned int,param:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexParameteriv(self,target:unsigned int,pname:unsigned int,params:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexSubImage1D(self,target:unsigned int,level:int,xoffset:int,width:int,format:unsigned int,type:unsigned int,pixels:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexSubImage2D(self,target:unsigned int,level:int,xoffset:int,yoffset:int,width:int,height:int,format:unsigned int,type:unsigned int,pixels:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTexSubImage3D(self,target:unsigned int,level:int,xoffset:int,yoffset:int,zoffset:int,width:int,height:int,depth:int,format:unsigned int,type:unsigned int,pixels:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTranslated(self,x:double,y:double,z:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glTranslatef(self,x:float,y:float,z:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex2d(self,x:double,y:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex2dv(self,v:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex2f(self,x:float,y:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex2fv(self,v:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex2i(self,x:int,y:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex2iv(self,v:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex2s(self,x:short,y:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex2sv(self,v:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex3d(self,x:double,y:double,z:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex3dv(self,v:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex3f(self,x:float,y:float,z:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex3fv(self,v:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex3i(self,x:int,y:int,z:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex3iv(self,v:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex3s(self,x:short,y:short,z:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex3sv(self,v:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex4d(self,x:double,y:double,z:double,w:double)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex4dv(self,v:array double*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex4f(self,x:float,y:float,z:float,w:float)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex4fv(self,v:array float*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex4i(self,x:int,y:int,z:int,w:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex4iv(self,v:array int*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex4s(self,x:short,y:short,z:short,w:short)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertex4sv(self,v:array short*)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glVertexPointer(self,size:int,type:unsigned int,stride:int,pointer:void)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.glViewport(self,x:int,y:int,width:int,height:int)",
    "PySide6.QtOpenGL.QOpenGLFunctions_1_2.initializeOpenGLFunctions(self)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t QOpenGLFunctions_1_2_SignatureByteSize = 3121;
static constexpr uint8_t QOpenGLFunctions_1_2_SignatureBytes[3121] = {
    0x78, 0xda, 0xcd, 0x5d, 0x5b, 0x8f, 0xdb, 0x36, 0x16, 0x7e, 0xef, 0xaf, 0xe8, 0xe3, 0x76, 0xa1,
    0x06, 0x18, 0x49, 0xd8, 0x87, 0x79, 0x28, 0xd0, 0x24, 0x33, 0x69, 0x80, 0x4c, 0x32, 0xc9, 0xcc,
    0x66, 0x81, 0x5d, 0x2c, 0x0a, 0x8e, 0x45, 0xd9, 0x4c, 0x64, 0x4a, 0x15, 0x25, 0x8f, 0xed, 0x5f,
    0xbf, 0xbc, 0xea, 0x36, 0xbe, 0x9d, 0x43, 0xda, 0xd9, 0x97, 0x56, 0xa3, 0x5a, 0xdf, 0xf9, 0x48,
    0x7e, 0x3c, 0x24, 0x0f, 0x0f, 0xd9, 0xfb, 0xcd, 0x03, 0xcb, 0xe8, 0x3f, 0x5e, 0x7d, 0x6e, 0x3e,
    0x55, 0x94, 0xbf, 0xfb, 0xf0, 0xea, 0xb3, 0xf9, 0xf7, 0x6d, 0xcb, 0x67, 0x0d, 0x2b, 0xb9, 0xf8,
    0xf3, 0xea, 0xcf, 0xf8, 0x6f, 0x82, 0x16, 0xf9, 0x2f, 0x3f, 0xdd, 0x9f, 0xf2, 0xdb, 0x57, 0xf3,
    0xe2, 0xf7, 0xd9, 0xac, 0x5d, 0xea, 0x6f, 0xa2, 0xb2, 0xba, 0x6e, 0xb9, 0x60, 0x73, 0x4e, 0xb3,
    0x9f, 0x19, 0x6f, 0xa2, 0x15, 0x29, 0x5a, 0x7a, 0x9d, 0x17, 0x25, 0x69, 0x00, 0x78, 0x45, 0xb5,
    0x20, 0xea, 0xa5, 0xc1, 0xcc, 0xe5, 0xd3, 0x18, 0xb5, 0xa6, 0x39, 0x18, 0xb3, 0xae, 0xc9, 0xe6,
    0xa6, 0xa0, 0x4b, 0xca, 0x1b, 0x03, 0xcb, 0xae, 0x25, 0xd4, 0xe9, 0x00, 0xaf, 0xe9, 0x9c, 0x71,
    0xf3, 0xe5, 0xb2, 0xcc, 0xe8, 0x88, 0x10, 0x00, 0x85, 0xf1, 0xec, 0x91, 0xae, 0x9b, 0xb6, 0xa6,
    0x06, 0xab, 0x21, 0xf5, 0x9c, 0x36, 0xe3, 0xe2, 0x35, 0xe6, 0x07, 0x58, 0x13, 0x05, 0xe5, 0xd9,
    0x9b, 0xb2, 0x28, 0x6b, 0x63, 0xa1, 0xa6, 0x99, 0xa9, 0xac, 0x68, 0x5e, 0x53, 0xca, 0xed, 0xf3,
    0x53, 0xd7, 0x2e, 0x11, 0x51, 0xd5, 0x0d, 0xad, 0x4f, 0x6d, 0xe5, 0xe6, 0xaf, 0x96, 0xa8, 0x97,
    0xfe, 0xd5, 0xa2, 0xd0, 0xfa, 0x16, 0x17, 0x39, 0x99, 0x35, 0x65, 0x3d, 0xae, 0x95, 0x6c, 0xc7,
    0xcb, 0xd3, 0x2d, 0xbc, 0x21, 0x45, 0xf1, 0x81, 0x09, 0xdb, 0xf6, 0x85, 0x7c, 0xf2, 0x04, 0x12,
    0x06, 0x89, 0x5f, 0xeb, 0x16, 0xdb, 0x54, 0xe3, 0xa2, 0x6b, 0x0b, 0xe2, 0x7a, 0x55, 0xb2, 0x0c,
    0x00, 0x5d, 0x50, 0x62, 0x1b, 0x6d, 0x49, 0xc4, 0x77, 0x2c, 0x41, 0x85, 0x32, 0xe8, 0x92, 0xe7,
    0x69, 0x7f, 0x6d, 0xe5, 0xec, 0x2a, 0xd3, 0x56, 0xde, 0xd2, 0xaa, 0x59, 0x18, 0x2b, 0x99, 0x7a,
    0xbc, 0xce, 0xca, 0xf6, 0xa9, 0xa0, 0x40, 0x94, 0xf7, 0x3c, 0xa3, 0x6b, 0x83, 0x32, 0x43, 0xd1,
    0x78, 0x68, 0x28, 0x9f, 0xb1, 0xc2, 0x2a, 0xf4, 0x1a, 0xd8, 0x26, 0xac, 0xba, 0x2f, 0x08, 0xb7,
    0x9d, 0xbe, 0x52, 0x8f, 0x63, 0xbd, 0x50, 0xdb, 0x95, 0xae, 0x89, 0x72, 0x54, 0x3f, 0x9b, 0x22,
    0xfe, 0x1d, 0x60, 0x41, 0x35, 0x45, 0xf2, 0xd4, 0x37, 0x86, 0xc5, 0x9e, 0x2d, 0x48, 0x6d, 0x9b,
    0x64, 0xf8, 0x46, 0x37, 0xcc, 0xe0, 0x05, 0xd8, 0xd0, 0xca, 0x58, 0x5a, 0x59, 0xbe, 0x03, 0x28,
    0x30, 0xe9, 0xac, 0x27, 0x6d, 0x8a, 0x6d, 0xf9, 0xda, 0x3f, 0x34, 0x55, 0x70, 0x93, 0x1b, 0xe4,
    0x09, 0x4b, 0x64, 0xad, 0xe6, 0xa7, 0x49, 0x1c, 0x0c, 0x3b, 0x61, 0xa7, 0x41, 0xc0, 0xe4, 0x58,
    0x4f, 0x4e, 0xe9, 0xc8, 0x50, 0x53, 0x4f, 0x9a, 0x18, 0x4c, 0xa5, 0x06, 0x70, 0x42, 0x4b, 0x42,
    0x80, 0x49, 0x89, 0x81, 0x0e, 0x17, 0x65, 0xed, 0x68, 0x99, 0x67, 0xa3, 0x3d, 0xf5, 0x08, 0x86,
    0x9d, 0xaa, 0x4e, 0x81, 0x80, 0xc9, 0xb5, 0x83, 0x5e, 0xd2, 0xf5, 0xc1, 0x41, 0x3f, 0x19, 0xbf,
    0xd3, 0x6c, 0x47, 0xaf, 0xe0, 0xf6, 0x26, 0xb4, 0x47, 0x68, 0x70, 0xfa, 0x6c, 0x07, 0xfd, 0xbe,
    0xe9, 0x47, 0xaf, 0xc6, 0xe4, 0x11, 0x62, 0x68, 0xd9, 0x3e, 0xee, 0x18, 0x59, 0xb4, 0x62, 0x07,
    0xf5, 0xa1, 0x40, 0x26, 0x2f, 0xc7, 0xf4, 0x51, 0x92, 0x69, 0xc5, 0xbe, 0x02, 0xa0, 0xc4, 0x93,
    0xa2, 0x3d, 0xac, 0x1d, 0x00, 0xf1, 0x3a, 0x4a, 0x03, 0xfa, 0xdc, 0xf4, 0x74, 0x9f, 0x6b, 0x79,
    0xa3, 0x1c, 0x70, 0x1a, 0xc6, 0x01, 0xa7, 0xf9, 0x59, 0xe7, 0x18, 0xc6, 0x44, 0x08, 0x67, 0x9c,
    0x1e, 0x75, 0xc6, 0x96, 0x22, 0xbc, 0x27, 0xa6, 0x01, 0xdc, 0x72, 0x7a, 0xa2, 0x5b, 0x76, 0x52,
    0x45, 0xf4, 0xb7, 0x34, 0x88, 0x8b, 0x4e, 0x7d, 0x5d, 0xb4, 0x2d, 0x81, 0x8f, 0xdb, 0x4e, 0xc3,
    0xba, 0xed, 0xd4, 0xcb, 0x6d, 0x4f, 0xcb, 0x83, 0xd0, 0x4f, 0x50, 0x4f, 0x9e, 0x06, 0xf0, 0xe4,
    0xd3, 0x32, 0xa1, 0xe4, 0x16, 0xd8, 0xbd, 0xdf, 0xc9, 0x65, 0xd7, 0x0f, 0x57, 0xde, 0x1d, 0x69,
    0x68, 0xcd, 0x88, 0x5d, 0x69, 0xc8, 0x55, 0xef, 0x44, 0x0b, 0x1e, 0xeb, 0x6c, 0x8d, 0x7f, 0x5f,
    0xca, 0x6f, 0xa8, 0x5d, 0xb7, 0x09, 0xb6, 0xa5, 0x7b, 0x96, 0xb0, 0xa2, 0xa9, 0x25, 0xa8, 0xfe,
    0x8f, 0x95, 0xf9, 0x04, 0xba, 0x9e, 0x55, 0xd6, 0x1e, 0xda, 0xa7, 0x47, 0x22, 0x9d, 0xfe, 0xfe,
    0x70, 0x87, 0x90, 0x2f, 0x1b, 0x6d, 0x66, 0x56, 0xb6, 0xdc, 0x3c, 0xe5, 0x65, 0xbd, 0x24, 0xd3,
    0xb0, 0xc8, 0x0b, 0x86, 0x19, 0x69, 0x08, 0x86, 0xd3, 0x11, 0x42, 0xba, 0xac, 0x9c, 0x14, 0xbb,
    0x48, 0x3c, 0xb3, 0x4c, 0xae, 0x40, 0x4f, 0xa7, 0xd8, 0x28, 0x53, 0x68, 0x8e, 0xf7, 0xa4, 0x26,
    0x4b, 0x2a, 0xd9, 0xb8, 0xe1, 0x69, 0x17, 0xdd, 0x8a, 0xcb, 0xdf, 0x4c, 0x5e, 0xa9, 0xef, 0x84,
    0xcf, 0x50, 0x36, 0x36, 0xcf, 0x3c, 0xcc, 0x43, 0xdd, 0x0b, 0x5f, 0x95, 0x45, 0xab, 0x5e, 0xdd,
    0xb2, 0x42, 0x9a, 0xbe, 0x7a, 0x7b, 0x99, 0x86, 0x62, 0x4b, 0x32, 0x87, 0x37, 0xd4, 0x84, 0x6c,
    0xec, 0x4d, 0x76, 0x41, 0xd9, 0x7c, 0xd1, 0x5c, 0x8e, 0x77, 0xaf, 0x30, 0x4c, 0x0b, 0x83, 0xa7,
    0x5a, 0x3b, 0xec, 0x5e, 0x54, 0xd9, 0x2f, 0xed, 0x33, 0x8c, 0x79, 0xa0, 0xd3, 0xdd, 0x61, 0xf5,
    0x82, 0x1d, 0xaa, 0xda, 0x80, 0x1d, 0xf1, 0x5a, 0xff, 0x73, 0x73, 0x3d, 0xd2, 0x26, 0xc2, 0xa6,
    0x87, 0xa3, 0x0d, 0x42, 0x21, 0x90, 0x2f, 0x39, 0x07, 0x97, 0x38, 0x24, 0x97, 0x81, 0xdb, 0x80,
    0xd1, 0xba, 0x67, 0x6b, 0x5a, 0xd8, 0xb9, 0xdc, 0x31, 0xe4, 0x97, 0xce, 0x07, 0x66, 0xeb, 0x91,
    0xae, 0xdf, 0x2b, 0x67, 0x75, 0xa8, 0x15, 0x0a, 0xba, 0xa2, 0xc5, 0x35, 0xae, 0x0e, 0x9e, 0xca,
    0x3a, 0x93, 0x73, 0x14, 0x34, 0xaf, 0xf8, 0x4c, 0xbc, 0x06, 0x35, 0xe8, 0x41, 0x51, 0x76, 0x5f,
    0x40, 0xed, 0xad, 0xcb, 0x3c, 0x17, 0x34, 0x58, 0x67, 0x1e, 0xd8, 0x8f, 0xc1, 0xf6, 0x37, 0xc7,
    0xb8, 0xa0, 0xd5, 0x3b, 0xa0, 0x95, 0x78, 0xd1, 0xda, 0x9e, 0x87, 0x62, 0x5b, 0x14, 0xb7, 0x72,
    0xfa, 0xee, 0xbd, 0x3d, 0xf6, 0x96, 0x16, 0x72, 0xd0, 0x18, 0xec, 0x3a, 0xbd, 0xd8, 0xbf, 0x8a,
    0x6a, 0xc2, 0xe7, 0xc0, 0x70, 0xaf, 0x41, 0xb5, 0xbb, 0x91, 0xe3, 0xed, 0x2c, 0xfb, 0xce, 0x6f,
    0xa5, 0xa8, 0xf7, 0x6d, 0x0e, 0x6c, 0xe3, 0x02, 0x91, 0xfa, 0xb5, 0x59, 0x5e, 0x90, 0x39, 0x76,
    0x85, 0xa5, 0xa1, 0xbe, 0xa8, 0xca, 0xb2, 0x05, 0xa6, 0xa4, 0xfe, 0x4a, 0x0a, 0x17, 0xec, 0xca,
    0x87, 0x7f, 0x01, 0x50, 0x99, 0xe8, 0x47, 0xba, 0x19, 0xa9, 0xb0, 0xe5, 0x34, 0x30, 0x6f, 0x0a,
    0x46, 0x79, 0xf3, 0xd0, 0xc8, 0x75, 0xa0, 0x41, 0xd4, 0xcd, 0x80, 0xc5, 0xac, 0xc9, 0xb3, 0xde,
    0xfc, 0x16, 0x7b, 0x64, 0x18, 0xe5, 0xac, 0x16, 0x93, 0xf5, 0x17, 0x0c, 0xfe, 0x75, 0x9b, 0xe7,
    0x6e, 0x3d, 0xe9, 0xa3, 0x72, 0x09, 0x65, 0x77, 0xe8, 0xf7, 0x72, 0xed, 0x57, 0x88, 0x3b, 0x66,
    0xc2, 0x3c, 0x63, 0x33, 0x0a, 0xdd, 0x74, 0x55, 0x56, 0x87, 0xa3, 0xa0, 0xc7, 0x54, 0xbc, 0xd2,
    0x30, 0x08, 0xfb, 0x5a, 0x8f, 0xc7, 0x8a, 0x6e, 0x66, 0x67, 0xe3, 0x4d, 0x43, 0x9e, 0x9d, 0xbb,
    0x7a, 0x6e, 0xb2, 0x39, 0xbd, 0x95, 0xfd, 0xcd, 0xbf, 0xe7, 0x39, 0xa4, 0x71, 0xf8, 0xc1, 0x37,
    0xc6, 0x70, 0xc3, 0x43, 0x74, 0x3c, 0x83, 0x12, 0xb4, 0xdf, 0xdd, 0xf0, 0x0c, 0x98, 0x46, 0x23,
    0xbf, 0xe8, 0x32, 0x14, 0x00, 0x5f, 0xad, 0x88, 0x1c, 0x0b, 0xe5, 0xbc, 0xe2, 0xca, 0xc6, 0xf4,
    0x5b, 0xb0, 0xf7, 0x1a, 0x40, 0xac, 0x1c, 0x06, 0x32, 0x5e, 0xdf, 0x43, 0xe5, 0x0e, 0x09, 0xb8,
    0x46, 0x1c, 0x20, 0x4c, 0xc8, 0x40, 0x57, 0x7b, 0x1d, 0x52, 0x3c, 0xa9, 0x99, 0x68, 0x85, 0xaf,
    0xa2, 0x38, 0x5c, 0x15, 0xc5, 0xe3, 0x2a, 0x92, 0xac, 0xb0, 0x55, 0x15, 0x87, 0xa8, 0xaa, 0x3b,
    0x2a, 0x16, 0x57, 0xfb, 0x9c, 0x0f, 0xbb, 0x32, 0x93, 0xdf, 0x18, 0x36, 0x3a, 0x38, 0xdc, 0xf8,
    0x24, 0xdc, 0xe8, 0x9b, 0xf9, 0xeb, 0x1b, 0xc2, 0x8a, 0xf6, 0x2a, 0x57, 0xa8, 0xcc, 0xae, 0xee,
    0xf3, 0x78, 0xf0, 0x79, 0xf4, 0x0d, 0x06, 0x72, 0xcb, 0x38, 0x13, 0x0b, 0x60, 0xdf, 0xbd, 0x2d,
    0x5a, 0xf8, 0x37, 0xe5, 0xdc, 0xea, 0x66, 0x5f, 0x9c, 0x00, 0x2a, 0x23, 0x85, 0xb8, 0x3a, 0x0c,
    0x89, 0x0d, 0xb8, 0x48, 0x68, 0x76, 0x84, 0x2c, 0xac, 0x96, 0x25, 0xde, 0x89, 0x54, 0x61, 0x73,
    0xd5, 0xdb, 0xba, 0xe4, 0x4d, 0x90, 0xb9, 0xfa, 0x6d, 0xdd, 0x8a, 0xc6, 0xe5, 0x5e, 0x15, 0x34,
    0x6f, 0x9c, 0xd3, 0xa9, 0xf5, 0x6c, 0xc2, 0x6d, 0xb0, 0x96, 0x4d, 0x53, 0x2e, 0xdd, 0x5f, 0x4d,
    0x59, 0xb9, 0xc7, 0xed, 0x47, 0x39, 0x21, 0xed, 0xfe, 0xb8, 0xed, 0x9e, 0x4f, 0x27, 0xf0, 0x8e,
    0xf2, 0xc1, 0x4a, 0xa1, 0x5f, 0x17, 0xfc, 0xfa, 0xdb, 0xb0, 0x40, 0x00, 0xb8, 0xe6, 0x75, 0x59,
    0x16, 0x94, 0xf0, 0xbd, 0x15, 0x2f, 0xa1, 0xff, 0xc9, 0xe5, 0x27, 0xff, 0x79, 0x92, 0x3f, 0x8c,
    0x78, 0xbb, 0xac, 0x36, 0xaf, 0x78, 0xa6, 0x9b, 0xe1, 0xbf, 0x10, 0x3b, 0xa7, 0x84, 0x8c, 0xce,
    0x17, 0x75, 0xd7, 0x04, 0x26, 0x41, 0x1a, 0x5f, 0x1e, 0x98, 0xe0, 0xac, 0xe4, 0xf1, 0x56, 0x37,
    0xf9, 0xf1, 0xfa, 0x36, 0xe3, 0x06, 0xbe, 0xc2, 0x6f, 0xea, 0xda, 0xe6, 0xef, 0x79, 0xa8, 0xe3,
    0x56, 0x91, 0x38, 0x3f, 0xd7, 0x3f, 0xa4, 0xa6, 0xcb, 0xb9, 0xec, 0xe0, 0xfb, 0xdb, 0x44, 0xae,
    0x58, 0x87, 0xaf, 0xf4, 0x76, 0xdc, 0x69, 0xed, 0xa4, 0xd3, 0x94, 0x05, 0xbc, 0xa1, 0xde, 0xcb,
    0x19, 0xeb, 0x9c, 0xd6, 0xc7, 0x4b, 0xaf, 0x8c, 0xe0, 0xcb, 0x7e, 0xc7, 0xf8, 0x92, 0xac, 0xff,
    0x9f, 0x0a, 0xfe, 0x40, 0x95, 0xb3, 0x95, 0x22, 0x0d, 0xd3, 0x4f, 0xea, 0xf2, 0x59, 0x73, 0x90,
    0x0b, 0x98, 0xa2, 0x5d, 0x72, 0xf3, 0x2c, 0x2a, 0xc2, 0x11, 0xcc, 0xe4, 0x8a, 0x82, 0xdb, 0xe5,
    0xca, 0xae, 0xf6, 0xf8, 0x6c, 0x7e, 0x00, 0x81, 0x74, 0x01, 0xc2, 0x53, 0x22, 0x4c, 0x67, 0x5c,
    0x29, 0xfe, 0xc1, 0x5c, 0xea, 0xfa, 0x2e, 0x0a, 0x1e, 0x43, 0xd6, 0x09, 0x5d, 0xab, 0x5f, 0x15,
    0x1f, 0x8a, 0x7f, 0x0a, 0xc6, 0xbf, 0x63, 0x97, 0x87, 0x3a, 0x3f, 0xb7, 0x8f, 0xf1, 0x78, 0x24,
    0x40, 0x6b, 0xa4, 0xd1, 0x2a, 0xf3, 0x0c, 0x7b, 0xdb, 0xda, 0x48, 0xe6, 0xf2, 0x89, 0xa1, 0x63,
    0xb4, 0xf9, 0x7a, 0xe5, 0x3e, 0x47, 0xae, 0x24, 0x34, 0x4a, 0x8e, 0xcc, 0x69, 0x36, 0x1f, 0x4f,
    0x28, 0x40, 0xe7, 0x77, 0x1a, 0x84, 0x39, 0x0c, 0x78, 0x2b, 0xb1, 0x89, 0x7d, 0xd8, 0xa4, 0x4d,
    0x43, 0x08, 0x87, 0x00, 0xcc, 0x1f, 0x31, 0x1f, 0x4f, 0xec, 0x43, 0x93, 0x46, 0x34, 0x88, 0x4b,
    0x56, 0x9a, 0x79, 0x49, 0xbf, 0x4b, 0x37, 0x9a, 0x79, 0xa6, 0x1b, 0xbd, 0xe7, 0xac, 0xf9, 0x28,
    0x1d, 0x9f, 0x00, 0x2e, 0x2c, 0xd4, 0x58, 0x56, 0xcb, 0x79, 0xde, 0x8a, 0x66, 0xc3, 0x78, 0xe1,
    0xce, 0x7e, 0xee, 0xdd, 0x7b, 0x84, 0x89, 0xb8, 0x64, 0x7b, 0x02, 0x37, 0x83, 0xd9, 0x88, 0x2a,
    0x3d, 0x00, 0xf7, 0xd0, 0x19, 0x0f, 0x3c, 0xea, 0xf8, 0xc8, 0xce, 0xae, 0xe3, 0x39, 0x58, 0xec,
    0x0f, 0x6a, 0x55, 0x70, 0x27, 0x7d, 0x77, 0x11, 0x78, 0x55, 0x37, 0x00, 0x3e, 0xd3, 0xe2, 0xae,
    0xb7, 0x10, 0x74, 0x8d, 0x37, 0x80, 0x3d, 0xcb, 0x52, 0x4f, 0xe3, 0xe7, 0x4e, 0x23, 0x6a, 0x4d,
    0x76, 0xd2, 0xee, 0x3b, 0xaa, 0xfe, 0x5d, 0xd5, 0x03, 0xec, 0x78, 0xb5, 0x06, 0x83, 0x17, 0x0b,
    0xde, 0x36, 0x0c, 0x5f, 0x28, 0x68, 0x4b, 0x71, 0xfa, 0xd0, 0xb0, 0xaa, 0x72, 0x0b, 0x42, 0x7b,
    0x02, 0xcc, 0xc0, 0x36, 0x6a, 0x1e, 0x82, 0x4e, 0x1f, 0x54, 0xd8, 0xff, 0x52, 0x93, 0x9a, 0x61,
    0xd4, 0x1f, 0xdc, 0xc4, 0xa2, 0x79, 0x4d, 0x84, 0x25, 0xf7, 0x24, 0x9f, 0x90, 0x33, 0x96, 0x0f,
    0x25, 0xc9, 0xde, 0x67, 0x94, 0x37, 0xac, 0xd9, 0x00, 0xbd, 0xb6, 0xfa, 0xf4, 0x8e, 0x48, 0x7f,
    0xec, 0x26, 0x23, 0x4b, 0xec, 0x6c, 0xa2, 0x47, 0xca, 0xc7, 0x48, 0x60, 0x25, 0x4a, 0x20, 0x35,
    0x00, 0xed, 0x9b, 0x83, 0x03, 0x80, 0xe6, 0x6c, 0xf6, 0xa9, 0x72, 0x27, 0x4b, 0x67, 0xf8, 0x19,
    0xee, 0x1d, 0xa9, 0x5c, 0x78, 0x7c, 0xd7, 0xec, 0xb6, 0xbd, 0x72, 0x11, 0x97, 0x36, 0x76, 0x4f,
    0x83, 0x31, 0xae, 0xdb, 0xb4, 0x37, 0xa3, 0x9d, 0xc0, 0xd6, 0xb0, 0x62, 0x91, 0x1f, 0x64, 0x61,
    0x16, 0xc9, 0x92, 0x84, 0x79, 0x38, 0xce, 0x01, 0xda, 0x36, 0x92, 0x42, 0x0c, 0xac, 0x88, 0x76,
    0xc0, 0xa2, 0xed, 0x69, 0xac, 0xba, 0x9f, 0xae, 0xba, 0x9f, 0xae, 0x06, 0x3f, 0x5d, 0x05, 0xac,
    0xb5, 0x18, 0x54, 0x6b, 0xfb, 0x09, 0xdb, 0x38, 0xbb, 0xfb, 0xe1, 0x29, 0x74, 0x11, 0x15, 0xfc,
    0x4e, 0x82, 0x76, 0x9b, 0x31, 0x66, 0x43, 0x7d, 0x47, 0xbd, 0xc2, 0x21, 0xf3, 0x29, 0xe4, 0xb8,
    0xdc, 0x60, 0xc0, 0xf8, 0x28, 0xc7, 0x68, 0xc5, 0xf7, 0xb5, 0x35, 0xdc, 0xda, 0x11, 0xfa, 0x03,
    0x5b, 0xe3, 0x66, 0x82, 0x58, 0x32, 0x89, 0xd3, 0xf9, 0xbe, 0xcc, 0xe9, 0x50, 0x63, 0x7b, 0x67,
    0x68, 0x05, 0xb5, 0x84, 0x97, 0x95, 0xb1, 0xc8, 0xc0, 0x45, 0x03, 0xfa, 0x49, 0x6b, 0x06, 0x5d,
    0x30, 0xd8, 0x08, 0x6f, 0xc6, 0x1b, 0x35, 0xd9, 0xf3, 0x8e, 0xbb, 0x1f, 0x8b, 0x91, 0x9d, 0x2b,
    0x6e, 0x71, 0xd7, 0x16, 0x4d, 0x98, 0x01, 0xb8, 0x47, 0xf2, 0x1c, 0x80, 0x3f, 0xd2, 0xe7, 0x03,
    0xcb, 0x20, 0x9f, 0x4a, 0xfe, 0xa8, 0x2a, 0xaf, 0x70, 0xc7, 0x8c, 0xf9, 0x7a, 0x74, 0xc0, 0x8d,
    0x6f, 0xc6, 0x7f, 0x6e, 0x71, 0x87, 0xdd, 0x9c, 0x8d, 0x20, 0xa7, 0xdd, 0x2c, 0x58, 0xd6, 0x11,
    0xb6, 0x7e, 0x4c, 0x72, 0x75, 0x4f, 0x5b, 0xb0, 0x47, 0x73, 0xa0, 0xbe, 0x87, 0xdb, 0x2c, 0x4e,
    0xde, 0x91, 0xb3, 0x31, 0xf2, 0x8d, 0x7b, 0xd8, 0x42, 0x1d, 0x93, 0x43, 0xf4, 0x3c, 0xcc, 0x66,
    0x61, 0x58, 0x47, 0x4c, 0x87, 0xaf, 0x4d, 0x4a, 0x9c, 0x24, 0x85, 0x91, 0x8c, 0xdf, 0xf1, 0x35,
    0x0b, 0x22, 0x7a, 0xdd, 0xe9, 0x13, 0x44, 0x4a, 0x71, 0xe6, 0x61, 0x0b, 0x0d, 0xff, 0x38, 0x44,
    0xcf, 0xe3, 0x6a, 0x06, 0xe6, 0xdc, 0xc1, 0xc6, 0x4f, 0x75, 0xb3, 0x28, 0x7f, 0xdc, 0x8e, 0xe2,
    0x3d, 0x11, 0xe2, 0x71, 0x51, 0x97, 0xed, 0xdc, 0xae, 0x96, 0x9a, 0xf2, 0xbb, 0x3b, 0x7e, 0x09,
    0x40, 0x51, 0x31, 0x6f, 0x39, 0x19, 0x70, 0xe2, 0x5c, 0x4e, 0x82, 0x3e, 0xea, 0x45, 0x77, 0x1a,
    0xc9, 0xee, 0x4b, 0xe0, 0xe4, 0xeb, 0x2c, 0x75, 0x47, 0xde, 0x4e, 0x37, 0x85, 0x4c, 0x75, 0xec,
    0x2c, 0x0a, 0xbc, 0x45, 0xa8, 0xf4, 0xb4, 0xcd, 0x07, 0xb9, 0x1e, 0xa6, 0x81, 0x23, 0x47, 0x3d,
    0x70, 0xd0, 0xb8, 0x8e, 0x86, 0x7d, 0xac, 0x09, 0x17, 0x79, 0x77, 0xda, 0x24, 0x28, 0x65, 0x87,
    0x1d, 0x9e, 0xf5, 0xbf, 0xcb, 0xd2, 0xee, 0x8d, 0xac, 0x6d, 0x08, 0xc2, 0x38, 0xe8, 0xcd, 0xf0,
    0x2f, 0x00, 0xa6, 0x72, 0x02, 0x0f, 0x52, 0x0d, 0x83, 0x23, 0x78, 0x60, 0x88, 0x62, 0x33, 0x2f,
    0x79, 0x3f, 0x73, 0x0a, 0x7a, 0x4c, 0xd0, 0xa2, 0x7f, 0xd2, 0x49, 0xd1, 0xa3, 0xd0, 0x8b, 0x9d,
    0xb3, 0x73, 0xd6, 0x08, 0x38, 0xe5, 0xea, 0xf7, 0x46, 0x7a, 0xc2, 0x27, 0x60, 0x84, 0x43, 0x7e,
    0x67, 0x12, 0xf3, 0xb0, 0x5f, 0x9b, 0x39, 0x15, 0xfc, 0xbb, 0x2e, 0x86, 0x01, 0xf8, 0xaa, 0x66,
    0x65, 0xcd, 0x1a, 0xd9, 0xa0, 0xd0, 0xb4, 0xea, 0xa8, 0xb2, 0x9f, 0xe2, 0xbd, 0x5e, 0x2b, 0x16,
    0x83, 0x2a, 0xf2, 0xd9, 0x41, 0x53, 0x50, 0x2f, 0xea, 0xdc, 0x17, 0x10, 0xd7, 0x0c, 0xf2, 0xc3,
    0x20, 0xb1, 0xa4, 0x2f, 0x44, 0xc8, 0x71, 0xf7, 0xbe, 0x14, 0x6e, 0xd5, 0xdb, 0x4d, 0x05, 0x37,
    0xe0, 0xf1, 0x70, 0x80, 0xe5, 0x3b, 0x05, 0xec, 0xa1, 0x72, 0x47, 0xcb, 0xba, 0x16, 0x68, 0xf7,
    0x1a, 0x20, 0x79, 0xce, 0xfe, 0x7a, 0x24, 0xf6, 0xe2, 0x60, 0x10, 0x0a, 0xc5, 0x6b, 0xea, 0xd7,
    0xe3, 0x74, 0xc7, 0x94, 0xcc, 0x9c, 0x6f, 0x03, 0x9d, 0xf2, 0x0d, 0x90, 0x3c, 0x67, 0x7d, 0x1d,
    0x52, 0xb2, 0x4f, 0x4c, 0xd1, 0x16, 0xaf, 0xaa, 0x24, 0x9c, 0xaa, 0x92, 0xdd, 0xaa, 0x8a, 0xb6,
    0x68, 0x75, 0x25, 0xc1, 0xd4, 0x95, 0xbc, 0x54, 0x57, 0xb4, 0x45, 0x6a, 0x2c, 0x09, 0xa4, 0xb1,
    0x64, 0xb7, 0xc6, 0xa2, 0x2d, 0x5a, 0x6b, 0x49, 0x30, 0xad, 0xa5, 0x47, 0xb5, 0x16, 0x3d, 0xe3,
    0x45, 0x97, 0x86, 0x13, 0x5d, 0x7a, 0x58, 0x74, 0x92, 0x25, 0x56, 0x7c, 0x69, 0x30, 0xf1, 0xa5,
    0xfb, 0xc4, 0x27, 0xd9, 0xe1, 0x24, 0x98, 0x06, 0x92, 0x60, 0x7a, 0x58, 0x82, 0x92, 0x1f, 0x56,
    0x8a, 0xde, 0x77, 0xb3, 0x7c, 0xa1, 0x24, 0x0b, 0x74, 0xd6, 0x47, 0x41, 0x81, 0xce, 0x9e, 0x9e,
    0x31, 0xaf, 0xea, 0x0b, 0x9d, 0x35, 0xae, 0x6f, 0x75, 0x81, 0xee, 0x4d, 0xf7, 0xb4, 0xee, 0xa2,
    0xe1, 0x1b, 0x78, 0xf0, 0x5b, 0x63, 0xbb, 0x6a, 0xbf, 0x1a, 0x77, 0x2d, 0x15, 0xe1, 0xc6, 0xf6,
    0x35, 0x09, 0x9b, 0x77, 0x94, 0x6d, 0x37, 0x73, 0x0f, 0x6b, 0x17, 0x51, 0xdf, 0x80, 0x23, 0xe8,
    0x1a, 0x77, 0x4a, 0xd7, 0x74, 0xb2, 0x9e, 0x2d, 0xb8, 0xd3, 0x49, 0x50, 0xd6, 0x91, 0xd5, 0xed,
    0x6c, 0xfe, 0xb5, 0x36, 0x59, 0xff, 0x1b, 0x60, 0xba, 0xbf, 0xc6, 0x9b, 0x92, 0xd4, 0x73, 0xe8,
    0x8e, 0x22, 0xb0, 0xef, 0x49, 0x40, 0xd1, 0x11, 0xb4, 0xdd, 0xce, 0x3d, 0x48, 0x92, 0xf6, 0x4d,
    0x0c, 0xee, 0x79, 0x0a, 0x77, 0x4a, 0xd4, 0x74, 0xba, 0x9e, 0x2a, 0xbc, 0x13, 0xf2, 0x8c, 0xd6,
    0x87, 0x42, 0xe6, 0xbf, 0xfe, 0x06, 0xc9, 0xe0, 0xfd, 0xa2, 0x72, 0x47, 0x8f, 0x67, 0x00, 0xfe,
    0x02, 0x03, 0x3c, 0x12, 0x8d, 0x07, 0xa0, 0x95, 0xea, 0x38, 0x96, 0xed, 0x9e, 0x84, 0xcf, 0x8b,
    0xee, 0x5e, 0xb2, 0x20, 0x73, 0x2e, 0x8d, 0x9e, 0x0f, 0xd1, 0x6d, 0x1f, 0xf2, 0x9d, 0x30, 0x3d,
    0xcc, 0x48, 0x97, 0xde, 0x14, 0x82, 0xa9, 0xc6, 0x0b, 0x35, 0x9b, 0x7b, 0x98, 0x31, 0x21, 0xdc,
    0xcd, 0xad, 0xe1, 0xce, 0x3b, 0x4f, 0x92, 0x82, 0x7f, 0xc0, 0x65, 0x28, 0xbb, 0xf2, 0x88, 0x01,
    0xfc, 0x17, 0x24, 0xa3, 0x3a, 0xf3, 0xc8, 0x7b, 0x7c, 0xb3, 0x97, 0xc5, 0x1e, 0xbb, 0xc4, 0xda,
    0x44, 0x06, 0xd1, 0xcb, 0x6a, 0x6b, 0x25, 0x48, 0xd6, 0xac, 0xc5, 0x72, 0xe9, 0x16, 0x39, 0x61,
    0xc5, 0x98, 0xef, 0x76, 0xc7, 0xab, 0x8a, 0x08, 0x81, 0xb4, 0xf7, 0x48, 0xd7, 0xa3, 0x63, 0x8b,
    0x02, 0xdc, 0x25, 0x7a, 0x04, 0xdf, 0xa9, 0x6b, 0x87, 0x94, 0x3b, 0x2e, 0xc0, 0x0e, 0xd5, 0x03,
    0x78, 0x4e, 0x50, 0x3b, 0x20, 0x86, 0xba, 0x67, 0xb8, 0xff, 0xdc, 0x6b, 0x32, 0xda, 0xc1, 0x08,
    0xc7, 0x02, 0x38, 0xf2, 0xf5, 0x00, 0x9e, 0x53, 0x4e, 0x07, 0x14, 0x4f, 0x54, 0x12, 0x35, 0x68,
    0xb9, 0xc4, 0xc1, 0xe4, 0x12, 0x8f, 0xe5, 0x22, 0x39, 0x21, 0x65, 0x13, 0x87, 0x92, 0x4d, 0x3c,
    0x94, 0x4d, 0xd4, 0xe0, 0xc4, 0x13, 0x87, 0x11, 0x4f, 0x3c, 0x16, 0x8f, 0x64, 0x83, 0x14, 0x51,
    0x1c, 0x4a, 0x44, 0xc9, 0x3e, 0x11, 0x45, 0x35, 0x5a, 0x4d, 0x49, 0x30, 0x35, 0x25, 0xbb, 0xd5,
    0x14, 0xd5, 0x58, 0x55, 0x25, 0xa1, 0x54, 0x95, 0xbc, 0x54, 0x55, 0x54, 0xe3, 0xb4, 0x95, 0x84,
    0xd1, 0x56, 0xb2, 0x5b, 0x5b, 0x92, 0x15, 0x52, 0x63, 0x49, 0x28, 0x8d, 0xa5, 0x47, 0x35, 0x16,
    0xfd, 0x85, 0x16, 0x5b, 0x1a, 0x4c, 0x6c, 0xe9, 0x61, 0xb1, 0x49, 0x8e, 0x48, 0xd1, 0xa5, 0xa1,
    0x44, 0x97, 0xee, 0x13, 0x9d, 0xe4, 0x86, 0x92, 0x5e, 0x1a, 0x46, 0x7a, 0xe9, 0x61, 0xe9, 0x49,
    0x76, 0x48, 0x09, 0xa6, 0xa1, 0x24, 0x78, 0xb1, 0xfb, 0x3d, 0xa5, 0xc1, 0x1b, 0xbe, 0x42, 0x5c,
    0x1c, 0x88, 0x10, 0x97, 0x32, 0x74, 0xc1, 0x9b, 0x02, 0x8d, 0x45, 0xc4, 0xdd, 0x80, 0x60, 0x6d,
    0x2a, 0x33, 0x17, 0xbb, 0x0c, 0x50, 0xda, 0x7b, 0x47, 0xb9, 0x3b, 0x75, 0xa3, 0xc4, 0x72, 0x62,
    0xa9, 0x10, 0x1e, 0x4b, 0x19, 0x5a, 0x81, 0x2d, 0x09, 0x0f, 0xcf, 0x26, 0x2d, 0xe6, 0xf0, 0xa2,
    0xc1, 0xb5, 0xa8, 0xec, 0xe0, 0x4b, 0x86, 0x90, 0xa2, 0x34, 0xc8, 0xe0, 0x05, 0x83, 0x2a, 0x51,
    0x59, 0xc1, 0x17, 0x0b, 0x2c, 0x44, 0xfc, 0x5d, 0x80, 0xfb, 0xae, 0xfd, 0x3b, 0x67, 0x90, 0xd8,
    0xeb, 0x92, 0xc0, 0x13, 0xee, 0x03, 0xbc, 0x04, 0xf7, 0x24, 0x28, 0x77, 0xf3, 0xff, 0xe2, 0xb9,
    0x68, 0x29, 0x7c, 0x2e, 0xab, 0x45, 0xf4, 0xf3, 0x1f, 0x72, 0x47, 0xed, 0xd0, 0xee, 0x25, 0xc6,
    0x9f, 0x1f, 0x70, 0x25, 0xad, 0xd7, 0x6d, 0x96, 0xd0, 0x7b, 0x9d, 0xb1, 0x5a, 0x0b, 0x73, 0xdf,
    0xe5, 0xa5, 0xf7, 0xb2, 0xce, 0x72, 0x23, 0xe6, 0x91, 0xee, 0x7f, 0xce, 0xe2, 0xa8, 0x94, 0xbe,
    0xa2, 0xdf, 0x00, 0x08, 0x11, 0x49, 0xef, 0x30, 0x43, 0x45, 0xd3, 0xbf, 0xd2, 0xba, 0xa1, 0xeb,
    0x00, 0x79, 0x45, 0x0e, 0xc8, 0x77, 0x91, 0x67, 0x71, 0x7c, 0x33, 0x8a, 0x1c, 0x8c, 0xe7, 0x82,
    0xce, 0xc2, 0xf8, 0xe4, 0x12, 0x39, 0x08, 0xaf, 0x05, 0x9c, 0x05, 0xf1, 0xcd, 0x22, 0x72, 0x30,
    0x9e, 0x8b, 0x35, 0x03, 0x13, 0x32, 0x7f, 0xc8, 0x21, 0x86, 0x51, 0x4f, 0x12, 0xb6, 0x77, 0x24,
    0x61, 0x54, 0x14, 0x20, 0x67, 0xc8, 0x01, 0x05, 0xd0, 0x52, 0xb0, 0x6c, 0x21, 0x07, 0x17, 0x44,
    0x53, 0x67, 0xc9, 0x13, 0x72, 0xd0, 0x61, 0xc4, 0x15, 0x3c, 0x43, 0xc8, 0xc1, 0x06, 0x11, 0x59,
    0xb0, 0xdc, 0x20, 0x07, 0x17, 0x40, 0x6a, 0xc1, 0xb3, 0x82, 0x1c, 0x6c, 0x10, 0xc9, 0x5d, 0x2c,
    0xe2, 0xf4, 0x95, 0xd1, 0xe7, 0x4a, 0x32, 0x0c, 0xbb, 0x73, 0xcd, 0x38, 0x6b, 0xd4, 0xa1, 0xc7,
    0x2d, 0x9d, 0xfc, 0x57, 0x77, 0x35, 0x9a, 0xba, 0xd7, 0xee, 0xa7, 0xff, 0x01, 0x58, 0x08, 0xc0,
    0xa7
};
#endif

PyTypeObject *init_QOpenGLFunctions_1_2(PyObject *module)
{
    if (SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX].type != nullptr)
        return SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX].type;

    Shiboken::AutoDecRef Sbk_QOpenGLFunctions_1_2_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtOpenGLTypeStructs[SBK_QAbstractOpenGLFunctions_IDX]))));

    _Sbk_QOpenGLFunctions_1_2_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QOpenGLFunctions_1_2",
        "QOpenGLFunctions_1_2*",
        &Sbk_QOpenGLFunctions_1_2_spec,
        &Shiboken::callCppDestructor< QOpenGLFunctions_1_2 >,
        Sbk_QOpenGLFunctions_1_2_Type_bases.object(),
        0);
    auto *pyType = Sbk_QOpenGLFunctions_1_2_TypeF(); // references _Sbk_QOpenGLFunctions_1_2_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QOpenGLFunctions_1_2_SignatureStrings);
#else
    InitSignatureBytes(pyType, QOpenGLFunctions_1_2_SignatureBytes, QOpenGLFunctions_1_2_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QOpenGLFunctions_1_2_PropertyStrings);
    SbkPySide6_QtOpenGLTypeStructs[SBK_QOpenGLFunctions_1_2_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QOpenGLFunctions_1_2_PythonToCpp_QOpenGLFunctions_1_2_PTR,
        is_QOpenGLFunctions_1_2_PythonToCpp_QOpenGLFunctions_1_2_PTR_Convertible,
        QOpenGLFunctions_1_2_PTR_CppToPython_QOpenGLFunctions_1_2);

    Shiboken::Conversions::registerConverterName(converter, "QOpenGLFunctions_1_2");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLFunctions_1_2*");
    Shiboken::Conversions::registerConverterName(converter, "QOpenGLFunctions_1_2&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QOpenGLFunctions_1_2).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QOpenGLFunctions_1_2Wrapper).name());


    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QOpenGLFunctions_1_2_TypeF(), &Sbk_QOpenGLFunctions_1_2_typeDiscovery);


    qRegisterMetaType< ::QOpenGLFunctions_1_2 *>();

    return pyType;
}

