// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <QtCore/QBuffer>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtquick_python.h"

// main header
#include "qquickitem_wrapper.h"

// inner classes
#include "qquickitem_updatepaintnodedata_wrapper.h"

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qcursor.h>
#include <QtGui/qevent.h>
#include <QtGui/qtransform.h>
#include <QtQml/qjsvalue.h>
#include <QtQuick/qquickitem.h>
#include <QtQuick/qquickitemgrabresult.h>
#include <QtQuick/qquickwindow.h>
#include <QtQuick/qsgnode.h>
#include <QtQuick/qsgtextureprovider.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qsharedpointer.h>
#include <qsize.h>
#include <qthread.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QQuickItemWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QQuickItemWrapper::QQuickItemWrapper(::QQuickItem * parent) : QQuickItem(parent)
{
}

::QRectF QQuickItemWrapper::boundingRect() const
{
    if (m_PyMethodCache[0])
        return this->::QQuickItem::boundingRect();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "boundingRect";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QQuickItem::boundingRect();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickItem", funcName, Shiboken::SbkType< QRectF >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QRectF cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QQuickItemWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

bool QQuickItemWrapper::childMouseEventFilter(::QQuickItem * arg__1, ::QEvent * arg__2)
{
    if (m_PyMethodCache[2])
        return this->::QQuickItem::childMouseEventFilter(arg__1, arg__2);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childMouseEventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QQuickItem::childMouseEventFilter(arg__1, arg__2);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__2)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__2)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickItem", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QQuickItemWrapper::classBegin()
{
    if (m_PyMethodCache[3]) {
        return this->::QQuickItem::classBegin();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "classBegin";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QQuickItem::classBegin();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

::QRectF QQuickItemWrapper::clipRect() const
{
    if (m_PyMethodCache[4])
        return this->::QQuickItem::clipRect();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "clipRect";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QQuickItem::clipRect();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickItem", funcName, Shiboken::SbkType< QRectF >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QRectF cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QQuickItemWrapper::componentComplete()
{
    if (m_PyMethodCache[5]) {
        return this->::QQuickItem::componentComplete();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "componentComplete";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QQuickItem::componentComplete();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[6]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

bool QQuickItemWrapper::contains(const ::QPointF & point) const
{
    if (m_PyMethodCache[7])
        return this->::QQuickItem::contains(point);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "contains";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QQuickItem::contains(point);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &point)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &point)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickItem", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QQuickItemWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[8]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[9]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::dragEnterEvent(::QDragEnterEvent * arg__1)
{
    if (m_PyMethodCache[10]) {
        return this->::QQuickItem::dragEnterEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragEnterEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QQuickItem::dragEnterEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::dragLeaveEvent(::QDragLeaveEvent * arg__1)
{
    if (m_PyMethodCache[11]) {
        return this->::QQuickItem::dragLeaveEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragLeaveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QQuickItem::dragLeaveEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::dragMoveEvent(::QDragMoveEvent * arg__1)
{
    if (m_PyMethodCache[12]) {
        return this->::QQuickItem::dragMoveEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragMoveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QQuickItem::dragMoveEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::dropEvent(::QDropEvent * arg__1)
{
    if (m_PyMethodCache[13]) {
        return this->::QQuickItem::dropEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dropEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QQuickItem::dropEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

bool QQuickItemWrapper::event(::QEvent * arg__1)
{
    if (m_PyMethodCache[14])
        return this->::QQuickItem::event(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QQuickItem::event(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickItem", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QQuickItemWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[15])
        return this->::QObject::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[15] = true;
        gil.release();
        return this->::QObject::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickItem", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QQuickItemWrapper::focusInEvent(::QFocusEvent * arg__1)
{
    if (m_PyMethodCache[16]) {
        return this->::QQuickItem::focusInEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusInEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[16] = true;
        gil.release();
        return this->::QQuickItem::focusInEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::focusOutEvent(::QFocusEvent * arg__1)
{
    if (m_PyMethodCache[17]) {
        return this->::QQuickItem::focusOutEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusOutEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[17] = true;
        gil.release();
        return this->::QQuickItem::focusOutEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::geometryChange(const ::QRectF & newGeometry, const ::QRectF & oldGeometry)
{
    if (m_PyMethodCache[18]) {
        return this->::QQuickItem::geometryChange(newGeometry, oldGeometry);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "geometryChange";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[18] = true;
        gil.release();
        return this->::QQuickItem::geometryChange(newGeometry, oldGeometry);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &newGeometry),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &oldGeometry)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &newGeometry),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &oldGeometry)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::hoverEnterEvent(::QHoverEvent * event)
{
    if (m_PyMethodCache[19]) {
        return this->::QQuickItem::hoverEnterEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hoverEnterEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[19] = true;
        gil.release();
        return this->::QQuickItem::hoverEnterEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHoverEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHoverEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::hoverLeaveEvent(::QHoverEvent * event)
{
    if (m_PyMethodCache[20]) {
        return this->::QQuickItem::hoverLeaveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hoverLeaveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[20] = true;
        gil.release();
        return this->::QQuickItem::hoverLeaveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHoverEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHoverEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::hoverMoveEvent(::QHoverEvent * event)
{
    if (m_PyMethodCache[21]) {
        return this->::QQuickItem::hoverMoveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hoverMoveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[21] = true;
        gil.release();
        return this->::QQuickItem::hoverMoveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHoverEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHoverEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::inputMethodEvent(::QInputMethodEvent * arg__1)
{
    if (m_PyMethodCache[22]) {
        return this->::QQuickItem::inputMethodEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "inputMethodEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[22] = true;
        gil.release();
        return this->::QQuickItem::inputMethodEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

::QVariant QQuickItemWrapper::inputMethodQuery(::Qt::InputMethodQuery query) const
{
    if (m_PyMethodCache[23])
        return this->::QQuickItem::inputMethodQuery(query);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "inputMethodQuery";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[23] = true;
        gil.release();
        return this->::QQuickItem::inputMethodQuery(query);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, &query)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, &query)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickItem", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QQuickItemWrapper::isTextureProvider() const
{
    if (m_PyMethodCache[24])
        return this->::QQuickItem::isTextureProvider();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "isTextureProvider";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[24] = true;
        gil.release();
        return this->::QQuickItem::isTextureProvider();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickItem", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QQuickItemWrapper::keyPressEvent(::QKeyEvent * event)
{
    if (m_PyMethodCache[25]) {
        return this->::QQuickItem::keyPressEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "keyPressEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[25] = true;
        gil.release();
        return this->::QQuickItem::keyPressEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    if (m_PyMethodCache[26]) {
        return this->::QQuickItem::keyReleaseEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "keyReleaseEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[26] = true;
        gil.release();
        return this->::QQuickItem::keyReleaseEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[27]) {
        return this->::QQuickItem::mouseDoubleClickEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseDoubleClickEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[27] = true;
        gil.release();
        return this->::QQuickItem::mouseDoubleClickEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[28]) {
        return this->::QQuickItem::mouseMoveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseMoveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[28] = true;
        gil.release();
        return this->::QQuickItem::mouseMoveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::mousePressEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[29]) {
        return this->::QQuickItem::mousePressEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mousePressEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[29] = true;
        gil.release();
        return this->::QQuickItem::mousePressEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[30]) {
        return this->::QQuickItem::mouseReleaseEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseReleaseEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[30] = true;
        gil.release();
        return this->::QQuickItem::mouseReleaseEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::mouseUngrabEvent()
{
    if (m_PyMethodCache[31]) {
        return this->::QQuickItem::mouseUngrabEvent();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseUngrabEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[31] = true;
        gil.release();
        return this->::QQuickItem::mouseUngrabEvent();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::releaseResources()
{
    if (m_PyMethodCache[32]) {
        return this->::QQuickItem::releaseResources();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "releaseResources";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[32] = true;
        gil.release();
        return this->::QQuickItem::releaseResources();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

::QSGTextureProvider * QQuickItemWrapper::textureProvider() const
{
    if (m_PyMethodCache[33])
        return this->::QQuickItem::textureProvider();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "textureProvider";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[33] = true;
        gil.release();
        return this->::QQuickItem::textureProvider();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTextureProvider_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickItem", funcName, Shiboken::SbkType< QSGTextureProvider >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSGTextureProvider *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QQuickItemWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[34]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[34] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::touchEvent(::QTouchEvent * event)
{
    if (m_PyMethodCache[35]) {
        return this->::QQuickItem::touchEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "touchEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[35] = true;
        gil.release();
        return this->::QQuickItem::touchEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTouchEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTouchEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::touchUngrabEvent()
{
    if (m_PyMethodCache[36]) {
        return this->::QQuickItem::touchUngrabEvent();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "touchUngrabEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[36] = true;
        gil.release();
        return this->::QQuickItem::touchUngrabEvent();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

::QSGNode * QQuickItemWrapper::updatePaintNode(::QSGNode * arg__1, ::QQuickItem::UpdatePaintNodeData * arg__2)
{
    if (m_PyMethodCache[37])
        return this->::QQuickItem::updatePaintNode(arg__1, arg__2);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "updatePaintNode";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[37] = true;
        gil.release();
        return this->::QQuickItem::updatePaintNode(arg__1, arg__2);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_UpdatePaintNodeData_IDX]), arg__2)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_UpdatePaintNodeData_IDX]), arg__2)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QQuickItem", funcName, Shiboken::SbkType< QSGNode >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QSGNode *cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (Shiboken::Object::checkType(pyResult))
        Shiboken::Object::releaseOwnership(pyResult);
    return cppResult;
}

void QQuickItemWrapper::updatePolish()
{
    if (m_PyMethodCache[38]) {
        return this->::QQuickItem::updatePolish();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "updatePolish";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[38] = true;
        gil.release();
        return this->::QQuickItem::updatePolish();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

void QQuickItemWrapper::wheelEvent(::QWheelEvent * event)
{
    if (m_PyMethodCache[39]) {
        return this->::QQuickItem::wheelEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "wheelEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[39] = true;
        gil.release();
        return this->::QQuickItem::wheelEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), event)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), event)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QQuickItem", funcName);
        return;
    }
}

const QMetaObject *QQuickItemWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QQuickItem::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QQuickItemWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QQuickItem::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QQuickItemWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QQuickItemWrapper *>(this));
    return QQuickItem::qt_metacast(_clname);
}

QQuickItemWrapper::~QQuickItemWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QQuickItem_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PyTypeObject *type = self->ob_type;
    PyTypeObject *myType = Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
    if (type != myType)
        Shiboken::ObjectType::copyMultipleInheritance(type, myType);

    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QQuickItem >()))
        return -1;

    QQuickItemWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|O:QQuickItem", &(pyArgs[0])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QQuickItem::QQuickItem(QQuickItem*=)
    if (numArgs == 0) {
        overloadId = 0; // QQuickItem(QQuickItem*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QQuickItem(QQuickItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                // fall through to handle extra keyword signals and properties
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return -1;
        ::QQuickItem *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // QQuickItem(QQuickItem*)
            void *addr = PySide::nextQObjectMemoryAddr();
            if (addr != nullptr) {
                cptr = new (addr) QQuickItemWrapper(cppArg0);
                PySide::setNextQObjectMemoryAddr(nullptr);
            } else {
                cptr = new QQuickItemWrapper(cppArg0);
            }

            // Ownership transferences (constructor heuristics).
            Shiboken::Object::setParent(pyArgs[0], self);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QQuickItem >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QQuickItemFunc_acceptHoverEvents(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // acceptHoverEvents()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->acceptHoverEvents();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_acceptTouchEvents(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // acceptTouchEvents()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->acceptTouchEvents();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_acceptedMouseButtons(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // acceptedMouseButtons()const
        QFlags<Qt::MouseButton> cppResult = const_cast<const ::QQuickItem *>(cppSelf)->acceptedMouseButtons();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MouseButton_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_activeFocusOnTab(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activeFocusOnTab()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->activeFocusOnTab();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_antialiasing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // antialiasing()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->antialiasing();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_baselineOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // baselineOffset()const
        qreal cppResult = const_cast<const ::QQuickItem *>(cppSelf)->baselineOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_boundingRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // boundingRect()const
        QRectF cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QQuickItem *>(cppSelf)->::QQuickItem::boundingRect()
            : const_cast<const ::QQuickItem *>(cppSelf)->boundingRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_childAt(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "childAt", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::childAt(qreal,qreal)const->QQuickItem*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // childAt(qreal,qreal)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "childAt", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // childAt(qreal,qreal)const
            QQuickItem * cppResult = const_cast<const ::QQuickItem *>(cppSelf)->childAt(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_childItems(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // childItems()const
        QList<QQuickItem*> cppResult = const_cast<const ::QQuickItem *>(cppSelf)->childItems();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtQuickTypeConverters[SBK_QtQuick_QList_QQuickItemPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_childMouseEventFilter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "childMouseEventFilter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::childMouseEventFilter(QQuickItem*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // childMouseEventFilter(QQuickItem*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "childMouseEventFilter", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QQuickItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // childMouseEventFilter(QQuickItem*,QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::childMouseEventFilter(cppArg0, cppArg1)
                : cppSelf->childMouseEventFilter(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_childrenRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // childrenRect()
        QRectF cppResult = cppSelf->childrenRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_classBegin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // classBegin()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QQuickItem::classBegin()
            : cppSelf->classBegin();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_clip(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clip()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->clip();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_clipRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clipRect()const
        QRectF cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QQuickItem *>(cppSelf)->::QQuickItem::clipRect()
            : const_cast<const ::QQuickItem *>(cppSelf)->clipRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_componentComplete(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // componentComplete()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QQuickItem::componentComplete()
            : cppSelf->componentComplete();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_containmentMask(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // containmentMask()const
        QObject * cppResult = const_cast<const ::QQuickItem *>(cppSelf)->containmentMask();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_contains(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::contains(QPointF)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // contains(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contains", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // contains(QPointF)const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QQuickItem *>(cppSelf)->::QQuickItem::contains(*cppArg0)
                : const_cast<const ::QQuickItem *>(cppSelf)->contains(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_cursor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cursor()const
        QCursor cppResult = const_cast<const ::QQuickItem *>(cppSelf)->cursor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_dragEnterEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::dragEnterEvent(QDragEnterEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragEnterEvent(QDragEnterEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragEnterEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDragEnterEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragEnterEvent(QDragEnterEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::dragEnterEvent(cppArg0)
                : cppSelf->dragEnterEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_dragLeaveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::dragLeaveEvent(QDragLeaveEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragLeaveEvent(QDragLeaveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragLeaveEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDragLeaveEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragLeaveEvent(QDragLeaveEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::dragLeaveEvent(cppArg0)
                : cppSelf->dragLeaveEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_dragMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::dragMoveEvent(QDragMoveEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragMoveEvent(QDragMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragMoveEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDragMoveEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragMoveEvent(QDragMoveEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::dragMoveEvent(cppArg0)
                : cppSelf->dragMoveEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_dropEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::dropEvent(QDropEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dropEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDropEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dropEvent(QDropEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::dropEvent(cppArg0)
                : cppSelf->dropEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_dumpItemTree(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // dumpItemTree()const
        const_cast<const ::QQuickItem *>(cppSelf)->dumpItemTree();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_ensurePolished(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ensurePolished()
        cppSelf->ensurePolished();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_filtersChildMouseEvents(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filtersChildMouseEvents()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->filtersChildMouseEvents();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_flags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // flags()const
        QFlags<QQuickItem::Flag> cppResult = const_cast<const ::QQuickItem *>(cppSelf)->flags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QQuickItem_Flag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_focusInEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::focusInEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusInEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusInEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::focusInEvent(cppArg0)
                : cppSelf->focusInEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_focusOutEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::focusOutEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusOutEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusOutEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::focusOutEvent(cppArg0)
                : cppSelf->focusOutEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_focusPolicy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // focusPolicy()const
        Qt::FocusPolicy cppResult = const_cast<const ::QQuickItem *>(cppSelf)->focusPolicy();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FocusPolicy_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_forceActiveFocus(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "forceActiveFocus", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::forceActiveFocus()
    // 1: QQuickItem::forceActiveFocus(Qt::FocusReason)
    if (numArgs == 0) {
        overloadId = 0; // forceActiveFocus()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FocusReason_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 1; // forceActiveFocus(Qt::FocusReason)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "forceActiveFocus", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // forceActiveFocus()
        {

            // forceActiveFocus()
            cppSelf->forceActiveFocus();
            break;
        }
        case 1: // forceActiveFocus(Qt::FocusReason reason)
        {
            ::Qt::FocusReason cppArg0{Qt::MouseFocusReason};
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // forceActiveFocus(Qt::FocusReason)
                cppSelf->forceActiveFocus(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_geometryChange(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "geometryChange", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::geometryChange(QRectF,QRectF)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
        overloadId = 0; // geometryChange(QRectF,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "geometryChange", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRectF cppArg1_local;
        ::QRectF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // geometryChange(QRectF,QRectF)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::geometryChange(*cppArg0, *cppArg1)
                : cppSelf->geometryChange(*cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_grabMouse(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // grabMouse()
        cppSelf->grabMouse();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_grabToImage(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "grabToImage", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    if (PyArg_ParseTuple(args, "|OO:grabToImage", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::grabToImage(QJSValue,const QSize&=)->bool
    // 1: QQuickItem::grabToImage(const QSize&=)->QSharedPointer<QQuickItemGrabResult>
    if (numArgs == 0) {
        overloadId = 1; // grabToImage(QSize)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0])))) {
        overloadId = 1; // grabToImage(QSize)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QJSValue_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // grabToImage(QJSValue,QSize)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1])))) {
            overloadId = 0; // grabToImage(QJSValue,QSize)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "grabToImage", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // grabToImage(const QJSValue &callback, const QSize &targetSize)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_targetSize = Shiboken::String::createStaticString("targetSize");
                if (PyDict_Contains(kwds, key_targetSize) != 0) {
                    value = PyDict_GetItem(kwds, key_targetSize);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_targetSize);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "grabToImage", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "grabToImage", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_targetSize);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "grabToImage", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QJSValue cppArg0_local;
            ::QJSValue *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QSize cppArg1_local = QSize();
            ::QSize *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // grabToImage(QJSValue,QSize)
                bool cppResult = cppSelf->grabToImage(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // grabToImage(const QSize &targetSize)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_targetSize = Shiboken::String::createStaticString("targetSize");
                if (PyDict_Contains(kwds, key_targetSize) != 0) {
                    value = PyDict_GetItem(kwds, key_targetSize);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_targetSize);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "grabToImage", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "grabToImage", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_targetSize);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "grabToImage", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QSize cppArg0_local = QSize();
            ::QSize *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0]) {
                if (pythonToCpp[0].isValue())
                    pythonToCpp[0](pyArgs[0], &cppArg0_local);
                else
                    pythonToCpp[0](pyArgs[0], &cppArg0);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // grabToImage(QSize)
                QSharedPointer<QQuickItemGrabResult> cppResult = cppSelf->grabToImage(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSharedPointer_QQuickItemGrabResult_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_grabTouchPoints(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::grabTouchPoints(QList<int>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(SbkPySide6_QtQuickTypeConverters[SBK_QtQuick_QList_int_IDX], (pyArg)))) {
        overloadId = 0; // grabTouchPoints(QList<int>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "grabTouchPoints", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        ::QList<int> cppArg0_local;
        ::QList<int> *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // grabTouchPoints(QList<int>)
            cppSelf->grabTouchPoints(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_hasActiveFocus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasActiveFocus()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->hasActiveFocus();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_hasFocus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasFocus()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->hasFocus();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_height(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // height()const
        qreal cppResult = const_cast<const ::QQuickItem *>(cppSelf)->height();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_heightValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // heightValid()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->heightValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_hoverEnterEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::hoverEnterEvent(QHoverEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHoverEvent_IDX]), (pyArg)))) {
        overloadId = 0; // hoverEnterEvent(QHoverEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hoverEnterEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHoverEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hoverEnterEvent(QHoverEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::hoverEnterEvent(cppArg0)
                : cppSelf->hoverEnterEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_hoverLeaveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::hoverLeaveEvent(QHoverEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHoverEvent_IDX]), (pyArg)))) {
        overloadId = 0; // hoverLeaveEvent(QHoverEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hoverLeaveEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHoverEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hoverLeaveEvent(QHoverEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::hoverLeaveEvent(cppArg0)
                : cppSelf->hoverLeaveEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_hoverMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::hoverMoveEvent(QHoverEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHoverEvent_IDX]), (pyArg)))) {
        overloadId = 0; // hoverMoveEvent(QHoverEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "hoverMoveEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QHoverEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // hoverMoveEvent(QHoverEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::hoverMoveEvent(cppArg0)
                : cppSelf->hoverMoveEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_implicitHeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // implicitHeight()const
        qreal cppResult = const_cast<const ::QQuickItem *>(cppSelf)->implicitHeight();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_implicitWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // implicitWidth()const
        qreal cppResult = const_cast<const ::QQuickItem *>(cppSelf)->implicitWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_inputMethodEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::inputMethodEvent(QInputMethodEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), (pyArg)))) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "inputMethodEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QInputMethodEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inputMethodEvent(QInputMethodEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::inputMethodEvent(cppArg0)
                : cppSelf->inputMethodEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_inputMethodQuery(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::inputMethodQuery(Qt::InputMethodQuery)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "inputMethodQuery", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        ::Qt::InputMethodQuery cppArg0 = static_cast< ::Qt::InputMethodQuery>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inputMethodQuery(Qt::InputMethodQuery)const
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QQuickItem *>(cppSelf)->::QQuickItem::inputMethodQuery(cppArg0)
                : const_cast<const ::QQuickItem *>(cppSelf)->inputMethodQuery(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_isAncestorOf(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::isAncestorOf(const QQuickItem*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArg)))) {
        overloadId = 0; // isAncestorOf(const QQuickItem*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "isAncestorOf", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuickItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // isAncestorOf(const QQuickItem*)const
            bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->isAncestorOf(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_isComponentComplete(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isComponentComplete()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->isComponentComplete();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_isEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isEnabled()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->isEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_isFocusScope(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isFocusScope()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->isFocusScope();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_isTextureProvider(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isTextureProvider()const
        bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QQuickItem *>(cppSelf)->::QQuickItem::isTextureProvider()
            : const_cast<const ::QQuickItem *>(cppSelf)->isTextureProvider();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_isUnderMouse(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isUnderMouse()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->isUnderMouse();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_isVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isVisible()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->isVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_itemTransform(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::itemTransform(QQuickItem*,bool*)const->PyTuple
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArg)))) {
        overloadId = 0; // itemTransform(QQuickItem*,bool*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "itemTransform", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuickItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // itemTransform(QQuickItem*,bool*)const
            // Begin code injection
            // TEMPLATE - fix_args,bool* - START
            bool ok_;
            ::QTransform retval_ = cppSelf->itemTransform(cppArg0, &ok_);
            // TEMPLATE - tuple_retval_ok - START
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &ok_));
            // TEMPLATE - tuple_retval_ok - END
            // TEMPLATE - fix_args,bool* - END
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_keepMouseGrab(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // keepMouseGrab()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->keepMouseGrab();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_keepTouchGrab(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // keepTouchGrab()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->keepTouchGrab();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_keyPressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::keyPressEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyPressEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyPressEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::keyPressEvent(cppArg0)
                : cppSelf->keyPressEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_keyReleaseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::keyReleaseEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyReleaseEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyReleaseEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::keyReleaseEvent(cppArg0)
                : cppSelf->keyReleaseEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_mapFromGlobal(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "mapFromGlobal", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::mapFromGlobal(QPointF)const->QPointF
    // 1: QQuickItem::mapFromGlobal(qreal,qreal)const->QPointF
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // mapFromGlobal(qreal,qreal)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // mapFromGlobal(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mapFromGlobal", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mapFromGlobal(const QPointF &point) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // mapFromGlobal(QPointF)const
                QPointF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapFromGlobal(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
            }
            break;
        }
        case 1: // mapFromGlobal(qreal x, qreal y) const
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mapFromGlobal(qreal,qreal)const
                QPointF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapFromGlobal(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_mapFromItem(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 4)
        return Shiboken::returnWrongArguments(args, "mapFromItem", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    if (PyArg_UnpackTuple(args, "mapFromItem", 2, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::mapFromItem(const QQuickItem*,QPointF)const->QPointF
    // 1: QQuickItem::mapFromItem(const QQuickItem*,QRectF)const->QRectF
    // 2: QQuickItem::mapFromItem(const QQuickItem*,qreal,qreal)->QPointF
    // 3: QQuickItem::mapFromItem(const QQuickItem*,qreal,qreal,qreal,qreal)const->QRectF
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 2; // mapFromItem(const QQuickItem*,qreal,qreal)
            } else if (numArgs == 5
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[4])))) {
                overloadId = 3; // mapFromItem(const QQuickItem*,qreal,qreal,qreal,qreal)const
            }
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
            overloadId = 1; // mapFromItem(const QQuickItem*,QRectF)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))) {
            overloadId = 0; // mapFromItem(const QQuickItem*,QPointF)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mapFromItem", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mapFromItem(const QQuickItem *item, const QPointF &point) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQuickItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // mapFromItem(const QQuickItem*,QPointF)const
                QPointF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapFromItem(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
            }
            break;
        }
        case 1: // mapFromItem(const QQuickItem *item, const QRectF &rect) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQuickItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRectF cppArg1_local;
            ::QRectF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // mapFromItem(const QQuickItem*,QRectF)const
                QRectF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapFromItem(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
            }
            break;
        }
        case 2: // mapFromItem(const QQuickItem *item, qreal x, qreal y)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQuickItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mapFromItem(const QQuickItem*,qreal,qreal)
                QPointF cppResult = cppSelf->mapFromItem(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
            }
            break;
        }
        case 3: // mapFromItem(const QQuickItem *item, qreal x, qreal y, qreal width, qreal height) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQuickItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            qreal cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mapFromItem(const QQuickItem*,qreal,qreal,qreal,qreal)const
                QRectF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapFromItem(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_mapFromScene(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::mapFromScene(QPointF)const->QPointF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // mapFromScene(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mapFromScene", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mapFromScene(QPointF)const
            QPointF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapFromScene(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_mapRectFromItem(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "mapRectFromItem", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::mapRectFromItem(const QQuickItem*,QRectF)const->QRectF
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
        overloadId = 0; // mapRectFromItem(const QQuickItem*,QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mapRectFromItem", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QQuickItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRectF cppArg1_local;
        ::QRectF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mapRectFromItem(const QQuickItem*,QRectF)const
            QRectF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapRectFromItem(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_mapRectFromScene(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::mapRectFromScene(QRectF)const->QRectF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 0; // mapRectFromScene(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mapRectFromScene", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mapRectFromScene(QRectF)const
            QRectF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapRectFromScene(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_mapRectToItem(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "mapRectToItem", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::mapRectToItem(const QQuickItem*,QRectF)const->QRectF
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
        overloadId = 0; // mapRectToItem(const QQuickItem*,QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mapRectToItem", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QQuickItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRectF cppArg1_local;
        ::QRectF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mapRectToItem(const QQuickItem*,QRectF)const
            QRectF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapRectToItem(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_mapRectToScene(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::mapRectToScene(QRectF)const->QRectF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArg)))) {
        overloadId = 0; // mapRectToScene(QRectF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mapRectToScene", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QRectF cppArg0_local;
        ::QRectF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mapRectToScene(QRectF)const
            QRectF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapRectToScene(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_mapToGlobal(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "mapToGlobal", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::mapToGlobal(QPointF)const->QPointF
    // 1: QQuickItem::mapToGlobal(qreal,qreal)const->QPointF
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 1; // mapToGlobal(qreal,qreal)const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // mapToGlobal(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mapToGlobal", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mapToGlobal(const QPointF &point) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // mapToGlobal(QPointF)const
                QPointF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapToGlobal(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
            }
            break;
        }
        case 1: // mapToGlobal(qreal x, qreal y) const
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mapToGlobal(qreal,qreal)const
                QPointF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapToGlobal(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_mapToItem(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 4)
        return Shiboken::returnWrongArguments(args, "mapToItem", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    if (PyArg_UnpackTuple(args, "mapToItem", 2, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::mapToItem(const QQuickItem*,QPointF)const->QPointF
    // 1: QQuickItem::mapToItem(const QQuickItem*,QRectF)const->QRectF
    // 2: QQuickItem::mapToItem(const QQuickItem*,qreal,qreal)->QPointF
    // 3: QQuickItem::mapToItem(const QQuickItem*,qreal,qreal,qreal,qreal)const->QRectF
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 2; // mapToItem(const QQuickItem*,qreal,qreal)
            } else if (numArgs == 5
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[4])))) {
                overloadId = 3; // mapToItem(const QQuickItem*,qreal,qreal,qreal,qreal)const
            }
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
            overloadId = 1; // mapToItem(const QQuickItem*,QRectF)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))) {
            overloadId = 0; // mapToItem(const QQuickItem*,QPointF)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mapToItem", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mapToItem(const QQuickItem *item, const QPointF &point) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQuickItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPointF cppArg1_local;
            ::QPointF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // mapToItem(const QQuickItem*,QPointF)const
                QPointF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapToItem(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
            }
            break;
        }
        case 1: // mapToItem(const QQuickItem *item, const QRectF &rect) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQuickItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRectF cppArg1_local;
            ::QRectF *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // mapToItem(const QQuickItem*,QRectF)const
                QRectF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapToItem(cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
            }
            break;
        }
        case 2: // mapToItem(const QQuickItem *item, qreal x, qreal y)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQuickItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mapToItem(const QQuickItem*,qreal,qreal)
                QPointF cppResult = cppSelf->mapToItem(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
            }
            break;
        }
        case 3: // mapToItem(const QQuickItem *item, qreal x, qreal y, qreal width, qreal height) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QQuickItem *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            qreal cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mapToItem(const QQuickItem*,qreal,qreal,qreal,qreal)const
                QRectF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapToItem(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_mapToScene(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::mapToScene(QPointF)const->QPointF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // mapToScene(QPointF)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mapToScene", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mapToScene(QPointF)const
            QPointF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->mapToScene(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_mouseDoubleClickEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::mouseDoubleClickEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseDoubleClickEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseDoubleClickEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseDoubleClickEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::mouseDoubleClickEvent(cppArg0)
                : cppSelf->mouseDoubleClickEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_mouseMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::mouseMoveEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseMoveEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseMoveEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::mouseMoveEvent(cppArg0)
                : cppSelf->mouseMoveEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_mousePressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::mousePressEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mousePressEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mousePressEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::mousePressEvent(cppArg0)
                : cppSelf->mousePressEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_mouseReleaseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::mouseReleaseEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseReleaseEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseReleaseEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::mouseReleaseEvent(cppArg0)
                : cppSelf->mouseReleaseEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_mouseUngrabEvent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mouseUngrabEvent()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QQuickItem::mouseUngrabEvent()
            : cppSelf->mouseUngrabEvent();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_nextItemInFocusChain(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "nextItemInFocusChain", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    if (PyArg_ParseTuple(args, "|O:nextItemInFocusChain", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::nextItemInFocusChain(bool=)->QQuickItem*
    if (numArgs == 0) {
        overloadId = 0; // nextItemInFocusChain(bool)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        overloadId = 0; // nextItemInFocusChain(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "nextItemInFocusChain", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_forward = Shiboken::String::createStaticString("forward");
            if (PyDict_Contains(kwds, key_forward) != 0) {
                value = PyDict_GetItem(kwds, key_forward);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_forward);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "nextItemInFocusChain", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "nextItemInFocusChain", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_forward);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "nextItemInFocusChain", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
            }
        }
        bool cppArg0 = true;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // nextItemInFocusChain(bool)
            QQuickItem * cppResult = cppSelf->nextItemInFocusChain(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_opacity(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // opacity()const
        qreal cppResult = const_cast<const ::QQuickItem *>(cppSelf)->opacity();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_parentItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // parentItem()const
        QQuickItem * cppResult = const_cast<const ::QQuickItem *>(cppSelf)->parentItem();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_polish(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // polish()
        cppSelf->polish();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_position(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // position()const
        QPointF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->position();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_releaseResources(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // releaseResources()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QQuickItem::releaseResources()
            : cppSelf->releaseResources();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_resetAntialiasing(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetAntialiasing()
        cppSelf->resetAntialiasing();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_resetHeight(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetHeight()
        cppSelf->resetHeight();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_resetWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // resetWidth()
        cppSelf->resetWidth();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_rotation(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // rotation()const
        qreal cppResult = const_cast<const ::QQuickItem *>(cppSelf)->rotation();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_scale(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scale()const
        qreal cppResult = const_cast<const ::QQuickItem *>(cppSelf)->scale();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_scopedFocusItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // scopedFocusItem()const
        QQuickItem * cppResult = const_cast<const ::QQuickItem *>(cppSelf)->scopedFocusItem();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_setAcceptHoverEvents(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setAcceptHoverEvents(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAcceptHoverEvents(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAcceptHoverEvents", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAcceptHoverEvents(bool)
            cppSelf->setAcceptHoverEvents(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setAcceptTouchEvents(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setAcceptTouchEvents(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAcceptTouchEvents(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAcceptTouchEvents", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAcceptTouchEvents(bool)
            cppSelf->setAcceptTouchEvents(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setAcceptedMouseButtons(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setAcceptedMouseButtons(QFlags<Qt::MouseButton>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_MouseButton_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setAcceptedMouseButtons(QFlags<Qt::MouseButton>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAcceptedMouseButtons", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        ::QFlags<Qt::MouseButton> cppArg0 = QFlags<Qt::MouseButton>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAcceptedMouseButtons(QFlags<Qt::MouseButton>)
            cppSelf->setAcceptedMouseButtons(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setActiveFocusOnTab(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setActiveFocusOnTab(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setActiveFocusOnTab(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActiveFocusOnTab", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActiveFocusOnTab(bool)
            cppSelf->setActiveFocusOnTab(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setAntialiasing(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setAntialiasing(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setAntialiasing(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAntialiasing", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAntialiasing(bool)
            cppSelf->setAntialiasing(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setBaselineOffset(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setBaselineOffset(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setBaselineOffset(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBaselineOffset", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBaselineOffset(qreal)
            cppSelf->setBaselineOffset(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setClip(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setClip(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setClip(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setClip", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setClip(bool)
            cppSelf->setClip(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setContainmentMask(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setContainmentMask(QObject*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArg)))) {
        overloadId = 0; // setContainmentMask(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setContainmentMask", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QObject *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setContainmentMask(QObject*)
            cppSelf->setContainmentMask(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setCursor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setCursor(QCursor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCursor_IDX]), (pyArg)))) {
        overloadId = 0; // setCursor(QCursor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCursor", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QCursor cppArg0_local;
        ::QCursor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCursor(QCursor)
            cppSelf->setCursor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setEnabled", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setEnabled(bool)
            cppSelf->setEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setFiltersChildMouseEvents(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setFiltersChildMouseEvents(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFiltersChildMouseEvents(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFiltersChildMouseEvents", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFiltersChildMouseEvents(bool)
            cppSelf->setFiltersChildMouseEvents(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setFlag(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setFlag", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::setFlag(QQuickItem::Flag,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_Flag_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setFlag(QQuickItem::Flag,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setFlag(QQuickItem::Flag,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_enabled = Shiboken::String::createStaticString("enabled");
            if (PyDict_Contains(kwds, key_enabled) != 0) {
                value = PyDict_GetItem(kwds, key_enabled);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_enabled);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_enabled);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setFlag", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
            }
        }
        ::QQuickItem::Flag cppArg0 = static_cast< ::QQuickItem::Flag>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlag(QQuickItem::Flag,bool)
            cppSelf->setFlag(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setFlags(QFlags<QQuickItem::Flag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QQuickItem_Flag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFlags(QFlags<QQuickItem::Flag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFlags", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        ::QFlags<QQuickItem::Flag> cppArg0 = QFlags<QQuickItem::Flag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFlags(QFlags<QQuickItem::Flag>)
            cppSelf->setFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setFocus(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setFocus", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::setFocus(bool)
    // 1: QQuickItem::setFocus(bool,Qt::FocusReason)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setFocus(bool)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FocusReason_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 1; // setFocus(bool,Qt::FocusReason)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFocus", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setFocus(bool arg__1)
        {
            bool cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setFocus(bool)
                cppSelf->setFocus(cppArg0);
            }
            break;
        }
        case 1: // setFocus(bool focus, Qt::FocusReason reason)
        {
            bool cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::FocusReason cppArg1{Qt::MouseFocusReason};
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setFocus(bool,Qt::FocusReason)
                cppSelf->setFocus(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setFocusPolicy(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setFocusPolicy(Qt::FocusPolicy)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FocusPolicy_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFocusPolicy(Qt::FocusPolicy)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFocusPolicy", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        ::Qt::FocusPolicy cppArg0{Qt::NoFocus};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFocusPolicy(Qt::FocusPolicy)
            cppSelf->setFocusPolicy(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setHeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setHeight(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setHeight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHeight", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHeight(qreal)
            cppSelf->setHeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setImplicitHeight(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setImplicitHeight(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setImplicitHeight(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setImplicitHeight", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setImplicitHeight(qreal)
            cppSelf->setImplicitHeight(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setImplicitSize(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setImplicitSize", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::setImplicitSize(qreal,qreal)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))) {
        overloadId = 0; // setImplicitSize(qreal,qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setImplicitSize", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qreal cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setImplicitSize(qreal,qreal)
            cppSelf->setImplicitSize(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setImplicitWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setImplicitWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setImplicitWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setImplicitWidth", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setImplicitWidth(qreal)
            cppSelf->setImplicitWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setKeepMouseGrab(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setKeepMouseGrab(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setKeepMouseGrab(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setKeepMouseGrab", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setKeepMouseGrab(bool)
            cppSelf->setKeepMouseGrab(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setKeepTouchGrab(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setKeepTouchGrab(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setKeepTouchGrab(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setKeepTouchGrab", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setKeepTouchGrab(bool)
            cppSelf->setKeepTouchGrab(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setOpacity(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setOpacity(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setOpacity(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOpacity", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOpacity(qreal)
            cppSelf->setOpacity(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setParentItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setParentItem(QQuickItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArg)))) {
        overloadId = 0; // setParentItem(QQuickItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setParentItem", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuickItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setParentItem(QQuickItem*)
            cppSelf->setParentItem(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setPosition(QPointF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // setPosition(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPosition", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPosition(QPointF)
            cppSelf->setPosition(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setRotation(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setRotation(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setRotation(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setRotation", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setRotation(qreal)
            cppSelf->setRotation(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setScale(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setScale(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setScale(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setScale", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setScale(qreal)
            cppSelf->setScale(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setSize(QSizeF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), (pyArg)))) {
        overloadId = 0; // setSize(QSizeF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSize", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QSizeF cppArg0_local;
        ::QSizeF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setSize(QSizeF)
            cppSelf->setSize(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setSmooth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setSmooth(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setSmooth(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSmooth", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSmooth(bool)
            cppSelf->setSmooth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setState(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setState(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setState", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setState(QString)
            cppSelf->setState(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setTransformOrigin(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setTransformOrigin(QQuickItem::TransformOrigin)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_TransformOrigin_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setTransformOrigin(QQuickItem::TransformOrigin)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTransformOrigin", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        ::QQuickItem::TransformOrigin cppArg0{QQuickItem::TopLeft};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTransformOrigin(QQuickItem::TransformOrigin)
            cppSelf->setTransformOrigin(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setTransformOriginPoint(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setTransformOriginPoint(QPointF)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg)))) {
        overloadId = 0; // setTransformOriginPoint(QPointF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTransformOriginPoint", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPointF cppArg0_local;
        ::QPointF *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTransformOriginPoint(QPointF)
            cppSelf->setTransformOriginPoint(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVisible", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVisible(bool)
            cppSelf->setVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setWidth(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setWidth(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWidth", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWidth(qreal)
            cppSelf->setWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setX(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setX(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setX(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setX", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setX(qreal)
            cppSelf->setX(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setY(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setY(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setY(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setY", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setY(qreal)
            cppSelf->setY(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_setZ(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::setZ(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setZ(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setZ", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setZ(qreal)
            cppSelf->setZ(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_size(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // size()const
        QSizeF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->size();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSizeF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_smooth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // smooth()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->smooth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_stackAfter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::stackAfter(const QQuickItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArg)))) {
        overloadId = 0; // stackAfter(const QQuickItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "stackAfter", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuickItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // stackAfter(const QQuickItem*)
            cppSelf->stackAfter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_stackBefore(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::stackBefore(const QQuickItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), (pyArg)))) {
        overloadId = 0; // stackBefore(const QQuickItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "stackBefore", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QQuickItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // stackBefore(const QQuickItem*)
            cppSelf->stackBefore(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_state(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // state()const
        QString cppResult = const_cast<const ::QQuickItem *>(cppSelf)->state();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_textureProvider(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textureProvider()const
        QSGTextureProvider * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QQuickItem *>(cppSelf)->::QQuickItem::textureProvider()
            : const_cast<const ::QQuickItem *>(cppSelf)->textureProvider();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGTextureProvider_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_touchEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::touchEvent(QTouchEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTouchEvent_IDX]), (pyArg)))) {
        overloadId = 0; // touchEvent(QTouchEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "touchEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTouchEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // touchEvent(QTouchEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::touchEvent(cppArg0)
                : cppSelf->touchEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_touchUngrabEvent(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // touchUngrabEvent()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QQuickItem::touchUngrabEvent()
            : cppSelf->touchUngrabEvent();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_transformOrigin(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transformOrigin()const
        QQuickItem::TransformOrigin cppResult = const_cast<const ::QQuickItem *>(cppSelf)->transformOrigin();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_TransformOrigin_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_transformOriginPoint(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // transformOriginPoint()const
        QPointF cppResult = const_cast<const ::QQuickItem *>(cppSelf)->transformOriginPoint();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_ungrabMouse(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ungrabMouse()
        cppSelf->ungrabMouse();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_ungrabTouchPoints(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ungrabTouchPoints()
        cppSelf->ungrabTouchPoints();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_unsetCursor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // unsetCursor()
        cppSelf->unsetCursor();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_update(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // update()
        cppSelf->update();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_updateInputMethod(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "updateInputMethod", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    if (PyArg_ParseTuple(args, "|O:updateInputMethod", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::updateInputMethod(QFlags<Qt::InputMethodQuery>=)
    if (numArgs == 0) {
        overloadId = 0; // updateInputMethod(QFlags<Qt::InputMethodQuery>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_InputMethodQuery_IDX])))->flagsConverter, (pyArgs[0])))) {
        overloadId = 0; // updateInputMethod(QFlags<Qt::InputMethodQuery>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updateInputMethod", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_queries = Shiboken::String::createStaticString("queries");
            if (PyDict_Contains(kwds, key_queries) != 0) {
                value = PyDict_GetItem(kwds, key_queries);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_queries);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "updateInputMethod", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_InputMethodQuery_IDX])))->flagsConverter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "updateInputMethod", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_queries);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "updateInputMethod", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);
            }
        }
        ::QFlags<Qt::InputMethodQuery> cppArg0(Qt::ImQueryInput);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updateInputMethod(QFlags<Qt::InputMethodQuery>)
            cppSelf->updateInputMethod(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_updatePaintNode(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "updatePaintNode", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QQuickItem::updatePaintNode(QSGNode*,QQuickItem::UpdatePaintNodeData*)->QSGNode*
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), (pyArgs[0])))
        && (pyArgs[1] != Py_None && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_UpdatePaintNodeData_IDX]), (pyArgs[1]))))) {
        overloadId = 0; // updatePaintNode(QSGNode*,QQuickItem::UpdatePaintNodeData*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "updatePaintNode", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QSGNode *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QQuickItem::UpdatePaintNodeData *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // updatePaintNode(QSGNode*,QQuickItem::UpdatePaintNodeData*)
            QSGNode * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::updatePaintNode(cppArg0, cppArg1)
                : cppSelf->updatePaintNode(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QSGNode_IDX]), cppResult);

            // Ownership transferences.
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_updatePolish(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // updatePolish()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QQuickItem::updatePolish()
            : cppSelf->updatePolish();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_viewportItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewportItem()const
        QQuickItem * cppResult = const_cast<const ::QQuickItem *>(cppSelf)->viewportItem();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_wheelEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QQuickItem::wheelEvent(QWheelEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), (pyArg)))) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "wheelEvent", errInfo, SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWheelEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wheelEvent(QWheelEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QQuickItem::wheelEvent(cppArg0)
                : cppSelf->wheelEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QQuickItemFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // width()const
        qreal cppResult = const_cast<const ::QQuickItem *>(cppSelf)->width();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_widthValid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // widthValid()const
        bool cppResult = const_cast<const ::QQuickItem *>(cppSelf)->widthValid();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_window(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // window()const
        QQuickWindow * cppResult = const_cast<const ::QQuickItem *>(cppSelf)->window();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickWindow_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_x(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // x()const
        qreal cppResult = const_cast<const ::QQuickItem *>(cppSelf)->x();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_y(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // y()const
        qreal cppResult = const_cast<const ::QQuickItem *>(cppSelf)->y();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QQuickItemFunc_z(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // z()const
        qreal cppResult = const_cast<const ::QQuickItem *>(cppSelf)->z();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QQuickItem_PropertyStrings[] = {
    "activeFocus:hasActiveFocus",
    "activeFocusOnTab::",
    "antialiasing::",
    "baselineOffset::",
    "childrenRect:",
    "clip::",
    "containmentMask::",
    "enabled:isEnabled:",
    "focus:hasFocus:",
    "focusPolicy::",
    "height::",
    "implicitHeight::",
    "implicitWidth::",
    "opacity::",
    "parent:parentItem:setParentItem",
    "rotation::",
    "scale::",
    "smooth::",
    "state::",
    "transformOrigin::",
    "transformOriginPoint:",
    "visible:isVisible:",
    "width::",
    "x::",
    "y::",
    "z::",
    nullptr // Sentinel
};

static const char *Sbk_QQuickItem_EnumFlagInfo[] = {
    "Flag:Flag:Flags",
    "ItemChange:Enum",
    "TransformOrigin:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QQuickItem_methods[] = {
    {"acceptHoverEvents", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_acceptHoverEvents), METH_NOARGS, nullptr},
    {"acceptTouchEvents", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_acceptTouchEvents), METH_NOARGS, nullptr},
    {"acceptedMouseButtons", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_acceptedMouseButtons), METH_NOARGS, nullptr},
    {"activeFocusOnTab", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_activeFocusOnTab), METH_NOARGS, nullptr},
    {"antialiasing", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_antialiasing), METH_NOARGS, nullptr},
    {"baselineOffset", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_baselineOffset), METH_NOARGS, nullptr},
    {"boundingRect", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_boundingRect), METH_NOARGS, nullptr},
    {"childAt", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_childAt), METH_VARARGS, nullptr},
    {"childItems", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_childItems), METH_NOARGS, nullptr},
    {"childMouseEventFilter", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_childMouseEventFilter), METH_VARARGS, nullptr},
    {"childrenRect", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_childrenRect), METH_NOARGS, nullptr},
    {"classBegin", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_classBegin), METH_NOARGS, nullptr},
    {"clip", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_clip), METH_NOARGS, nullptr},
    {"clipRect", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_clipRect), METH_NOARGS, nullptr},
    {"componentComplete", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_componentComplete), METH_NOARGS, nullptr},
    {"containmentMask", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_containmentMask), METH_NOARGS, nullptr},
    {"contains", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_contains), METH_O, nullptr},
    {"cursor", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_cursor), METH_NOARGS, nullptr},
    {"dragEnterEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_dragEnterEvent), METH_O, nullptr},
    {"dragLeaveEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_dragLeaveEvent), METH_O, nullptr},
    {"dragMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_dragMoveEvent), METH_O, nullptr},
    {"dropEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_dropEvent), METH_O, nullptr},
    {"dumpItemTree", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_dumpItemTree), METH_NOARGS, nullptr},
    {"ensurePolished", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_ensurePolished), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_event), METH_O, nullptr},
    {"filtersChildMouseEvents", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_filtersChildMouseEvents), METH_NOARGS, nullptr},
    {"flags", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_flags), METH_NOARGS, nullptr},
    {"focusInEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_focusInEvent), METH_O, nullptr},
    {"focusOutEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_focusOutEvent), METH_O, nullptr},
    {"focusPolicy", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_focusPolicy), METH_NOARGS, nullptr},
    {"forceActiveFocus", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_forceActiveFocus), METH_VARARGS, nullptr},
    {"geometryChange", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_geometryChange), METH_VARARGS, nullptr},
    {"grabMouse", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_grabMouse), METH_NOARGS, nullptr},
    {"grabToImage", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_grabToImage), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"grabTouchPoints", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_grabTouchPoints), METH_O, nullptr},
    {"hasActiveFocus", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_hasActiveFocus), METH_NOARGS, nullptr},
    {"hasFocus", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_hasFocus), METH_NOARGS, nullptr},
    {"height", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_height), METH_NOARGS, nullptr},
    {"heightValid", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_heightValid), METH_NOARGS, nullptr},
    {"hoverEnterEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_hoverEnterEvent), METH_O, nullptr},
    {"hoverLeaveEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_hoverLeaveEvent), METH_O, nullptr},
    {"hoverMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_hoverMoveEvent), METH_O, nullptr},
    {"implicitHeight", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_implicitHeight), METH_NOARGS, nullptr},
    {"implicitWidth", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_implicitWidth), METH_NOARGS, nullptr},
    {"inputMethodEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_inputMethodEvent), METH_O, nullptr},
    {"inputMethodQuery", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_inputMethodQuery), METH_O, nullptr},
    {"isAncestorOf", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_isAncestorOf), METH_O, nullptr},
    {"isComponentComplete", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_isComponentComplete), METH_NOARGS, nullptr},
    {"isEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_isEnabled), METH_NOARGS, nullptr},
    {"isFocusScope", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_isFocusScope), METH_NOARGS, nullptr},
    {"isTextureProvider", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_isTextureProvider), METH_NOARGS, nullptr},
    {"isUnderMouse", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_isUnderMouse), METH_NOARGS, nullptr},
    {"isVisible", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_isVisible), METH_NOARGS, nullptr},
    {"itemTransform", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_itemTransform), METH_O, nullptr},
    {"keepMouseGrab", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_keepMouseGrab), METH_NOARGS, nullptr},
    {"keepTouchGrab", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_keepTouchGrab), METH_NOARGS, nullptr},
    {"keyPressEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_keyPressEvent), METH_O, nullptr},
    {"keyReleaseEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_keyReleaseEvent), METH_O, nullptr},
    {"mapFromGlobal", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mapFromGlobal), METH_VARARGS, nullptr},
    {"mapFromItem", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mapFromItem), METH_VARARGS, nullptr},
    {"mapFromScene", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mapFromScene), METH_O, nullptr},
    {"mapRectFromItem", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mapRectFromItem), METH_VARARGS, nullptr},
    {"mapRectFromScene", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mapRectFromScene), METH_O, nullptr},
    {"mapRectToItem", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mapRectToItem), METH_VARARGS, nullptr},
    {"mapRectToScene", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mapRectToScene), METH_O, nullptr},
    {"mapToGlobal", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mapToGlobal), METH_VARARGS, nullptr},
    {"mapToItem", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mapToItem), METH_VARARGS, nullptr},
    {"mapToScene", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mapToScene), METH_O, nullptr},
    {"mouseDoubleClickEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mouseDoubleClickEvent), METH_O, nullptr},
    {"mouseMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mouseMoveEvent), METH_O, nullptr},
    {"mousePressEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mousePressEvent), METH_O, nullptr},
    {"mouseReleaseEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mouseReleaseEvent), METH_O, nullptr},
    {"mouseUngrabEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_mouseUngrabEvent), METH_NOARGS, nullptr},
    {"nextItemInFocusChain", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_nextItemInFocusChain), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"opacity", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_opacity), METH_NOARGS, nullptr},
    {"parentItem", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_parentItem), METH_NOARGS, nullptr},
    {"polish", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_polish), METH_NOARGS, nullptr},
    {"position", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_position), METH_NOARGS, nullptr},
    {"releaseResources", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_releaseResources), METH_NOARGS, nullptr},
    {"resetAntialiasing", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_resetAntialiasing), METH_NOARGS, nullptr},
    {"resetHeight", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_resetHeight), METH_NOARGS, nullptr},
    {"resetWidth", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_resetWidth), METH_NOARGS, nullptr},
    {"rotation", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_rotation), METH_NOARGS, nullptr},
    {"scale", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_scale), METH_NOARGS, nullptr},
    {"scopedFocusItem", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_scopedFocusItem), METH_NOARGS, nullptr},
    {"setAcceptHoverEvents", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setAcceptHoverEvents), METH_O, nullptr},
    {"setAcceptTouchEvents", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setAcceptTouchEvents), METH_O, nullptr},
    {"setAcceptedMouseButtons", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setAcceptedMouseButtons), METH_O, nullptr},
    {"setActiveFocusOnTab", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setActiveFocusOnTab), METH_O, nullptr},
    {"setAntialiasing", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setAntialiasing), METH_O, nullptr},
    {"setBaselineOffset", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setBaselineOffset), METH_O, nullptr},
    {"setClip", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setClip), METH_O, nullptr},
    {"setContainmentMask", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setContainmentMask), METH_O, nullptr},
    {"setCursor", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setCursor), METH_O, nullptr},
    {"setEnabled", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setEnabled), METH_O, nullptr},
    {"setFiltersChildMouseEvents", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setFiltersChildMouseEvents), METH_O, nullptr},
    {"setFlag", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setFlag), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setFlags", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setFlags), METH_O, nullptr},
    {"setFocus", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setFocus), METH_VARARGS, nullptr},
    {"setFocusPolicy", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setFocusPolicy), METH_O, nullptr},
    {"setHeight", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setHeight), METH_O, nullptr},
    {"setImplicitHeight", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setImplicitHeight), METH_O, nullptr},
    {"setImplicitSize", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setImplicitSize), METH_VARARGS, nullptr},
    {"setImplicitWidth", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setImplicitWidth), METH_O, nullptr},
    {"setKeepMouseGrab", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setKeepMouseGrab), METH_O, nullptr},
    {"setKeepTouchGrab", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setKeepTouchGrab), METH_O, nullptr},
    {"setOpacity", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setOpacity), METH_O, nullptr},
    {"setParentItem", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setParentItem), METH_O, nullptr},
    {"setPosition", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setPosition), METH_O, nullptr},
    {"setRotation", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setRotation), METH_O, nullptr},
    {"setScale", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setScale), METH_O, nullptr},
    {"setSize", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setSize), METH_O, nullptr},
    {"setSmooth", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setSmooth), METH_O, nullptr},
    {"setState", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setState), METH_O, nullptr},
    {"setTransformOrigin", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setTransformOrigin), METH_O, nullptr},
    {"setTransformOriginPoint", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setTransformOriginPoint), METH_O, nullptr},
    {"setVisible", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setVisible), METH_O, nullptr},
    {"setWidth", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setWidth), METH_O, nullptr},
    {"setX", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setX), METH_O, nullptr},
    {"setY", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setY), METH_O, nullptr},
    {"setZ", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_setZ), METH_O, nullptr},
    {"size", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_size), METH_NOARGS, nullptr},
    {"smooth", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_smooth), METH_NOARGS, nullptr},
    {"stackAfter", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_stackAfter), METH_O, nullptr},
    {"stackBefore", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_stackBefore), METH_O, nullptr},
    {"state", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_state), METH_NOARGS, nullptr},
    {"textureProvider", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_textureProvider), METH_NOARGS, nullptr},
    {"touchEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_touchEvent), METH_O, nullptr},
    {"touchUngrabEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_touchUngrabEvent), METH_NOARGS, nullptr},
    {"transformOrigin", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_transformOrigin), METH_NOARGS, nullptr},
    {"transformOriginPoint", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_transformOriginPoint), METH_NOARGS, nullptr},
    {"ungrabMouse", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_ungrabMouse), METH_NOARGS, nullptr},
    {"ungrabTouchPoints", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_ungrabTouchPoints), METH_NOARGS, nullptr},
    {"unsetCursor", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_unsetCursor), METH_NOARGS, nullptr},
    {"update", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_update), METH_NOARGS, nullptr},
    {"updateInputMethod", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_updateInputMethod), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"updatePaintNode", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_updatePaintNode), METH_VARARGS, nullptr},
    {"updatePolish", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_updatePolish), METH_NOARGS, nullptr},
    {"viewportItem", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_viewportItem), METH_NOARGS, nullptr},
    {"wheelEvent", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_wheelEvent), METH_O, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_width), METH_NOARGS, nullptr},
    {"widthValid", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_widthValid), METH_NOARGS, nullptr},
    {"window", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_window), METH_NOARGS, nullptr},
    {"x", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_x), METH_NOARGS, nullptr},
    {"y", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_y), METH_NOARGS, nullptr},
    {"z", reinterpret_cast<PyCFunction>(Sbk_QQuickItemFunc_z), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QQuickItem_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QQuickItemWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QQuickItem_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QQuickItem_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
extern "C"
{
static PyObject *Sbk_QQuickItem__repr__(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QQuickItem *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    QBuffer buffer;
    buffer.open(QBuffer::ReadWrite);
    QDebug dbg(&buffer);
    dbg << cppSelf;
    buffer.close();
    QByteArray str = buffer.data();
    const auto idx = str.indexOf('(');
    auto *typeName = Py_TYPE(self)->tp_name;
    if (idx >= 0)
        str.replace(0, idx, typeName);
    str = str.trimmed();
    Shiboken::AutoDecRef tpDict(PepType_GetDict(Py_TYPE(self)));
    PyObject *mod = PyDict_GetItem(tpDict.object(), Shiboken::PyMagicName::module());
    if (mod != nullptr && std::strchr(typeName, '.') == nullptr)
        return Shiboken::String::fromFormat("<%s.%s at %p>", Shiboken::String::toCString(mod), str.constData(), self);
    return Shiboken::String::fromFormat("<%s at %p>", str.constData(), self);
}
} // extern C

int *
Sbk_QQuickItem_mi_init(const void *cptr)
{
    static int mi_offsets[] = {-2, 0, 0, 0, 0};
    if (mi_offsets[0] == -2) {
        const auto *class_ptr = reinterpret_cast<const QQuickItem *>(cptr);
        const auto base = reinterpret_cast<uintptr_t>(class_ptr);
        int *p = mi_offsets;
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QObject *>(static_cast<const QQuickItem *>(static_cast<const void *>(class_ptr)))) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QQmlParserStatus *>(class_ptr)) - base);
        *p++ = int(reinterpret_cast<uintptr_t>(static_cast<const QQmlParserStatus *>(static_cast<const QQuickItem *>(static_cast<const void *>(class_ptr)))) - base);
        std::sort(mi_offsets, p);
        auto *end = std::unique(mi_offsets, p);
        *end++ = -1;
        if (mi_offsets[0] == 0)
            std::memmove(&mi_offsets[0], &mi_offsets[1], (end - mi_offsets  - 1) * sizeof(int));
    }
    return mi_offsets;
}
static void * Sbk_QQuickItemSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QQuickItem *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]))
        return static_cast< ::QQmlParserStatus *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QQuickItem_Type = nullptr;
static PyTypeObject *Sbk_QQuickItem_TypeF(void)
{
    return _Sbk_QQuickItem_Type;
}

static PyType_Slot Sbk_QQuickItem_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_repr,        reinterpret_cast<void *>(Sbk_QQuickItem__repr__)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QQuickItem_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QQuickItem_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QQuickItem_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QQuickItem_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QQuickItem_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QQuickItem_spec = {
    "2:PySide6.QtQuick.QQuickItem",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QQuickItem_slots
};

} //extern "C"

static void *Sbk_QQuickItem_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QQuickItem *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QQmlParserStatus >())
        return dynamic_cast< ::QQuickItem *>(reinterpret_cast< ::QQmlParserStatus *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QQuickItem_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QQuickItem::Flag>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QQuickItem::Flag *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QQuickItem_Flag_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_Flag_IDX])))
        return Enum_PythonToCpp_QQuickItem_Flag;
    return {};
}

static PyObject *QQuickItem_Flag_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QQuickItem::Flag>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QQuickItem::Flag *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_Flag_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QQuickItem_Flag(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QQuickItem::Flag>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QQuickItem::Flag> *>(cppOut) = value;

}

static PyObject *QQuickItem_Flag_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QQuickItem::Flag> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_Flag_IDX]), flags.toInt());

}

static void Enum_PythonToCpp_QQuickItem_ItemChange(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QQuickItem::ItemChange>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QQuickItem::ItemChange *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QQuickItem_ItemChange_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_ItemChange_IDX])))
        return Enum_PythonToCpp_QQuickItem_ItemChange;
    return {};
}

static PyObject *QQuickItem_ItemChange_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QQuickItem::ItemChange>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QQuickItem::ItemChange *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_ItemChange_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QQuickItem_TransformOrigin(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QQuickItem::TransformOrigin>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QQuickItem::TransformOrigin *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QQuickItem_TransformOrigin_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_TransformOrigin_IDX])))
        return Enum_PythonToCpp_QQuickItem_TransformOrigin;
    return {};
}

static PyObject *QQuickItem_TransformOrigin_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QQuickItem::TransformOrigin>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QQuickItem::TransformOrigin *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_TransformOrigin_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QQuickItem_PythonToCpp_QQuickItem_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QQuickItem_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QQuickItem_PythonToCpp_QQuickItem_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QQuickItem_TypeF()))
        return QQuickItem_PythonToCpp_QQuickItem_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QQuickItem_PTR_CppToPython_QQuickItem(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QQuickItem *>(const_cast<void *>(cppIn)), Sbk_QQuickItem_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QQuickItem_SignatureStrings[] = {
    "PySide6.QtQuick.QQuickItem(self,parent:PySide6.QtQuick.QQuickItem=nullptr,*:KeywordOnly=None,parent:QQuickItem=None,x:qreal=None,y:qreal=None,z:qreal=None,width:qreal=None,height:qreal=None,opacity:qreal=None,enabled:bool=None,visible:bool=None,state:QString=None,childrenRect:QRectF=None,baselineOffset:qreal=None,clip:bool=None,focus:bool=None,activeFocus:bool=None,activeFocusOnTab:bool=None,focusPolicy:Qt.FocusPolicy=None,rotation:qreal=None,scale:qreal=None,transformOrigin:QQuickItem.TransformOrigin=None,transformOriginPoint:QPointF=None,smooth:bool=None,antialiasing:bool=None,implicitWidth:qreal=None,implicitHeight:qreal=None,containmentMask:QObject=None)",
    "PySide6.QtQuick.QQuickItem.acceptHoverEvents(self)->bool",
    "PySide6.QtQuick.QQuickItem.acceptTouchEvents(self)->bool",
    "PySide6.QtQuick.QQuickItem.acceptedMouseButtons(self)->PySide6.QtCore.Qt.MouseButton",
    "PySide6.QtQuick.QQuickItem.activeFocusOnTab(self)->bool",
    "PySide6.QtQuick.QQuickItem.antialiasing(self)->bool",
    "PySide6.QtQuick.QQuickItem.baselineOffset(self)->qreal",
    "PySide6.QtQuick.QQuickItem.boundingRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QQuickItem.childAt(self,x:qreal,y:qreal)->PySide6.QtQuick.QQuickItem",
    "PySide6.QtQuick.QQuickItem.childItems(self)->QList[PySide6.QtQuick.QQuickItem]",
    "PySide6.QtQuick.QQuickItem.childMouseEventFilter(self,arg__1:PySide6.QtQuick.QQuickItem,arg__2:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtQuick.QQuickItem.childrenRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QQuickItem.classBegin(self)",
    "PySide6.QtQuick.QQuickItem.clip(self)->bool",
    "PySide6.QtQuick.QQuickItem.clipRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QQuickItem.componentComplete(self)",
    "PySide6.QtQuick.QQuickItem.containmentMask(self)->PySide6.QtCore.QObject",
    "PySide6.QtQuick.QQuickItem.contains(self,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->bool",
    "PySide6.QtQuick.QQuickItem.cursor(self)->PySide6.QtGui.QCursor",
    "PySide6.QtQuick.QQuickItem.dragEnterEvent(self,arg__1:PySide6.QtGui.QDragEnterEvent)",
    "PySide6.QtQuick.QQuickItem.dragLeaveEvent(self,arg__1:PySide6.QtGui.QDragLeaveEvent)",
    "PySide6.QtQuick.QQuickItem.dragMoveEvent(self,arg__1:PySide6.QtGui.QDragMoveEvent)",
    "PySide6.QtQuick.QQuickItem.dropEvent(self,arg__1:PySide6.QtGui.QDropEvent)",
    "PySide6.QtQuick.QQuickItem.dumpItemTree(self)",
    "PySide6.QtQuick.QQuickItem.ensurePolished(self)",
    "PySide6.QtQuick.QQuickItem.event(self,arg__1:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtQuick.QQuickItem.filtersChildMouseEvents(self)->bool",
    "PySide6.QtQuick.QQuickItem.flags(self)->PySide6.QtQuick.QQuickItem.Flag",
    "PySide6.QtQuick.QQuickItem.focusInEvent(self,arg__1:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtQuick.QQuickItem.focusOutEvent(self,arg__1:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtQuick.QQuickItem.focusPolicy(self)->PySide6.QtCore.Qt.FocusPolicy",
    "1:PySide6.QtQuick.QQuickItem.forceActiveFocus(self)",
    "0:PySide6.QtQuick.QQuickItem.forceActiveFocus(self,reason:PySide6.QtCore.Qt.FocusReason)",
    "PySide6.QtQuick.QQuickItem.geometryChange(self,newGeometry:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],oldGeometry:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtQuick.QQuickItem.grabMouse(self)",
    "1:PySide6.QtQuick.QQuickItem.grabToImage(self,callback:typing.Union[PySide6.QtQml.QJSValue, PySide6.QtQml.QJSValue.SpecialValue, bool, QLatin1String, QString, char*, double, int, uint],targetSize:PySide6.QtCore.QSize=QSize())->bool",
    "0:PySide6.QtQuick.QQuickItem.grabToImage(self,targetSize:PySide6.QtCore.QSize=QSize())->PySide6.QtQuick.QSharedPointer_QQuickItemGrabResult",
    "PySide6.QtQuick.QQuickItem.grabTouchPoints(self,ids:QList[int])",
    "PySide6.QtQuick.QQuickItem.hasActiveFocus(self)->bool",
    "PySide6.QtQuick.QQuickItem.hasFocus(self)->bool",
    "PySide6.QtQuick.QQuickItem.height(self)->qreal",
    "PySide6.QtQuick.QQuickItem.heightValid(self)->bool",
    "PySide6.QtQuick.QQuickItem.hoverEnterEvent(self,event:PySide6.QtGui.QHoverEvent)",
    "PySide6.QtQuick.QQuickItem.hoverLeaveEvent(self,event:PySide6.QtGui.QHoverEvent)",
    "PySide6.QtQuick.QQuickItem.hoverMoveEvent(self,event:PySide6.QtGui.QHoverEvent)",
    "PySide6.QtQuick.QQuickItem.implicitHeight(self)->qreal",
    "PySide6.QtQuick.QQuickItem.implicitWidth(self)->qreal",
    "PySide6.QtQuick.QQuickItem.inputMethodEvent(self,arg__1:PySide6.QtGui.QInputMethodEvent)",
    "PySide6.QtQuick.QQuickItem.inputMethodQuery(self,query:PySide6.QtCore.Qt.InputMethodQuery)->QVariant",
    "PySide6.QtQuick.QQuickItem.isAncestorOf(self,child:PySide6.QtQuick.QQuickItem)->bool",
    "PySide6.QtQuick.QQuickItem.isComponentComplete(self)->bool",
    "PySide6.QtQuick.QQuickItem.isEnabled(self)->bool",
    "PySide6.QtQuick.QQuickItem.isFocusScope(self)->bool",
    "PySide6.QtQuick.QQuickItem.isTextureProvider(self)->bool",
    "PySide6.QtQuick.QQuickItem.isUnderMouse(self)->bool",
    "PySide6.QtQuick.QQuickItem.isVisible(self)->bool",
    "PySide6.QtQuick.QQuickItem.itemTransform(self,arg__1:PySide6.QtQuick.QQuickItem)->Tuple[bool, PySide6.QtGui.QTransform]",
    "PySide6.QtQuick.QQuickItem.keepMouseGrab(self)->bool",
    "PySide6.QtQuick.QQuickItem.keepTouchGrab(self)->bool",
    "PySide6.QtQuick.QQuickItem.keyPressEvent(self,event:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtQuick.QQuickItem.keyReleaseEvent(self,event:PySide6.QtGui.QKeyEvent)",
    "1:PySide6.QtQuick.QQuickItem.mapFromGlobal(self,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->PySide6.QtCore.QPointF",
    "0:PySide6.QtQuick.QQuickItem.mapFromGlobal(self,x:qreal,y:qreal)->PySide6.QtCore.QPointF",
    "3:PySide6.QtQuick.QQuickItem.mapFromItem(self,item:PySide6.QtQuick.QQuickItem,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->PySide6.QtCore.QPointF",
    "2:PySide6.QtQuick.QQuickItem.mapFromItem(self,item:PySide6.QtQuick.QQuickItem,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])->PySide6.QtCore.QRectF",
    "1:PySide6.QtQuick.QQuickItem.mapFromItem(self,item:PySide6.QtQuick.QQuickItem,x:qreal,y:qreal)->PySide6.QtCore.QPointF",
    "0:PySide6.QtQuick.QQuickItem.mapFromItem(self,item:PySide6.QtQuick.QQuickItem,x:qreal,y:qreal,width:qreal,height:qreal)->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QQuickItem.mapFromScene(self,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->PySide6.QtCore.QPointF",
    "PySide6.QtQuick.QQuickItem.mapRectFromItem(self,item:PySide6.QtQuick.QQuickItem,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QQuickItem.mapRectFromScene(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QQuickItem.mapRectToItem(self,item:PySide6.QtQuick.QQuickItem,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QQuickItem.mapRectToScene(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])->PySide6.QtCore.QRectF",
    "1:PySide6.QtQuick.QQuickItem.mapToGlobal(self,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->PySide6.QtCore.QPointF",
    "0:PySide6.QtQuick.QQuickItem.mapToGlobal(self,x:qreal,y:qreal)->PySide6.QtCore.QPointF",
    "3:PySide6.QtQuick.QQuickItem.mapToItem(self,item:PySide6.QtQuick.QQuickItem,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->PySide6.QtCore.QPointF",
    "2:PySide6.QtQuick.QQuickItem.mapToItem(self,item:PySide6.QtQuick.QQuickItem,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])->PySide6.QtCore.QRectF",
    "1:PySide6.QtQuick.QQuickItem.mapToItem(self,item:PySide6.QtQuick.QQuickItem,x:qreal,y:qreal)->PySide6.QtCore.QPointF",
    "0:PySide6.QtQuick.QQuickItem.mapToItem(self,item:PySide6.QtQuick.QQuickItem,x:qreal,y:qreal,width:qreal,height:qreal)->PySide6.QtCore.QRectF",
    "PySide6.QtQuick.QQuickItem.mapToScene(self,point:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])->PySide6.QtCore.QPointF",
    "PySide6.QtQuick.QQuickItem.mouseDoubleClickEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtQuick.QQuickItem.mouseMoveEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtQuick.QQuickItem.mousePressEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtQuick.QQuickItem.mouseReleaseEvent(self,event:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtQuick.QQuickItem.mouseUngrabEvent(self)",
    "PySide6.QtQuick.QQuickItem.nextItemInFocusChain(self,forward:bool=true)->PySide6.QtQuick.QQuickItem",
    "PySide6.QtQuick.QQuickItem.opacity(self)->qreal",
    "PySide6.QtQuick.QQuickItem.parentItem(self)->PySide6.QtQuick.QQuickItem",
    "PySide6.QtQuick.QQuickItem.polish(self)",
    "PySide6.QtQuick.QQuickItem.position(self)->PySide6.QtCore.QPointF",
    "PySide6.QtQuick.QQuickItem.releaseResources(self)",
    "PySide6.QtQuick.QQuickItem.resetAntialiasing(self)",
    "PySide6.QtQuick.QQuickItem.resetHeight(self)",
    "PySide6.QtQuick.QQuickItem.resetWidth(self)",
    "PySide6.QtQuick.QQuickItem.rotation(self)->qreal",
    "PySide6.QtQuick.QQuickItem.scale(self)->qreal",
    "PySide6.QtQuick.QQuickItem.scopedFocusItem(self)->PySide6.QtQuick.QQuickItem",
    "PySide6.QtQuick.QQuickItem.setAcceptHoverEvents(self,enabled:bool)",
    "PySide6.QtQuick.QQuickItem.setAcceptTouchEvents(self,accept:bool)",
    "PySide6.QtQuick.QQuickItem.setAcceptedMouseButtons(self,buttons:PySide6.QtCore.Qt.MouseButton)",
    "PySide6.QtQuick.QQuickItem.setActiveFocusOnTab(self,arg__1:bool)",
    "PySide6.QtQuick.QQuickItem.setAntialiasing(self,arg__1:bool)",
    "PySide6.QtQuick.QQuickItem.setBaselineOffset(self,arg__1:qreal)",
    "PySide6.QtQuick.QQuickItem.setClip(self,arg__1:bool)",
    "PySide6.QtQuick.QQuickItem.setContainmentMask(self,mask:PySide6.QtCore.QObject)",
    "PySide6.QtQuick.QQuickItem.setCursor(self,cursor:typing.Union[PySide6.QtGui.QCursor, PySide6.QtCore.Qt.CursorShape, PySide6.QtGui.QPixmap])",
    "PySide6.QtQuick.QQuickItem.setEnabled(self,arg__1:bool)",
    "PySide6.QtQuick.QQuickItem.setFiltersChildMouseEvents(self,filter:bool)",
    "PySide6.QtQuick.QQuickItem.setFlag(self,flag:PySide6.QtQuick.QQuickItem.Flag,enabled:bool=true)",
    "PySide6.QtQuick.QQuickItem.setFlags(self,flags:PySide6.QtQuick.QQuickItem.Flag)",
    "1:PySide6.QtQuick.QQuickItem.setFocus(self,arg__1:bool)",
    "0:PySide6.QtQuick.QQuickItem.setFocus(self,focus:bool,reason:PySide6.QtCore.Qt.FocusReason)",
    "PySide6.QtQuick.QQuickItem.setFocusPolicy(self,policy:PySide6.QtCore.Qt.FocusPolicy)",
    "PySide6.QtQuick.QQuickItem.setHeight(self,arg__1:qreal)",
    "PySide6.QtQuick.QQuickItem.setImplicitHeight(self,arg__1:qreal)",
    "PySide6.QtQuick.QQuickItem.setImplicitSize(self,arg__1:qreal,arg__2:qreal)",
    "PySide6.QtQuick.QQuickItem.setImplicitWidth(self,arg__1:qreal)",
    "PySide6.QtQuick.QQuickItem.setKeepMouseGrab(self,arg__1:bool)",
    "PySide6.QtQuick.QQuickItem.setKeepTouchGrab(self,arg__1:bool)",
    "PySide6.QtQuick.QQuickItem.setOpacity(self,arg__1:qreal)",
    "PySide6.QtQuick.QQuickItem.setParentItem(self,parent:PySide6.QtQuick.QQuickItem)",
    "PySide6.QtQuick.QQuickItem.setPosition(self,arg__1:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "PySide6.QtQuick.QQuickItem.setRotation(self,arg__1:qreal)",
    "PySide6.QtQuick.QQuickItem.setScale(self,arg__1:qreal)",
    "PySide6.QtQuick.QQuickItem.setSize(self,size:typing.Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize])",
    "PySide6.QtQuick.QQuickItem.setSmooth(self,arg__1:bool)",
    "PySide6.QtQuick.QQuickItem.setState(self,arg__1:QString)",
    "PySide6.QtQuick.QQuickItem.setTransformOrigin(self,arg__1:PySide6.QtQuick.QQuickItem.TransformOrigin)",
    "PySide6.QtQuick.QQuickItem.setTransformOriginPoint(self,arg__1:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element])",
    "PySide6.QtQuick.QQuickItem.setVisible(self,arg__1:bool)",
    "PySide6.QtQuick.QQuickItem.setWidth(self,arg__1:qreal)",
    "PySide6.QtQuick.QQuickItem.setX(self,arg__1:qreal)",
    "PySide6.QtQuick.QQuickItem.setY(self,arg__1:qreal)",
    "PySide6.QtQuick.QQuickItem.setZ(self,arg__1:qreal)",
    "PySide6.QtQuick.QQuickItem.size(self)->PySide6.QtCore.QSizeF",
    "PySide6.QtQuick.QQuickItem.smooth(self)->bool",
    "PySide6.QtQuick.QQuickItem.stackAfter(self,arg__1:PySide6.QtQuick.QQuickItem)",
    "PySide6.QtQuick.QQuickItem.stackBefore(self,arg__1:PySide6.QtQuick.QQuickItem)",
    "PySide6.QtQuick.QQuickItem.state(self)->QString",
    "PySide6.QtQuick.QQuickItem.textureProvider(self)->PySide6.QtQuick.QSGTextureProvider",
    "PySide6.QtQuick.QQuickItem.touchEvent(self,event:PySide6.QtGui.QTouchEvent)",
    "PySide6.QtQuick.QQuickItem.touchUngrabEvent(self)",
    "PySide6.QtQuick.QQuickItem.transformOrigin(self)->PySide6.QtQuick.QQuickItem.TransformOrigin",
    "PySide6.QtQuick.QQuickItem.transformOriginPoint(self)->PySide6.QtCore.QPointF",
    "PySide6.QtQuick.QQuickItem.ungrabMouse(self)",
    "PySide6.QtQuick.QQuickItem.ungrabTouchPoints(self)",
    "PySide6.QtQuick.QQuickItem.unsetCursor(self)",
    "PySide6.QtQuick.QQuickItem.update(self)",
    "PySide6.QtQuick.QQuickItem.updateInputMethod(self,queries:PySide6.QtCore.Qt.InputMethodQuery=Qt.ImQueryInput)",
    "PySide6.QtQuick.QQuickItem.updatePaintNode(self,arg__1:PySide6.QtQuick.QSGNode,arg__2:PySide6.QtQuick.QQuickItem.UpdatePaintNodeData)->PySide6.QtQuick.QSGNode",
    "PySide6.QtQuick.QQuickItem.updatePolish(self)",
    "PySide6.QtQuick.QQuickItem.viewportItem(self)->PySide6.QtQuick.QQuickItem",
    "PySide6.QtQuick.QQuickItem.wheelEvent(self,event:PySide6.QtGui.QWheelEvent)",
    "PySide6.QtQuick.QQuickItem.width(self)->qreal",
    "PySide6.QtQuick.QQuickItem.widthValid(self)->bool",
    "PySide6.QtQuick.QQuickItem.window(self)->PySide6.QtQuick.QQuickWindow",
    "PySide6.QtQuick.QQuickItem.x(self)->qreal",
    "PySide6.QtQuick.QQuickItem.y(self)->qreal",
    "PySide6.QtQuick.QQuickItem.z(self)->qreal",
    nullptr}; // Sentinel
#else
static constexpr size_t QQuickItem_SignatureByteSize = 1930;
static constexpr uint8_t QQuickItem_SignatureBytes[1930] = {
    0x78, 0xda, 0xd5, 0x5a, 0xdd, 0x6f, 0xdb, 0x36, 0x10, 0x7f, 0xef, 0x5f, 0x91, 0xc7, 0xba, 0xd0,
    0x8c, 0xa4, 0x03, 0xf6, 0x60, 0x20, 0x03, 0x12, 0x37, 0x49, 0xb3, 0x34, 0x75, 0x1c, 0x3b, 0xed,
    0xb6, 0x22, 0x28, 0x68, 0xe9, 0x6c, 0x73, 0x91, 0x45, 0x95, 0xa4, 0xe2, 0xb8, 0x7f, 0xfd, 0x48,
    0x4a, 0xb6, 0xa8, 0x0f, 0xf3, 0xc3, 0x71, 0xd7, 0xec, 0xc5, 0x96, 0xa8, 0xbb, 0x1f, 0x8f, 0xe4,
    0xf1, 0xee, 0xc8, 0xbb, 0x9b, 0xd5, 0x08, 0x47, 0xf0, 0x5b, 0x77, 0xc8, 0x87, 0x19, 0x0e, 0x1f,
    0xba, 0x43, 0xf5, 0x77, 0xc9, 0x61, 0xf1, 0x9a, 0x41, 0x3c, 0x0d, 0x52, 0x44, 0x21, 0xe1, 0xbd,
    0x9b, 0xad, 0x64, 0xc7, 0x49, 0x16, 0xc7, 0x29, 0xa7, 0xc1, 0x9b, 0xde, 0x15, 0xac, 0x96, 0x84,
    0x46, 0x83, 0x24, 0x5e, 0x1d, 0x7f, 0x24, 0x09, 0xac, 0x99, 0x35, 0x62, 0xd5, 0xfc, 0xd4, 0xfb,
    0x46, 0x01, 0xc5, 0xf9, 0xcb, 0x4a, 0x7f, 0xf9, 0xae, 0xbf, 0x2c, 0x71, 0xc4, 0xe7, 0x7a, 0xc3,
    0x1c, 0xf0, 0x6c, 0xce, 0xf5, 0x16, 0x92, 0xa2, 0x10, 0xf3, 0x0a, 0x04, 0x24, 0x68, 0x12, 0x43,
    0xd4, 0x9b, 0x10, 0x52, 0xb4, 0x3c, 0x62, 0x86, 0x45, 0x93, 0xd6, 0xc2, 0x38, 0xe2, 0xd0, 0x1b,
    0x8e, 0x38, 0xc5, 0xc9, 0x2c, 0x6f, 0x0a, 0xe7, 0x38, 0x8e, 0x84, 0xb4, 0xb7, 0x10, 0x0a, 0x81,
    0xe5, 0xef, 0x79, 0xfe, 0x61, 0x82, 0xc4, 0x3c, 0xe0, 0x04, 0x06, 0xd3, 0x29, 0x83, 0x4a, 0xe7,
    0x61, 0x8c, 0x53, 0x0d, 0x74, 0x4a, 0xc2, 0x8c, 0x69, 0xef, 0x28, 0xe4, 0xf8, 0x11, 0xce, 0xb7,
    0xb7, 0x0e, 0x92, 0x31, 0x9a, 0xd4, 0x01, 0x6e, 0x48, 0x8c, 0xc3, 0x55, 0x6f, 0xc8, 0xbb, 0xe7,
    0xe5, 0x6b, 0xfe, 0x9d, 0x12, 0x21, 0x36, 0x26, 0x89, 0x2e, 0x03, 0x0b, 0x91, 0x18, 0x99, 0xd6,
    0xc0, 0x29, 0x4a, 0xd8, 0x94, 0xd0, 0xc5, 0x80, 0xe2, 0x19, 0x4e, 0xb4, 0xb9, 0xef, 0x8e, 0xab,
    0x9f, 0x5a, 0xe9, 0x6f, 0x08, 0x96, 0x0b, 0xa6, 0xfe, 0x8a, 0x09, 0x60, 0x0b, 0x42, 0xc4, 0x3a,
    0x68, 0x43, 0x48, 0x38, 0x46, 0x31, 0x46, 0x4c, 0x4c, 0x9e, 0xd6, 0x8c, 0x17, 0xa9, 0x90, 0x15,
    0xf3, 0xcf, 0xf5, 0x65, 0x5b, 0x7f, 0x78, 0xdf, 0x58, 0xbe, 0x90, 0x24, 0x1c, 0xe1, 0x64, 0x21,
    0x94, 0xe4, 0x1a, 0xb1, 0x87, 0xde, 0x70, 0x30, 0xf9, 0x47, 0xcc, 0xbc, 0xfa, 0xd8, 0x79, 0xb5,
    0x5d, 0xe7, 0xba, 0x28, 0x0c, 0x21, 0xe5, 0xef, 0xc9, 0x23, 0xd0, 0xb3, 0x47, 0xc1, 0xcd, 0x94,
    0xb2, 0x76, 0x7e, 0xf9, 0x5d, 0x8a, 0x63, 0x67, 0x1c, 0x93, 0x2c, 0x9c, 0xef, 0xc2, 0x08, 0xd1,
    0x35, 0xc9, 0x18, 0x9c, 0x66, 0x9c, 0x93, 0x64, 0xc3, 0x5b, 0xb2, 0xf5, 0x09, 0x05, 0xf1, 0xd7,
    0xd5, 0xa8, 0xcc, 0xa0, 0x55, 0x65, 0x70, 0x16, 0x46, 0x5b, 0x01, 0x57, 0x9e, 0xaa, 0x1e, 0xaf,
    0xb9, 0xd4, 0x62, 0x18, 0xd9, 0x48, 0x96, 0x44, 0xa2, 0x1b, 0xb9, 0x23, 0xb6, 0x8d, 0x57, 0xed,
    0x16, 0x13, 0x88, 0xda, 0x5c, 0x27, 0x39, 0xff, 0x7a, 0xf7, 0xaf, 0x37, 0x7e, 0x05, 0xaf, 0xce,
    0x69, 0x05, 0x95, 0x4f, 0x9b, 0x75, 0x18, 0x7e, 0xc0, 0x8c, 0x7f, 0xd9, 0xce, 0x72, 0x6f, 0x85,
    0x53, 0xeb, 0xa6, 0x14, 0xe3, 0x1c, 0xc7, 0x1c, 0x68, 0x2e, 0x31, 0xa2, 0xb3, 0xaf, 0x5f, 0x8f,
    0x0c, 0x36, 0x30, 0xa7, 0x78, 0xdb, 0xab, 0x4f, 0x8c, 0x42, 0x72, 0x58, 0x1b, 0xdd, 0xf8, 0xec,
    0x3e, 0xc9, 0x31, 0x62, 0xec, 0x14, 0xc4, 0x26, 0xce, 0x21, 0xcc, 0xb4, 0x38, 0x75, 0x55, 0x1c,
    0x49, 0xfb, 0x3c, 0xc1, 0xc8, 0x22, 0x15, 0x1b, 0x3a, 0x11, 0xf4, 0xc2, 0x12, 0x00, 0x07, 0x07,
    0xf9, 0xaa, 0x86, 0x61, 0x5b, 0xd7, 0xb9, 0xb9, 0x70, 0x00, 0x62, 0x85, 0x33, 0x53, 0xd6, 0x8d,
    0xaf, 0x52, 0xa1, 0xd0, 0xdd, 0xbb, 0x44, 0xd8, 0xd2, 0x2f, 0x75, 0xc8, 0xdc, 0xf2, 0x05, 0x07,
    0xad, 0xed, 0x7a, 0xf3, 0x45, 0x86, 0x45, 0xab, 0xc0, 0x16, 0x6a, 0x72, 0x83, 0xf8, 0xbc, 0x7b,
    0x16, 0x83, 0x94, 0xf7, 0xde, 0x65, 0x4a, 0x33, 0xca, 0x08, 0x6d, 0x8e, 0x4a, 0x61, 0xf6, 0xd5,
    0x47, 0x13, 0x7b, 0x44, 0xd1, 0xec, 0x4c, 0xf6, 0xab, 0xf4, 0x6b, 0x8b, 0x8e, 0x2a, 0xac, 0x77,
    0x15, 0xca, 0x8e, 0x0d, 0xf4, 0x03, 0xa0, 0x47, 0x70, 0x02, 0x2d, 0x29, 0xad, 0xa0, 0xd7, 0xc4,
    0x11, 0x73, 0x43, 0x68, 0x81, 0x24, 0xa9, 0x03, 0x5c, 0x41, 0x64, 0x86, 0xca, 0x16, 0xa9, 0x7c,
    0x18, 0x53, 0x70, 0xd0, 0x49, 0x48, 0x58, 0x46, 0x41, 0x3a, 0x64, 0x36, 0x87, 0xc8, 0x81, 0xde,
    0x20, 0xa4, 0x9f, 0x79, 0x98, 0x2a, 0x5b, 0xc4, 0xfa, 0x55, 0x0b, 0xe5, 0xec, 0xba, 0xa6, 0x31,
    0x9a, 0xb5, 0xf8, 0xaa, 0x06, 0xdd, 0xb9, 0xa0, 0x33, 0xe2, 0x48, 0x3f, 0x75, 0x99, 0x58, 0x27,
    0x5f, 0xf9, 0x33, 0xfb, 0xec, 0x2b, 0xb8, 0x41, 0xc6, 0xf7, 0x8a, 0x97, 0xc7, 0x4b, 0xdb, 0x1d,
    0xb3, 0x16, 0x54, 0xbd, 0x32, 0x59, 0x74, 0x81, 0x46, 0x43, 0x38, 0x29, 0xfd, 0x73, 0xb1, 0xde,
    0x87, 0xde, 0x3c, 0x81, 0x70, 0x72, 0x4c, 0x04, 0x6d, 0x5b, 0x64, 0xb9, 0x55, 0x5f, 0x8d, 0x03,
    0x9b, 0x01, 0x59, 0x00, 0xa7, 0xab, 0xfe, 0x1c, 0x25, 0xb3, 0x5c, 0x51, 0x83, 0x04, 0x96, 0x17,
    0x45, 0xb3, 0xd9, 0x9e, 0x29, 0xeb, 0xdc, 0x34, 0x67, 0xb2, 0xf9, 0x3e, 0x20, 0x71, 0xf4, 0x7c,
    0x14, 0xb3, 0xec, 0x14, 0x4d, 0x94, 0xca, 0x16, 0xf3, 0x67, 0x9c, 0x73, 0x49, 0x3c, 0x26, 0x97,
    0x0b, 0xb4, 0x1e, 0xa5, 0x08, 0x6e, 0xe3, 0x09, 0x0a, 0x1f, 0xb6, 0x09, 0x37, 0x5c, 0xc4, 0xdd,
    0xe1, 0x1f, 0xa3, 0x4f, 0x28, 0xce, 0x40, 0x97, 0x4e, 0x6f, 0xef, 0x8e, 0x52, 0x08, 0x45, 0xb4,
    0x54, 0x10, 0xc9, 0xcd, 0x12, 0x1c, 0x0c, 0x3f, 0x88, 0x48, 0x3a, 0x39, 0xca, 0x0f, 0x00, 0xe2,
    0x75, 0xfd, 0x10, 0xce, 0x11, 0x7d, 0x13, 0x1c, 0x44, 0x24, 0x13, 0x07, 0x86, 0xe0, 0x40, 0x99,
    0xfc, 0x4c, 0xfc, 0xde, 0x07, 0x5c, 0xe8, 0x26, 0xf0, 0x11, 0xfe, 0x0e, 0x8d, 0x95, 0x94, 0x8d,
    0xc7, 0xea, 0xf7, 0x75, 0x67, 0xbd, 0x1d, 0x0f, 0xbd, 0xc6, 0xe9, 0x0e, 0xde, 0x40, 0x1d, 0x09,
    0x89, 0x21, 0x52, 0xde, 0x09, 0xe8, 0xd7, 0xb2, 0x93, 0x0b, 0xd1, 0xc7, 0x2d, 0xb0, 0x2c, 0xe6,
    0xaf, 0xac, 0x92, 0x88, 0x60, 0x58, 0x01, 0x14, 0x0a, 0x8b, 0x23, 0xd6, 0xcb, 0x43, 0x29, 0x39,
    0x72, 0xe3, 0xf2, 0xce, 0x11, 0x6b, 0xec, 0x11, 0xbb, 0x41, 0x12, 0x5c, 0x7e, 0xf4, 0xea, 0xe0,
    0xe0, 0x1c, 0xb2, 0xe6, 0xe4, 0x62, 0xbd, 0x71, 0xe4, 0xdc, 0x83, 0x3a, 0x49, 0xd4, 0x5c, 0xaa,
    0x32, 0xe0, 0x75, 0x63, 0x54, 0x9e, 0x39, 0x3a, 0x56, 0xc0, 0xba, 0x3b, 0x7d, 0x36, 0x60, 0xcd,
    0x95, 0x3e, 0x07, 0xaf, 0x7a, 0x28, 0x73, 0x9e, 0xdb, 0xca, 0x21, 0xcf, 0x9d, 0x2b, 0x49, 0x33,
    0x7e, 0x0d, 0x7c, 0x4e, 0x22, 0xab, 0xb5, 0xbf, 0xac, 0xd1, 0x76, 0x1c, 0x81, 0x87, 0x19, 0xd0,
    0xdc, 0xf0, 0x07, 0xdf, 0xe4, 0x63, 0x8b, 0xc1, 0xbd, 0xac, 0x51, 0xcb, 0x23, 0xc3, 0x27, 0x44,
    0xb1, 0x38, 0x4e, 0x19, 0x3b, 0x61, 0x27, 0x49, 0x08, 0x8c, 0x13, 0x3a, 0x98, 0x16, 0x76, 0x49,
    0x7a, 0x62, 0xc3, 0x0e, 0x77, 0xd0, 0x38, 0xcc, 0xfa, 0xed, 0x61, 0xb1, 0x0b, 0xeb, 0x59, 0x7e,
    0xc7, 0xe1, 0xce, 0xa0, 0xb6, 0xdb, 0x28, 0x24, 0xa9, 0x47, 0x27, 0x63, 0x78, 0xe2, 0x32, 0xe0,
    0xa1, 0xe4, 0x51, 0x10, 0x51, 0x77, 0xc6, 0xbb, 0x24, 0x92, 0xaa, 0xba, 0x31, 0xfa, 0x2e, 0x3c,
    0x9f, 0xf2, 0x3b, 0x1a, 0x67, 0x06, 0x15, 0xb5, 0x15, 0x37, 0x17, 0x8e, 0x87, 0x34, 0x01, 0x3b,
    0xce, 0xc4, 0x44, 0x7f, 0xc9, 0x5d, 0x40, 0x4d, 0xed, 0x36, 0x68, 0xc6, 0x43, 0xe2, 0x03, 0x40,
    0xaa, 0x46, 0x26, 0xcd, 0xab, 0xab, 0xb0, 0x92, 0x49, 0x19, 0x59, 0x3f, 0xa6, 0xd5, 0x0d, 0x05,
    0xc6, 0x6c, 0xdb, 0xfd, 0x0a, 0x56, 0xf6, 0x6d, 0x22, 0xc0, 0x6e, 0x21, 0x16, 0x91, 0x06, 0xb8,
    0xc3, 0x19, 0x3d, 0xf5, 0x02, 0xa5, 0xe7, 0x94, 0x2c, 0x2e, 0x62, 0x32, 0x41, 0xf1, 0x7f, 0x7b,
    0xb6, 0x6a, 0x07, 0x35, 0x3b, 0xdc, 0x16, 0x71, 0x4d, 0xb7, 0x10, 0x15, 0xe0, 0x5f, 0x1d, 0x80,
    0xcb, 0xeb, 0x52, 0xa9, 0x98, 0xa6, 0x8b, 0x82, 0x9f, 0x3c, 0x4b, 0x6f, 0xf7, 0x3a, 0x18, 0x2a,
    0xef, 0x4a, 0x77, 0x8f, 0x1b, 0xb7, 0x5d, 0x25, 0x1c, 0xed, 0x55, 0x48, 0xe7, 0x85, 0x3e, 0xfc,
    0x91, 0xdd, 0xea, 0x97, 0xd9, 0x95, 0x7b, 0xec, 0x5d, 0x2e, 0x54, 0x0a, 0x61, 0x46, 0x21, 0x24,
    0xf0, 0x22, 0x36, 0x9f, 0x59, 0x56, 0x35, 0x9e, 0x97, 0xa0, 0x58, 0x6e, 0x62, 0x6a, 0xd3, 0xfa,
    0xd3, 0xe4, 0x10, 0xa7, 0x83, 0x97, 0x3f, 0x59, 0x63, 0xf2, 0xe3, 0xa7, 0xca, 0x66, 0x0b, 0xc6,
    0xe4, 0x7f, 0xe4, 0x83, 0xaa, 0xc2, 0xee, 0xcd, 0x03, 0xf9, 0x28, 0xcb, 0x0b, 0xf7, 0x3f, 0x2f,
    0x40, 0xef, 0x8f, 0xf6, 0x28, 0xe2, 0xde, 0x7c, 0xcf, 0x33, 0x3a, 0xdd, 0xb7, 0xe7, 0xa9, 0xec,
    0xfa, 0x17, 0xec, 0x77, 0x64, 0x94, 0xfe, 0x4e, 0xdd, 0xe3, 0xf4, 0xc5, 0x89, 0xf5, 0xc1, 0x16,
    0xf8, 0x96, 0xf7, 0xaa, 0x1d, 0x2b, 0xac, 0xcb, 0x31, 0xdc, 0x07, 0xcf, 0x29, 0xd0, 0xf7, 0x01,
    0x74, 0x0c, 0xf6, 0x7d, 0x20, 0xef, 0x12, 0x79, 0x57, 0x54, 0x22, 0x1a, 0x39, 0x12, 0x71, 0x74,
    0x94, 0x0f, 0x97, 0x89, 0x3a, 0x78, 0xf6, 0xe7, 0xa8, 0x48, 0x4a, 0x05, 0xe2, 0x84, 0xb5, 0x44,
    0xb4, 0xc8, 0xce, 0x73, 0x9a, 0xc1, 0xce, 0xe9, 0xbf, 0x22, 0xf5, 0xef, 0x7c, 0x07, 0x91, 0xd7,
    0x22, 0x6c, 0xb6, 0xd1, 0xce, 0xfd, 0xa6, 0x2a, 0x01, 0x60, 0x9f, 0x83, 0x94, 0x30, 0x2c, 0xb3,
    0xf5, 0xdb, 0xee, 0xa2, 0xed, 0x2a, 0x4c, 0xf3, 0x55, 0xbc, 0x05, 0x46, 0x32, 0x1a, 0x02, 0xb3,
    0xf7, 0x29, 0xf4, 0x08, 0xf8, 0x49, 0x23, 0x39, 0x6c, 0x65, 0xd1, 0x2f, 0x81, 0xac, 0xc4, 0xda,
    0xd5, 0x8f, 0x91, 0xb6, 0xa8, 0x56, 0x70, 0x5e, 0x20, 0x55, 0xca, 0xe0, 0x41, 0x4d, 0x52, 0x88,
    0x94, 0x7a, 0x3d, 0x7f, 0x4d, 0xe5, 0xac, 0xb5, 0x56, 0x14, 0x54, 0xaa, 0x49, 0x3a, 0x4e, 0x10,
    0xf5, 0xda, 0x82, 0x20, 0xaf, 0x1c, 0xf0, 0x40, 0x68, 0x29, 0x32, 0x08, 0x26, 0xf9, 0x4b, 0xcf,
    0x58, 0x6a, 0x60, 0x87, 0x6f, 0x29, 0x37, 0x58, 0x5f, 0x9c, 0x38, 0xc9, 0x57, 0x57, 0x2d, 0x1f,
    0xe6, 0xd3, 0x66, 0x01, 0xc2, 0x9a, 0x3d, 0xf7, 0x47, 0x16, 0xfe, 0xfe, 0x3a, 0x67, 0xed, 0xd3,
    0x69, 0xbf, 0x25, 0x91, 0x1c, 0x2c, 0x64, 0xad, 0x49, 0x7b, 0x2e, 0xd9, 0x8a, 0x57, 0x66, 0x6e,
    0x83, 0x3c, 0x8b, 0xbb, 0xcd, 0xfb, 0x69, 0xb9, 0xdc, 0xa6, 0xf3, 0xe3, 0xdd, 0xfc, 0xcb, 0x68,
    0x8e, 0x52, 0x68, 0x3a, 0x41, 0xfc, 0x24, 0x1c, 0xed, 0xbd, 0x4d, 0x16, 0xfd, 0x16, 0xd0, 0x67,
    0x4e, 0xce, 0x0d, 0xe9, 0xc4, 0x20, 0xcf, 0x35, 0xba, 0xe1, 0xc4, 0xa8, 0xd0, 0x02, 0x99, 0x61,
    0xec, 0x59, 0x32, 0x8b, 0xd5, 0xc2, 0x2c, 0x65, 0xfa, 0x1d, 0xf0, 0x59, 0xd9, 0x01, 0xb3, 0xf5,
    0x60, 0xb9, 0xb3, 0x92, 0x88, 0x65, 0x56, 0xae, 0x32, 0x5f, 0x87, 0xee, 0x7c, 0x65, 0x95, 0xd7,
    0xf3, 0x13, 0x7b, 0x6b, 0x64, 0x2d, 0x69, 0x19, 0xa4, 0x79, 0xfd, 0x97, 0x31, 0x73, 0x69, 0x03,
    0xd5, 0xcc, 0xb9, 0xd7, 0x0e, 0xbb, 0x6c, 0xe6, 0x04, 0x76, 0xe2, 0x57, 0xd9, 0xaa, 0x06, 0xf7,
    0xba, 0x48, 0xc6, 0x0b, 0xaa, 0x74, 0x36, 0x5e, 0x92, 0x5c, 0x35, 0xee, 0x69, 0x7d, 0x36, 0xc8,
    0x55, 0xe3, 0xc2, 0xd6, 0x87, 0x7b, 0xa0, 0x05, 0x26, 0x5e, 0x42, 0xdf, 0x54, 0x23, 0x14, 0x7b,
    0xe9, 0xa5, 0x15, 0x50, 0x0f, 0x41, 0xd6, 0xa2, 0xfc, 0xe8, 0x60, 0xdd, 0x22, 0xd3, 0xad, 0x1e,
    0x16, 0x78, 0x4d, 0xcf, 0x68, 0x13, 0x1f, 0xf8, 0xb1, 0x6d, 0x94, 0x91, 0xc9, 0xfc, 0xaa, 0x71,
    0xf8, 0x92, 0xb6, 0x65, 0xf4, 0xb2, 0xd9, 0x3a, 0xb0, 0x91, 0x2a, 0x93, 0xf4, 0xd6, 0x96, 0x91,
    0x2c, 0x45, 0xad, 0x70, 0x15, 0xc9, 0x68, 0x1b, 0x63, 0xad, 0x9a, 0xd3, 0x31, 0x09, 0x52, 0x2f,
    0x02, 0xf5, 0xec, 0x45, 0xe9, 0xc1, 0x4b, 0x52, 0x27, 0x3d, 0x6f, 0xe4, 0x33, 0xed, 0x3b, 0xda,
    0x95, 0x3f, 0xfd, 0x59, 0xfe, 0xf2, 0x67, 0xf9, 0xdb, 0x97, 0x65, 0xad, 0xe2, 0x2d, 0xc7, 0x0c,
    0xa5, 0xd2, 0x46, 0xe6, 0x52, 0x6f, 0x1d, 0xd2, 0x52, 0x8c, 0xa3, 0xf0, 0xe1, 0x64, 0xea, 0x5e,
    0x1a, 0xd9, 0xb1, 0xa2, 0x9d, 0x82, 0xd0, 0x2f, 0xd8, 0x13, 0x5c, 0x99, 0x45, 0x2d, 0xb6, 0x91,
    0x89, 0x9e, 0xb7, 0x67, 0x38, 0x9b, 0x35, 0x16, 0x17, 0xb5, 0x5c, 0xa8, 0x11, 0x74, 0x13, 0xff,
    0x1b, 0x4e, 0xde, 0xe5, 0x21, 0xa1, 0x63, 0xc5, 0xf2, 0x3a, 0x79, 0xf3, 0x16, 0xab, 0x60, 0xae,
    0xfa, 0xaa, 0xed, 0x70, 0x0f, 0xf0, 0xd2, 0x18, 0xec, 0x74, 0xbc, 0xcd, 0x92, 0x7a, 0x71, 0x90,
    0x95, 0xb8, 0x5e, 0xaa, 0x62, 0x61, 0xa9, 0xc6, 0xeb, 0x66, 0xe2, 0x34, 0x42, 0x2e, 0x85, 0xa9,
    0x39, 0x9d, 0x56, 0x48, 0x50, 0x56, 0x1c, 0x60, 0x60, 0x0e, 0x35, 0x07, 0xc7, 0xb2, 0x6d, 0xa1,
    0x1e, 0xd5, 0x27, 0x87, 0xde, 0x94, 0x5d, 0xfc, 0x48, 0x22, 0xcb, 0x1e, 0x19, 0x5d, 0x48, 0x9a,
    0x66, 0x29, 0x72, 0x03, 0xf5, 0xae, 0x8a, 0xfa, 0x0e, 0x71, 0xd4, 0xae, 0xf5, 0xf2, 0xab, 0x83,
    0x78, 0x8e, 0x17, 0x22, 0x8f, 0x18, 0x96, 0x29, 0xa1, 0x7b, 0xb8, 0x82, 0x59, 0xce, 0x01, 0x62,
    0xdb, 0x16, 0xfb, 0xbc, 0x21, 0x32, 0x4a, 0xb5, 0xf4, 0x2a, 0x64, 0x51, 0xd4, 0x5e, 0x95, 0x45,
    0x4b, 0x9c, 0x44, 0x64, 0x69, 0x1e, 0xef, 0x67, 0x45, 0x63, 0x42, 0x79, 0x72, 0x96, 0xd0, 0xfd,
    0x42, 0xec, 0x7b, 0x95, 0xf2, 0x5f, 0x3e, 0xb0, 0xb3, 0x15
};
#endif

PyTypeObject *init_QQuickItem(PyObject *module)
{
    if (SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX].type != nullptr)
        return SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX].type;

    Shiboken::AutoDecRef Sbk_QQuickItem_Type_bases(PyTuple_Pack(2,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX])),
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtQmlTypeStructs[SBK_QQmlParserStatus_IDX]))));

    _Sbk_QQuickItem_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QQuickItem",
        "QQuickItem*",
        &Sbk_QQuickItem_spec,
        &Shiboken::callCppDestructor< QQuickItem >,
        Sbk_QQuickItem_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QQuickItem_TypeF(); // references _Sbk_QQuickItem_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QQuickItem_SignatureStrings);
#else
    InitSignatureBytes(pyType, QQuickItem_SignatureBytes, QQuickItem_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QQuickItem_PropertyStrings);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QQuickItem_PythonToCpp_QQuickItem_PTR,
        is_QQuickItem_PythonToCpp_QQuickItem_PTR_Convertible,
        QQuickItem_PTR_CppToPython_QQuickItem);

    Shiboken::Conversions::registerConverterName(converter, "QQuickItem");
    Shiboken::Conversions::registerConverterName(converter, "QQuickItem*");
    Shiboken::Conversions::registerConverterName(converter, "QQuickItem&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QQuickItem).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QQuickItemWrapper).name());

    MultipleInheritanceInitFunction func = Sbk_QQuickItem_mi_init;
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QQuickItem_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QQuickItem_TypeF(), &Sbk_QQuickItemSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QQuickItem_TypeF(), &Sbk_QQuickItem_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QQuickItem_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'Flag'.
    const char *Flag_Initializer[] = {
        "ItemClipsChildrenToShape",
        "ItemAcceptsInputMethod",
        "ItemIsFocusScope",
        "ItemHasContents",
        "ItemAcceptsDrops",
        "ItemIsViewport",
        "ItemObservesViewport",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Flag_InitializerValues[] = {
        uint8_t(QQuickItem::Flag::ItemClipsChildrenToShape), //  0x01  1
        uint8_t(QQuickItem::Flag::ItemAcceptsInputMethod),   //  0x02  2
        uint8_t(QQuickItem::Flag::ItemIsFocusScope),         //  0x04  4
        uint8_t(QQuickItem::Flag::ItemHasContents),          //  0x08  8
        uint8_t(QQuickItem::Flag::ItemAcceptsDrops),         //  0x10  16
        uint8_t(QQuickItem::Flag::ItemIsViewport),           //  0x20  32
        uint8_t(QQuickItem::Flag::ItemObservesViewport)      //  0x40  64
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QQuickItem_TypeF(),
        "2:PySide6.QtQuick.QQuickItem.Flag",
        Flag_Initializer, Flag_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_Flag_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtQuickTypeStructs[SBK_QFlags_QQuickItem_Flag_IDX].type =
        EType;
    // Register converter for enum 'QQuickItem::Flag'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QQuickItem_Flag_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QQuickItem_Flag,
            is_Enum_PythonToCpp_QQuickItem_Flag_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QQuickItem::Flag");
        Shiboken::Conversions::registerConverterAlias(converter, "Flag");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QQuickItem_Flag_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QQuickItem_Flag,
            is_Enum_PythonToCpp_QQuickItem_Flag_Convertible);
        // Register converter for flag 'QFlags<QQuickItem::Flag>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QQuickItem::Flag>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QQuickItem::Flags");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Flag' enum/flags.

    // Initialization of enum 'ItemChange'.
    const char *ItemChange_Initializer[] = {
        "ItemChildAddedChange",
        "ItemChildRemovedChange",
        "ItemSceneChange",
        "ItemVisibleHasChanged",
        "ItemParentHasChanged",
        "ItemOpacityHasChanged",
        "ItemActiveFocusHasChanged",
        "ItemRotationHasChanged",
        "ItemAntialiasingHasChanged",
        "ItemDevicePixelRatioHasChanged",
        "ItemEnabledHasChanged",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ItemChange_InitializerValues[] = {
        uint8_t(QQuickItem::ItemChange::ItemChildAddedChange),           //  0x00  0
        uint8_t(QQuickItem::ItemChange::ItemChildRemovedChange),         //  0x01  1
        uint8_t(QQuickItem::ItemChange::ItemSceneChange),                //  0x02  2
        uint8_t(QQuickItem::ItemChange::ItemVisibleHasChanged),          //  0x03  3
        uint8_t(QQuickItem::ItemChange::ItemParentHasChanged),           //  0x04  4
        uint8_t(QQuickItem::ItemChange::ItemOpacityHasChanged),          //  0x05  5
        uint8_t(QQuickItem::ItemChange::ItemActiveFocusHasChanged),      //  0x06  6
        uint8_t(QQuickItem::ItemChange::ItemRotationHasChanged),         //  0x07  7
        uint8_t(QQuickItem::ItemChange::ItemAntialiasingHasChanged),     //  0x08  8
        uint8_t(QQuickItem::ItemChange::ItemDevicePixelRatioHasChanged), //  0x09  9
        uint8_t(QQuickItem::ItemChange::ItemEnabledHasChanged)           //  0x0a  10
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QQuickItem_TypeF(),
        "2:PySide6.QtQuick.QQuickItem.ItemChange",
        ItemChange_Initializer, ItemChange_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_ItemChange_IDX].type = EType;
    // Register converter for enum 'QQuickItem::ItemChange'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QQuickItem_ItemChange_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QQuickItem_ItemChange,
            is_Enum_PythonToCpp_QQuickItem_ItemChange_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QQuickItem::ItemChange");
        Shiboken::Conversions::registerConverterAlias(converter, "ItemChange");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ItemChange' enum.

    // Initialization of enum 'TransformOrigin'.
    const char *TransformOrigin_Initializer[] = {
        "TopLeft",
        "Top",
        "TopRight",
        "Left",
        "Center",
        "Right",
        "BottomLeft",
        "Bottom",
        "BottomRight",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TransformOrigin_InitializerValues[] = {
        uint8_t(QQuickItem::TransformOrigin::TopLeft),    //  0x00  0
        uint8_t(QQuickItem::TransformOrigin::Top),        //  0x01  1
        uint8_t(QQuickItem::TransformOrigin::TopRight),   //  0x02  2
        uint8_t(QQuickItem::TransformOrigin::Left),       //  0x03  3
        uint8_t(QQuickItem::TransformOrigin::Center),     //  0x04  4
        uint8_t(QQuickItem::TransformOrigin::Right),      //  0x05  5
        uint8_t(QQuickItem::TransformOrigin::BottomLeft), //  0x06  6
        uint8_t(QQuickItem::TransformOrigin::Bottom),     //  0x07  7
        uint8_t(QQuickItem::TransformOrigin::BottomRight) //  0x08  8
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QQuickItem_TypeF(),
        "2:PySide6.QtQuick.QQuickItem.TransformOrigin",
        TransformOrigin_Initializer, TransformOrigin_InitializerValues);
    SbkPySide6_QtQuickTypeStructs[SBK_QQuickItem_TransformOrigin_IDX].type = EType;
    // Register converter for enum 'QQuickItem::TransformOrigin'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QQuickItem_TransformOrigin_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QQuickItem_TransformOrigin,
            is_Enum_PythonToCpp_QQuickItem_TransformOrigin_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QQuickItem::TransformOrigin");
        Shiboken::Conversions::registerConverterAlias(converter, "TransformOrigin");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'TransformOrigin' enum.

    PySide::Signal::registerSignals(pyType, &::QQuickItem::staticMetaObject);
    qRegisterMetaType< ::QQuickItem::Flag >("QQuickItem::Flag");
    qRegisterMetaType< ::QQuickItem::ItemChange >("QQuickItem::ItemChange");
    qRegisterMetaType< ::QQuickItem::TransformOrigin >("QQuickItem::TransformOrigin");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QQuickItem::staticMetaObject, sizeof(QQuickItemWrapper));

    return pyType;
}
