// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qttest_python.h"

// main header
#include "qtest_wrapper.h"

// inner classes
#include "qtest_pysideqtoucheventsequence_wrapper.h"

// Extra includes
#include <QtTest>

// Argument includes
#include <QString>
#include <QtGui/qinputdevice.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qpointingdevice.h>
#include <QtGui/qwindow.h>
#include <QtTest/qbenchmarkmetric.h>
#include <QtTest/qtestkeyboard.h>
#include <QtTest/qtestmouse.h>
#include <QtTest/qttestglobal.h>
#include <QtWidgets/qwidget.h>
#include <pysideqtesttouch.h>
#include <qdeadlinetimer.h>
#include <qlogging.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qpoint.h>
#include <qregularexpression.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>


// Target ---------------------------------------------------------

extern "C" {
static PyObject *Sbk_QTestFunc_addColumnInternal(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "addColumnInternal", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::addColumnInternal(int,const char*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        overloadId = 0; // addColumnInternal(int,const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addColumnInternal", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        const char* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addColumnInternal(int,const char*)
            ::QTest::addColumnInternal(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_asciiToKey(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QTest::asciiToKey(char)->Qt::Key
    if (SbkChar_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArg)))) {
        overloadId = 0; // asciiToKey(char)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "asciiToKey", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        char cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // asciiToKey(char)
            Qt::Key cppResult = ::QTest::asciiToKey(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Key_IDX])))->converter, &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_compare_ptr_helper(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "compare_ptr_helper", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::compare_ptr_helper(const volatile QObject*,const volatile QObject*,const char*,const char*,const char*,int)->bool
    // 1: static QTest::compare_ptr_helper(const volatile void*,const volatile void*,const char*,const char*,const char*,int)->bool
    if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))
        && Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))
        && Shiboken::String::check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3])))
        && Shiboken::String::check(pyArgs[4]) && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
        overloadId = 1; // compare_ptr_helper(const volatile void*,const volatile void*,const char*,const char*,const char*,int)
    } else if (numArgs == 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))
        && Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))
        && Shiboken::String::check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3])))
        && Shiboken::String::check(pyArgs[4]) && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
        overloadId = 0; // compare_ptr_helper(const volatile QObject*,const volatile QObject*,const char*,const char*,const char*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "compare_ptr_helper", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // compare_ptr_helper(const volatile QObject *t1, const volatile QObject *t2, const char *actual, const char *expected, const char *file, int line)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QObject *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            const char* cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            const char* cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // compare_ptr_helper(const volatile QObject*,const volatile QObject*,const char*,const char*,const char*,int)
                bool cppResult = ::QTest::compare_ptr_helper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // compare_ptr_helper(const volatile void *t1, const volatile void *t2, const char *actual, const char *expected, const char *file, int line)
        {
            void* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            void* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            const char* cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            const char* cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // compare_ptr_helper(const volatile void*,const volatile void*,const char*,const char*,const char*,int)
                bool cppResult = ::QTest::compare_ptr_helper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_compare_string_helper(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "compare_string_helper", 6, 6, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::compare_string_helper(const char*,const char*,const char*,const char*,const char*,int)->bool
    if (numArgs == 6
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))
        && Shiboken::String::check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))
        && Shiboken::String::check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3])))
        && Shiboken::String::check(pyArgs[4]) && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
        overloadId = 0; // compare_string_helper(const char*,const char*,const char*,const char*,const char*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "compare_string_helper", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        const char* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        const char* cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        const char* cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        const char* cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);
        int cppArg5;
        pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // compare_string_helper(const char*,const char*,const char*,const char*,const char*,int)
            bool cppResult = ::QTest::compare_string_helper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_createTouchDevice(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "createTouchDevice", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OO:createTouchDevice", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::createTouchDevice(QInputDevice::DeviceType=,QFlags<QInputDevice::Capability>=)->QPointingDevice*
    if (numArgs == 0) {
        overloadId = 0; // createTouchDevice(QInputDevice::DeviceType,QFlags<QInputDevice::Capability>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_DeviceType_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // createTouchDevice(QInputDevice::DeviceType,QFlags<QInputDevice::Capability>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QInputDevice_Capability_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // createTouchDevice(QInputDevice::DeviceType,QFlags<QInputDevice::Capability>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createTouchDevice", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_devType = Shiboken::String::createStaticString("devType");
            if (PyDict_Contains(kwds, key_devType) != 0) {
                value = PyDict_GetItem(kwds, key_devType);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_devType);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "createTouchDevice", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputDevice_DeviceType_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "createTouchDevice", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_devType);
            }
            static PyObject *const key_caps = Shiboken::String::createStaticString("caps");
            if (PyDict_Contains(kwds, key_caps) != 0) {
                value = PyDict_GetItem(kwds, key_caps);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_caps);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "createTouchDevice", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QInputDevice_Capability_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "createTouchDevice", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_caps);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "createTouchDevice", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
            }
        }
        ::QInputDevice::DeviceType cppArg0(QInputDevice::DeviceType::TouchScreen);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<QInputDevice::Capability> cppArg1(QInputDevice::Capability::Position);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createTouchDevice(QInputDevice::DeviceType,QFlags<QInputDevice::Capability>)
            QPointingDevice * cppResult = ::QTest::createTouchDevice(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_currentAppName(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentAppName()
        const char * cppResult = ::QTest::currentAppName();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_currentDataTag(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentDataTag()
        const char * cppResult = ::QTest::currentDataTag();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_currentTestFailed(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentTestFailed()
        bool cppResult = ::QTest::currentTestFailed();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_currentTestFunction(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentTestFunction()
        const char * cppResult = ::QTest::currentTestFunction();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_currentTestResolved(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentTestResolved()
        bool cppResult = ::QTest::currentTestResolved();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_failOnWarning(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "failOnWarning", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::failOnWarning()
    // 1: static QTest::failOnWarning(QRegularExpression)
    // 2: static QTest::failOnWarning(const char*)
    if (numArgs == 0) {
        overloadId = 0; // failOnWarning()
    } else if (numArgs == 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        overloadId = 2; // failOnWarning(const char*)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArgs[0])))) {
        overloadId = 1; // failOnWarning(QRegularExpression)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "failOnWarning", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // failOnWarning()
        {

            // failOnWarning()
            ::QTest::failOnWarning();
            break;
        }
        case 1: // failOnWarning(const QRegularExpression &messagePattern)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRegularExpression cppArg0_local;
            ::QRegularExpression *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // failOnWarning(QRegularExpression)
                ::QTest::failOnWarning(*cppArg0);
            }
            break;
        }
        case 2: // failOnWarning(const char *message)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // failOnWarning(const char*)
                ::QTest::failOnWarning(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_formatString(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "formatString", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::formatString(const char*,const char*,size_t)->char*
    if (numArgs == 3
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<size_t>(), (pyArgs[2])))) {
        overloadId = 0; // formatString(const char*,const char*,size_t)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "formatString", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        const char* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        size_t cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // formatString(const char*,const char*,size_t)
            char * cppResult = ::QTest::formatString(cppArg0, cppArg1, cppArg2);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_ignoreMessage(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "ignoreMessage", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::ignoreMessage(QtMsgType,QRegularExpression)
    // 1: static QTest::ignoreMessage(QtMsgType,const char*)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QtMsgType_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 2
            && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            overloadId = 1; // ignoreMessage(QtMsgType,const char*)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArgs[1])))) {
            overloadId = 0; // ignoreMessage(QtMsgType,QRegularExpression)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "ignoreMessage", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // ignoreMessage(QtMsgType type, const QRegularExpression &messagePattern)
        {
            ::QtMsgType cppArg0{QtDebugMsg};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRegularExpression cppArg1_local;
            ::QRegularExpression *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // ignoreMessage(QtMsgType,QRegularExpression)
                ::QTest::ignoreMessage(cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // ignoreMessage(QtMsgType type, const char *message)
        {
            ::QtMsgType cppArg0{QtDebugMsg};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // ignoreMessage(QtMsgType,const char*)
                ::QTest::ignoreMessage(cppArg0, cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_keyClick(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:keyClick", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::keyClick(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>=,int=)
    // 1: static QTest::keyClick(QWidget*,char,QFlags<Qt::KeyboardModifier>=,int=)
    // 2: static QTest::keyClick(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>=,int=)
    // 3: static QTest::keyClick(QWindow*,char,QFlags<Qt::KeyboardModifier>=,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Key_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // keyClick(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 2; // keyClick(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 2; // keyClick(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // keyClick(QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 3; // keyClick(QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 3; // keyClick(QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Key_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // keyClick(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // keyClick(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 0; // keyClick(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // keyClick(QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // keyClick(QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 1; // keyClick(QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // keyClick(QWidget *widget, Qt::Key key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::Key cppArg1 = static_cast< ::Qt::Key>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyClick(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyClick(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // keyClick(QWidget *widget, char key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyClick(QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyClick(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 2: // keyClick(QWindow *window, Qt::Key key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::Key cppArg1 = static_cast< ::Qt::Key>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyClick(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyClick(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 3: // keyClick(QWindow *window, char key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyClick(QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyClick(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_keyClicks(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "keyClicks", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:keyClicks", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::keyClicks(QWidget*,QString,QFlags<Qt::KeyboardModifier>=,int=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // keyClicks(QWidget*,QString,QFlags<Qt::KeyboardModifier>,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // keyClicks(QWidget*,QString,QFlags<Qt::KeyboardModifier>,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                overloadId = 0; // keyClicks(QWidget*,QString,QFlags<Qt::KeyboardModifier>,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "keyClicks", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
            if (PyDict_Contains(kwds, key_modifier) != 0) {
                value = PyDict_GetItem(kwds, key_modifier);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_modifier);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "keyClicks", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "keyClicks", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_modifier);
            }
            static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
            if (PyDict_Contains(kwds, key_delay) != 0) {
                value = PyDict_GetItem(kwds, key_delay);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_delay);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "keyClicks", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "keyClicks", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_delay);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "keyClicks", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        int cppArg3 = -1;
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyClicks(QWidget*,QString,QFlags<Qt::KeyboardModifier>,int)
            ::QTest::keyClicks(cppArg0, cppArg1, cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_keyEvent(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:keyEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::keyEvent(QTest::KeyAction,QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>=,int=)
    // 1: static QTest::keyEvent(QTest::KeyAction,QWidget*,char,QFlags<Qt::KeyboardModifier>=,int=)
    // 2: static QTest::keyEvent(QTest::KeyAction,QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>=,int=)
    // 3: static QTest::keyEvent(QTest::KeyAction,QWindow*,char,QFlags<Qt::KeyboardModifier>=,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_KeyAction_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[1])))) {
            if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Key_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 2; // keyEvent(QTest::KeyAction,QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 2; // keyEvent(QTest::KeyAction,QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                        overloadId = 2; // keyEvent(QTest::KeyAction,QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                    }
                }
            } else if (numArgs >= 3
                && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 3; // keyEvent(QTest::KeyAction,QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 3; // keyEvent(QTest::KeyAction,QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                        overloadId = 3; // keyEvent(QTest::KeyAction,QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
                    }
                }
            }
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
            if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Key_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // keyEvent(QTest::KeyAction,QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // keyEvent(QTest::KeyAction,QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                        overloadId = 0; // keyEvent(QTest::KeyAction,QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                    }
                }
            } else if (numArgs >= 3
                && SbkChar_Check(pyArgs[2]) && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // keyEvent(QTest::KeyAction,QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 1; // keyEvent(QTest::KeyAction,QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                        overloadId = 1; // keyEvent(QTest::KeyAction,QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // keyEvent(QTest::KeyAction action, QWidget *widget, Qt::Key key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            ::QTest::KeyAction cppArg0{QTest::Press};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QWidget *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::Key cppArg2 = static_cast< ::Qt::Key>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<Qt::KeyboardModifier> cppArg3(Qt::NoModifier);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = -1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyEvent(QTest::KeyAction,QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 1: // keyEvent(QTest::KeyAction action, QWidget *widget, char ascii, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            ::QTest::KeyAction cppArg0{QTest::Press};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QWidget *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            char cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<Qt::KeyboardModifier> cppArg3(Qt::NoModifier);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = -1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyEvent(QTest::KeyAction,QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 2: // keyEvent(QTest::KeyAction action, QWindow *window, Qt::Key key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            ::QTest::KeyAction cppArg0{QTest::Press};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QWindow *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::Key cppArg2 = static_cast< ::Qt::Key>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<Qt::KeyboardModifier> cppArg3(Qt::NoModifier);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = -1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyEvent(QTest::KeyAction,QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 3: // keyEvent(QTest::KeyAction action, QWindow *window, char ascii, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            ::QTest::KeyAction cppArg0{QTest::Press};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QWindow *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            char cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<Qt::KeyboardModifier> cppArg3(Qt::NoModifier);
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = -1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyEvent(QTest::KeyAction,QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_keyPress(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:keyPress", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::keyPress(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>=,int=)
    // 1: static QTest::keyPress(QWidget*,char,QFlags<Qt::KeyboardModifier>=,int=)
    // 2: static QTest::keyPress(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>=,int=)
    // 3: static QTest::keyPress(QWindow*,char,QFlags<Qt::KeyboardModifier>=,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Key_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // keyPress(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 2; // keyPress(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 2; // keyPress(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // keyPress(QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 3; // keyPress(QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 3; // keyPress(QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Key_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // keyPress(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // keyPress(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 0; // keyPress(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // keyPress(QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // keyPress(QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 1; // keyPress(QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // keyPress(QWidget *widget, Qt::Key key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::Key cppArg1 = static_cast< ::Qt::Key>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyPress(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyPress(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // keyPress(QWidget *widget, char key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyPress(QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyPress(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 2: // keyPress(QWindow *window, Qt::Key key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::Key cppArg1 = static_cast< ::Qt::Key>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyPress(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyPress(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 3: // keyPress(QWindow *window, char key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyPress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyPress(QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyPress(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_keyRelease(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:keyRelease", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::keyRelease(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>=,int=)
    // 1: static QTest::keyRelease(QWidget*,char,QFlags<Qt::KeyboardModifier>=,int=)
    // 2: static QTest::keyRelease(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>=,int=)
    // 3: static QTest::keyRelease(QWindow*,char,QFlags<Qt::KeyboardModifier>=,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Key_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // keyRelease(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 2; // keyRelease(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 2; // keyRelease(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // keyRelease(QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 3; // keyRelease(QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 3; // keyRelease(QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Key_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // keyRelease(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // keyRelease(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 0; // keyRelease(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        } else if (numArgs >= 2
            && SbkChar_Check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // keyRelease(QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // keyRelease(QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                    overloadId = 1; // keyRelease(QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // keyRelease(QWidget *widget, Qt::Key key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::Key cppArg1 = static_cast< ::Qt::Key>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyRelease(QWidget*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyRelease(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 1: // keyRelease(QWidget *widget, char key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyRelease(QWidget*,char,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyRelease(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 2: // keyRelease(QWindow *window, Qt::Key key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::Key cppArg1 = static_cast< ::Qt::Key>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyRelease(QWindow*,Qt::Key,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyRelease(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
        case 3: // keyRelease(QWindow *window, char key, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_modifier = Shiboken::String::createStaticString("modifier");
                if (PyDict_Contains(kwds, key_modifier) != 0) {
                    value = PyDict_GetItem(kwds, key_modifier);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_modifier);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_modifier);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "keyRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            char cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2(Qt::NoModifier);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3 = -1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // keyRelease(QWindow*,char,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::keyRelease(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_keySequence(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "keySequence", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::keySequence(QWidget*,QKeySequence)
    // 1: static QTest::keySequence(QWindow*,QKeySequence)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), (pyArgs[1])))) {
        overloadId = 1; // keySequence(QWindow*,QKeySequence)
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), (pyArgs[1])))) {
        overloadId = 0; // keySequence(QWidget*,QKeySequence)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "keySequence", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // keySequence(QWidget *widget, const QKeySequence &keySequence)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QKeySequence cppArg1_local;
            ::QKeySequence *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // keySequence(QWidget*,QKeySequence)
                ::QTest::keySequence(cppArg0, *cppArg1);
            }
            break;
        }
        case 1: // keySequence(QWindow *window, const QKeySequence &keySequence)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QKeySequence cppArg1_local;
            ::QKeySequence *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // keySequence(QWindow*,QKeySequence)
                ::QTest::keySequence(cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_keyToAscii(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QTest::keyToAscii(Qt::Key)->char
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Key_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // keyToAscii(Qt::Key)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyToAscii", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        ::Qt::Key cppArg0 = static_cast< ::Qt::Key>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyToAscii(Qt::Key)
            char cppResult = ::QTest::keyToAscii(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<char>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_mouseClick(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:mouseClick", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::mouseClick(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>=,QPoint=,int=)
    // 1: static QTest::mouseClick(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>=,QPoint=,int=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseButton_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // mouseClick(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // mouseClick(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // mouseClick(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                    overloadId = 1; // mouseClick(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                }
            }
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseButton_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // mouseClick(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // mouseClick(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 0; // mouseClick(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                    overloadId = 0; // mouseClick(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mouseClick(QWidget *widget, Qt::MouseButton button, QFlags<Qt::KeyboardModifier> stateKey, QPoint pos, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stateKey = Shiboken::String::createStaticString("stateKey");
                if (PyDict_Contains(kwds, key_stateKey) != 0) {
                    value = PyDict_GetItem(kwds, key_stateKey);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_stateKey);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_stateKey);
                }
                static PyObject *const key_pos = Shiboken::String::createStaticString("pos");
                if (PyDict_Contains(kwds, key_pos) != 0) {
                    value = PyDict_GetItem(kwds, key_pos);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_pos);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pos);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::MouseButton cppArg1{Qt::NoButton};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2 = Qt::KeyboardModifiers();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QPoint cppArg3 = QPoint();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = -1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mouseClick(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                ::QTest::mouseClick(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 1: // mouseClick(QWindow *window, Qt::MouseButton button, QFlags<Qt::KeyboardModifier> stateKey, QPoint pos, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stateKey = Shiboken::String::createStaticString("stateKey");
                if (PyDict_Contains(kwds, key_stateKey) != 0) {
                    value = PyDict_GetItem(kwds, key_stateKey);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_stateKey);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_stateKey);
                }
                static PyObject *const key_pos = Shiboken::String::createStaticString("pos");
                if (PyDict_Contains(kwds, key_pos) != 0) {
                    value = PyDict_GetItem(kwds, key_pos);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_pos);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pos);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "mouseClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::MouseButton cppArg1{Qt::NoButton};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2 = Qt::KeyboardModifiers();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QPoint cppArg3 = QPoint();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = -1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mouseClick(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                ::QTest::mouseClick(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_mouseDClick(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:mouseDClick", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::mouseDClick(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>=,QPoint=,int=)
    // 1: static QTest::mouseDClick(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>=,QPoint=,int=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseButton_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // mouseDClick(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // mouseDClick(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // mouseDClick(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                    overloadId = 1; // mouseDClick(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                }
            }
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseButton_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // mouseDClick(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // mouseDClick(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 0; // mouseDClick(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                    overloadId = 0; // mouseDClick(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mouseDClick(QWidget *widget, Qt::MouseButton button, QFlags<Qt::KeyboardModifier> stateKey, QPoint pos, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stateKey = Shiboken::String::createStaticString("stateKey");
                if (PyDict_Contains(kwds, key_stateKey) != 0) {
                    value = PyDict_GetItem(kwds, key_stateKey);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_stateKey);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_stateKey);
                }
                static PyObject *const key_pos = Shiboken::String::createStaticString("pos");
                if (PyDict_Contains(kwds, key_pos) != 0) {
                    value = PyDict_GetItem(kwds, key_pos);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_pos);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pos);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::MouseButton cppArg1{Qt::NoButton};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2 = Qt::KeyboardModifiers();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QPoint cppArg3 = QPoint();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = -1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mouseDClick(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                ::QTest::mouseDClick(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 1: // mouseDClick(QWindow *window, Qt::MouseButton button, QFlags<Qt::KeyboardModifier> stateKey, QPoint pos, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stateKey = Shiboken::String::createStaticString("stateKey");
                if (PyDict_Contains(kwds, key_stateKey) != 0) {
                    value = PyDict_GetItem(kwds, key_stateKey);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_stateKey);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_stateKey);
                }
                static PyObject *const key_pos = Shiboken::String::createStaticString("pos");
                if (PyDict_Contains(kwds, key_pos) != 0) {
                    value = PyDict_GetItem(kwds, key_pos);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_pos);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pos);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "mouseDClick", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::MouseButton cppArg1{Qt::NoButton};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2 = Qt::KeyboardModifiers();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QPoint cppArg3 = QPoint();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = -1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mouseDClick(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                ::QTest::mouseDClick(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_mouseEvent(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 5, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "mouseEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:mouseEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::mouseEvent(QTest::MouseAction,QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int=)
    // 1: static QTest::mouseEvent(QTest::MouseAction,QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_MouseAction_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs >= 5
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseButton_IDX])))->converter, (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[4])))) {
            if (numArgs == 5) {
                overloadId = 1; // mouseEvent(QTest::MouseAction,QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
            } else if (numArgs >= 6
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
                overloadId = 1; // mouseEvent(QTest::MouseAction,QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
            }
        } else if (numArgs >= 5
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseButton_IDX])))->converter, (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[4])))) {
            if (numArgs == 5) {
                overloadId = 0; // mouseEvent(QTest::MouseAction,QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
            } else if (numArgs >= 6
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
                overloadId = 0; // mouseEvent(QTest::MouseAction,QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mouseEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mouseEvent(QTest::MouseAction action, QWidget *widget, Qt::MouseButton button, QFlags<Qt::KeyboardModifier> stateKey, QPoint pos, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, "mouseEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "mouseEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            ::QTest::MouseAction cppArg0{QTest::MousePress};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QWidget *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::MouseButton cppArg2{Qt::NoButton};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<Qt::KeyboardModifier> cppArg3 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QPoint cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5 = -1;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mouseEvent(QTest::MouseAction,QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                ::QTest::mouseEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
        case 1: // mouseEvent(QTest::MouseAction action, QWindow *window, Qt::MouseButton button, QFlags<Qt::KeyboardModifier> stateKey, QPoint pos, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, "mouseEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "mouseEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            ::QTest::MouseAction cppArg0{QTest::MousePress};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QWindow *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::MouseButton cppArg2{Qt::NoButton};
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<Qt::KeyboardModifier> cppArg3 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QPoint cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5 = -1;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mouseEvent(QTest::MouseAction,QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                ::QTest::mouseEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_mouseMove(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "mouseMove", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:mouseMove", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::mouseMove(QWidget*,QPoint=,int=)
    // 1: static QTest::mouseMove(QWindow*,QPoint=,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // mouseMove(QWindow*,QPoint,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // mouseMove(QWindow*,QPoint,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 1; // mouseMove(QWindow*,QPoint,int)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // mouseMove(QWidget*,QPoint,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // mouseMove(QWidget*,QPoint,int)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                overloadId = 0; // mouseMove(QWidget*,QPoint,int)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mouseMove", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mouseMove(QWidget *widget, QPoint pos, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_pos = Shiboken::String::createStaticString("pos");
                if (PyDict_Contains(kwds, key_pos) != 0) {
                    value = PyDict_GetItem(kwds, key_pos);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_pos);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseMove", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "mouseMove", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pos);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseMove", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "mouseMove", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "mouseMove", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPoint cppArg1 = QPoint();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = -1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mouseMove(QWidget*,QPoint,int)
                ::QTest::mouseMove(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // mouseMove(QWindow *window, QPoint pos, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_pos = Shiboken::String::createStaticString("pos");
                if (PyDict_Contains(kwds, key_pos) != 0) {
                    value = PyDict_GetItem(kwds, key_pos);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_pos);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseMove", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "mouseMove", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pos);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseMove", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "mouseMove", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "mouseMove", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPoint cppArg1 = QPoint();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = -1;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mouseMove(QWindow*,QPoint,int)
                ::QTest::mouseMove(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_mousePress(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:mousePress", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::mousePress(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>=,QPoint=,int=)
    // 1: static QTest::mousePress(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>=,QPoint=,int=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseButton_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // mousePress(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // mousePress(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // mousePress(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                    overloadId = 1; // mousePress(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                }
            }
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseButton_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // mousePress(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // mousePress(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 0; // mousePress(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                    overloadId = 0; // mousePress(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mousePress(QWidget *widget, Qt::MouseButton button, QFlags<Qt::KeyboardModifier> stateKey, QPoint pos, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stateKey = Shiboken::String::createStaticString("stateKey");
                if (PyDict_Contains(kwds, key_stateKey) != 0) {
                    value = PyDict_GetItem(kwds, key_stateKey);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_stateKey);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_stateKey);
                }
                static PyObject *const key_pos = Shiboken::String::createStaticString("pos");
                if (PyDict_Contains(kwds, key_pos) != 0) {
                    value = PyDict_GetItem(kwds, key_pos);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_pos);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pos);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::MouseButton cppArg1{Qt::NoButton};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2 = Qt::KeyboardModifiers();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QPoint cppArg3 = QPoint();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = -1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mousePress(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                ::QTest::mousePress(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 1: // mousePress(QWindow *window, Qt::MouseButton button, QFlags<Qt::KeyboardModifier> stateKey, QPoint pos, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stateKey = Shiboken::String::createStaticString("stateKey");
                if (PyDict_Contains(kwds, key_stateKey) != 0) {
                    value = PyDict_GetItem(kwds, key_stateKey);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_stateKey);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_stateKey);
                }
                static PyObject *const key_pos = Shiboken::String::createStaticString("pos");
                if (PyDict_Contains(kwds, key_pos) != 0) {
                    value = PyDict_GetItem(kwds, key_pos);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_pos);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pos);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "mousePress", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::MouseButton cppArg1{Qt::NoButton};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2 = Qt::KeyboardModifiers();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QPoint cppArg3 = QPoint();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = -1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mousePress(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                ::QTest::mousePress(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_mouseRelease(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:mouseRelease", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::mouseRelease(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>=,QPoint=,int=)
    // 1: static QTest::mouseRelease(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>=,QPoint=,int=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseButton_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // mouseRelease(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // mouseRelease(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // mouseRelease(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                    overloadId = 1; // mouseRelease(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                }
            }
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_MouseButton_IDX])))->converter, (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // mouseRelease(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 0; // mouseRelease(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 0; // mouseRelease(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                    overloadId = 0; // mouseRelease(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // mouseRelease(QWidget *widget, Qt::MouseButton button, QFlags<Qt::KeyboardModifier> stateKey, QPoint pos, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stateKey = Shiboken::String::createStaticString("stateKey");
                if (PyDict_Contains(kwds, key_stateKey) != 0) {
                    value = PyDict_GetItem(kwds, key_stateKey);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_stateKey);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_stateKey);
                }
                static PyObject *const key_pos = Shiboken::String::createStaticString("pos");
                if (PyDict_Contains(kwds, key_pos) != 0) {
                    value = PyDict_GetItem(kwds, key_pos);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_pos);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pos);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::MouseButton cppArg1{Qt::NoButton};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2 = Qt::KeyboardModifiers();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QPoint cppArg3 = QPoint();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = -1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mouseRelease(QWidget*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                ::QTest::mouseRelease(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
        case 1: // mouseRelease(QWindow *window, Qt::MouseButton button, QFlags<Qt::KeyboardModifier> stateKey, QPoint pos, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_stateKey = Shiboken::String::createStaticString("stateKey");
                if (PyDict_Contains(kwds, key_stateKey) != 0) {
                    value = PyDict_GetItem(kwds, key_stateKey);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_stateKey);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_stateKey);
                }
                static PyObject *const key_pos = Shiboken::String::createStaticString("pos");
                if (PyDict_Contains(kwds, key_pos) != 0) {
                    value = PyDict_GetItem(kwds, key_pos);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_pos);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pos);
                }
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "mouseRelease", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::Qt::MouseButton cppArg1{Qt::NoButton};
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QFlags<Qt::KeyboardModifier> cppArg2 = Qt::KeyboardModifiers();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QPoint cppArg3 = QPoint();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = -1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // mouseRelease(QWindow*,Qt::MouseButton,QFlags<Qt::KeyboardModifier>,QPoint,int)
                ::QTest::mouseRelease(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_qCaught(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qCaught", 3, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::qCaught(const char*,const char*,int)
    // 1: static QTest::qCaught(const char*,const char*,const char*,int)
    if (numArgs >= 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        if (numArgs == 4
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
            overloadId = 1; // qCaught(const char*,const char*,const char*,int)
        } else if (numArgs == 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
            overloadId = 0; // qCaught(const char*,const char*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "qCaught", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // qCaught(const char *expected, const char *file, int line)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qCaught(const char*,const char*,int)
                ::QTest::qCaught(cppArg0, cppArg1, cppArg2);
            }
            break;
        }
        case 1: // qCaught(const char *expected, const char *what, const char *file, int line)
        {
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            const char* cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qCaught(const char*,const char*,const char*,int)
                ::QTest::qCaught(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_qCleanup(PyObject *self)
{
    SBK_UNUSED(self)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // qCleanup()
        ::QTest::qCleanup();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_qElementData(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qElementData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::qElementData(const char*,int)->void*
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // qElementData(const char*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "qElementData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qElementData(const char*,int)
            void * cppResult = ::QTest::qElementData(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_qExpectFail(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qExpectFail", 5, 5, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::qExpectFail(const char*,const char*,QTest::TestFailMode,const char*,int)->bool
    if (numArgs == 5
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_TestFailMode_IDX])))->converter, (pyArgs[2])))
        && Shiboken::String::check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
        overloadId = 0; // qExpectFail(const char*,const char*,QTest::TestFailMode,const char*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "qExpectFail", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        const char* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QTest::TestFailMode cppArg2 = static_cast< ::QTest::TestFailMode>(0);
        pythonToCpp[2](pyArgs[2], &cppArg2);
        const char* cppArg3;
        pythonToCpp[3](pyArgs[3], &cppArg3);
        int cppArg4;
        pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qExpectFail(const char*,const char*,QTest::TestFailMode,const char*,int)
            bool cppResult = ::QTest::qExpectFail(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_qFindTestData(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:qFindTestData", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::qFindTestData(QString,const char*=,int=,const char*=,const char*=)->QString
    // 1: static QTest::qFindTestData(const char*,const char*=,int=,const char*=,const char*=)->QString
    if (numArgs >= 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // qFindTestData(const char*,const char*,int,const char*,const char*)
        } else if (numArgs >= 2
            && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // qFindTestData(const char*,const char*,int,const char*,const char*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // qFindTestData(const char*,const char*,int,const char*,const char*)
                } else if (numArgs >= 4
                    && Shiboken::String::check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 1; // qFindTestData(const char*,const char*,int,const char*,const char*)
                    } else if (numArgs >= 5
                        && Shiboken::String::check(pyArgs[4]) && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[4])))) {
                        overloadId = 1; // qFindTestData(const char*,const char*,int,const char*,const char*)
                    }
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qFindTestData(QString,const char*,int,const char*,const char*)
        } else if (numArgs >= 2
            && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // qFindTestData(QString,const char*,int,const char*,const char*)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // qFindTestData(QString,const char*,int,const char*,const char*)
                } else if (numArgs >= 4
                    && Shiboken::String::check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // qFindTestData(QString,const char*,int,const char*,const char*)
                    } else if (numArgs >= 5
                        && Shiboken::String::check(pyArgs[4]) && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[4])))) {
                        overloadId = 0; // qFindTestData(QString,const char*,int,const char*,const char*)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // qFindTestData(const QString &basepath, const char *file, int line, const char *builddir, const char *sourcedir)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_file = Shiboken::String::createStaticString("file");
                if (PyDict_Contains(kwds, key_file) != 0) {
                    value = PyDict_GetItem(kwds, key_file);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_file);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_file);
                }
                static PyObject *const key_line = Shiboken::String::createStaticString("line");
                if (PyDict_Contains(kwds, key_line) != 0) {
                    value = PyDict_GetItem(kwds, key_line);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_line);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_line);
                }
                static PyObject *const key_builddir = Shiboken::String::createStaticString("builddir");
                if (PyDict_Contains(kwds, key_builddir) != 0) {
                    value = PyDict_GetItem(kwds, key_builddir);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_builddir);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!Shiboken::String::check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_builddir);
                }
                static PyObject *const key_sourcedir = Shiboken::String::createStaticString("sourcedir");
                if (PyDict_Contains(kwds, key_sourcedir) != 0) {
                    value = PyDict_GetItem(kwds, key_sourcedir);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_sourcedir);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!Shiboken::String::check(pyArgs[4]) && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sourcedir);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = 0;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            const char* cppArg3 = nullptr;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            const char* cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFindTestData(QString,const char*,int,const char*,const char*)
                QString cppResult = ::QTest::qFindTestData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
        case 1: // qFindTestData(const char *basepath, const char *file, int line, const char *builddir, const char *sourcedir)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_file = Shiboken::String::createStaticString("file");
                if (PyDict_Contains(kwds, key_file) != 0) {
                    value = PyDict_GetItem(kwds, key_file);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_file);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_file);
                }
                static PyObject *const key_line = Shiboken::String::createStaticString("line");
                if (PyDict_Contains(kwds, key_line) != 0) {
                    value = PyDict_GetItem(kwds, key_line);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_line);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_line);
                }
                static PyObject *const key_builddir = Shiboken::String::createStaticString("builddir");
                if (PyDict_Contains(kwds, key_builddir) != 0) {
                    value = PyDict_GetItem(kwds, key_builddir);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_builddir);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!Shiboken::String::check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_builddir);
                }
                static PyObject *const key_sourcedir = Shiboken::String::createStaticString("sourcedir");
                if (PyDict_Contains(kwds, key_sourcedir) != 0) {
                    value = PyDict_GetItem(kwds, key_sourcedir);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_sourcedir);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!Shiboken::String::check(pyArgs[4]) && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_sourcedir);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "qFindTestData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            const char* cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2 = 0;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            const char* cppArg3 = nullptr;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            const char* cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qFindTestData(const char*,const char*,int,const char*,const char*)
                QString cppResult = ::QTest::qFindTestData(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_qGlobalData(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qGlobalData", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::qGlobalData(const char*,int)->void*
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // qGlobalData(const char*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "qGlobalData", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qGlobalData(const char*,int)
            void * cppResult = ::QTest::qGlobalData(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_qRun(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // qRun()
        int cppResult = ::QTest::qRun();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_qSkip(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "qSkip", 3, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::qSkip(const char*,const char*,int)
    if (numArgs == 3
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))) {
        overloadId = 0; // qSkip(const char*,const char*,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "qSkip", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        const char* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        int cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qSkip(const char*,const char*,int)
            ::QTest::qSkip(cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_qSleep(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QTest::qSleep(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // qSleep(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "qSleep", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qSleep(int)
            ::QTest::qSleep(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_qWait(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QTest::qWait(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // qWait(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "qWait", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // qWait(int)
            ::QTest::qWait(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_qWaitForWindowActive(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "qWaitForWindowActive", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OO:qWaitForWindowActive", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::qWaitForWindowActive(QWidget*,int=)->bool
    // 1: static QTest::qWaitForWindowActive(QWindow*,int=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // qWaitForWindowActive(QWindow*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // qWaitForWindowActive(QWindow*,int)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qWaitForWindowActive(QWidget*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // qWaitForWindowActive(QWidget*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "qWaitForWindowActive", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // qWaitForWindowActive(QWidget *widget, int timeout)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
                if (PyDict_Contains(kwds, key_timeout) != 0) {
                    value = PyDict_GetItem(kwds, key_timeout);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_timeout);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qWaitForWindowActive", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "qWaitForWindowActive", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_timeout);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "qWaitForWindowActive", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 5000;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qWaitForWindowActive(QWidget*,int)
                bool cppResult = ::QTest::qWaitForWindowActive(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // qWaitForWindowActive(QWindow *window, int timeout)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
                if (PyDict_Contains(kwds, key_timeout) != 0) {
                    value = PyDict_GetItem(kwds, key_timeout);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_timeout);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qWaitForWindowActive", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "qWaitForWindowActive", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_timeout);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "qWaitForWindowActive", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 5000;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qWaitForWindowActive(QWindow*,int)
                bool cppResult = ::QTest::qWaitForWindowActive(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_qWaitForWindowExposed(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "qWaitForWindowExposed", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OO:qWaitForWindowExposed", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::qWaitForWindowExposed(QWidget*,int=)->bool
    // 1: static QTest::qWaitForWindowExposed(QWindow*,int=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // qWaitForWindowExposed(QWindow*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 1; // qWaitForWindowExposed(QWindow*,int)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qWaitForWindowExposed(QWidget*,int)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
            overloadId = 0; // qWaitForWindowExposed(QWidget*,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "qWaitForWindowExposed", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // qWaitForWindowExposed(QWidget *widget, int timeout)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
                if (PyDict_Contains(kwds, key_timeout) != 0) {
                    value = PyDict_GetItem(kwds, key_timeout);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_timeout);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qWaitForWindowExposed", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "qWaitForWindowExposed", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_timeout);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "qWaitForWindowExposed", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 5000;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qWaitForWindowExposed(QWidget*,int)
                bool cppResult = ::QTest::qWaitForWindowExposed(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // qWaitForWindowExposed(QWindow *window, int timeout)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
                if (PyDict_Contains(kwds, key_timeout) != 0) {
                    value = PyDict_GetItem(kwds, key_timeout);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_timeout);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qWaitForWindowExposed", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "qWaitForWindowExposed", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_timeout);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "qWaitForWindowExposed", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1 = 5000;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qWaitForWindowExposed(QWindow*,int)
                bool cppResult = ::QTest::qWaitForWindowExposed(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_qWaitForWindowFocused(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "qWaitForWindowFocused", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OO:qWaitForWindowFocused", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::qWaitForWindowFocused(QWidget*,QDeadlineTimer=)->bool
    // 1: static QTest::qWaitForWindowFocused(QWindow*,QDeadlineTimer=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // qWaitForWindowFocused(QWindow*,QDeadlineTimer)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[1])))) {
            overloadId = 1; // qWaitForWindowFocused(QWindow*,QDeadlineTimer)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // qWaitForWindowFocused(QWidget*,QDeadlineTimer)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[1])))) {
            overloadId = 0; // qWaitForWindowFocused(QWidget*,QDeadlineTimer)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "qWaitForWindowFocused", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // qWaitForWindowFocused(QWidget *widget, QDeadlineTimer timeout)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
                if (PyDict_Contains(kwds, key_timeout) != 0) {
                    value = PyDict_GetItem(kwds, key_timeout);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_timeout);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qWaitForWindowFocused", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "qWaitForWindowFocused", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_timeout);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "qWaitForWindowFocused", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QDeadlineTimer cppArg1(std::chrono::seconds{5});
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qWaitForWindowFocused(QWidget*,QDeadlineTimer)
                bool cppResult = ::QTest::qWaitForWindowFocused(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // qWaitForWindowFocused(QWindow *widget, QDeadlineTimer timeout)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_timeout = Shiboken::String::createStaticString("timeout");
                if (PyDict_Contains(kwds, key_timeout) != 0) {
                    value = PyDict_GetItem(kwds, key_timeout);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_timeout);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "qWaitForWindowFocused", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDeadlineTimer_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "qWaitForWindowFocused", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_timeout);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "qWaitForWindowFocused", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QDeadlineTimer cppArg1(std::chrono::seconds{5});
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qWaitForWindowFocused(QWindow*,QDeadlineTimer)
                bool cppResult = ::QTest::qWaitForWindowFocused(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_runningTest(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // runningTest()
        bool cppResult = ::QTest::runningTest();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_sendKeyEvent(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 5, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:sendKeyEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::sendKeyEvent(QTest::KeyAction,QWidget*,Qt::Key,QString,QFlags<Qt::KeyboardModifier>,int=)
    // 1: static QTest::sendKeyEvent(QTest::KeyAction,QWidget*,Qt::Key,char,QFlags<Qt::KeyboardModifier>,int=)
    // 2: static QTest::sendKeyEvent(QTest::KeyAction,QWindow*,Qt::Key,QString,QFlags<Qt::KeyboardModifier>,int=)
    // 3: static QTest::sendKeyEvent(QTest::KeyAction,QWindow*,Qt::Key,char,QFlags<Qt::KeyboardModifier>,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_KeyAction_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Key_IDX])))->converter, (pyArgs[2])))) {
            if (numArgs >= 5
                && SbkChar_Check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[3])))
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 3; // sendKeyEvent(QTest::KeyAction,QWindow*,Qt::Key,char,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
                    overloadId = 3; // sendKeyEvent(QTest::KeyAction,QWindow*,Qt::Key,char,QFlags<Qt::KeyboardModifier>,int)
                }
            } else if (numArgs >= 5
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 2; // sendKeyEvent(QTest::KeyAction,QWindow*,Qt::Key,QString,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
                    overloadId = 2; // sendKeyEvent(QTest::KeyAction,QWindow*,Qt::Key,QString,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        } else if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_Key_IDX])))->converter, (pyArgs[2])))) {
            if (numArgs >= 5
                && SbkChar_Check(pyArgs[3]) && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<char>(), (pyArgs[3])))
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 1; // sendKeyEvent(QTest::KeyAction,QWidget*,Qt::Key,char,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
                    overloadId = 1; // sendKeyEvent(QTest::KeyAction,QWidget*,Qt::Key,char,QFlags<Qt::KeyboardModifier>,int)
                }
            } else if (numArgs >= 5
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 0; // sendKeyEvent(QTest::KeyAction,QWidget*,Qt::Key,QString,QFlags<Qt::KeyboardModifier>,int)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
                    overloadId = 0; // sendKeyEvent(QTest::KeyAction,QWidget*,Qt::Key,QString,QFlags<Qt::KeyboardModifier>,int)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // sendKeyEvent(QTest::KeyAction action, QWidget *widget, Qt::Key code, QString text, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            ::QTest::KeyAction cppArg0{QTest::Press};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QWidget *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::Key cppArg2 = static_cast< ::Qt::Key>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QFlags<Qt::KeyboardModifier> cppArg4 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5 = -1;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sendKeyEvent(QTest::KeyAction,QWidget*,Qt::Key,QString,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::sendKeyEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
        case 1: // sendKeyEvent(QTest::KeyAction action, QWidget *widget, Qt::Key code, char ascii, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            ::QTest::KeyAction cppArg0{QTest::Press};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QWidget *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::Key cppArg2 = static_cast< ::Qt::Key>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);
            char cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QFlags<Qt::KeyboardModifier> cppArg4 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5 = -1;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sendKeyEvent(QTest::KeyAction,QWidget*,Qt::Key,char,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::sendKeyEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
        case 2: // sendKeyEvent(QTest::KeyAction action, QWindow *window, Qt::Key code, QString text, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            ::QTest::KeyAction cppArg0{QTest::Press};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QWindow *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::Key cppArg2 = static_cast< ::Qt::Key>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QFlags<Qt::KeyboardModifier> cppArg4 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5 = -1;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sendKeyEvent(QTest::KeyAction,QWindow*,Qt::Key,QString,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::sendKeyEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
        case 3: // sendKeyEvent(QTest::KeyAction action, QWindow *window, Qt::Key code, char ascii, QFlags<Qt::KeyboardModifier> modifier, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "sendKeyEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            ::QTest::KeyAction cppArg0{QTest::Press};
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QWindow *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::Key cppArg2 = static_cast< ::Qt::Key>(0);
            pythonToCpp[2](pyArgs[2], &cppArg2);
            char cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QFlags<Qt::KeyboardModifier> cppArg4 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5 = -1;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // sendKeyEvent(QTest::KeyAction,QWindow*,Qt::Key,char,QFlags<Qt::KeyboardModifier>,int)
                ::QTest::sendKeyEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_setBenchmarkResult(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setBenchmarkResult", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::setBenchmarkResult(qreal,QTest::QBenchmarkMetric)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_QBenchmarkMetric_IDX])))->converter, (pyArgs[1])))) {
        overloadId = 0; // setBenchmarkResult(qreal,QTest::QBenchmarkMetric)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setBenchmarkResult", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QTest::QBenchmarkMetric cppArg1{QTest::FramesPerSecond};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBenchmarkResult(qreal,QTest::QBenchmarkMetric)
            ::QTest::setBenchmarkResult(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_setMainSourcePath(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setMainSourcePath", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setMainSourcePath", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::setMainSourcePath(const char*,const char*=)
    if (numArgs >= 1
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setMainSourcePath(const char*,const char*)
        } else if (numArgs >= 2
            && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
            overloadId = 0; // setMainSourcePath(const char*,const char*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setMainSourcePath", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_builddir = Shiboken::String::createStaticString("builddir");
            if (PyDict_Contains(kwds, key_builddir) != 0) {
                value = PyDict_GetItem(kwds, key_builddir);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_builddir);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setMainSourcePath", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setMainSourcePath", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_builddir);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setMainSourcePath", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
            }
        }
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        const char* cppArg1 = nullptr;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMainSourcePath(const char*,const char*)
            ::QTest::setMainSourcePath(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_setThrowOnFail(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QTest::setThrowOnFail(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setThrowOnFail(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setThrowOnFail", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setThrowOnFail(bool)
            ::QTest::setThrowOnFail(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_setThrowOnSkip(PyObject *self, PyObject *pyArg)
{
    SBK_UNUSED(self)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: static QTest::setThrowOnSkip(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setThrowOnSkip(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setThrowOnSkip", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setThrowOnSkip(bool)
            ::QTest::setThrowOnSkip(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_simulateEvent(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 6, 7));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "simulateEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOO:simulateEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::simulateEvent(QWidget*,bool,int,QFlags<Qt::KeyboardModifier>,QString,bool,int=)
    // 1: static QTest::simulateEvent(QWindow*,bool,int,QFlags<Qt::KeyboardModifier>,QString,bool,int=)
    if (numArgs >= 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[5])))) {
        if (numArgs == 6) {
            overloadId = 1; // simulateEvent(QWindow*,bool,int,QFlags<Qt::KeyboardModifier>,QString,bool,int)
        } else if (numArgs >= 7
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))) {
            overloadId = 1; // simulateEvent(QWindow*,bool,int,QFlags<Qt::KeyboardModifier>,QString,bool,int)
        }
    } else if (numArgs >= 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[5])))) {
        if (numArgs == 6) {
            overloadId = 0; // simulateEvent(QWidget*,bool,int,QFlags<Qt::KeyboardModifier>,QString,bool,int)
        } else if (numArgs >= 7
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))) {
            overloadId = 0; // simulateEvent(QWidget*,bool,int,QFlags<Qt::KeyboardModifier>,QString,bool,int)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "simulateEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // simulateEvent(QWidget *widget, bool press, int code, QFlags<Qt::KeyboardModifier> modifier, QString text, bool repeat, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "simulateEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, "simulateEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "simulateEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            bool cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<Qt::KeyboardModifier> cppArg3 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QString cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            bool cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6 = -1;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // simulateEvent(QWidget*,bool,int,QFlags<Qt::KeyboardModifier>,QString,bool,int)
                ::QTest::simulateEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
            }
            break;
        }
        case 1: // simulateEvent(QWindow *window, bool press, int code, QFlags<Qt::KeyboardModifier> modifier, QString text, bool repeat, int delay)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_delay = Shiboken::String::createStaticString("delay");
                if (PyDict_Contains(kwds, key_delay) != 0) {
                    value = PyDict_GetItem(kwds, key_delay);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_delay);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "simulateEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, "simulateEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_delay);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "simulateEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            bool cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QFlags<Qt::KeyboardModifier> cppArg3 = QFlags<Qt::KeyboardModifier>(0);
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QString cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            bool cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6 = -1;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // simulateEvent(QWindow*,bool,int,QFlags<Qt::KeyboardModifier>,QString,bool,int)
                ::QTest::simulateEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QTestFunc_testObject(PyObject *self)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // testObject()
        QObject * cppResult = ::QTest::testObject();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_toPrettyCString(PyObject *self, PyObject *args)
{
    SBK_UNUSED(self)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "toPrettyCString", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::toPrettyCString(const char*,qsizetype)->char*
    if (numArgs == 2
        && Shiboken::String::check(pyArgs[0]) && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qsizetype>(), (pyArgs[1])))) {
        overloadId = 0; // toPrettyCString(const char*,qsizetype)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "toPrettyCString", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        const char* cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        qsizetype cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // toPrettyCString(const char*,qsizetype)
            char * cppResult = ::QTest::toPrettyCString(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_touchEvent(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "touchEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:touchEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::generateTouchEvent(QWidget*,QPointingDevice*,bool=)->QTest::PySideQTouchEventSequence*
    // 1: static QTest::generateTouchEvent(QWindow*,QPointingDevice*,bool=)->QTest::PySideQTouchEventSequence*
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 1; // generateTouchEvent(QWindow*,QPointingDevice*,bool)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2])))) {
            overloadId = 1; // generateTouchEvent(QWindow*,QPointingDevice*,bool)
        }
    } else if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPointingDevice_IDX]), (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // generateTouchEvent(QWidget*,QPointingDevice*,bool)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2])))) {
            overloadId = 0; // generateTouchEvent(QWidget*,QPointingDevice*,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "touchEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // generateTouchEvent(QWidget *widget, QPointingDevice *device, bool autoCommit)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_autoCommit = Shiboken::String::createStaticString("autoCommit");
                if (PyDict_Contains(kwds, key_autoCommit) != 0) {
                    value = PyDict_GetItem(kwds, key_autoCommit);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_autoCommit);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "touchEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "touchEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_autoCommit);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "touchEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPointingDevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            bool cppArg2 = true;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // generateTouchEvent(QWidget*,QPointingDevice*,bool)
                QTest::PySideQTouchEventSequence * cppResult = ::QTest::generateTouchEvent(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_PySideQTouchEventSequence_IDX]), cppResult);

                // Ownership transferences.
                Shiboken::Object::getOwnership(pyResult);
            }
            break;
        }
        case 1: // generateTouchEvent(QWindow *window, QPointingDevice *device, bool autoCommit)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_autoCommit = Shiboken::String::createStaticString("autoCommit");
                if (PyDict_Contains(kwds, key_autoCommit) != 0) {
                    value = PyDict_GetItem(kwds, key_autoCommit);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_autoCommit);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "touchEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "touchEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_autoCommit);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "touchEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QWindow *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPointingDevice *cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            bool cppArg2 = true;
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (Shiboken::Errors::occurred() == nullptr) {
                // generateTouchEvent(QWindow*,QPointingDevice*,bool)
                QTest::PySideQTouchEventSequence * cppResult = ::QTest::generateTouchEvent(cppArg0, cppArg1, cppArg2);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_PySideQTouchEventSequence_IDX]), cppResult);

                // Ownership transferences.
                Shiboken::Object::getOwnership(pyResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QTestFunc_wheelEvent(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "wheelEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:wheelEvent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QTest::wheelEvent(QWindow*,QPointF,QPoint,QPoint=,QFlags<Qt::KeyboardModifier>=,Qt::ScrollPhase=)
    if (numArgs >= 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[2])))) {
        if (numArgs == 3) {
            overloadId = 0; // wheelEvent(QWindow*,QPointF,QPoint,QPoint,QFlags<Qt::KeyboardModifier>,Qt::ScrollPhase)
        } else if (numArgs >= 4
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 0; // wheelEvent(QWindow*,QPointF,QPoint,QPoint,QFlags<Qt::KeyboardModifier>,Qt::ScrollPhase)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 0; // wheelEvent(QWindow*,QPointF,QPoint,QPoint,QFlags<Qt::KeyboardModifier>,Qt::ScrollPhase)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScrollPhase_IDX])))->converter, (pyArgs[5])))) {
                    overloadId = 0; // wheelEvent(QWindow*,QPointF,QPoint,QPoint,QFlags<Qt::KeyboardModifier>,Qt::ScrollPhase)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "wheelEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_pixelDelta = Shiboken::String::createStaticString("pixelDelta");
            if (PyDict_Contains(kwds, key_pixelDelta) != 0) {
                value = PyDict_GetItem(kwds, key_pixelDelta);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_pixelDelta);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "wheelEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "wheelEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_pixelDelta);
            }
            static PyObject *const key_stateKey = Shiboken::String::createStaticString("stateKey");
            if (PyDict_Contains(kwds, key_stateKey) != 0) {
                value = PyDict_GetItem(kwds, key_stateKey);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_stateKey);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "wheelEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_KeyboardModifier_IDX])))->flagsConverter, (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "wheelEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_stateKey);
            }
            static PyObject *const key_phase = Shiboken::String::createStaticString("phase");
            if (PyDict_Contains(kwds, key_phase) != 0) {
                value = PyDict_GetItem(kwds, key_phase);
                if (value != nullptr && pyArgs[5] != nullptr ) {
                    errInfo.reset(key_phase);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "wheelEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[5] = value;
                    if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ScrollPhase_IDX])))->converter, (pyArgs[5]))))
                        return Shiboken::returnWrongArguments(args, "wheelEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_phase);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "wheelEvent", errInfo, SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWindow *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPointF cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QPoint cppArg2;
        pythonToCpp[2](pyArgs[2], &cppArg2);
        if (!Shiboken::Object::isValid(pyArgs[3]))
            return {};
        ::QPoint cppArg3 = QPoint(0, 0);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QFlags<Qt::KeyboardModifier> cppArg4(Qt::NoModifier);
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);
        ::Qt::ScrollPhase cppArg5(Qt::NoScrollPhase);
        if (pythonToCpp[5])
            pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wheelEvent(QWindow*,QPointF,QPoint,QPoint,QFlags<Qt::KeyboardModifier>,Qt::ScrollPhase)
            ::QTest::wheelEvent(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QTest_PropertyStrings[] = {
    nullptr // Sentinel
};

static const char *Sbk_QTest_EnumFlagInfo[] = {
    "ComparisonOperation:Enum",
    "KeyAction:Enum",
    "MouseAction:Enum",
    "QBenchmarkMetric:Enum",
    "TestFailMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QTest_methods[] = {
    {"addColumnInternal", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_addColumnInternal), METH_VARARGS|METH_STATIC, nullptr},
    {"asciiToKey", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_asciiToKey), METH_O|METH_STATIC, nullptr},
    {"compare_ptr_helper", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_compare_ptr_helper), METH_VARARGS|METH_STATIC, nullptr},
    {"compare_string_helper", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_compare_string_helper), METH_VARARGS|METH_STATIC, nullptr},
    {"createTouchDevice", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_createTouchDevice), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"currentAppName", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_currentAppName), METH_NOARGS|METH_STATIC, nullptr},
    {"currentDataTag", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_currentDataTag), METH_NOARGS|METH_STATIC, nullptr},
    {"currentTestFailed", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_currentTestFailed), METH_NOARGS|METH_STATIC, nullptr},
    {"currentTestFunction", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_currentTestFunction), METH_NOARGS|METH_STATIC, nullptr},
    {"currentTestResolved", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_currentTestResolved), METH_NOARGS|METH_STATIC, nullptr},
    {"failOnWarning", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_failOnWarning), METH_VARARGS|METH_STATIC, nullptr},
    {"formatString", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_formatString), METH_VARARGS|METH_STATIC, nullptr},
    {"ignoreMessage", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_ignoreMessage), METH_VARARGS|METH_STATIC, nullptr},
    {"keyClick", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_keyClick), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"keyClicks", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_keyClicks), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"keyEvent", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_keyEvent), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"keyPress", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_keyPress), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"keyRelease", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_keyRelease), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"keySequence", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_keySequence), METH_VARARGS|METH_STATIC, nullptr},
    {"keyToAscii", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_keyToAscii), METH_O|METH_STATIC, nullptr},
    {"mouseClick", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_mouseClick), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"mouseDClick", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_mouseDClick), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"mouseEvent", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_mouseEvent), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"mouseMove", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_mouseMove), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"mousePress", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_mousePress), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"mouseRelease", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_mouseRelease), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"qCaught", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_qCaught), METH_VARARGS|METH_STATIC, nullptr},
    {"qCleanup", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_qCleanup), METH_NOARGS|METH_STATIC, nullptr},
    {"qElementData", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_qElementData), METH_VARARGS|METH_STATIC, nullptr},
    {"qExpectFail", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_qExpectFail), METH_VARARGS|METH_STATIC, nullptr},
    {"qFindTestData", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_qFindTestData), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"qGlobalData", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_qGlobalData), METH_VARARGS|METH_STATIC, nullptr},
    {"qRun", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_qRun), METH_NOARGS|METH_STATIC, nullptr},
    {"qSkip", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_qSkip), METH_VARARGS|METH_STATIC, nullptr},
    {"qSleep", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_qSleep), METH_O|METH_STATIC, nullptr},
    {"qWait", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_qWait), METH_O|METH_STATIC, nullptr},
    {"qWaitForWindowActive", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_qWaitForWindowActive), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"qWaitForWindowExposed", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_qWaitForWindowExposed), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"qWaitForWindowFocused", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_qWaitForWindowFocused), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"runningTest", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_runningTest), METH_NOARGS|METH_STATIC, nullptr},
    {"sendKeyEvent", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_sendKeyEvent), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"setBenchmarkResult", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_setBenchmarkResult), METH_VARARGS|METH_STATIC, nullptr},
    {"setMainSourcePath", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_setMainSourcePath), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"setThrowOnFail", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_setThrowOnFail), METH_O|METH_STATIC, nullptr},
    {"setThrowOnSkip", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_setThrowOnSkip), METH_O|METH_STATIC, nullptr},
    {"simulateEvent", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_simulateEvent), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"testObject", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_testObject), METH_NOARGS|METH_STATIC, nullptr},
    {"toPrettyCString", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_toPrettyCString), METH_VARARGS|METH_STATIC, nullptr},
    {"touchEvent", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_touchEvent), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"wheelEvent", reinterpret_cast<PyCFunction>(Sbk_QTestFunc_wheelEvent), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_QTest_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QTest_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QTest_Type = nullptr;
static PyTypeObject *Sbk_QTest_TypeF(void)
{
    return _Sbk_QTest_Type;
}

static PyType_Slot Sbk_QTest_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(Sbk_object_dealloc /* PYSIDE-832: Prevent replacement of "0" with subtype_dealloc. */)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QTest_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QTest_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QTest_methods)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QTest_spec = {
    "2:PySide6.QtTest.QTest",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QTest_slots
};

} //extern "C"

// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QTest_TestFailMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTest::TestFailMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTest::TestFailMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTest_TestFailMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_TestFailMode_IDX])))
        return Enum_PythonToCpp_QTest_TestFailMode;
    return {};
}

static PyObject *QTest_TestFailMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTest::TestFailMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTest::TestFailMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_TestFailMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTest_ComparisonOperation(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTest::ComparisonOperation>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTest::ComparisonOperation *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTest_ComparisonOperation_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_ComparisonOperation_IDX])))
        return Enum_PythonToCpp_QTest_ComparisonOperation;
    return {};
}

static PyObject *QTest_ComparisonOperation_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTest::ComparisonOperation>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTest::ComparisonOperation *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_ComparisonOperation_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTest_QBenchmarkMetric(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTest::QBenchmarkMetric>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTest::QBenchmarkMetric *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTest_QBenchmarkMetric_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_QBenchmarkMetric_IDX])))
        return Enum_PythonToCpp_QTest_QBenchmarkMetric;
    return {};
}

static PyObject *QTest_QBenchmarkMetric_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTest::QBenchmarkMetric>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTest::QBenchmarkMetric *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_QBenchmarkMetric_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTest_KeyAction(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTest::KeyAction>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTest::KeyAction *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTest_KeyAction_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_KeyAction_IDX])))
        return Enum_PythonToCpp_QTest_KeyAction;
    return {};
}

static PyObject *QTest_KeyAction_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTest::KeyAction>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTest::KeyAction *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_KeyAction_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QTest_MouseAction(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QTest::MouseAction>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QTest::MouseAction *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QTest_MouseAction_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_MouseAction_IDX])))
        return Enum_PythonToCpp_QTest_MouseAction;
    return {};
}

static PyObject *QTest_MouseAction_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QTest::MouseAction>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QTest::MouseAction *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtTestTypeStructs[SBK_QTest_MouseAction_IDX]), castCppIn);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QtTestQTest_SignatureStrings[] = {
    "PySide6.QtTest.QTest.addColumnInternal(id:int,name:char*)",
    "PySide6.QtTest.QTest.asciiToKey(ascii:char)->PySide6.QtCore.Qt.Key",
    "1:PySide6.QtTest.QTest.compare_ptr_helper(t1:PySide6.QtCore.QObject,t2:PySide6.QtCore.QObject,actual:char*,expected:char*,file:char*,line:int)->bool",
    "0:PySide6.QtTest.QTest.compare_ptr_helper(t1:void,t2:void,actual:char*,expected:char*,file:char*,line:int)->bool",
    "PySide6.QtTest.QTest.compare_string_helper(t1:char*,t2:char*,actual:char*,expected:char*,file:char*,line:int)->bool",
    "PySide6.QtTest.QTest.createTouchDevice(devType:PySide6.QtGui.QInputDevice.DeviceType=QInputDevice.DeviceType.TouchScreen,caps:PySide6.QtGui.QInputDevice.Capability=QInputDevice.Capability.Position)->PySide6.QtGui.QPointingDevice",
    "PySide6.QtTest.QTest.currentAppName()->char*",
    "PySide6.QtTest.QTest.currentDataTag()->char*",
    "PySide6.QtTest.QTest.currentTestFailed()->bool",
    "PySide6.QtTest.QTest.currentTestFunction()->char*",
    "PySide6.QtTest.QTest.currentTestResolved()->bool",
    "2:PySide6.QtTest.QTest.failOnWarning()",
    "1:PySide6.QtTest.QTest.failOnWarning(messagePattern:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "0:PySide6.QtTest.QTest.failOnWarning(message:char*)",
    "PySide6.QtTest.QTest.formatString(prefix:char*,suffix:char*,numArguments:size_t)->char*",
    "1:PySide6.QtTest.QTest.ignoreMessage(type:PySide6.QtCore.QtMsgType,messagePattern:typing.Union[PySide6.QtCore.QRegularExpression, QString])",
    "0:PySide6.QtTest.QTest.ignoreMessage(type:PySide6.QtCore.QtMsgType,message:char*)",
    "3:PySide6.QtTest.QTest.keyClick(widget:PySide6.QtWidgets.QWidget,key:PySide6.QtCore.Qt.Key,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "2:PySide6.QtTest.QTest.keyClick(widget:PySide6.QtWidgets.QWidget,key:char,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "1:PySide6.QtTest.QTest.keyClick(window:PySide6.QtGui.QWindow,key:PySide6.QtCore.Qt.Key,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "0:PySide6.QtTest.QTest.keyClick(window:PySide6.QtGui.QWindow,key:char,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "PySide6.QtTest.QTest.keyClicks(widget:PySide6.QtWidgets.QWidget,sequence:QString,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "3:PySide6.QtTest.QTest.keyEvent(action:PySide6.QtTest.QTest.KeyAction,widget:PySide6.QtWidgets.QWidget,key:PySide6.QtCore.Qt.Key,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "2:PySide6.QtTest.QTest.keyEvent(action:PySide6.QtTest.QTest.KeyAction,widget:PySide6.QtWidgets.QWidget,ascii:char,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "1:PySide6.QtTest.QTest.keyEvent(action:PySide6.QtTest.QTest.KeyAction,window:PySide6.QtGui.QWindow,key:PySide6.QtCore.Qt.Key,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "0:PySide6.QtTest.QTest.keyEvent(action:PySide6.QtTest.QTest.KeyAction,window:PySide6.QtGui.QWindow,ascii:char,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "3:PySide6.QtTest.QTest.keyPress(widget:PySide6.QtWidgets.QWidget,key:PySide6.QtCore.Qt.Key,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "2:PySide6.QtTest.QTest.keyPress(widget:PySide6.QtWidgets.QWidget,key:char,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "1:PySide6.QtTest.QTest.keyPress(window:PySide6.QtGui.QWindow,key:PySide6.QtCore.Qt.Key,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "0:PySide6.QtTest.QTest.keyPress(window:PySide6.QtGui.QWindow,key:char,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "3:PySide6.QtTest.QTest.keyRelease(widget:PySide6.QtWidgets.QWidget,key:PySide6.QtCore.Qt.Key,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "2:PySide6.QtTest.QTest.keyRelease(widget:PySide6.QtWidgets.QWidget,key:char,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "1:PySide6.QtTest.QTest.keyRelease(window:PySide6.QtGui.QWindow,key:PySide6.QtCore.Qt.Key,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "0:PySide6.QtTest.QTest.keyRelease(window:PySide6.QtGui.QWindow,key:char,modifier:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,delay:int=-1)",
    "1:PySide6.QtTest.QTest.keySequence(widget:PySide6.QtWidgets.QWidget,keySequence:typing.Union[PySide6.QtGui.QKeySequence, PySide6.QtCore.QKeyCombination, PySide6.QtGui.QKeySequence.StandardKey, QString, int])",
    "0:PySide6.QtTest.QTest.keySequence(window:PySide6.QtGui.QWindow,keySequence:typing.Union[PySide6.QtGui.QKeySequence, PySide6.QtCore.QKeyCombination, PySide6.QtGui.QKeySequence.StandardKey, QString, int])",
    "PySide6.QtTest.QTest.keyToAscii(key:PySide6.QtCore.Qt.Key)->char",
    "1:PySide6.QtTest.QTest.mouseClick(widget:PySide6.QtWidgets.QWidget,button:PySide6.QtCore.Qt.MouseButton,stateKey:PySide6.QtCore.Qt.KeyboardModifier=Qt.KeyboardModifiers(),pos:PySide6.QtCore.QPoint=QPoint(),delay:int=-1)",
    "0:PySide6.QtTest.QTest.mouseClick(window:PySide6.QtGui.QWindow,button:PySide6.QtCore.Qt.MouseButton,stateKey:PySide6.QtCore.Qt.KeyboardModifier=Qt.KeyboardModifiers(),pos:PySide6.QtCore.QPoint=QPoint(),delay:int=-1)",
    "1:PySide6.QtTest.QTest.mouseDClick(widget:PySide6.QtWidgets.QWidget,button:PySide6.QtCore.Qt.MouseButton,stateKey:PySide6.QtCore.Qt.KeyboardModifier=Qt.KeyboardModifiers(),pos:PySide6.QtCore.QPoint=QPoint(),delay:int=-1)",
    "0:PySide6.QtTest.QTest.mouseDClick(window:PySide6.QtGui.QWindow,button:PySide6.QtCore.Qt.MouseButton,stateKey:PySide6.QtCore.Qt.KeyboardModifier=Qt.KeyboardModifiers(),pos:PySide6.QtCore.QPoint=QPoint(),delay:int=-1)",
    "1:PySide6.QtTest.QTest.mouseEvent(action:PySide6.QtTest.QTest.MouseAction,widget:PySide6.QtWidgets.QWidget,button:PySide6.QtCore.Qt.MouseButton,stateKey:PySide6.QtCore.Qt.KeyboardModifier,pos:PySide6.QtCore.QPoint,delay:int=-1)",
    "0:PySide6.QtTest.QTest.mouseEvent(action:PySide6.QtTest.QTest.MouseAction,window:PySide6.QtGui.QWindow,button:PySide6.QtCore.Qt.MouseButton,stateKey:PySide6.QtCore.Qt.KeyboardModifier,pos:PySide6.QtCore.QPoint,delay:int=-1)",
    "1:PySide6.QtTest.QTest.mouseMove(widget:PySide6.QtWidgets.QWidget,pos:PySide6.QtCore.QPoint=QPoint(),delay:int=-1)",
    "0:PySide6.QtTest.QTest.mouseMove(window:PySide6.QtGui.QWindow,pos:PySide6.QtCore.QPoint=QPoint(),delay:int=-1)",
    "1:PySide6.QtTest.QTest.mousePress(widget:PySide6.QtWidgets.QWidget,button:PySide6.QtCore.Qt.MouseButton,stateKey:PySide6.QtCore.Qt.KeyboardModifier=Qt.KeyboardModifiers(),pos:PySide6.QtCore.QPoint=QPoint(),delay:int=-1)",
    "0:PySide6.QtTest.QTest.mousePress(window:PySide6.QtGui.QWindow,button:PySide6.QtCore.Qt.MouseButton,stateKey:PySide6.QtCore.Qt.KeyboardModifier=Qt.KeyboardModifiers(),pos:PySide6.QtCore.QPoint=QPoint(),delay:int=-1)",
    "1:PySide6.QtTest.QTest.mouseRelease(widget:PySide6.QtWidgets.QWidget,button:PySide6.QtCore.Qt.MouseButton,stateKey:PySide6.QtCore.Qt.KeyboardModifier=Qt.KeyboardModifiers(),pos:PySide6.QtCore.QPoint=QPoint(),delay:int=-1)",
    "0:PySide6.QtTest.QTest.mouseRelease(window:PySide6.QtGui.QWindow,button:PySide6.QtCore.Qt.MouseButton,stateKey:PySide6.QtCore.Qt.KeyboardModifier=Qt.KeyboardModifiers(),pos:PySide6.QtCore.QPoint=QPoint(),delay:int=-1)",
    "1:PySide6.QtTest.QTest.qCaught(expected:char*,file:char*,line:int)",
    "0:PySide6.QtTest.QTest.qCaught(expected:char*,what:char*,file:char*,line:int)",
    "PySide6.QtTest.QTest.qCleanup()",
    "PySide6.QtTest.QTest.qElementData(elementName:char*,metaTypeId:int)->void",
    "PySide6.QtTest.QTest.qExpectFail(dataIndex:char*,comment:char*,mode:PySide6.QtTest.QTest.TestFailMode,file:char*,line:int)->bool",
    "1:PySide6.QtTest.QTest.qFindTestData(basepath:QString,file:char*=nullptr,line:int=0,builddir:char*=nullptr,sourcedir:char*=nullptr)->QString",
    "0:PySide6.QtTest.QTest.qFindTestData(basepath:char*,file:char*=nullptr,line:int=0,builddir:char*=nullptr,sourcedir:char*=nullptr)->QString",
    "PySide6.QtTest.QTest.qGlobalData(tagName:char*,typeId:int)->void",
    "PySide6.QtTest.QTest.qRun()->int",
    "PySide6.QtTest.QTest.qSkip(message:char*,file:char*,line:int)",
    "PySide6.QtTest.QTest.qSleep(ms:int)",
    "PySide6.QtTest.QTest.qWait(ms:int)",
    "1:PySide6.QtTest.QTest.qWaitForWindowActive(widget:PySide6.QtWidgets.QWidget,timeout:int=5000)->bool",
    "0:PySide6.QtTest.QTest.qWaitForWindowActive(window:PySide6.QtGui.QWindow,timeout:int=5000)->bool",
    "1:PySide6.QtTest.QTest.qWaitForWindowExposed(widget:PySide6.QtWidgets.QWidget,timeout:int=5000)->bool",
    "0:PySide6.QtTest.QTest.qWaitForWindowExposed(window:PySide6.QtGui.QWindow,timeout:int=5000)->bool",
    "1:PySide6.QtTest.QTest.qWaitForWindowFocused(widget:PySide6.QtWidgets.QWidget,timeout:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64]=std.chrono.seconds{5})->bool",
    "0:PySide6.QtTest.QTest.qWaitForWindowFocused(widget:PySide6.QtGui.QWindow,timeout:typing.Union[PySide6.QtCore.QDeadlineTimer, PySide6.QtCore.QDeadlineTimer.ForeverConstant, qint64]=std.chrono.seconds{5})->bool",
    "PySide6.QtTest.QTest.runningTest()->bool",
    "3:PySide6.QtTest.QTest.sendKeyEvent(action:PySide6.QtTest.QTest.KeyAction,widget:PySide6.QtWidgets.QWidget,code:PySide6.QtCore.Qt.Key,text:QString,modifier:PySide6.QtCore.Qt.KeyboardModifier,delay:int=-1)",
    "2:PySide6.QtTest.QTest.sendKeyEvent(action:PySide6.QtTest.QTest.KeyAction,widget:PySide6.QtWidgets.QWidget,code:PySide6.QtCore.Qt.Key,ascii:char,modifier:PySide6.QtCore.Qt.KeyboardModifier,delay:int=-1)",
    "1:PySide6.QtTest.QTest.sendKeyEvent(action:PySide6.QtTest.QTest.KeyAction,window:PySide6.QtGui.QWindow,code:PySide6.QtCore.Qt.Key,text:QString,modifier:PySide6.QtCore.Qt.KeyboardModifier,delay:int=-1)",
    "0:PySide6.QtTest.QTest.sendKeyEvent(action:PySide6.QtTest.QTest.KeyAction,window:PySide6.QtGui.QWindow,code:PySide6.QtCore.Qt.Key,ascii:char,modifier:PySide6.QtCore.Qt.KeyboardModifier,delay:int=-1)",
    "PySide6.QtTest.QTest.setBenchmarkResult(result:qreal,metric:PySide6.QtTest.QTest.QBenchmarkMetric)",
    "PySide6.QtTest.QTest.setMainSourcePath(file:char*,builddir:char*=nullptr)",
    "PySide6.QtTest.QTest.setThrowOnFail(enable:bool)",
    "PySide6.QtTest.QTest.setThrowOnSkip(enable:bool)",
    "1:PySide6.QtTest.QTest.simulateEvent(widget:PySide6.QtWidgets.QWidget,press:bool,code:int,modifier:PySide6.QtCore.Qt.KeyboardModifier,text:QString,repeat:bool,delay:int=-1)",
    "0:PySide6.QtTest.QTest.simulateEvent(window:PySide6.QtGui.QWindow,press:bool,code:int,modifier:PySide6.QtCore.Qt.KeyboardModifier,text:QString,repeat:bool,delay:int=-1)",
    "PySide6.QtTest.QTest.testObject()->PySide6.QtCore.QObject",
    "PySide6.QtTest.QTest.toPrettyCString(unicode:char*,length:qsizetype)->char*",
    "1:PySide6.QtTest.QTest.touchEvent(widget:PySide6.QtWidgets.QWidget,device:PySide6.QtGui.QPointingDevice,autoCommit:bool=true)->PySide6.QtTest.QTouchEventSequence",
    "0:PySide6.QtTest.QTest.touchEvent(window:PySide6.QtGui.QWindow,device:PySide6.QtGui.QPointingDevice,autoCommit:bool=true)->PySide6.QtTest.QTouchEventSequence",
    "PySide6.QtTest.QTest.wheelEvent(window:PySide6.QtGui.QWindow,pos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint],angleDelta:PySide6.QtCore.QPoint,pixelDelta:PySide6.QtCore.QPoint=QPoint(0, 0),stateKey:PySide6.QtCore.Qt.KeyboardModifier=Qt.NoModifier,phase:PySide6.QtCore.Qt.ScrollPhase=Qt.NoScrollPhase)",
    nullptr}; // Sentinel
#else
static constexpr size_t QtTestQTest_SignatureByteSize = 1508;
static constexpr uint8_t QtTestQTest_SignatureBytes[1508] = {
    0x78, 0xda, 0xdd, 0x5a, 0xdd, 0x6f, 0xdb, 0x36, 0x10, 0x7f, 0xcf, 0x5f, 0x91, 0x47, 0x79, 0x50,
    0x05, 0xb7, 0x5b, 0xfb, 0x60, 0xc0, 0x03, 0x52, 0x27, 0x29, 0x82, 0xc0, 0xad, 0x13, 0x7b, 0xc8,
    0xc3, 0x10, 0x14, 0xb4, 0x74, 0xb1, 0xb9, 0x50, 0xa4, 0xc2, 0x0f, 0x27, 0xde, 0xb0, 0xff, 0x7d,
    0x47, 0x4a, 0xfe, 0x8c, 0x28, 0xcb, 0x99, 0xe3, 0x3a, 0x7d, 0xb1, 0x64, 0xea, 0x78, 0xfc, 0xfd,
    0xee, 0x8e, 0xe4, 0x51, 0xa7, 0xde, 0xb4, 0x4f, 0x13, 0xf8, 0x14, 0x5d, 0xe9, 0x01, 0x28, 0x1d,
    0x5d, 0xb9, 0x5f, 0x92, 0x24, 0x1d, 0xc1, 0x4c, 0xca, 0x2f, 0xb8, 0x06, 0xc9, 0x09, 0x0b, 0x68,
    0xd2, 0xa2, 0x5c, 0x87, 0x9c, 0xa4, 0xd0, 0x8a, 0xc7, 0x44, 0xfe, 0xd2, 0x38, 0xea, 0x95, 0xf6,
    0x54, 0x31, 0xa5, 0x03, 0x71, 0x09, 0xd3, 0xc0, 0xdd, 0x3a, 0xe1, 0xc6, 0xbb, 0xdf, 0x17, 0xc2,
    0x1d, 0x21, 0x01, 0x2f, 0x11, 0x8a, 0x1c, 0xbd, 0x6f, 0x95, 0x2a, 0x89, 0x45, 0x9a, 0x11, 0x09,
    0xdf, 0x33, 0x2d, 0xbf, 0x8f, 0x81, 0x65, 0x20, 0x03, 0xbd, 0x2c, 0x9a, 0xab, 0xf8, 0x36, 0xfc,
    0x0b, 0x62, 0x1d, 0xea, 0x0f, 0xbe, 0x27, 0x24, 0xd6, 0x86, 0xb0, 0x1c, 0x6e, 0x08, 0x4f, 0x19,
    0xb6, 0x41, 0x52, 0xfc, 0xbd, 0xa3, 0xac, 0x20, 0x12, 0x32, 0xca, 0xc1, 0x92, 0x43, 0x94, 0x43,
    0x21, 0xd8, 0x51, 0x73, 0x1b, 0x50, 0x13, 0x41, 0x13, 0x0b, 0xc1, 0x5d, 0x5f, 0x38, 0x60, 0xe5,
    0x70, 0x4a, 0x4b, 0xca, 0x47, 0x4b, 0x23, 0xe6, 0x3a, 0x70, 0xc8, 0xfc, 0x66, 0xa7, 0x63, 0x4a,
    0x20, 0x1a, 0x06, 0xc2, 0xc4, 0xe3, 0x53, 0x98, 0xd0, 0x18, 0x82, 0x04, 0x26, 0x83, 0x69, 0x06,
    0x4b, 0x16, 0xf9, 0x62, 0x68, 0x74, 0x75, 0xc1, 0x33, 0xa3, 0x73, 0x91, 0x28, 0xbf, 0x58, 0xa9,
    0xb6, 0xa7, 0x3d, 0x72, 0x1a, 0xfb, 0xa8, 0x1d, 0x78, 0x18, 0x93, 0x4c, 0x55, 0xa9, 0xeb, 0x90,
    0x8c, 0x0c, 0x29, 0xa3, 0x7a, 0xda, 0xf6, 0xb4, 0x47, 0x3d, 0xa1, 0xa8, 0xa6, 0x82, 0xaf, 0x84,
    0x95, 0x53, 0xd4, 0x13, 0x48, 0x11, 0xcd, 0x95, 0xf7, 0xf1, 0x90, 0x34, 0x52, 0x02, 0xd7, 0x27,
    0x59, 0xf6, 0x15, 0x83, 0x39, 0x40, 0x25, 0xce, 0x42, 0x95, 0xc2, 0xa7, 0x44, 0x93, 0x01, 0x19,
    0xd5, 0x13, 0xb6, 0xf7, 0xe7, 0x04, 0x4d, 0x9f, 0x04, 0xd5, 0xd6, 0x5e, 0x12, 0x37, 0x3c, 0xb6,
    0x8c, 0xea, 0x0f, 0x70, 0x0d, 0x4a, 0xb0, 0xc9, 0xd2, 0x10, 0x1f, 0xca, 0xa3, 0xf6, 0x0e, 0x81,
    0x7c, 0xe3, 0x37, 0x44, 0x72, 0x34, 0x4b, 0xd0, 0xf0, 0xcd, 0xb8, 0x55, 0xb1, 0x14, 0x94, 0x22,
    0x23, 0xe8, 0x11, 0x6d, 0x67, 0x7f, 0x4b, 0x4f, 0x33, 0x6c, 0x8d, 0xfe, 0xe0, 0x88, 0xf0, 0xcf,
    0xf5, 0xb9, 0x76, 0x0d, 0x23, 0xc3, 0x88, 0x3c, 0x7b, 0xca, 0x24, 0xf6, 0x42, 0x89, 0xf0, 0xf8,
    0xaa, 0xef, 0x62, 0xf6, 0xb6, 0xe1, 0x9b, 0x4a, 0xa5, 0xa3, 0x55, 0x2e, 0x2b, 0x77, 0x42, 0xa6,
    0x44, 0xe7, 0x7a, 0x03, 0x1c, 0xe9, 0x8e, 0x3e, 0x15, 0x81, 0xad, 0xcc, 0xdd, 0xe2, 0x0f, 0x37,
    0xe9, 0x89, 0x1c, 0x99, 0x14, 0x8d, 0xa4, 0x5a, 0x8a, 0xfe, 0x0d, 0xdf, 0xf5, 0xdc, 0xa2, 0x1e,
    0xe6, 0x74, 0xc4, 0x91, 0x47, 0x37, 0xc7, 0x10, 0xe8, 0xd5, 0x60, 0x2f, 0xd6, 0xaa, 0xae, 0x1a,
    0xd9, 0x38, 0x0e, 0x5f, 0xdb, 0x2e, 0x2f, 0xc0, 0x32, 0xb3, 0xda, 0xaf, 0xe5, 0x1a, 0xef, 0x61,
    0xda, 0x61, 0x34, 0xbe, 0x0f, 0x1e, 0x69, 0x32, 0x02, 0xbd, 0x24, 0x74, 0xe3, 0x1a, 0x54, 0x74,
    0x95, 0xdf, 0x84, 0x28, 0xd9, 0x2a, 0x5d, 0xa4, 0xc3, 0x54, 0x24, 0xf4, 0x8e, 0x82, 0x2c, 0x7f,
    0x3c, 0x14, 0x44, 0x26, 0xdd, 0x42, 0xa4, 0x8d, 0x6d, 0x5f, 0xc5, 0xec, 0x5f, 0x98, 0x00, 0x23,
    0x53, 0xbb, 0xea, 0xb4, 0xdf, 0xbd, 0x6f, 0xf8, 0x22, 0x74, 0x3b, 0x88, 0x96, 0xee, 0xce, 0x10,
    0xbd, 0xdf, 0x88, 0x88, 0x27, 0xe2, 0x71, 0x7d, 0xb5, 0xba, 0x71, 0xad, 0x7b, 0x30, 0x58, 0xf3,
    0xff, 0xc2, 0xdb, 0xa9, 0xb1, 0x2a, 0xb1, 0xa8, 0xcd, 0xde, 0x53, 0xf0, 0x60, 0x80, 0xc7, 0xd0,
    0x2a, 0xa6, 0xc1, 0xce, 0x80, 0xf9, 0x43, 0xff, 0x6c, 0x82, 0x0b, 0x41, 0x40, 0xdc, 0xd2, 0x5a,
    0x2e, 0x84, 0x03, 0x9d, 0xb8, 0xc7, 0xe1, 0x41, 0x4f, 0x90, 0x9d, 0x12, 0x59, 0xe4, 0x65, 0x7b,
    0x98, 0x48, 0xdb, 0x21, 0x3f, 0xd0, 0xe9, 0xb6, 0x33, 0x12, 0xaf, 0x60, 0x7a, 0x7f, 0xf4, 0xf7,
    0xec, 0xc6, 0x73, 0xd8, 0x0b, 0xff, 0x16, 0x10, 0xf7, 0x14, 0xaf, 0x33, 0x44, 0x07, 0x1a, 0x89,
    0x35, 0xe1, 0xed, 0x29, 0xc2, 0xae, 0x81, 0x01, 0x51, 0x70, 0xd8, 0x31, 0xb6, 0x15, 0xc8, 0x3d,
    0x45, 0xd9, 0x02, 0xd3, 0x81, 0xc6, 0x59, 0x6d, 0x80, 0x7b, 0x32, 0x58, 0xbf, 0x48, 0x1e, 0x6a,
    0x79, 0x71, 0x26, 0xec, 0x4b, 0xd0, 0x1d, 0x87, 0xcb, 0x85, 0x5c, 0x78, 0xbc, 0x8e, 0x1b, 0x1f,
    0x76, 0x44, 0x3a, 0xa4, 0x9c, 0xb8, 0x35, 0xfd, 0xd8, 0xdf, 0x37, 0xea, 0x6b, 0xc2, 0x13, 0x24,
    0x68, 0xfd, 0x32, 0xcb, 0xf0, 0xc3, 0x63, 0x64, 0x74, 0x5b, 0x65, 0xdf, 0x25, 0x3e, 0xd5, 0x06,
    0x3e, 0x18, 0x2e, 0x3e, 0x26, 0x03, 0x71, 0x62, 0x37, 0xb5, 0xc0, 0x1b, 0xad, 0xc5, 0x01, 0xcc,
    0xe7, 0xdc, 0x54, 0x18, 0x05, 0x35, 0x0f, 0x00, 0x43, 0xa3, 0xf5, 0xca, 0x0e, 0x3c, 0x1b, 0xa6,
    0x6b, 0x95, 0x7c, 0x76, 0x4f, 0x43, 0xa5, 0x89, 0x86, 0x4b, 0x1f, 0x9a, 0x67, 0xc1, 0xb8, 0xde,
    0xa6, 0x82, 0x46, 0x98, 0x09, 0xf5, 0xac, 0xb7, 0x7b, 0xb5, 0xd0, 0xce, 0x2f, 0x28, 0x52, 0x6b,
    0x22, 0xad, 0x70, 0xab, 0xf0, 0xf3, 0xc1, 0xf2, 0xaa, 0xf2, 0xd9, 0xe9, 0xcf, 0xec, 0xb4, 0xd3,
    0x9f, 0xd5, 0x6b, 0x9b, 0x53, 0x59, 0x87, 0xbe, 0xee, 0x59, 0x62, 0xd7, 0x36, 0xf0, 0x93, 0xdd,
    0xc2, 0x79, 0xdb, 0x72, 0xdc, 0xa3, 0x8f, 0x6b, 0xf3, 0xab, 0xf2, 0x61, 0x57, 0x4c, 0x6a, 0x6c,
    0x84, 0x3b, 0x9d, 0x0f, 0xc5, 0x90, 0x15, 0x96, 0xda, 0x69, 0x94, 0xd6, 0x3c, 0x17, 0xbc, 0xc9,
    0xa5, 0xa5, 0x46, 0x0a, 0xff, 0x26, 0x57, 0x96, 0xda, 0x79, 0xf6, 0x9b, 0xf4, 0x5a, 0xad, 0x84,
    0xf8, 0xad, 0xf9, 0xed, 0xa1, 0x43, 0xcc, 0x68, 0xac, 0x83, 0x1a, 0x65, 0x23, 0x9f, 0x71, 0x3c,
    0x2a, 0x1e, 0xc7, 0x44, 0x57, 0x69, 0xf3, 0xe8, 0x42, 0x1b, 0x73, 0x93, 0x05, 0xbe, 0xe7, 0x67,
    0x0c, 0xd2, 0xa2, 0x1a, 0x13, 0x40, 0x7e, 0xff, 0x75, 0x5e, 0x90, 0x0c, 0x53, 0xd0, 0xc4, 0xbe,
    0x1a, 0xbf, 0x48, 0x8a, 0x42, 0x97, 0xad, 0xc9, 0xf9, 0x34, 0x39, 0xb8, 0xb6, 0x4a, 0x13, 0x24,
    0xa8, 0xed, 0x82, 0x27, 0x30, 0xab, 0x21, 0xc4, 0x22, 0xb5, 0x8a, 0x67, 0x4a, 0x45, 0x02, 0xe5,
    0xcc, 0x67, 0x65, 0x1e, 0x74, 0x0c, 0x54, 0x55, 0xda, 0x7c, 0xb6, 0x3f, 0xc7, 0x98, 0xb1, 0x77,
    0x8e, 0xcd, 0x10, 0x63, 0x2b, 0x23, 0x7a, 0x3c, 0x7f, 0x39, 0xba, 0x50, 0xd8, 0xe6, 0x86, 0xb1,
    0x4c, 0xcb, 0xb9, 0xe2, 0x76, 0x13, 0x03, 0x8d, 0xb2, 0x24, 0xa1, 0x72, 0x4d, 0x42, 0x09, 0x23,
    0x63, 0x78, 0xd6, 0x8e, 0x48, 0x0a, 0xb5, 0x5e, 0x2f, 0x96, 0x83, 0x59, 0x77, 0xe0, 0x4e, 0xa1,
    0x94, 0x03, 0xf9, 0xc2, 0xc4, 0x90, 0x30, 0x07, 0x43, 0x93, 0xd1, 0x92, 0x77, 0x75, 0x4d, 0xcf,
    0x5e, 0x1b, 0x57, 0x45, 0x43, 0x39, 0x8f, 0x40, 0xff, 0x9e, 0x66, 0xab, 0x35, 0xa7, 0x6d, 0x42,
    0xb4, 0xcf, 0x00, 0xb0, 0xbb, 0xaa, 0x92, 0xb9, 0x21, 0x54, 0xcf, 0x45, 0x7c, 0xee, 0xb7, 0x42,
    0xe7, 0x42, 0xe6, 0x2b, 0x87, 0x4d, 0x45, 0xea, 0xec, 0xe9, 0x9a, 0xa6, 0x20, 0x8c, 0x76, 0xa6,
    0xff, 0xd8, 0x6c, 0x36, 0x37, 0x94, 0xac, 0x3d, 0x83, 0x54, 0xac, 0x60, 0xbe, 0x01, 0x6a, 0xb1,
    0xc0, 0x49, 0x25, 0x14, 0x24, 0xaf, 0x4c, 0x63, 0x31, 0xca, 0x6b, 0xf1, 0x38, 0x17, 0xb1, 0xd9,
    0x8a, 0x47, 0x65, 0x21, 0xf0, 0x14, 0x48, 0x62, 0xa3, 0x6a, 0x80, 0xc2, 0xf2, 0xf9, 0xf1, 0x7c,
    0xe5, 0x71, 0x84, 0x18, 0x60, 0x02, 0xb2, 0x23, 0x38, 0x6e, 0x13, 0x98, 0x14, 0x1e, 0x3f, 0x20,
    0x83, 0x4f, 0xbf, 0xdd, 0xb6, 0x95, 0x4e, 0xa2, 0x78, 0x2c, 0x05, 0x17, 0x91, 0x82, 0x58, 0xf0,
    0x44, 0xfd, 0xf3, 0xf1, 0xdf, 0xad, 0xec, 0xe6, 0x65, 0x55, 0x66, 0xb7, 0x1f, 0xcd, 0xa8, 0x94,
    0x8f, 0x34, 0xdc, 0x16, 0x8c, 0xed, 0xfd, 0xbc, 0xec, 0xed, 0x79, 0x39, 0xa9, 0x80, 0xdb, 0xb7,
    0x18, 0x3b, 0xad, 0x9b, 0xc4, 0xab, 0x5b, 0xc1, 0xf2, 0x0b, 0x39, 0x0d, 0x4f, 0xfa, 0x25, 0x75,
    0xad, 0x7a, 0x2f, 0x31, 0xf7, 0x4c, 0xe6, 0x65, 0x45, 0x8a, 0x7a, 0x19, 0xc7, 0x8b, 0xa8, 0x54,
    0xcc, 0xf3, 0xd7, 0xf7, 0x49, 0xf3, 0x87, 0x13, 0xd9, 0x89, 0x3f, 0x3c, 0x24, 0xf4, 0x67, 0xe0,
    0xf1, 0x38, 0x25, 0xf2, 0xfe, 0x1a, 0x94, 0x61, 0x3a, 0x90, 0xee, 0xd2, 0x7a, 0x90, 0x40, 0x98,
    0xcd, 0xa8, 0x24, 0x8d, 0xcb, 0x79, 0x5d, 0xcd, 0x7b, 0x76, 0x9d, 0x94, 0x7f, 0x88, 0x2e, 0xa1,
    0xbc, 0xef, 0xd2, 0x81, 0x1e, 0x26, 0x15, 0xc1, 0xd2, 0x66, 0x5b, 0x9e, 0x3b, 0xf8, 0x35, 0x0d,
    0x70, 0xb9, 0x78, 0xfc, 0xc6, 0x5d, 0xda, 0x06, 0x9c, 0x0c, 0x51, 0x91, 0x5d, 0x04, 0x36, 0x76,
    0x70, 0x5b, 0xfe, 0x4a, 0x07, 0x5f, 0x78, 0xd2, 0xd4, 0x30, 0x4c, 0xcf, 0x73, 0xb7, 0x6e, 0x3e,
    0x62, 0xdb, 0xa3, 0x9c, 0xd3, 0x98, 0xfb, 0xcf, 0x1e, 0xe3, 0xb7, 0x71, 0xd1, 0x4a, 0x88, 0x4a,
    0xc8, 0x00, 0x93, 0x66, 0xa7, 0xad, 0x5e, 0x08, 0xae, 0x81, 0xad, 0x3a, 0x9c, 0xef, 0x07, 0x68,
    0x29, 0x4c, 0x8d, 0x3f, 0xf9, 0x07, 0x79, 0x41, 0xc9, 0x77, 0x80, 0xf9, 0x13, 0x4f, 0x4f, 0x81,
    0x67, 0x65, 0xad, 0xa7, 0x9d, 0xe2, 0xbb, 0x1f, 0xc3, 0xa9, 0x43, 0x5f, 0x64, 0x6a, 0xc0, 0x47,
    0x98, 0xa3, 0x3e, 0xd8, 0xcf, 0x7c, 0x6c, 0x72, 0xb8, 0xe9, 0x43, 0x1f, 0x6d, 0x3f, 0x42, 0xab,
    0xe9, 0xd8, 0xc4, 0x7d, 0x3f, 0xd6, 0xaa, 0xfc, 0xba, 0x2c, 0x24, 0x46, 0x8b, 0x0e, 0x1e, 0x16,
    0x68, 0x6e, 0x8b, 0xb6, 0x96, 0x06, 0x56, 0x18, 0x16, 0x83, 0xcf, 0xc7, 0x9d, 0xbd, 0x67, 0xf7,
    0x39, 0x74, 0x05, 0x61, 0x85, 0x37, 0x5f, 0x19, 0x5d, 0x29, 0xb6, 0xc7, 0x31, 0x00, 0xab, 0x13,
    0x69, 0x78, 0x34, 0xad, 0x4c, 0x1e, 0x1c, 0xcc, 0xf3, 0xe7, 0x59, 0x83, 0x6b, 0xbf, 0x0d, 0x09,
    0x1f, 0x31, 0x38, 0x05, 0xa6, 0x89, 0xe7, 0x35, 0x59, 0x46, 0x9f, 0x80, 0x55, 0x08, 0xcc, 0x8e,
    0xc0, 0xcd, 0xf0, 0xb8, 0xd9, 0xd8, 0xf6, 0xb0, 0xbd, 0x54, 0x99, 0xca, 0xc6, 0x78, 0x0a, 0x2a,
    0xe9, 0xd6, 0x8f, 0xa5, 0x60, 0xac, 0x67, 0x9f, 0xe6, 0x3d, 0x96, 0x1a, 0x1a, 0x47, 0xff, 0x01,
    0x11, 0x95, 0x89, 0xe2
};
#endif

PyTypeObject *init_QtTestQTest(PyObject *module)
{
    if (SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX].type != nullptr)
        return SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX].type;

    Shiboken::AutoDecRef Sbk_QTest_Type_bases(PyTuple_Pack(1,
        SbkObject_TypeF()));

    _Sbk_QTest_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QTest",
        "QTest",
        &Sbk_QTest_spec,
        nullptr,
        Sbk_QTest_Type_bases.object(),
        0);
    auto *pyType = Sbk_QTest_TypeF(); // references _Sbk_QTest_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QtTestQTest_SignatureStrings);
#else
    InitSignatureBytes(pyType, QtTestQTest_SignatureBytes, QtTestQTest_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QTest_PropertyStrings);
    SbkPySide6_QtTestTypeStructs[SBK_QtTestQTest_IDX].type = pyType;


    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QTest_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'TestFailMode'.
    const char *TestFailMode_Initializer[] = {
        "Abort",
        "Continue",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t TestFailMode_InitializerValues[] = {
        uint8_t(QTest::TestFailMode::Abort),   //  0x01  1
        uint8_t(QTest::TestFailMode::Continue) //  0x02  2
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTest_TypeF(),
        "2:PySide6.QtTest.QTest.TestFailMode",
        TestFailMode_Initializer, TestFailMode_InitializerValues);
    SbkPySide6_QtTestTypeStructs[SBK_QTest_TestFailMode_IDX].type = EType;
    // Register converter for enum 'QTest::TestFailMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTest_TestFailMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTest_TestFailMode,
            is_Enum_PythonToCpp_QTest_TestFailMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTest::TestFailMode");
        Shiboken::Conversions::registerConverterAlias(converter, "TestFailMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'TestFailMode' enum.

    // Initialization of enum 'ComparisonOperation'.
    const char *ComparisonOperation_Initializer[] = {
        "CustomCompare",
        "Equal",
        "NotEqual",
        "LessThan",
        "LessThanOrEqual",
        "GreaterThan",
        "GreaterThanOrEqual",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ComparisonOperation_InitializerValues[] = {
        int8_t(QTest::ComparisonOperation::CustomCompare),     //  0x00  0
        int8_t(QTest::ComparisonOperation::Equal),             //  0x01  1
        int8_t(QTest::ComparisonOperation::NotEqual),          //  0x02  2
        int8_t(QTest::ComparisonOperation::LessThan),          //  0x03  3
        int8_t(QTest::ComparisonOperation::LessThanOrEqual),   //  0x04  4
        int8_t(QTest::ComparisonOperation::GreaterThan),       //  0x05  5
        int8_t(QTest::ComparisonOperation::GreaterThanOrEqual) //  0x06  6
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTest_TypeF(),
        "2:PySide6.QtTest.QTest.ComparisonOperation",
        ComparisonOperation_Initializer, ComparisonOperation_InitializerValues);
    SbkPySide6_QtTestTypeStructs[SBK_QTest_ComparisonOperation_IDX].type = EType;
    // Register converter for enum 'QTest::ComparisonOperation'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTest_ComparisonOperation_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTest_ComparisonOperation,
            is_Enum_PythonToCpp_QTest_ComparisonOperation_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTest::ComparisonOperation");
        Shiboken::Conversions::registerConverterAlias(converter, "ComparisonOperation");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ComparisonOperation' enum.

    // Initialization of enum 'QBenchmarkMetric'.
    const char *QBenchmarkMetric_Initializer[] = {
        "FramesPerSecond",
        "BitsPerSecond",
        "BytesPerSecond",
        "WalltimeMilliseconds",
        "CPUTicks",
        "InstructionReads",
        "Events",
        "WalltimeNanoseconds",
        "BytesAllocated",
        "CPUMigrations",
        "CPUCycles",
        "BusCycles",
        "StalledCycles",
        "Instructions",
        "BranchInstructions",
        "BranchMisses",
        "CacheReferences",
        "CacheReads",
        "CacheWrites",
        "CachePrefetches",
        "CacheMisses",
        "CacheReadMisses",
        "CacheWriteMisses",
        "CachePrefetchMisses",
        "ContextSwitches",
        "PageFaults",
        "MinorPageFaults",
        "MajorPageFaults",
        "AlignmentFaults",
        "EmulationFaults",
        "RefCPUCycles",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t QBenchmarkMetric_InitializerValues[] = {
        uint8_t(QTest::QBenchmarkMetric::FramesPerSecond),      //  0x00  0
        uint8_t(QTest::QBenchmarkMetric::BitsPerSecond),        //  0x01  1
        uint8_t(QTest::QBenchmarkMetric::BytesPerSecond),       //  0x02  2
        uint8_t(QTest::QBenchmarkMetric::WalltimeMilliseconds), //  0x03  3
        uint8_t(QTest::QBenchmarkMetric::CPUTicks),             //  0x04  4
        uint8_t(QTest::QBenchmarkMetric::InstructionReads),     //  0x05  5
        uint8_t(QTest::QBenchmarkMetric::Events),               //  0x06  6
        uint8_t(QTest::QBenchmarkMetric::WalltimeNanoseconds),  //  0x07  7
        uint8_t(QTest::QBenchmarkMetric::BytesAllocated),       //  0x08  8
        uint8_t(QTest::QBenchmarkMetric::CPUMigrations),        //  0x09  9
        uint8_t(QTest::QBenchmarkMetric::CPUCycles),            //  0x0a  10
        uint8_t(QTest::QBenchmarkMetric::BusCycles),            //  0x0b  11
        uint8_t(QTest::QBenchmarkMetric::StalledCycles),        //  0x0c  12
        uint8_t(QTest::QBenchmarkMetric::Instructions),         //  0x0d  13
        uint8_t(QTest::QBenchmarkMetric::BranchInstructions),   //  0x0e  14
        uint8_t(QTest::QBenchmarkMetric::BranchMisses),         //  0x0f  15
        uint8_t(QTest::QBenchmarkMetric::CacheReferences),      //  0x10  16
        uint8_t(QTest::QBenchmarkMetric::CacheReads),           //  0x11  17
        uint8_t(QTest::QBenchmarkMetric::CacheWrites),          //  0x12  18
        uint8_t(QTest::QBenchmarkMetric::CachePrefetches),      //  0x13  19
        uint8_t(QTest::QBenchmarkMetric::CacheMisses),          //  0x14  20
        uint8_t(QTest::QBenchmarkMetric::CacheReadMisses),      //  0x15  21
        uint8_t(QTest::QBenchmarkMetric::CacheWriteMisses),     //  0x16  22
        uint8_t(QTest::QBenchmarkMetric::CachePrefetchMisses),  //  0x17  23
        uint8_t(QTest::QBenchmarkMetric::ContextSwitches),      //  0x18  24
        uint8_t(QTest::QBenchmarkMetric::PageFaults),           //  0x19  25
        uint8_t(QTest::QBenchmarkMetric::MinorPageFaults),      //  0x1a  26
        uint8_t(QTest::QBenchmarkMetric::MajorPageFaults),      //  0x1b  27
        uint8_t(QTest::QBenchmarkMetric::AlignmentFaults),      //  0x1c  28
        uint8_t(QTest::QBenchmarkMetric::EmulationFaults),      //  0x1d  29
        uint8_t(QTest::QBenchmarkMetric::RefCPUCycles)          //  0x1e  30
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTest_TypeF(),
        "2:PySide6.QtTest.QTest.QBenchmarkMetric",
        QBenchmarkMetric_Initializer, QBenchmarkMetric_InitializerValues);
    SbkPySide6_QtTestTypeStructs[SBK_QTest_QBenchmarkMetric_IDX].type = EType;
    // Register converter for enum 'QTest::QBenchmarkMetric'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTest_QBenchmarkMetric_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTest_QBenchmarkMetric,
            is_Enum_PythonToCpp_QTest_QBenchmarkMetric_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTest::QBenchmarkMetric");
        Shiboken::Conversions::registerConverterAlias(converter, "QBenchmarkMetric");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'QBenchmarkMetric' enum.

    // Initialization of enum 'KeyAction'.
    const char *KeyAction_Initializer[] = {
        "Press",
        "Release",
        "Click",
        "Shortcut",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t KeyAction_InitializerValues[] = {
        uint8_t(QTest::KeyAction::Press),   //  0x00  0
        uint8_t(QTest::KeyAction::Release), //  0x01  1
        uint8_t(QTest::KeyAction::Click),   //  0x02  2
        uint8_t(QTest::KeyAction::Shortcut) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTest_TypeF(),
        "2:PySide6.QtTest.QTest.KeyAction",
        KeyAction_Initializer, KeyAction_InitializerValues);
    SbkPySide6_QtTestTypeStructs[SBK_QTest_KeyAction_IDX].type = EType;
    // Register converter for enum 'QTest::KeyAction'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTest_KeyAction_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTest_KeyAction,
            is_Enum_PythonToCpp_QTest_KeyAction_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTest::KeyAction");
        Shiboken::Conversions::registerConverterAlias(converter, "KeyAction");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'KeyAction' enum.

    // Initialization of enum 'MouseAction'.
    const char *MouseAction_Initializer[] = {
        "MousePress",
        "MouseRelease",
        "MouseClick",
        "MouseDClick",
        "MouseMove",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t MouseAction_InitializerValues[] = {
        uint8_t(QTest::MouseAction::MousePress),   //  0x00  0
        uint8_t(QTest::MouseAction::MouseRelease), //  0x01  1
        uint8_t(QTest::MouseAction::MouseClick),   //  0x02  2
        uint8_t(QTest::MouseAction::MouseDClick),  //  0x03  3
        uint8_t(QTest::MouseAction::MouseMove)     //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QTest_TypeF(),
        "2:PySide6.QtTest.QTest.MouseAction",
        MouseAction_Initializer, MouseAction_InitializerValues);
    SbkPySide6_QtTestTypeStructs[SBK_QTest_MouseAction_IDX].type = EType;
    // Register converter for enum 'QTest::MouseAction'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QTest_MouseAction_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QTest_MouseAction,
            is_Enum_PythonToCpp_QTest_MouseAction_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QTest::MouseAction");
        Shiboken::Conversions::registerConverterAlias(converter, "MouseAction");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'MouseAction' enum.

    qRegisterMetaType< ::QTest::TestFailMode >("QTest::TestFailMode");
    qRegisterMetaType< ::QTest::ComparisonOperation >("QTest::ComparisonOperation");
    qRegisterMetaType< ::QTest::QBenchmarkMetric >("QTest::QBenchmarkMetric");
    qRegisterMetaType< ::QTest::KeyAction >("QTest::KeyAction");
    qRegisterMetaType< ::QTest::MouseAction >("QTest::MouseAction");

    return pyType;
}

PyTypeObject *init_QtTestQTestStaticFields(PyObject *module)
{
    auto *obType = PyObject_GetAttrString(module, "QTest");
    auto *type = reinterpret_cast<PyTypeObject *>(obType);
    Shiboken::AutoDecRef dict(PepType_GetDict(type));
    PyDict_SetItemString(dict, "mouseDoubleClickInterval",
                         Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &QTest::mouseDoubleClickInterval));
    return type;
}
