// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qfiledialog_wrapper.h"

// Extra includes
#include <QAbstractProxyModel>
#include <QUrl>

// Argument includes
#include <QList>
#include <QString>
#include <QStringList>
#include <QtGui/qabstractfileiconprovider.h>
#include <QtGui/qevent.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtWidgets/qabstractitemdelegate.h>
#include <QtWidgets/qfiledialog.h>
#include <QtWidgets/qwidget.h>
#include <qabstractproxymodel.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qdir.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qsize.h>
#include <qurl.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QFileDialogWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QFileDialogWrapper::QFileDialogWrapper(::QWidget * parent, ::QFlags<Qt::WindowType> f) : QFileDialog(parent, f)
{
}

QFileDialogWrapper::QFileDialogWrapper(::QWidget * parent, const ::QString & caption, const ::QString & directory, const ::QString & filter) : QFileDialog(parent, caption, directory, filter)
{
}

void QFileDialogWrapper::accept()
{
    if (m_PyMethodCache[0]) {
        return this->::QFileDialog::accept();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "accept";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QFileDialog::accept();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::actionEvent(::QActionEvent * event)
{
    if (m_PyMethodCache[1]) {
        return this->::QWidget::actionEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "actionEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QActionEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QActionEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::changeEvent(::QEvent * e)
{
    if (m_PyMethodCache[2]) {
        return this->::QFileDialog::changeEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "changeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QFileDialog::changeEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::closeEvent(::QCloseEvent * arg__1)
{
    if (m_PyMethodCache[4]) {
        return this->::QDialog::closeEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "closeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QDialog::closeEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCloseEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCloseEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[5]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::contextMenuEvent(::QContextMenuEvent * arg__1)
{
    if (m_PyMethodCache[6]) {
        return this->::QDialog::contextMenuEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "contextMenuEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QDialog::contextMenuEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[7]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

int QFileDialogWrapper::devType() const
{
    if (m_PyMethodCache[8])
        return this->::QWidget::devType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "devType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QWidget::devType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QFileDialogWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[9]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::done(int result)
{
    if (m_PyMethodCache[10]) {
        return this->::QFileDialog::done(result);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "done";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QFileDialog::done(result);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &result)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        result
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::dragEnterEvent(::QDragEnterEvent * event)
{
    if (m_PyMethodCache[11]) {
        return this->::QWidget::dragEnterEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragEnterEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QWidget::dragEnterEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::dragLeaveEvent(::QDragLeaveEvent * event)
{
    if (m_PyMethodCache[12]) {
        return this->::QWidget::dragLeaveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragLeaveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QWidget::dragLeaveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::dragMoveEvent(::QDragMoveEvent * event)
{
    if (m_PyMethodCache[13]) {
        return this->::QWidget::dragMoveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragMoveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QWidget::dragMoveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::dropEvent(::QDropEvent * event)
{
    if (m_PyMethodCache[14]) {
        return this->::QWidget::dropEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dropEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QWidget::dropEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::enterEvent(::QEnterEvent * event)
{
    if (m_PyMethodCache[15]) {
        return this->::QWidget::enterEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "enterEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[15] = true;
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEnterEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEnterEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

bool QFileDialogWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[16])
        return this->::QWidget::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[16] = true;
        gil.release();
        return this->::QWidget::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QFileDialogWrapper::eventFilter(::QObject * arg__1, ::QEvent * arg__2)
{
    if (m_PyMethodCache[17])
        return this->::QDialog::eventFilter(arg__1, arg__2);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[17] = true;
        gil.release();
        return this->::QDialog::eventFilter(arg__1, arg__2);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__2)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__2)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QFileDialogWrapper::exec()
{
    if (m_PyMethodCache[18]) {
        return this->::QDialog::exec();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "exec";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[18] = true;
        gil.release();
        return this->::QDialog::exec();
    }

    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);

    return cppResult;
}

void QFileDialogWrapper::focusInEvent(::QFocusEvent * event)
{
    if (m_PyMethodCache[19]) {
        return this->::QWidget::focusInEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusInEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[19] = true;
        gil.release();
        return this->::QWidget::focusInEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

bool QFileDialogWrapper::focusNextPrevChild(bool next)
{
    if (m_PyMethodCache[20])
        return this->::QWidget::focusNextPrevChild(next);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusNextPrevChild";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[20] = true;
        gil.release();
        return this->::QWidget::focusNextPrevChild(next);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &next)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &next)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QFileDialogWrapper::focusOutEvent(::QFocusEvent * event)
{
    if (m_PyMethodCache[21]) {
        return this->::QWidget::focusOutEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusOutEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[21] = true;
        gil.release();
        return this->::QWidget::focusOutEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

bool QFileDialogWrapper::hasHeightForWidth() const
{
    if (m_PyMethodCache[22])
        return this->::QWidget::hasHeightForWidth();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hasHeightForWidth";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[22] = true;
        gil.release();
        return this->::QWidget::hasHeightForWidth();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QFileDialogWrapper::heightForWidth(int arg__1) const
{
    if (m_PyMethodCache[23])
        return this->::QWidget::heightForWidth(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "heightForWidth";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[23] = true;
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        arg__1
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QFileDialogWrapper::hideEvent(::QHideEvent * event)
{
    if (m_PyMethodCache[24]) {
        return this->::QWidget::hideEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hideEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[24] = true;
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHideEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHideEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::initPainter(::QPainter * painter) const
{
    if (m_PyMethodCache[25]) {
        return this->::QWidget::initPainter(painter);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "initPainter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[25] = true;
        gil.release();
        return this->::QWidget::initPainter(painter);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    if (m_PyMethodCache[26]) {
        return this->::QWidget::inputMethodEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "inputMethodEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[26] = true;
        gil.release();
        return this->::QWidget::inputMethodEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

::QVariant QFileDialogWrapper::inputMethodQuery(::Qt::InputMethodQuery arg__1) const
{
    if (m_PyMethodCache[27])
        return this->::QWidget::inputMethodQuery(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "inputMethodQuery";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[27] = true;
        gil.release();
        return this->::QWidget::inputMethodQuery(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, &arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QFileDialogWrapper::keyPressEvent(::QKeyEvent * arg__1)
{
    if (m_PyMethodCache[28]) {
        return this->::QDialog::keyPressEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "keyPressEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[28] = true;
        gil.release();
        return this->::QDialog::keyPressEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    if (m_PyMethodCache[29]) {
        return this->::QWidget::keyReleaseEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "keyReleaseEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[29] = true;
        gil.release();
        return this->::QWidget::keyReleaseEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::leaveEvent(::QEvent * event)
{
    if (m_PyMethodCache[30]) {
        return this->::QWidget::leaveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "leaveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[30] = true;
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

int QFileDialogWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    if (m_PyMethodCache[31])
        return this->::QWidget::metric(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "metric";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[31] = true;
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSize QFileDialogWrapper::minimumSizeHint() const
{
    if (m_PyMethodCache[32])
        return this->::QDialog::minimumSizeHint();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "minimumSizeHint";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[32] = true;
        gil.release();
        return this->::QDialog::minimumSizeHint();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QFileDialogWrapper::mouseDoubleClickEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[33]) {
        return this->::QWidget::mouseDoubleClickEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseDoubleClickEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[33] = true;
        gil.release();
        return this->::QWidget::mouseDoubleClickEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::mouseMoveEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[34]) {
        return this->::QWidget::mouseMoveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseMoveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[34] = true;
        gil.release();
        return this->::QWidget::mouseMoveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::mousePressEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[35]) {
        return this->::QWidget::mousePressEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mousePressEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[35] = true;
        gil.release();
        return this->::QWidget::mousePressEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::mouseReleaseEvent(::QMouseEvent * event)
{
    if (m_PyMethodCache[36]) {
        return this->::QWidget::mouseReleaseEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseReleaseEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[36] = true;
        gil.release();
        return this->::QWidget::mouseReleaseEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::moveEvent(::QMoveEvent * event)
{
    if (m_PyMethodCache[37]) {
        return this->::QWidget::moveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "moveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[37] = true;
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMoveEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMoveEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

bool QFileDialogWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    if (m_PyMethodCache[38]) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "nativeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[38] = true;
        gil.release();
        return this->::QWidget::nativeEvent(eventType, message, result);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &eventType),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), message)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return false;
    }
    // Begin code injection
    // TEMPLATE - return_native_eventfilter_conversion - START
    bool cppResult = false;
    if (PySequence_Check(pyResult.object()) && (PySequence_Size(pyResult.object()) == 2)) {
        Shiboken::AutoDecRef pyItem(PySequence_GetItem(pyResult.object(), 0));
        Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyItem, &(cppResult));
        if (result) {
            Shiboken::AutoDecRef pyResultItem(PySequence_GetItem(pyResult, 1));
            Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<long>(), pyResultItem, (result));
        }
    }
    // TEMPLATE - return_native_eventfilter_conversion - END
    // End of code injection


    return cppResult;
}

::QPaintEngine * QFileDialogWrapper::paintEngine() const
{
    if (m_PyMethodCache[39])
        return this->::QWidget::paintEngine();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "paintEngine";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[39] = true;
        gil.release();
        return this->::QWidget::paintEngine();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, Shiboken::SbkType< QPaintEngine >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPaintEngine *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QFileDialogWrapper::paintEvent(::QPaintEvent * event)
{
    if (m_PyMethodCache[40]) {
        return this->::QWidget::paintEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "paintEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[40] = true;
        gil.release();
        return this->::QWidget::paintEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

::QPaintDevice * QFileDialogWrapper::redirected(::QPoint * offset) const
{
    if (m_PyMethodCache[41])
        return this->::QWidget::redirected(offset);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "redirected";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[41] = true;
        gil.release();
        return this->::QWidget::redirected(offset);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), offset)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), offset)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, Shiboken::SbkType< QPaintDevice >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPaintDevice *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QFileDialogWrapper::reject()
{
    if (m_PyMethodCache[42]) {
        return this->::QDialog::reject();
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "reject";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[42] = true;
        gil.release();
        return this->::QDialog::reject();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::resizeEvent(::QResizeEvent * arg__1)
{
    if (m_PyMethodCache[43]) {
        return this->::QDialog::resizeEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resizeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[43] = true;
        gil.release();
        return this->::QDialog::resizeEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::setVisible(bool visible)
{
    if (m_PyMethodCache[44]) {
        return this->::QFileDialog::setVisible(visible);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setVisible";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[44] = true;
        gil.release();
        return this->::QFileDialog::setVisible(visible);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &visible)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &visible)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

::QPainter * QFileDialogWrapper::sharedPainter() const
{
    if (m_PyMethodCache[45])
        return this->::QWidget::sharedPainter();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sharedPainter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[45] = true;
        gil.release();
        return this->::QWidget::sharedPainter();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, Shiboken::SbkType< QPainter >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPainter *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QFileDialogWrapper::showEvent(::QShowEvent * arg__1)
{
    if (m_PyMethodCache[46]) {
        return this->::QDialog::showEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "showEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[46] = true;
        gil.release();
        return this->::QDialog::showEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

::QSize QFileDialogWrapper::sizeHint() const
{
    if (m_PyMethodCache[47])
        return this->::QDialog::sizeHint();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sizeHint";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[47] = true;
        gil.release();
        return this->::QDialog::sizeHint();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QFileDialog", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QFileDialogWrapper::tabletEvent(::QTabletEvent * event)
{
    if (m_PyMethodCache[48]) {
        return this->::QWidget::tabletEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "tabletEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[48] = true;
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTabletEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTabletEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[49]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[49] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

void QFileDialogWrapper::wheelEvent(::QWheelEvent * event)
{
    if (m_PyMethodCache[50]) {
        return this->::QWidget::wheelEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "wheelEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[50] = true;
        gil.release();
        return this->::QWidget::wheelEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QFileDialog", funcName);
        return;
    }
}

const QMetaObject *QFileDialogWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QFileDialog::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QFileDialogWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QFileDialog::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QFileDialogWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QFileDialogWrapper *>(this));
    return QFileDialog::qt_metacast(_clname);
}

QFileDialogWrapper::~QFileDialogWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QFileDialog_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QFileDialog >()))
        return -1;

    QFileDialogWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OOOO:QFileDialog", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QFileDialog::QFileDialog(QWidget*,QFlags<Qt::WindowType>)
    // 1: QFileDialog::QFileDialog(QWidget*=,const QString&=,const QString&=,const QString&=)
    if (numArgs == 0) {
        overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                    overloadId = 1; // QFileDialog(QWidget*,QString,QString,QString)
                }
            }
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // QFileDialog(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QFileDialog(QWidget *parent, QFlags<Qt::WindowType> f)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWidget *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<Qt::WindowType> cppArg1 = QFlags<Qt::WindowType>(0);
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFileDialog(QWidget*,QFlags<Qt::WindowType>)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QFileDialogWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QFileDialogWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QFileDialog(QWidget *parent, const QString &caption, const QString &directory, const QString &filter)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                static PyObject *const key_caption = Shiboken::String::createStaticString("caption");
                if (PyDict_Contains(kwds, key_caption) != 0) {
                    value = PyDict_GetItem(kwds, key_caption);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_caption);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_caption);
                }
                static PyObject *const key_directory = Shiboken::String::createStaticString("directory");
                if (PyDict_Contains(kwds, key_directory) != 0) {
                    value = PyDict_GetItem(kwds, key_directory);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_directory);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_directory);
                }
                static PyObject *const key_filter = Shiboken::String::createStaticString("filter");
                if (PyDict_Contains(kwds, key_filter) != 0) {
                    value = PyDict_GetItem(kwds, key_filter);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_filter);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_filter);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWidget *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QString cppArg1 = QString();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::QString cppArg2 = QString();
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            ::QString cppArg3 = QString();
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QFileDialog(QWidget*,QString,QString,QString)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QFileDialogWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QFileDialogWrapper(cppArg0, cppArg1, cppArg2, cppArg3);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QFileDialog >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QFileDialogFunc_accept(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // accept()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::QFileDialog::accept()
            : cppSelf->accept();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_acceptMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // acceptMode()const
        QFileDialog::AcceptMode cppResult = const_cast<const ::QFileDialog *>(cppSelf)->acceptMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_AcceptMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_changeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::changeEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "changeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // changeEvent(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QFileDialog::changeEvent(cppArg0)
                : cppSelf->changeEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_defaultSuffix(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // defaultSuffix()const
        QString cppResult = const_cast<const ::QFileDialog *>(cppSelf)->defaultSuffix();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_directory(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // directory()const
        QDir cppResult = const_cast<const ::QFileDialog *>(cppSelf)->directory();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_directoryUrl(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // directoryUrl()const
        QUrl cppResult = const_cast<const ::QFileDialog *>(cppSelf)->directoryUrl();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_done(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QDialog::done(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // done(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "done", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // done(int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QFileDialog::done(cppArg0)
                : cppSelf->done(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_fileMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // fileMode()const
        QFileDialog::FileMode cppResult = const_cast<const ::QFileDialog *>(cppSelf)->fileMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_FileMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_filter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // filter()const
        QFlags<QDir::Filter> cppResult = const_cast<const ::QFileDialog *>(cppSelf)->filter();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_getExistingDirectory(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "getExistingDirectory", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:getExistingDirectory", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFileDialog::getExistingDirectory(QWidget*=,const QString&=,const QString&=,QFlags<QFileDialog::Option>=)->QString
    if (numArgs == 0) {
        overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[3])))) {
                    overloadId = 0; // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "getExistingDirectory", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getExistingDirectory", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "getExistingDirectory", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            static PyObject *const key_caption = Shiboken::String::createStaticString("caption");
            if (PyDict_Contains(kwds, key_caption) != 0) {
                value = PyDict_GetItem(kwds, key_caption);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_caption);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getExistingDirectory", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "getExistingDirectory", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_caption);
            }
            static PyObject *const key_dir = Shiboken::String::createStaticString("dir");
            if (PyDict_Contains(kwds, key_dir) != 0) {
                value = PyDict_GetItem(kwds, key_dir);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_dir);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getExistingDirectory", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "getExistingDirectory", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_dir);
            }
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getExistingDirectory", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "getExistingDirectory", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "getExistingDirectory", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2 = QString();
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QFlags<QFileDialog::Option> cppArg3(QFileDialog::Option::ShowDirsOnly);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // getExistingDirectory(QWidget*,QString,QString,QFlags<QFileDialog::Option>)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QString cppResult = ::QFileDialog::getExistingDirectory(cppArg0, cppArg1, cppArg2, cppArg3);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_getExistingDirectoryUrl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "getExistingDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:getExistingDirectoryUrl", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFileDialog::getExistingDirectoryUrl(QWidget*=,const QString&=,const QUrl&=,QFlags<QFileDialog::Option>=,const QStringList&=)->QUrl
    if (numArgs == 0) {
        overloadId = 0; // getExistingDirectoryUrl(QWidget*,QString,QUrl,QFlags<QFileDialog::Option>,QStringList)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // getExistingDirectoryUrl(QWidget*,QString,QUrl,QFlags<QFileDialog::Option>,QStringList)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // getExistingDirectoryUrl(QWidget*,QString,QUrl,QFlags<QFileDialog::Option>,QStringList)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // getExistingDirectoryUrl(QWidget*,QString,QUrl,QFlags<QFileDialog::Option>,QStringList)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // getExistingDirectoryUrl(QWidget*,QString,QUrl,QFlags<QFileDialog::Option>,QStringList)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[4])))) {
                        overloadId = 0; // getExistingDirectoryUrl(QWidget*,QString,QUrl,QFlags<QFileDialog::Option>,QStringList)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "getExistingDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getExistingDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "getExistingDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            static PyObject *const key_caption = Shiboken::String::createStaticString("caption");
            if (PyDict_Contains(kwds, key_caption) != 0) {
                value = PyDict_GetItem(kwds, key_caption);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_caption);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getExistingDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "getExistingDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_caption);
            }
            static PyObject *const key_dir = Shiboken::String::createStaticString("dir");
            if (PyDict_Contains(kwds, key_dir) != 0) {
                value = PyDict_GetItem(kwds, key_dir);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_dir);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getExistingDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "getExistingDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_dir);
            }
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getExistingDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "getExistingDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            static PyObject *const key_supportedSchemes = Shiboken::String::createStaticString("supportedSchemes");
            if (PyDict_Contains(kwds, key_supportedSchemes) != 0) {
                value = PyDict_GetItem(kwds, key_supportedSchemes);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_supportedSchemes);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getExistingDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "getExistingDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_supportedSchemes);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "getExistingDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QUrl cppArg2_local = QUrl();
        ::QUrl *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }
        ::QFlags<QFileDialog::Option> cppArg3(QFileDialog::Option::ShowDirsOnly);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QStringList cppArg4 = QStringList();
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);

        if (Shiboken::Errors::occurred() == nullptr) {
            // getExistingDirectoryUrl(QWidget*,QString,QUrl,QFlags<QFileDialog::Option>,QStringList)
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            QUrl cppResult = ::QFileDialog::getExistingDirectoryUrl(cppArg0, cppArg1, *cppArg2, cppArg3, cppArg4);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_getOpenFileName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:getOpenFileName", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFileDialog::getOpenFileName(QWidget*=,const QString&=,const QString&=,const QString&=,QString=,QFlags<QFileDialog::Option>=)->(fileName, selectedFilter)
    if (numArgs == 0) {
        overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[5])))) {
                            overloadId = 0; // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            static PyObject *const key_caption = Shiboken::String::createStaticString("caption");
            if (PyDict_Contains(kwds, key_caption) != 0) {
                value = PyDict_GetItem(kwds, key_caption);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_caption);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_caption);
            }
            static PyObject *const key_dir = Shiboken::String::createStaticString("dir");
            if (PyDict_Contains(kwds, key_dir) != 0) {
                value = PyDict_GetItem(kwds, key_dir);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_dir);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_dir);
            }
            static PyObject *const key_filter = Shiboken::String::createStaticString("filter");
            if (PyDict_Contains(kwds, key_filter) != 0) {
                value = PyDict_GetItem(kwds, key_filter);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_filter);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_filter);
            }
            static PyObject *const key_selectedFilter = Shiboken::String::createStaticString("selectedFilter");
            if (PyDict_Contains(kwds, key_selectedFilter) != 0) {
                value = PyDict_GetItem(kwds, key_selectedFilter);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_selectedFilter);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_selectedFilter);
            }
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[5] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[5] = value;
                    if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[5]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "getOpenFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2 = QString();
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QString cppArg3 = QString();
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QString cppArg4 = QString();
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QFlags<QFileDialog::Option> cppArg5 = QFileDialog::Options();
        if (pythonToCpp[5])
            pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // getOpenFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtwidgets.cpp (qfiledialog-return)]
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QString retval_ = QFileDialog::getOpenFileName(cppArg0, cppArg1, cppArg2, cppArg3, &cppArg4, cppArg5);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppArg4));
            // END of custom code block [file: ../glue/qtwidgets.cpp (qfiledialog-return)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_getOpenFileNames(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:getOpenFileNames", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFileDialog::getOpenFileNames(QWidget*=,const QString&=,const QString&=,const QString&=,QString=,QFlags<QFileDialog::Option>=)->(fileNames, selectedFilter)
    if (numArgs == 0) {
        overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[5])))) {
                            overloadId = 0; // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            static PyObject *const key_caption = Shiboken::String::createStaticString("caption");
            if (PyDict_Contains(kwds, key_caption) != 0) {
                value = PyDict_GetItem(kwds, key_caption);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_caption);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_caption);
            }
            static PyObject *const key_dir = Shiboken::String::createStaticString("dir");
            if (PyDict_Contains(kwds, key_dir) != 0) {
                value = PyDict_GetItem(kwds, key_dir);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_dir);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_dir);
            }
            static PyObject *const key_filter = Shiboken::String::createStaticString("filter");
            if (PyDict_Contains(kwds, key_filter) != 0) {
                value = PyDict_GetItem(kwds, key_filter);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_filter);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_filter);
            }
            static PyObject *const key_selectedFilter = Shiboken::String::createStaticString("selectedFilter");
            if (PyDict_Contains(kwds, key_selectedFilter) != 0) {
                value = PyDict_GetItem(kwds, key_selectedFilter);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_selectedFilter);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_selectedFilter);
            }
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[5] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[5] = value;
                    if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[5]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "getOpenFileNames", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2 = QString();
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QString cppArg3 = QString();
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QString cppArg4 = QString();
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QFlags<QFileDialog::Option> cppArg5 = QFileDialog::Options();
        if (pythonToCpp[5])
            pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // getOpenFileNames(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtwidgets.cpp (qfiledialog-return)]
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QStringList retval_ = QFileDialog::getOpenFileNames(cppArg0, cppArg1, cppArg2, cppArg3, &cppArg4, cppArg5);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppArg4));
            // END of custom code block [file: ../glue/qtwidgets.cpp (qfiledialog-return)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_getOpenFileUrl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 7));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOO:getOpenFileUrl", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFileDialog::getOpenFileUrl(QWidget*=,const QString&=,const QUrl&=,const QString&=,QString=,QFlags<QFileDialog::Option>=,const QStringList&=)->(fileName, selectedFilter)
    if (numArgs == 0) {
        overloadId = 0; // getOpenFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // getOpenFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // getOpenFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // getOpenFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // getOpenFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 0; // getOpenFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 0; // getOpenFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[6])))) {
                                overloadId = 0; // getOpenFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            static PyObject *const key_caption = Shiboken::String::createStaticString("caption");
            if (PyDict_Contains(kwds, key_caption) != 0) {
                value = PyDict_GetItem(kwds, key_caption);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_caption);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_caption);
            }
            static PyObject *const key_dir = Shiboken::String::createStaticString("dir");
            if (PyDict_Contains(kwds, key_dir) != 0) {
                value = PyDict_GetItem(kwds, key_dir);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_dir);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_dir);
            }
            static PyObject *const key_filter = Shiboken::String::createStaticString("filter");
            if (PyDict_Contains(kwds, key_filter) != 0) {
                value = PyDict_GetItem(kwds, key_filter);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_filter);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_filter);
            }
            static PyObject *const key_selectedFilter = Shiboken::String::createStaticString("selectedFilter");
            if (PyDict_Contains(kwds, key_selectedFilter) != 0) {
                value = PyDict_GetItem(kwds, key_selectedFilter);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_selectedFilter);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_selectedFilter);
            }
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[5] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[5] = value;
                    if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[5]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            static PyObject *const key_supportedSchemes = Shiboken::String::createStaticString("supportedSchemes");
            if (PyDict_Contains(kwds, key_supportedSchemes) != 0) {
                value = PyDict_GetItem(kwds, key_supportedSchemes);
                if (value != nullptr && pyArgs[6] != nullptr ) {
                    errInfo.reset(key_supportedSchemes);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[6] = value;
                    if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[6]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_supportedSchemes);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "getOpenFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QUrl cppArg2_local = QUrl();
        ::QUrl *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }
        ::QString cppArg3 = QString();
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QString cppArg4 = QString();
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QFlags<QFileDialog::Option> cppArg5 = QFileDialog::Options();
        if (pythonToCpp[5])
            pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // getOpenFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtwidgets.cpp (qfiledialog-return)]
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QUrl retval_ = QFileDialog::getOpenFileUrl(cppArg0, cppArg1, (*cppArg2), cppArg3, &cppArg4, cppArg5);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppArg4));
            // END of custom code block [file: ../glue/qtwidgets.cpp (qfiledialog-return)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_getOpenFileUrls(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 7));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOO:getOpenFileUrls", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFileDialog::getOpenFileUrls(QWidget*=,const QString&=,const QUrl&=,const QString&=,QString=,QFlags<QFileDialog::Option>=,const QStringList&=)->(fileName, selectedFilter)
    if (numArgs == 0) {
        overloadId = 0; // getOpenFileUrls(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // getOpenFileUrls(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // getOpenFileUrls(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // getOpenFileUrls(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // getOpenFileUrls(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 0; // getOpenFileUrls(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 0; // getOpenFileUrls(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[6])))) {
                                overloadId = 0; // getOpenFileUrls(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            static PyObject *const key_caption = Shiboken::String::createStaticString("caption");
            if (PyDict_Contains(kwds, key_caption) != 0) {
                value = PyDict_GetItem(kwds, key_caption);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_caption);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_caption);
            }
            static PyObject *const key_dir = Shiboken::String::createStaticString("dir");
            if (PyDict_Contains(kwds, key_dir) != 0) {
                value = PyDict_GetItem(kwds, key_dir);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_dir);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_dir);
            }
            static PyObject *const key_filter = Shiboken::String::createStaticString("filter");
            if (PyDict_Contains(kwds, key_filter) != 0) {
                value = PyDict_GetItem(kwds, key_filter);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_filter);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_filter);
            }
            static PyObject *const key_selectedFilter = Shiboken::String::createStaticString("selectedFilter");
            if (PyDict_Contains(kwds, key_selectedFilter) != 0) {
                value = PyDict_GetItem(kwds, key_selectedFilter);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_selectedFilter);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_selectedFilter);
            }
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[5] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[5] = value;
                    if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[5]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            static PyObject *const key_supportedSchemes = Shiboken::String::createStaticString("supportedSchemes");
            if (PyDict_Contains(kwds, key_supportedSchemes) != 0) {
                value = PyDict_GetItem(kwds, key_supportedSchemes);
                if (value != nullptr && pyArgs[6] != nullptr ) {
                    errInfo.reset(key_supportedSchemes);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[6] = value;
                    if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[6]))))
                        return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_supportedSchemes);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "getOpenFileUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QUrl cppArg2_local = QUrl();
        ::QUrl *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }
        ::QString cppArg3 = QString();
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QString cppArg4 = QString();
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QFlags<QFileDialog::Option> cppArg5 = QFileDialog::Options();
        if (pythonToCpp[5])
            pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // getOpenFileUrls(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtwidgets.cpp (qfiledialog-return)]
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QList<QUrl> retval_ = QFileDialog::getOpenFileUrls(cppArg0, cppArg1, (*cppArg2), cppArg3, &cppArg4, cppArg5);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QUrl_IDX], &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppArg4));
            // END of custom code block [file: ../glue/qtwidgets.cpp (qfiledialog-return)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_getSaveFileName(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:getSaveFileName", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFileDialog::getSaveFileName(QWidget*=,const QString&=,const QString&=,const QString&=,QString=,QFlags<QFileDialog::Option>=)->(fileName, selectedFilter)
    if (numArgs == 0) {
        overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[5])))) {
                            overloadId = 0; // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            static PyObject *const key_caption = Shiboken::String::createStaticString("caption");
            if (PyDict_Contains(kwds, key_caption) != 0) {
                value = PyDict_GetItem(kwds, key_caption);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_caption);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_caption);
            }
            static PyObject *const key_dir = Shiboken::String::createStaticString("dir");
            if (PyDict_Contains(kwds, key_dir) != 0) {
                value = PyDict_GetItem(kwds, key_dir);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_dir);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_dir);
            }
            static PyObject *const key_filter = Shiboken::String::createStaticString("filter");
            if (PyDict_Contains(kwds, key_filter) != 0) {
                value = PyDict_GetItem(kwds, key_filter);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_filter);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_filter);
            }
            static PyObject *const key_selectedFilter = Shiboken::String::createStaticString("selectedFilter");
            if (PyDict_Contains(kwds, key_selectedFilter) != 0) {
                value = PyDict_GetItem(kwds, key_selectedFilter);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_selectedFilter);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_selectedFilter);
            }
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[5] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[5] = value;
                    if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[5]))))
                        return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "getSaveFileName", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        ::QString cppArg2 = QString();
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);
        ::QString cppArg3 = QString();
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QString cppArg4 = QString();
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QFlags<QFileDialog::Option> cppArg5 = QFileDialog::Options();
        if (pythonToCpp[5])
            pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // getSaveFileName(QWidget*,QString,QString,QString,QString*,QFlags<QFileDialog::Option>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtwidgets.cpp (qfiledialog-return)]
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QString retval_ = QFileDialog::getSaveFileName(cppArg0, cppArg1, cppArg2, cppArg3, &cppArg4, cppArg5);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppArg4));
            // END of custom code block [file: ../glue/qtwidgets.cpp (qfiledialog-return)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_getSaveFileUrl(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 7));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOO:getSaveFileUrl", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFileDialog::getSaveFileUrl(QWidget*=,const QString&=,const QUrl&=,const QString&=,QString=,QFlags<QFileDialog::Option>=,const QStringList&=)->(fileName, selectedFilter)
    if (numArgs == 0) {
        overloadId = 0; // getSaveFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // getSaveFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // getSaveFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // getSaveFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3])))) {
                    if (numArgs == 4) {
                        overloadId = 0; // getSaveFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                    } else if (numArgs >= 5
                        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4])))) {
                        if (numArgs == 5) {
                            overloadId = 0; // getSaveFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                        } else if (numArgs >= 6
                            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[5])))) {
                            if (numArgs == 6) {
                                overloadId = 0; // getSaveFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                            } else if (numArgs >= 7
                                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[6])))) {
                                overloadId = 0; // getSaveFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
                            }
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            static PyObject *const key_caption = Shiboken::String::createStaticString("caption");
            if (PyDict_Contains(kwds, key_caption) != 0) {
                value = PyDict_GetItem(kwds, key_caption);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_caption);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_caption);
            }
            static PyObject *const key_dir = Shiboken::String::createStaticString("dir");
            if (PyDict_Contains(kwds, key_dir) != 0) {
                value = PyDict_GetItem(kwds, key_dir);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_dir);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_dir);
            }
            static PyObject *const key_filter = Shiboken::String::createStaticString("filter");
            if (PyDict_Contains(kwds, key_filter) != 0) {
                value = PyDict_GetItem(kwds, key_filter);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_filter);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_filter);
            }
            static PyObject *const key_selectedFilter = Shiboken::String::createStaticString("selectedFilter");
            if (PyDict_Contains(kwds, key_selectedFilter) != 0) {
                value = PyDict_GetItem(kwds, key_selectedFilter);
                if (value != nullptr && pyArgs[4] != nullptr ) {
                    errInfo.reset(key_selectedFilter);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[4] = value;
                    if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[4]))))
                        return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_selectedFilter);
            }
            static PyObject *const key_options = Shiboken::String::createStaticString("options");
            if (PyDict_Contains(kwds, key_options) != 0) {
                value = PyDict_GetItem(kwds, key_options);
                if (value != nullptr && pyArgs[5] != nullptr ) {
                    errInfo.reset(key_options);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[5] = value;
                    if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArgs[5]))))
                        return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_options);
            }
            static PyObject *const key_supportedSchemes = Shiboken::String::createStaticString("supportedSchemes");
            if (PyDict_Contains(kwds, key_supportedSchemes) != 0) {
                value = PyDict_GetItem(kwds, key_supportedSchemes);
                if (value != nullptr && pyArgs[6] != nullptr ) {
                    errInfo.reset(key_supportedSchemes);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[6] = value;
                    if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[6]))))
                        return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_supportedSchemes);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "getSaveFileUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0 = nullptr;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QUrl cppArg2_local = QUrl();
        ::QUrl *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }
        ::QString cppArg3 = QString();
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);
        ::QString cppArg4 = QString();
        if (pythonToCpp[4])
            pythonToCpp[4](pyArgs[4], &cppArg4);
        ::QFlags<QFileDialog::Option> cppArg5 = QFileDialog::Options();
        if (pythonToCpp[5])
            pythonToCpp[5](pyArgs[5], &cppArg5);

        if (Shiboken::Errors::occurred() == nullptr) {
            // getSaveFileUrl(QWidget*,QString,QUrl,QString,QString*,QFlags<QFileDialog::Option>,QStringList)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtwidgets.cpp (qfiledialog-return)]
            PyThreadState *_save = PyEval_SaveThread(); // Py_BEGIN_ALLOW_THREADS
            ::QUrl retval_ = QFileDialog::getSaveFileUrl(cppArg0, cppArg1, (*cppArg2), cppArg3, &cppArg4, cppArg5);
            PyEval_RestoreThread(_save); // Py_END_ALLOW_THREADS
            pyResult = PyTuple_New(2);
            PyTuple_SetItem(pyResult, 0, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &retval_));
            PyTuple_SetItem(pyResult, 1, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppArg4));
            // END of custom code block [file: ../glue/qtwidgets.cpp (qfiledialog-return)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_history(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // history()const
        QStringList cppResult = const_cast<const ::QFileDialog *>(cppSelf)->history();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_iconProvider(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // iconProvider()const
        QAbstractFileIconProvider * cppResult = const_cast<const ::QFileDialog *>(cppSelf)->iconProvider();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_itemDelegate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // itemDelegate()const
        QAbstractItemDelegate * cppResult = const_cast<const ::QFileDialog *>(cppSelf)->itemDelegate();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_labelText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::labelText(QFileDialog::DialogLabel)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_DialogLabel_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // labelText(QFileDialog::DialogLabel)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "labelText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QFileDialog::DialogLabel cppArg0{QFileDialog::LookIn};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // labelText(QFileDialog::DialogLabel)const
            QString cppResult = const_cast<const ::QFileDialog *>(cppSelf)->labelText(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_mimeTypeFilters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mimeTypeFilters()const
        QStringList cppResult = const_cast<const ::QFileDialog *>(cppSelf)->mimeTypeFilters();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_nameFilters(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // nameFilters()const
        QStringList cppResult = const_cast<const ::QFileDialog *>(cppSelf)->nameFilters();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_open(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 1)
        return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    if (PyArg_UnpackTuple(args, "open", 0, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileDialog::open(QObject*,const char*)
    // 1: QDialog::open()
    if (numArgs == 0) {
        overloadId = 1; // open()
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && Shiboken::String::check(pyArgs[1]) && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<const char *>(), (pyArgs[1])))) {
        overloadId = 0; // open(QObject*,const char*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "open", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // open(QObject *receiver, const char *member)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QObject *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            const char* cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // open(QObject*,const char*)
                cppSelf->open(cppArg0, cppArg1);
            }
            break;
        }
        case 1: // open()
        {

            // open()
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? reinterpret_cast<QDialog *>(cppSelf)->::QDialog::open()
                : reinterpret_cast<QDialog *>(cppSelf)->open();
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_options(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // options()const
        QFlags<QFileDialog::Option> cppResult = const_cast<const ::QFileDialog *>(cppSelf)->options();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_proxyModel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // proxyModel()const
        QAbstractProxyModel * cppResult = const_cast<const ::QFileDialog *>(cppSelf)->proxyModel();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractProxyModel_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_restoreState(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::restoreState(QByteArray)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArg)))) {
        overloadId = 0; // restoreState(QByteArray)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "restoreState", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // restoreState(QByteArray)
            bool cppResult = cppSelf->restoreState(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_saveFileContent(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 2, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "saveFileContent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:saveFileContent", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: static QFileDialog::saveFileContent(QByteArray,QString,QWidget*=)
    if (numArgs >= 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        if (numArgs == 2) {
            overloadId = 0; // saveFileContent(QByteArray,QString,QWidget*)
        } else if (numArgs >= 3
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2])))) {
            overloadId = 0; // saveFileContent(QByteArray,QString,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "saveFileContent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
            if (PyDict_Contains(kwds, key_parent) != 0) {
                value = PyDict_GetItem(kwds, key_parent);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_parent);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "saveFileContent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "saveFileContent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_parent);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "saveFileContent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QByteArray cppArg0_local;
        ::QByteArray *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QWidget *cppArg2 = nullptr;
        if (pythonToCpp[2])
            pythonToCpp[2](pyArgs[2], &cppArg2);

        if (Shiboken::Errors::occurred() == nullptr) {
            // saveFileContent(QByteArray,QString,QWidget*)
            ::QFileDialog::saveFileContent(*cppArg0, cppArg1, cppArg2);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_saveState(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // saveState()const
        QByteArray cppResult = const_cast<const ::QFileDialog *>(cppSelf)->saveState();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_selectFile(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::selectFile(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // selectFile(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "selectFile", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectFile(QString)
            cppSelf->selectFile(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_selectMimeTypeFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::selectMimeTypeFilter(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // selectMimeTypeFilter(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "selectMimeTypeFilter", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectMimeTypeFilter(QString)
            cppSelf->selectMimeTypeFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_selectNameFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::selectNameFilter(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // selectNameFilter(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "selectNameFilter", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // selectNameFilter(QString)
            cppSelf->selectNameFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_selectUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::selectUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // selectUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "selectUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // selectUrl(QUrl)
            cppSelf->selectUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_selectedFiles(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedFiles()const
        QStringList cppResult = const_cast<const ::QFileDialog *>(cppSelf)->selectedFiles();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_selectedMimeTypeFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedMimeTypeFilter()const
        QString cppResult = const_cast<const ::QFileDialog *>(cppSelf)->selectedMimeTypeFilter();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_selectedNameFilter(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedNameFilter()const
        QString cppResult = const_cast<const ::QFileDialog *>(cppSelf)->selectedNameFilter();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_selectedUrls(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedUrls()const
        QList<QUrl> cppResult = const_cast<const ::QFileDialog *>(cppSelf)->selectedUrls();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QUrl_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_setAcceptMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setAcceptMode(QFileDialog::AcceptMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_AcceptMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setAcceptMode(QFileDialog::AcceptMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAcceptMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QFileDialog::AcceptMode cppArg0{QFileDialog::AcceptOpen};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setAcceptMode(QFileDialog::AcceptMode)
            cppSelf->setAcceptMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setDefaultSuffix(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setDefaultSuffix(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDefaultSuffix(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDefaultSuffix", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDefaultSuffix(QString)
            cppSelf->setDefaultSuffix(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setDirectory(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setDirectory(QDir)
    // 1: QFileDialog::setDirectory(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // setDirectory(QString)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDir_IDX]), (pyArg)))) {
        overloadId = 0; // setDirectory(QDir)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDirectory", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setDirectory(const QDir &directory)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::QDir cppArg0_local;
            ::QDir *cppArg0 = &cppArg0_local;
            if (pythonToCpp.isValue())
                pythonToCpp(pyArg, &cppArg0_local);
            else
                pythonToCpp(pyArg, &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setDirectory(QDir)
                cppSelf->setDirectory(*cppArg0);
            }
            break;
        }
        case 1: // setDirectory(const QString &directory)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setDirectory(QString)
                cppSelf->setDirectory(cppArg0);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setDirectoryUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setDirectoryUrl(QUrl)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // setDirectoryUrl(QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDirectoryUrl", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setDirectoryUrl(QUrl)
            cppSelf->setDirectoryUrl(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setFileMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setFileMode(QFileDialog::FileMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_FileMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setFileMode(QFileDialog::FileMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFileMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QFileDialog::FileMode cppArg0{QFileDialog::AnyFile};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFileMode(QFileDialog::FileMode)
            cppSelf->setFileMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setFilter(QFlags<QDir::Filter>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_QDir_Filter_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setFilter(QFlags<QDir::Filter>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFilter", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QFlags<QDir::Filter> cppArg0 = QFlags<QDir::Filter>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFilter(QFlags<QDir::Filter>)
            cppSelf->setFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setHistory(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setHistory(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setHistory(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHistory", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setHistory(QStringList)
            cppSelf->setHistory(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setIconProvider(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setIconProvider(QAbstractFileIconProvider*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IDX]), (pyArg)))) {
        overloadId = 0; // setIconProvider(QAbstractFileIconProvider*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setIconProvider", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractFileIconProvider *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setIconProvider(QAbstractFileIconProvider*)
            cppSelf->setIconProvider(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setItemDelegate(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setItemDelegate(QAbstractItemDelegate*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]), (pyArg)))) {
        overloadId = 0; // setItemDelegate(QAbstractItemDelegate*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItemDelegate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractItemDelegate *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemDelegate(QAbstractItemDelegate*)
            cppSelf->setItemDelegate(cppArg0);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(self), "setItemDelegate(QAbstractItemDelegate*)1", pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setLabelText(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setLabelText", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileDialog::setLabelText(QFileDialog::DialogLabel,QString)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_DialogLabel_IDX])))->converter, (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
        overloadId = 0; // setLabelText(QFileDialog::DialogLabel,QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setLabelText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QFileDialog::DialogLabel cppArg0{QFileDialog::LookIn};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLabelText(QFileDialog::DialogLabel,QString)
            cppSelf->setLabelText(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setMimeTypeFilters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setMimeTypeFilters(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setMimeTypeFilters(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMimeTypeFilters", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMimeTypeFilters(QStringList)
            cppSelf->setMimeTypeFilters(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setNameFilter(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setNameFilter(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setNameFilter(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNameFilter", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNameFilter(QString)
            cppSelf->setNameFilter(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setNameFilters(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setNameFilters(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setNameFilters(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setNameFilters", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setNameFilters(QStringList)
            cppSelf->setNameFilters(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setOption(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setOption", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QFileDialog::setOption(QFileDialog::Option,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_Option_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setOption(QFileDialog::Option,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // setOption(QFileDialog::Option,bool)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_on = Shiboken::String::createStaticString("on");
            if (PyDict_Contains(kwds, key_on) != 0) {
                value = PyDict_GetItem(kwds, key_on);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_on);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_on);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
            }
        }
        ::QFileDialog::Option cppArg0 = static_cast< ::QFileDialog::Option>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOption(QFileDialog::Option,bool)
            cppSelf->setOption(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setOptions(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setOptions(QFlags<QFileDialog::Option>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setOptions(QFlags<QFileDialog::Option>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOptions", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QFlags<QFileDialog::Option> cppArg0 = QFlags<QFileDialog::Option>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOptions(QFlags<QFileDialog::Option>)
            cppSelf->setOptions(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setProxyModel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setProxyModel(QAbstractProxyModel*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QAbstractProxyModel_IDX]), (pyArg)))) {
        overloadId = 0; // setProxyModel(QAbstractProxyModel*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setProxyModel", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QAbstractProxyModel *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setProxyModel(QAbstractProxyModel*)
            cppSelf->setProxyModel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setSidebarUrls(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setSidebarUrls(QList<QUrl>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QUrl_IDX], (pyArg)))) {
        overloadId = 0; // setSidebarUrls(QList<QUrl>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSidebarUrls", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QList<QUrl> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSidebarUrls(QList<QUrl>)
            cppSelf->setSidebarUrls(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setSupportedSchemes(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setSupportedSchemes(QStringList)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArg)))) {
        overloadId = 0; // setSupportedSchemes(QStringList)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setSupportedSchemes", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QStringList cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setSupportedSchemes(QStringList)
            cppSelf->setSupportedSchemes(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setViewMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::setViewMode(QFileDialog::ViewMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_ViewMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setViewMode(QFileDialog::ViewMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setViewMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QFileDialog::ViewMode cppArg0{QFileDialog::Detail};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setViewMode(QFileDialog::ViewMode)
            cppSelf->setViewMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_setVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::setVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setVisible", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setVisible(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QFileDialog::setVisible(cppArg0)
                : cppSelf->setVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QFileDialogFunc_sidebarUrls(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sidebarUrls()const
        QList<QUrl> cppResult = const_cast<const ::QFileDialog *>(cppSelf)->sidebarUrls();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QUrl_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_supportedSchemes(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // supportedSchemes()const
        QStringList cppResult = const_cast<const ::QFileDialog *>(cppSelf)->supportedSchemes();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_testOption(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QFileDialog::testOption(QFileDialog::Option)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_Option_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // testOption(QFileDialog::Option)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "testOption", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);

    // Call function/method
    {
        ::QFileDialog::Option cppArg0 = static_cast< ::QFileDialog::Option>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // testOption(QFileDialog::Option)const
            bool cppResult = const_cast<const ::QFileDialog *>(cppSelf)->testOption(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QFileDialogFunc_viewMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // viewMode()const
        QFileDialog::ViewMode cppResult = const_cast<const ::QFileDialog *>(cppSelf)->viewMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_ViewMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QFileDialog_PropertyStrings[] = {
    "acceptMode::",
    "defaultSuffix::",
    "fileMode::",
    "options::",
    "supportedSchemes::",
    "viewMode::",
    nullptr // Sentinel
};

static const char *Sbk_QFileDialog_EnumFlagInfo[] = {
    "AcceptMode:Enum",
    "DialogLabel:Enum",
    "FileMode:Enum",
    "Option:Flag:Options",
    "ViewMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QFileDialog_methods[] = {
    {"accept", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_accept), METH_NOARGS, nullptr},
    {"acceptMode", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_acceptMode), METH_NOARGS, nullptr},
    {"changeEvent", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_changeEvent), METH_O, nullptr},
    {"defaultSuffix", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_defaultSuffix), METH_NOARGS, nullptr},
    {"directory", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_directory), METH_NOARGS, nullptr},
    {"directoryUrl", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_directoryUrl), METH_NOARGS, nullptr},
    {"done", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_done), METH_O, nullptr},
    {"fileMode", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_fileMode), METH_NOARGS, nullptr},
    {"filter", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_filter), METH_NOARGS, nullptr},
    {"getExistingDirectory", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_getExistingDirectory), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"getExistingDirectoryUrl", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_getExistingDirectoryUrl), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"getOpenFileName", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_getOpenFileName), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"getOpenFileNames", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_getOpenFileNames), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"getOpenFileUrl", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_getOpenFileUrl), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"getOpenFileUrls", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_getOpenFileUrls), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"getSaveFileName", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_getSaveFileName), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"getSaveFileUrl", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_getSaveFileUrl), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"history", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_history), METH_NOARGS, nullptr},
    {"iconProvider", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_iconProvider), METH_NOARGS, nullptr},
    {"itemDelegate", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_itemDelegate), METH_NOARGS, nullptr},
    {"labelText", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_labelText), METH_O, nullptr},
    {"mimeTypeFilters", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_mimeTypeFilters), METH_NOARGS, nullptr},
    {"nameFilters", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_nameFilters), METH_NOARGS, nullptr},
    {"open", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_open), METH_VARARGS, nullptr},
    {"options", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_options), METH_NOARGS, nullptr},
    {"proxyModel", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_proxyModel), METH_NOARGS, nullptr},
    {"restoreState", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_restoreState), METH_O, nullptr},
    {"saveFileContent", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_saveFileContent), METH_VARARGS|METH_KEYWORDS|METH_STATIC, nullptr},
    {"saveState", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_saveState), METH_NOARGS, nullptr},
    {"selectFile", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_selectFile), METH_O, nullptr},
    {"selectMimeTypeFilter", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_selectMimeTypeFilter), METH_O, nullptr},
    {"selectNameFilter", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_selectNameFilter), METH_O, nullptr},
    {"selectUrl", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_selectUrl), METH_O, nullptr},
    {"selectedFiles", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_selectedFiles), METH_NOARGS, nullptr},
    {"selectedMimeTypeFilter", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_selectedMimeTypeFilter), METH_NOARGS, nullptr},
    {"selectedNameFilter", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_selectedNameFilter), METH_NOARGS, nullptr},
    {"selectedUrls", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_selectedUrls), METH_NOARGS, nullptr},
    {"setAcceptMode", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setAcceptMode), METH_O, nullptr},
    {"setDefaultSuffix", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setDefaultSuffix), METH_O, nullptr},
    {"setDirectory", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setDirectory), METH_O, nullptr},
    {"setDirectoryUrl", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setDirectoryUrl), METH_O, nullptr},
    {"setFileMode", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setFileMode), METH_O, nullptr},
    {"setFilter", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setFilter), METH_O, nullptr},
    {"setHistory", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setHistory), METH_O, nullptr},
    {"setIconProvider", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setIconProvider), METH_O, nullptr},
    {"setItemDelegate", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setItemDelegate), METH_O, nullptr},
    {"setLabelText", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setLabelText), METH_VARARGS, nullptr},
    {"setMimeTypeFilters", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setMimeTypeFilters), METH_O, nullptr},
    {"setNameFilter", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setNameFilter), METH_O, nullptr},
    {"setNameFilters", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setNameFilters), METH_O, nullptr},
    {"setOption", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setOption), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setOptions", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setOptions), METH_O, nullptr},
    {"setProxyModel", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setProxyModel), METH_O, nullptr},
    {"setSidebarUrls", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setSidebarUrls), METH_O, nullptr},
    {"setSupportedSchemes", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setSupportedSchemes), METH_O, nullptr},
    {"setViewMode", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setViewMode), METH_O, nullptr},
    {"setVisible", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_setVisible), METH_O, nullptr},
    {"sidebarUrls", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_sidebarUrls), METH_NOARGS, nullptr},
    {"supportedSchemes", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_supportedSchemes), METH_NOARGS, nullptr},
    {"testOption", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_testOption), METH_O, nullptr},
    {"viewMode", reinterpret_cast<PyCFunction>(Sbk_QFileDialogFunc_viewMode), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QFileDialog_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QFileDialog *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QFileDialogWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QFileDialog_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QFileDialog_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QFileDialogSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QFileDialog *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX]))
        return static_cast< ::QDialog *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QFileDialog_Type = nullptr;
static PyTypeObject *Sbk_QFileDialog_TypeF(void)
{
    return _Sbk_QFileDialog_Type;
}

static PyType_Slot Sbk_QFileDialog_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QFileDialog_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QFileDialog_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QFileDialog_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QFileDialog_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QFileDialog_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QFileDialog_spec = {
    "2:PySide6.QtWidgets.QFileDialog",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QFileDialog_slots
};

} //extern "C"

static void *Sbk_QFileDialog_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QFileDialog *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QFileDialog *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QFileDialog *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QFileDialog_ViewMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFileDialog::ViewMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFileDialog::ViewMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFileDialog_ViewMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_ViewMode_IDX])))
        return Enum_PythonToCpp_QFileDialog_ViewMode;
    return {};
}

static PyObject *QFileDialog_ViewMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFileDialog::ViewMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFileDialog::ViewMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_ViewMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFileDialog_FileMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFileDialog::FileMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFileDialog::FileMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFileDialog_FileMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_FileMode_IDX])))
        return Enum_PythonToCpp_QFileDialog_FileMode;
    return {};
}

static PyObject *QFileDialog_FileMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFileDialog::FileMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFileDialog::FileMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_FileMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFileDialog_AcceptMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFileDialog::AcceptMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFileDialog::AcceptMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFileDialog_AcceptMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_AcceptMode_IDX])))
        return Enum_PythonToCpp_QFileDialog_AcceptMode;
    return {};
}

static PyObject *QFileDialog_AcceptMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFileDialog::AcceptMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFileDialog::AcceptMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_AcceptMode_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFileDialog_DialogLabel(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFileDialog::DialogLabel>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFileDialog::DialogLabel *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFileDialog_DialogLabel_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_DialogLabel_IDX])))
        return Enum_PythonToCpp_QFileDialog_DialogLabel;
    return {};
}

static PyObject *QFileDialog_DialogLabel_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFileDialog::DialogLabel>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFileDialog::DialogLabel *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_DialogLabel_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QFileDialog_Option(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QFileDialog::Option>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QFileDialog::Option *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QFileDialog_Option_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_Option_IDX])))
        return Enum_PythonToCpp_QFileDialog_Option;
    return {};
}

static PyObject *QFileDialog_Option_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QFileDialog::Option>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QFileDialog::Option *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_Option_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QFileDialog_Option(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QFileDialog::Option>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QFileDialog::Option> *>(cppOut) = value;

}

static PyObject *QFileDialog_Option_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QFileDialog::Option> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_Option_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QFileDialog_PythonToCpp_QFileDialog_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QFileDialog_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QFileDialog_PythonToCpp_QFileDialog_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QFileDialog_TypeF()))
        return QFileDialog_PythonToCpp_QFileDialog_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QFileDialog_PTR_CppToPython_QFileDialog(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QFileDialog *>(const_cast<void *>(cppIn)), Sbk_QFileDialog_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QFileDialog_SignatureStrings[] = {
    "1:PySide6.QtWidgets.QFileDialog(self,parent:PySide6.QtWidgets.QWidget,f:PySide6.QtCore.Qt.WindowType,*:KeywordOnly=None,viewMode:QFileDialog.ViewMode=None,fileMode:QFileDialog.FileMode=None,acceptMode:QFileDialog.AcceptMode=None,defaultSuffix:QString=None,options:PySide6.QtGui.QAbstractFileIconProvider.Option=None,supportedSchemes:QStringList=None)",
    "0:PySide6.QtWidgets.QFileDialog(self,parent:PySide6.QtWidgets.QWidget=nullptr,caption:QString=QString(),directory:QString=QString(),filter:QString=QString(),*:KeywordOnly=None,viewMode:QFileDialog.ViewMode=None,fileMode:QFileDialog.FileMode=None,acceptMode:QFileDialog.AcceptMode=None,defaultSuffix:QString=None,options:PySide6.QtGui.QAbstractFileIconProvider.Option=None,supportedSchemes:QStringList=None)",
    "PySide6.QtWidgets.QFileDialog.accept(self)",
    "PySide6.QtWidgets.QFileDialog.acceptMode(self)->PySide6.QtWidgets.QFileDialog.AcceptMode",
    "PySide6.QtWidgets.QFileDialog.changeEvent(self,e:PySide6.QtCore.QEvent)",
    "PySide6.QtWidgets.QFileDialog.defaultSuffix(self)->QString",
    "PySide6.QtWidgets.QFileDialog.directory(self)->PySide6.QtCore.QDir",
    "PySide6.QtWidgets.QFileDialog.directoryUrl(self)->PySide6.QtCore.QUrl",
    "PySide6.QtWidgets.QFileDialog.done(self,result:int)",
    "PySide6.QtWidgets.QFileDialog.fileMode(self)->PySide6.QtWidgets.QFileDialog.FileMode",
    "PySide6.QtWidgets.QFileDialog.filter(self)->PySide6.QtCore.QDir.Filter",
    "PySide6.QtWidgets.QFileDialog.getExistingDirectory(parent:PySide6.QtWidgets.QWidget=nullptr,caption:QString=QString(),dir:QString=QString(),options:PySide6.QtWidgets.QFileDialog.Option=QFileDialog.Option.ShowDirsOnly)->QString",
    "PySide6.QtWidgets.QFileDialog.getExistingDirectoryUrl(parent:PySide6.QtWidgets.QWidget=nullptr,caption:QString=QString(),dir:typing.Union[PySide6.QtCore.QUrl, QString]=QUrl(),options:PySide6.QtWidgets.QFileDialog.Option=QFileDialog.Option.ShowDirsOnly,supportedSchemes:QStringList=QStringList())->PySide6.QtCore.QUrl",
    "PySide6.QtWidgets.QFileDialog.getOpenFileName(parent:PySide6.QtWidgets.QWidget=nullptr,caption:QString=QString(),dir:QString=QString(),filter:QString=QString(),selectedFilter:QString=QString(),options:PySide6.QtWidgets.QFileDialog.Option=QFileDialog.Options())->Tuple[str, str]",
    "PySide6.QtWidgets.QFileDialog.getOpenFileNames(parent:PySide6.QtWidgets.QWidget=nullptr,caption:QString=QString(),dir:QString=QString(),filter:QString=QString(),selectedFilter:QString=QString(),options:PySide6.QtWidgets.QFileDialog.Option=QFileDialog.Options())->Tuple[List[str], str]",
    "PySide6.QtWidgets.QFileDialog.getOpenFileUrl(parent:PySide6.QtWidgets.QWidget=nullptr,caption:QString=QString(),dir:typing.Union[PySide6.QtCore.QUrl, QString]=QUrl(),filter:QString=QString(),selectedFilter:QString=QString(),options:PySide6.QtWidgets.QFileDialog.Option=QFileDialog.Options(),supportedSchemes:QStringList=QStringList())->Tuple[PySide6.QtCore.QUrl, str]",
    "PySide6.QtWidgets.QFileDialog.getOpenFileUrls(parent:PySide6.QtWidgets.QWidget=nullptr,caption:QString=QString(),dir:typing.Union[PySide6.QtCore.QUrl, QString]=QUrl(),filter:QString=QString(),selectedFilter:QString=QString(),options:PySide6.QtWidgets.QFileDialog.Option=QFileDialog.Options(),supportedSchemes:QStringList=QStringList())->Tuple[List[PySide6.QtCore.QUrl], str]",
    "PySide6.QtWidgets.QFileDialog.getSaveFileName(parent:PySide6.QtWidgets.QWidget=nullptr,caption:QString=QString(),dir:QString=QString(),filter:QString=QString(),selectedFilter:QString=QString(),options:PySide6.QtWidgets.QFileDialog.Option=QFileDialog.Options())->Tuple[str, str]",
    "PySide6.QtWidgets.QFileDialog.getSaveFileUrl(parent:PySide6.QtWidgets.QWidget=nullptr,caption:QString=QString(),dir:typing.Union[PySide6.QtCore.QUrl, QString]=QUrl(),filter:QString=QString(),selectedFilter:QString=QString(),options:PySide6.QtWidgets.QFileDialog.Option=QFileDialog.Options(),supportedSchemes:QStringList=QStringList())->Tuple[PySide6.QtCore.QUrl, str]",
    "PySide6.QtWidgets.QFileDialog.history(self)->QStringList",
    "PySide6.QtWidgets.QFileDialog.iconProvider(self)->PySide6.QtGui.QAbstractFileIconProvider",
    "PySide6.QtWidgets.QFileDialog.itemDelegate(self)->PySide6.QtWidgets.QAbstractItemDelegate",
    "PySide6.QtWidgets.QFileDialog.labelText(self,label:PySide6.QtWidgets.QFileDialog.DialogLabel)->QString",
    "PySide6.QtWidgets.QFileDialog.mimeTypeFilters(self)->QStringList",
    "PySide6.QtWidgets.QFileDialog.nameFilters(self)->QStringList",
    "1:PySide6.QtWidgets.QFileDialog.open(self,receiver:PySide6.QtCore.QObject,member:char*)",
    "0:PySide6.QtWidgets.QFileDialog.open(self)",
    "PySide6.QtWidgets.QFileDialog.options(self)->PySide6.QtWidgets.QFileDialog.Option",
    "PySide6.QtWidgets.QFileDialog.proxyModel(self)->PySide6.QtCore.QAbstractProxyModel",
    "PySide6.QtWidgets.QFileDialog.restoreState(self,state:typing.Union[PySide6.QtCore.QByteArray, char*])->bool",
    "PySide6.QtWidgets.QFileDialog.saveFileContent(fileContent:typing.Union[PySide6.QtCore.QByteArray, char*],fileNameHint:QString,parent:PySide6.QtWidgets.QWidget=nullptr)",
    "PySide6.QtWidgets.QFileDialog.saveState(self)->PySide6.QtCore.QByteArray",
    "PySide6.QtWidgets.QFileDialog.selectFile(self,filename:QString)",
    "PySide6.QtWidgets.QFileDialog.selectMimeTypeFilter(self,filter:QString)",
    "PySide6.QtWidgets.QFileDialog.selectNameFilter(self,filter:QString)",
    "PySide6.QtWidgets.QFileDialog.selectUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtWidgets.QFileDialog.selectedFiles(self)->QStringList",
    "PySide6.QtWidgets.QFileDialog.selectedMimeTypeFilter(self)->QString",
    "PySide6.QtWidgets.QFileDialog.selectedNameFilter(self)->QString",
    "PySide6.QtWidgets.QFileDialog.selectedUrls(self)->QList[PySide6.QtCore.QUrl]",
    "PySide6.QtWidgets.QFileDialog.setAcceptMode(self,mode:PySide6.QtWidgets.QFileDialog.AcceptMode)",
    "PySide6.QtWidgets.QFileDialog.setDefaultSuffix(self,suffix:QString)",
    "1:PySide6.QtWidgets.QFileDialog.setDirectory(self,directory:PySide6.QtCore.QDir)",
    "0:PySide6.QtWidgets.QFileDialog.setDirectory(self,directory:QString)",
    "PySide6.QtWidgets.QFileDialog.setDirectoryUrl(self,directory:typing.Union[PySide6.QtCore.QUrl, QString])",
    "PySide6.QtWidgets.QFileDialog.setFileMode(self,mode:PySide6.QtWidgets.QFileDialog.FileMode)",
    "PySide6.QtWidgets.QFileDialog.setFilter(self,filters:PySide6.QtCore.QDir.Filter)",
    "PySide6.QtWidgets.QFileDialog.setHistory(self,paths:QStringList)",
    "PySide6.QtWidgets.QFileDialog.setIconProvider(self,provider:PySide6.QtGui.QAbstractFileIconProvider)",
    "PySide6.QtWidgets.QFileDialog.setItemDelegate(self,delegate:PySide6.QtWidgets.QAbstractItemDelegate)",
    "PySide6.QtWidgets.QFileDialog.setLabelText(self,label:PySide6.QtWidgets.QFileDialog.DialogLabel,text:QString)",
    "PySide6.QtWidgets.QFileDialog.setMimeTypeFilters(self,filters:QStringList)",
    "PySide6.QtWidgets.QFileDialog.setNameFilter(self,filter:QString)",
    "PySide6.QtWidgets.QFileDialog.setNameFilters(self,filters:QStringList)",
    "PySide6.QtWidgets.QFileDialog.setOption(self,option:PySide6.QtWidgets.QFileDialog.Option,on:bool=true)",
    "PySide6.QtWidgets.QFileDialog.setOptions(self,options:PySide6.QtWidgets.QFileDialog.Option)",
    "PySide6.QtWidgets.QFileDialog.setProxyModel(self,model:PySide6.QtCore.QAbstractProxyModel)",
    "PySide6.QtWidgets.QFileDialog.setSidebarUrls(self,urls:QList[PySide6.QtCore.QUrl])",
    "PySide6.QtWidgets.QFileDialog.setSupportedSchemes(self,schemes:QStringList)",
    "PySide6.QtWidgets.QFileDialog.setViewMode(self,mode:PySide6.QtWidgets.QFileDialog.ViewMode)",
    "PySide6.QtWidgets.QFileDialog.setVisible(self,visible:bool)",
    "PySide6.QtWidgets.QFileDialog.sidebarUrls(self)->QList[PySide6.QtCore.QUrl]",
    "PySide6.QtWidgets.QFileDialog.supportedSchemes(self)->QStringList",
    "PySide6.QtWidgets.QFileDialog.testOption(self,option:PySide6.QtWidgets.QFileDialog.Option)->bool",
    "PySide6.QtWidgets.QFileDialog.viewMode(self)->PySide6.QtWidgets.QFileDialog.ViewMode",
    nullptr}; // Sentinel
#else
static constexpr size_t QFileDialog_SignatureByteSize = 1056;
static constexpr uint8_t QFileDialog_SignatureBytes[1056] = {
    0x78, 0xda, 0xed, 0x59, 0x4d, 0x6f, 0xdb, 0x38, 0x10, 0xbd, 0xf7, 0x57, 0xe4, 0x18, 0x17, 0x5c,
    0x61, 0x7b, 0xd9, 0x83, 0x81, 0x2c, 0x90, 0xad, 0x9b, 0x6d, 0xb0, 0xf9, 0x84, 0xd3, 0xed, 0xa1,
    0xc8, 0x41, 0x96, 0xc6, 0x36, 0x17, 0xb2, 0x28, 0x90, 0xb4, 0x13, 0xfd, 0xfb, 0x1d, 0x8a, 0xa2,
    0x42, 0x5b, 0xb2, 0x38, 0x8a, 0xbd, 0x2d, 0xd0, 0xcd, 0x25, 0x16, 0xc9, 0xe1, 0xe3, 0xf0, 0x71,
    0x38, 0x9c, 0x99, 0x7c, 0x18, 0xdf, 0x95, 0x53, 0x9e, 0xc2, 0x6f, 0xd1, 0xbd, 0xfe, 0xca, 0xd3,
    0x05, 0x68, 0x15, 0xdd, 0x5f, 0xf0, 0x0c, 0x26, 0x3c, 0xce, 0xc4, 0xe2, 0x54, 0x41, 0x36, 0x67,
    0x45, 0x2c, 0x21, 0xd7, 0x5d, 0x92, 0xf6, 0x83, 0xcd, 0xbd, 0xb1, 0x8f, 0x42, 0x02, 0xfe, 0x44,
    0x5f, 0x79, 0x9e, 0x8a, 0xa7, 0x87, 0xb2, 0x00, 0xf6, 0x7e, 0xfc, 0x17, 0x94, 0x4f, 0x42, 0xa6,
    0xb7, 0x79, 0x56, 0x9e, 0xdd, 0x88, 0x1c, 0xd8, 0x86, 0xc3, 0xd3, 0xb5, 0x48, 0x61, 0xec, 0x2d,
    0x16, 0xfd, 0x5d, 0x77, 0x5a, 0x91, 0x39, 0x0e, 0xb4, 0x44, 0x2e, 0xea, 0x4e, 0x2b, 0x12, 0x27,
    0x09, 0x14, 0xba, 0x25, 0x74, 0xde, 0x74, 0x5b, 0xb1, 0x14, 0xe6, 0xf1, 0x3a, 0xd3, 0xd3, 0xf5,
    0x7c, 0xce, 0x9f, 0xc7, 0xf7, 0x53, 0x2d, 0x79, 0xbe, 0xb0, 0x43, 0xa2, 0xd0, 0x5c, 0xe4, 0xca,
    0xd3, 0xff, 0xcf, 0x35, 0x8f, 0xee, 0xcf, 0x67, 0x4a, 0xcb, 0x38, 0xd1, 0x06, 0xf4, 0x32, 0x11,
    0xf9, 0x9d, 0x14, 0x1b, 0x1c, 0x97, 0xd1, 0x6d, 0x25, 0x6f, 0xe7, 0xaa, 0x75, 0x51, 0x08, 0xa9,
    0x21, 0x9d, 0x26, 0x4b, 0x58, 0x81, 0x72, 0xc8, 0x57, 0x5c, 0xe9, 0x4a, 0x62, 0xf4, 0xee, 0xd7,
    0x63, 0xd0, 0x7b, 0x96, 0xaf, 0xb3, 0xac, 0xd0, 0x92, 0x25, 0x71, 0xb5, 0x7a, 0xb3, 0x83, 0xfa,
    0xf7, 0x74, 0xc4, 0x52, 0x2e, 0x21, 0xd1, 0x42, 0x96, 0x1d, 0x63, 0xc8, 0xa3, 0x06, 0xd9, 0x31,
    0xf0, 0xff, 0x3d, 0x96, 0xde, 0x43, 0x89, 0xac, 0xfa, 0xd5, 0xd9, 0xd0, 0x44, 0xcd, 0x96, 0xac,
    0xf8, 0x2f, 0xbf, 0xf7, 0xcb, 0xbf, 0x50, 0x10, 0x00, 0x4e, 0x96, 0x71, 0xbe, 0x80, 0x4f, 0x1b,
    0x34, 0x0c, 0x6b, 0x24, 0xd0, 0xba, 0x62, 0xd5, 0x60, 0x48, 0xc1, 0x2d, 0x8e, 0x9d, 0x8e, 0x35,
    0x21, 0xa1, 0xa9, 0xce, 0xa6, 0xda, 0x5b, 0xb3, 0x0a, 0x4c, 0xb8, 0xa4, 0x42, 0x7c, 0x91, 0xd9,
    0x3e, 0x14, 0x1c, 0x0a, 0xa1, 0xe0, 0x99, 0x59, 0x12, 0x24, 0x28, 0xdc, 0xcc, 0x98, 0x87, 0xf7,
    0xed, 0xac, 0x94, 0x76, 0x2c, 0xce, 0x7c, 0xc3, 0xa0, 0x78, 0x93, 0x7a, 0xe8, 0x30, 0x40, 0x28,
    0x11, 0x80, 0xc1, 0x8e, 0x4f, 0xcf, 0x68, 0x8c, 0x78, 0x04, 0x93, 0x86, 0xe3, 0xe3, 0x38, 0x81,
    0x8e, 0xde, 0xf6, 0x55, 0xea, 0xd2, 0xa9, 0xbe, 0x40, 0xed, 0xae, 0x68, 0xba, 0x14, 0x4f, 0xa8,
    0xa6, 0x32, 0x4e, 0x82, 0x6c, 0x3b, 0x5d, 0x5b, 0x34, 0x36, 0x70, 0xa4, 0x5d, 0xea, 0xb2, 0xc0,
    0x46, 0xf4, 0x25, 0x47, 0x91, 0x6f, 0x1d, 0x06, 0xc5, 0x4e, 0x6a, 0xf9, 0xc7, 0x33, 0xd3, 0x3c,
    0x32, 0x0b, 0xfd, 0x1e, 0xc6, 0xfb, 0x3e, 0x1d, 0xbd, 0xca, 0xde, 0xb1, 0xe3, 0xb6, 0x80, 0xdc,
    0xf4, 0xdc, 0xc4, 0x2b, 0xf8, 0xef, 0x4c, 0x63, 0xef, 0xcb, 0x80, 0x16, 0x8e, 0x67, 0x06, 0xe9,
    0xc5, 0x3e, 0x81, 0x03, 0xe9, 0x54, 0x15, 0x33, 0x0f, 0xeb, 0x22, 0x83, 0x6f, 0xe8, 0xd1, 0xd9,
    0x09, 0xfe, 0x79, 0x1c, 0xc6, 0x8a, 0xfa, 0xc9, 0x69, 0x31, 0xf6, 0x63, 0xb8, 0x79, 0x1c, 0x4a,
    0xce, 0x0f, 0xbd, 0x66, 0x3f, 0x92, 0xba, 0x61, 0xd7, 0xd2, 0xb2, 0xdc, 0xb9, 0xa9, 0xc1, 0x7c,
    0xab, 0x37, 0xc2, 0xa9, 0x84, 0x57, 0x66, 0xdd, 0xb1, 0x33, 0xb2, 0x99, 0x4f, 0xe3, 0x0d, 0xbc,
    0x79, 0xc6, 0x7d, 0xac, 0xbc, 0x5d, 0xfe, 0xef, 0x70, 0xf9, 0x97, 0x08, 0xe3, 0x85, 0xc5, 0x1e,
    0x78, 0x60, 0x22, 0xf7, 0x52, 0x96, 0x76, 0x14, 0xd9, 0x9b, 0xe1, 0x84, 0x90, 0x35, 0xac, 0x26,
    0xc8, 0xf2, 0x22, 0xd6, 0x7d, 0x21, 0xaf, 0x43, 0xbf, 0xf4, 0xc4, 0x03, 0xc8, 0x59, 0x3c, 0x83,
    0xec, 0x01, 0x9e, 0xeb, 0x34, 0xa4, 0x6a, 0x06, 0xce, 0xc9, 0xfe, 0x5c, 0x19, 0x49, 0x72, 0xc0,
    0xb8, 0xe2, 0x2b, 0x30, 0xb5, 0x02, 0x6b, 0x22, 0x6a, 0x38, 0xb7, 0x39, 0xfa, 0x83, 0x9e, 0xc9,
    0x1f, 0x02, 0x3a, 0x0b, 0xf4, 0xe6, 0x2e, 0xc7, 0x48, 0x80, 0x6f, 0xd0, 0x4c, 0x77, 0xcd, 0xe3,
    0x76, 0xf6, 0x0f, 0x5a, 0x31, 0x5b, 0xc1, 0x6a, 0x86, 0xa3, 0x98, 0xa0, 0xc9, 0xf7, 0xc1, 0x04,
    0xff, 0x05, 0x37, 0x94, 0xb0, 0xd4, 0x57, 0x80, 0x96, 0xaf, 0x58, 0xb3, 0x0f, 0x20, 0x16, 0x52,
    0x3c, 0x97, 0x26, 0xab, 0xd9, 0x9b, 0x7a, 0x39, 0x73, 0xb8, 0x6b, 0x24, 0x03, 0x90, 0x98, 0x7f,
    0xa1, 0xe5, 0xc3, 0x54, 0x3b, 0x33, 0x63, 0xca, 0x7c, 0xf6, 0xfb, 0x8a, 0x3f, 0x4a, 0x0d, 0xe7,
    0x52, 0xc6, 0x25, 0x3b, 0xa9, 0x48, 0x7b, 0x44, 0x4d, 0x66, 0x42, 0x84, 0xd6, 0x52, 0xb5, 0x4b,
    0xfb, 0x28, 0x72, 0x6d, 0xb2, 0xe0, 0xf9, 0xcb, 0xf7, 0xc0, 0xf5, 0xaa, 0x92, 0x85, 0x79, 0x2f,
    0x3e, 0x63, 0xe2, 0xe8, 0xfc, 0x02, 0xb9, 0xea, 0x32, 0x22, 0xe8, 0xf9, 0x42, 0x48, 0x07, 0xcb,
    0x8d, 0x3e, 0x21, 0xa0, 0xca, 0x4b, 0x9a, 0x0e, 0x4b, 0xad, 0xd1, 0xda, 0x58, 0xb5, 0xd3, 0x78,
    0x44, 0x9a, 0x7f, 0xbd, 0x75, 0x91, 0x1a, 0x24, 0xcf, 0xef, 0xd2, 0x70, 0x6e, 0x9a, 0xfb, 0xf4,
    0x7a, 0x0c, 0x97, 0xf5, 0xb3, 0xb5, 0xcc, 0x06, 0xbc, 0x27, 0x34, 0xf0, 0xea, 0x39, 0x81, 0x57,
    0x78, 0x0a, 0x37, 0xbd, 0x83, 0x29, 0xb2, 0xbb, 0x72, 0x18, 0x3b, 0x2c, 0x0d, 0x9e, 0x5f, 0x05,
    0x8f, 0x6e, 0xe6, 0xde, 0xd8, 0x28, 0x08, 0xa6, 0xcf, 0xb7, 0xeb, 0x50, 0x6c, 0x65, 0x6a, 0x6f,
    0xd4, 0x52, 0x54, 0x98, 0x6f, 0x3d, 0x69, 0x95, 0x91, 0xf0, 0xc1, 0xf5, 0xcb, 0x76, 0xa3, 0xa0,
    0x87, 0x35, 0x28, 0x5b, 0x15, 0x25, 0xaf, 0x68, 0xd9, 0x51, 0x4a, 0x09, 0xbb, 0xd6, 0x3e, 0x40,
    0xb2, 0x99, 0xea, 0xc9, 0x6e, 0x89, 0xca, 0x43, 0x39, 0xa6, 0xc9, 0xea, 0x0b, 0xbf, 0x22, 0x45,
    0x39, 0x20, 0x37, 0x81, 0x86, 0xbd, 0x73, 0x51, 0xd5, 0x78, 0x7f, 0x79, 0x8a, 0x00, 0xf8, 0xd9,
    0x0b, 0x71, 0xd0, 0x53, 0xea, 0xe5, 0x56, 0x3c, 0x45, 0x00, 0xb8, 0xdc, 0x0d, 0x75, 0x58, 0x51,
    0xb7, 0xa8, 0x35, 0x5d, 0xca, 0x22, 0xbb, 0x51, 0x0f, 0x4b, 0xeb, 0xd6, 0x98, 0x18, 0xfc, 0x10,
    0x16, 0xb9, 0x3a, 0x28, 0x00, 0x62, 0x1a, 0x67, 0x0e, 0x30, 0xc7, 0xeb, 0x8e, 0x38, 0xa8, 0x39,
    0xd2, 0x61, 0x47, 0x70, 0xa8, 0x07, 0xf7, 0x00, 0x0e, 0xd2, 0xc3, 0x06, 0x2b, 0x16, 0xc1, 0x46,
    0x39, 0xa4, 0x38, 0x9f, 0xa1, 0x9c, 0x09, 0x13, 0xce, 0xb4, 0x5c, 0x03, 0x79, 0x19, 0xe5, 0xaf,
    0x43, 0x4b, 0x28, 0x08, 0xd8, 0x77, 0xdb, 0xa1, 0x54, 0x75, 0x7b, 0xb3, 0x71, 0x38, 0x9c, 0x22,
    0x40, 0x9b, 0xe1, 0x59, 0x2c, 0x9b, 0x87, 0xc0, 0xbc, 0x95, 0xc8, 0xf0, 0xde, 0xb7, 0x80, 0x02,
    0xb9, 0x93, 0x0a, 0xd5, 0xfe, 0xba, 0x9d, 0x17, 0x11, 0xb0, 0xdc, 0xff, 0x7e, 0xc8, 0x5e, 0xcb,
    0x4d, 0x20, 0x61, 0x2b, 0x3e, 0x73, 0xd1, 0xce, 0xc6, 0x36, 0xaa, 0x23, 0x0f, 0xce, 0xdd, 0xe1,
    0xec, 0xa0, 0xc7, 0xb3, 0x8b, 0xac, 0x41, 0xf1, 0x84, 0xc6, 0xa0, 0xf8, 0x95, 0x36, 0x4e, 0x8b,
    0x84, 0x37, 0xfe, 0x19, 0x04, 0x73, 0x03, 0x77, 0x00, 0xef, 0xfe, 0x05, 0xc3, 0xaa, 0xdf, 0x90
};
#endif

PyTypeObject *init_QFileDialog(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX].type;

    Shiboken::AutoDecRef Sbk_QFileDialog_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX]))));

    _Sbk_QFileDialog_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QFileDialog",
        "QFileDialog*",
        &Sbk_QFileDialog_spec,
        &Shiboken::callCppDestructor< QFileDialog >,
        Sbk_QFileDialog_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QFileDialog_TypeF(); // references _Sbk_QFileDialog_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QFileDialog_SignatureStrings);
#else
    InitSignatureBytes(pyType, QFileDialog_SignatureBytes, QFileDialog_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QFileDialog_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QFileDialog_PythonToCpp_QFileDialog_PTR,
        is_QFileDialog_PythonToCpp_QFileDialog_PTR_Convertible,
        QFileDialog_PTR_CppToPython_QFileDialog);

    Shiboken::Conversions::registerConverterName(converter, "QFileDialog");
    Shiboken::Conversions::registerConverterName(converter, "QFileDialog*");
    Shiboken::Conversions::registerConverterName(converter, "QFileDialog&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QFileDialog).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QFileDialogWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QFileDialog_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QFileDialog_TypeF(), &Sbk_QFileDialogSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QFileDialog_TypeF(), &Sbk_QFileDialog_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QFileDialog_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ViewMode'.
    const char *ViewMode_Initializer[] = {
        "Detail",
        "List",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t ViewMode_InitializerValues[] = {
        uint8_t(QFileDialog::ViewMode::Detail), //  0x00  0
        uint8_t(QFileDialog::ViewMode::List)    //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFileDialog_TypeF(),
        "2:PySide6.QtWidgets.QFileDialog.ViewMode",
        ViewMode_Initializer, ViewMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_ViewMode_IDX].type = EType;
    // Register converter for enum 'QFileDialog::ViewMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFileDialog_ViewMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFileDialog_ViewMode,
            is_Enum_PythonToCpp_QFileDialog_ViewMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFileDialog::ViewMode");
        Shiboken::Conversions::registerConverterAlias(converter, "ViewMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ViewMode' enum.

    // Initialization of enum 'FileMode'.
    const char *FileMode_Initializer[] = {
        "AnyFile",
        "ExistingFile",
        "Directory",
        "ExistingFiles",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t FileMode_InitializerValues[] = {
        uint8_t(QFileDialog::FileMode::AnyFile),      //  0x00  0
        uint8_t(QFileDialog::FileMode::ExistingFile), //  0x01  1
        uint8_t(QFileDialog::FileMode::Directory),    //  0x02  2
        uint8_t(QFileDialog::FileMode::ExistingFiles) //  0x03  3
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFileDialog_TypeF(),
        "2:PySide6.QtWidgets.QFileDialog.FileMode",
        FileMode_Initializer, FileMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_FileMode_IDX].type = EType;
    // Register converter for enum 'QFileDialog::FileMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFileDialog_FileMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFileDialog_FileMode,
            is_Enum_PythonToCpp_QFileDialog_FileMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFileDialog::FileMode");
        Shiboken::Conversions::registerConverterAlias(converter, "FileMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'FileMode' enum.

    // Initialization of enum 'AcceptMode'.
    const char *AcceptMode_Initializer[] = {
        "AcceptOpen",
        "AcceptSave",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t AcceptMode_InitializerValues[] = {
        uint8_t(QFileDialog::AcceptMode::AcceptOpen), //  0x00  0
        uint8_t(QFileDialog::AcceptMode::AcceptSave)  //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFileDialog_TypeF(),
        "2:PySide6.QtWidgets.QFileDialog.AcceptMode",
        AcceptMode_Initializer, AcceptMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_AcceptMode_IDX].type = EType;
    // Register converter for enum 'QFileDialog::AcceptMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFileDialog_AcceptMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFileDialog_AcceptMode,
            is_Enum_PythonToCpp_QFileDialog_AcceptMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFileDialog::AcceptMode");
        Shiboken::Conversions::registerConverterAlias(converter, "AcceptMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'AcceptMode' enum.

    // Initialization of enum 'DialogLabel'.
    const char *DialogLabel_Initializer[] = {
        "LookIn",
        "FileName",
        "FileType",
        "Accept",
        "Reject",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DialogLabel_InitializerValues[] = {
        uint8_t(QFileDialog::DialogLabel::LookIn),   //  0x00  0
        uint8_t(QFileDialog::DialogLabel::FileName), //  0x01  1
        uint8_t(QFileDialog::DialogLabel::FileType), //  0x02  2
        uint8_t(QFileDialog::DialogLabel::Accept),   //  0x03  3
        uint8_t(QFileDialog::DialogLabel::Reject)    //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFileDialog_TypeF(),
        "2:PySide6.QtWidgets.QFileDialog.DialogLabel",
        DialogLabel_Initializer, DialogLabel_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_DialogLabel_IDX].type = EType;
    // Register converter for enum 'QFileDialog::DialogLabel'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFileDialog_DialogLabel_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFileDialog_DialogLabel,
            is_Enum_PythonToCpp_QFileDialog_DialogLabel_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFileDialog::DialogLabel");
        Shiboken::Conversions::registerConverterAlias(converter, "DialogLabel");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DialogLabel' enum.

    // Initialization of enum 'Option'.
    const char *Option_Initializer[] = {
        "ShowDirsOnly",
        "DontResolveSymlinks",
        "DontConfirmOverwrite",
        "DontUseNativeDialog",
        "ReadOnly",
        "HideNameFilterDetails",
        "DontUseCustomDirectoryIcons",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Option_InitializerValues[] = {
        uint8_t(QFileDialog::Option::ShowDirsOnly),               //  0x01  1
        uint8_t(QFileDialog::Option::DontResolveSymlinks),        //  0x02  2
        uint8_t(QFileDialog::Option::DontConfirmOverwrite),       //  0x04  4
        uint8_t(QFileDialog::Option::DontUseNativeDialog),        //  0x08  8
        uint8_t(QFileDialog::Option::ReadOnly),                   //  0x10  16
        uint8_t(QFileDialog::Option::HideNameFilterDetails),      //  0x20  32
        uint8_t(QFileDialog::Option::DontUseCustomDirectoryIcons) //  0x40  64
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QFileDialog_TypeF(),
        "2:PySide6.QtWidgets.QFileDialog.Option",
        Option_Initializer, Option_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_Option_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QFileDialog_Option_IDX].type =
        EType;
    // Register converter for enum 'QFileDialog::Option'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QFileDialog_Option_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QFileDialog_Option,
            is_Enum_PythonToCpp_QFileDialog_Option_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QFileDialog::Option");
        Shiboken::Conversions::registerConverterAlias(converter, "Option");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QFileDialog_Option_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QFileDialog_Option,
            is_Enum_PythonToCpp_QFileDialog_Option_Convertible);
        // Register converter for flag 'QFlags<QFileDialog::Option>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QFileDialog::Option>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFileDialog::Options");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'Option' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QFileDialog::staticMetaObject);
    qRegisterMetaType< ::QFileDialog::ViewMode >("QFileDialog::ViewMode");
    qRegisterMetaType< ::QFileDialog::FileMode >("QFileDialog::FileMode");
    qRegisterMetaType< ::QFileDialog::AcceptMode >("QFileDialog::AcceptMode");
    qRegisterMetaType< ::QFileDialog::DialogLabel >("QFileDialog::DialogLabel");
    qRegisterMetaType< ::QFileDialog::Option >("QFileDialog::Option");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QFileDialog::staticMetaObject, sizeof(QFileDialogWrapper));

    return pyType;
}
