// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qgraphicsscene_wrapper.h"

// Extra includes
#include <QVarLengthArray>

// Argument includes
#include <QAnyStringView>
#include <QList>
#include <QString>
#include <QtGui/qbrush.h>
#include <QtGui/qevent.h>
#include <QtGui/qfont.h>
#include <QtGui/qpainter.h>
#include <QtGui/qpainterpath.h>
#include <QtGui/qpalette.h>
#include <QtGui/qpen.h>
#include <QtGui/qpixmap.h>
#include <QtGui/qpolygon.h>
#include <QtGui/qtransform.h>
#include <QtWidgets/qgraphicsitem.h>
#include <QtWidgets/qgraphicsproxywidget.h>
#include <QtWidgets/qgraphicsscene.h>
#include <QtWidgets/qgraphicssceneevent.h>
#include <QtWidgets/qgraphicsview.h>
#include <QtWidgets/qgraphicswidget.h>
#include <QtWidgets/qstyle.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qline.h>
#include <qmetaobject.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qthread.h>
#include <qvariant.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QGraphicsSceneWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QGraphicsSceneWrapper::QGraphicsSceneWrapper(::QObject * parent) : QGraphicsScene(parent)
{
}

QGraphicsSceneWrapper::QGraphicsSceneWrapper(const ::QRectF & sceneRect, ::QObject * parent) : QGraphicsScene(sceneRect, parent)
{
}

QGraphicsSceneWrapper::QGraphicsSceneWrapper(qreal x, qreal y, qreal width, qreal height, ::QObject * parent) : QGraphicsScene(x, y, width, height, parent)
{
}

void QGraphicsSceneWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[1]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::contextMenuEvent(::QGraphicsSceneContextMenuEvent * event)
{
    if (m_PyMethodCache[2]) {
        return this->::QGraphicsScene::contextMenuEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "contextMenuEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QGraphicsScene::contextMenuEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[4]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::dragEnterEvent(::QGraphicsSceneDragDropEvent * event)
{
    if (m_PyMethodCache[5]) {
        return this->::QGraphicsScene::dragEnterEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragEnterEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QGraphicsScene::dragEnterEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneDragDropEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneDragDropEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::dragLeaveEvent(::QGraphicsSceneDragDropEvent * event)
{
    if (m_PyMethodCache[6]) {
        return this->::QGraphicsScene::dragLeaveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragLeaveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QGraphicsScene::dragLeaveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneDragDropEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneDragDropEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::dragMoveEvent(::QGraphicsSceneDragDropEvent * event)
{
    if (m_PyMethodCache[7]) {
        return this->::QGraphicsScene::dragMoveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragMoveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QGraphicsScene::dragMoveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneDragDropEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneDragDropEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::drawBackground(::QPainter * painter, const ::QRectF & rect)
{
    if (m_PyMethodCache[8]) {
        return this->::QGraphicsScene::drawBackground(painter, rect);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawBackground";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QGraphicsScene::drawBackground(painter, rect);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &rect)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &rect)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::drawForeground(::QPainter * painter, const ::QRectF & rect)
{
    if (m_PyMethodCache[9]) {
        return this->::QGraphicsScene::drawForeground(painter, rect);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "drawForeground";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QGraphicsScene::drawForeground(painter, rect);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &rect)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &rect)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::dropEvent(::QGraphicsSceneDragDropEvent * event)
{
    if (m_PyMethodCache[10]) {
        return this->::QGraphicsScene::dropEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dropEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QGraphicsScene::dropEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneDragDropEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneDragDropEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

bool QGraphicsSceneWrapper::event(::QEvent * event)
{
    if (m_PyMethodCache[11])
        return this->::QGraphicsScene::event(event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QGraphicsScene::event(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGraphicsScene", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QGraphicsSceneWrapper::eventFilter(::QObject * watched, ::QEvent * event)
{
    if (m_PyMethodCache[12])
        return this->::QGraphicsScene::eventFilter(watched, event);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QGraphicsScene::eventFilter(watched, event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), watched),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGraphicsScene", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGraphicsSceneWrapper::focusInEvent(::QFocusEvent * event)
{
    if (m_PyMethodCache[13]) {
        return this->::QGraphicsScene::focusInEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusInEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QGraphicsScene::focusInEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

bool QGraphicsSceneWrapper::focusNextPrevChild(bool next)
{
    if (m_PyMethodCache[14])
        return this->::QGraphicsScene::focusNextPrevChild(next);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusNextPrevChild";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QGraphicsScene::focusNextPrevChild(next);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &next)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &next)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGraphicsScene", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGraphicsSceneWrapper::focusOutEvent(::QFocusEvent * event)
{
    if (m_PyMethodCache[15]) {
        return this->::QGraphicsScene::focusOutEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusOutEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[15] = true;
        gil.release();
        return this->::QGraphicsScene::focusOutEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::helpEvent(::QGraphicsSceneHelpEvent * event)
{
    if (m_PyMethodCache[16]) {
        return this->::QGraphicsScene::helpEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "helpEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[16] = true;
        gil.release();
        return this->::QGraphicsScene::helpEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneHelpEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneHelpEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::inputMethodEvent(::QInputMethodEvent * event)
{
    if (m_PyMethodCache[17]) {
        return this->::QGraphicsScene::inputMethodEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "inputMethodEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[17] = true;
        gil.release();
        return this->::QGraphicsScene::inputMethodEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

::QVariant QGraphicsSceneWrapper::inputMethodQuery(::Qt::InputMethodQuery query) const
{
    if (m_PyMethodCache[18])
        return this->::QGraphicsScene::inputMethodQuery(query);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "inputMethodQuery";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[18] = true;
        gil.release();
        return this->::QGraphicsScene::inputMethodQuery(query);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, &query)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, &query)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QGraphicsScene", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QGraphicsSceneWrapper::keyPressEvent(::QKeyEvent * event)
{
    if (m_PyMethodCache[19]) {
        return this->::QGraphicsScene::keyPressEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "keyPressEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[19] = true;
        gil.release();
        return this->::QGraphicsScene::keyPressEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::keyReleaseEvent(::QKeyEvent * event)
{
    if (m_PyMethodCache[20]) {
        return this->::QGraphicsScene::keyReleaseEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "keyReleaseEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[20] = true;
        gil.release();
        return this->::QGraphicsScene::keyReleaseEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::mouseDoubleClickEvent(::QGraphicsSceneMouseEvent * event)
{
    if (m_PyMethodCache[21]) {
        return this->::QGraphicsScene::mouseDoubleClickEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseDoubleClickEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[21] = true;
        gil.release();
        return this->::QGraphicsScene::mouseDoubleClickEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::mouseMoveEvent(::QGraphicsSceneMouseEvent * event)
{
    if (m_PyMethodCache[22]) {
        return this->::QGraphicsScene::mouseMoveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseMoveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[22] = true;
        gil.release();
        return this->::QGraphicsScene::mouseMoveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::mousePressEvent(::QGraphicsSceneMouseEvent * event)
{
    if (m_PyMethodCache[23]) {
        return this->::QGraphicsScene::mousePressEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mousePressEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[23] = true;
        gil.release();
        return this->::QGraphicsScene::mousePressEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::mouseReleaseEvent(::QGraphicsSceneMouseEvent * event)
{
    if (m_PyMethodCache[24]) {
        return this->::QGraphicsScene::mouseReleaseEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseReleaseEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[24] = true;
        gil.release();
        return this->::QGraphicsScene::mouseReleaseEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMouseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMouseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::timerEvent(::QTimerEvent * event)
{
    if (m_PyMethodCache[25]) {
        return this->::QObject::timerEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[25] = true;
        gil.release();
        return this->::QObject::timerEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

void QGraphicsSceneWrapper::wheelEvent(::QGraphicsSceneWheelEvent * event)
{
    if (m_PyMethodCache[26]) {
        return this->::QGraphicsScene::wheelEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "wheelEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[26] = true;
        gil.release();
        return this->::QGraphicsScene::wheelEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneWheelEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneWheelEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QGraphicsScene", funcName);
        return;
    }
}

const QMetaObject *QGraphicsSceneWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QGraphicsScene::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QGraphicsSceneWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QGraphicsScene::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QGraphicsSceneWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QGraphicsSceneWrapper *>(this));
    return QGraphicsScene::qt_metacast(_clname);
}

QGraphicsSceneWrapper::~QGraphicsSceneWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QGraphicsScene_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QGraphicsScene >()))
        return -1;

    QGraphicsSceneWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 3)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:QGraphicsScene", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QGraphicsScene::QGraphicsScene(QObject*=)
    // 1: QGraphicsScene::QGraphicsScene(QRectF,QObject*=)
    // 2: QGraphicsScene::QGraphicsScene(qreal,qreal,qreal,qreal,QObject*=)
    if (numArgs == 0) {
        overloadId = 0; // QGraphicsScene(QObject*)
    } else if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 2; // QGraphicsScene(qreal,qreal,qreal,qreal,QObject*)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4])))) {
            overloadId = 2; // QGraphicsScene(qreal,qreal,qreal,qreal,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QGraphicsScene(QRectF,QObject*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QGraphicsScene(QRectF,QObject*)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QGraphicsScene(QObject*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QGraphicsScene(QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QObject *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGraphicsScene(QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QGraphicsSceneWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QGraphicsSceneWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QGraphicsScene(const QRectF &sceneRect, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QObject *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGraphicsScene(QRectF,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QGraphicsSceneWrapper(*cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QGraphicsSceneWrapper(*cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
        case 2: // QGraphicsScene(qreal x, qreal y, qreal width, qreal height, QObject *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return -1;
            ::QObject *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QGraphicsScene(qreal,qreal,qreal,qreal,QObject*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QGraphicsSceneWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QGraphicsSceneWrapper(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[4], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QGraphicsScene >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QGraphicsSceneFunc_activePanel(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activePanel()const
        QGraphicsItem * cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->activePanel();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_activeWindow(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // activeWindow()const
        QGraphicsWidget * cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->activeWindow();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_addEllipse(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addEllipse", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:addEllipse", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::addEllipse(QRectF,const QPen&=,const QBrush&=)->QGraphicsEllipseItem*
    // 1: QGraphicsScene::addEllipse(qreal,qreal,qreal,qreal,const QPen&=,const QBrush&=)->QGraphicsEllipseItem*
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 1; // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[4])))) {
            if (numArgs == 5) {
                overloadId = 1; // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
            } else if (numArgs >= 6
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[5])))) {
                overloadId = 1; // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addEllipse(QRectF,QPen,QBrush)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // addEllipse(QRectF,QPen,QBrush)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[2])))) {
                overloadId = 0; // addEllipse(QRectF,QPen,QBrush)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addEllipse", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addEllipse(const QRectF &rect, const QPen &pen, const QBrush &brush)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_pen = Shiboken::String::createStaticString("pen");
                if (PyDict_Contains(kwds, key_pen) != 0) {
                    value = PyDict_GetItem(kwds, key_pen);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_pen);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addEllipse", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "addEllipse", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pen);
                }
                static PyObject *const key_brush = Shiboken::String::createStaticString("brush");
                if (PyDict_Contains(kwds, key_brush) != 0) {
                    value = PyDict_GetItem(kwds, key_brush);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_brush);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addEllipse", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "addEllipse", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_brush);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "addEllipse", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPen cppArg1_local = QPen();
            ::QPen *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QBrush cppArg2_local = QBrush();
            ::QBrush *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2]) {
                if (pythonToCpp[2].isValue())
                    pythonToCpp[2](pyArgs[2], &cppArg2_local);
                else
                    pythonToCpp[2](pyArgs[2], &cppArg2);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // addEllipse(QRectF,QPen,QBrush)
                QGraphicsEllipseItem * cppResult = cppSelf->addEllipse(*cppArg0, *cppArg1, *cppArg2);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsEllipseItem_IDX]), cppResult);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // addEllipse(qreal x, qreal y, qreal w, qreal h, const QPen &pen, const QBrush &brush)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_pen = Shiboken::String::createStaticString("pen");
                if (PyDict_Contains(kwds, key_pen) != 0) {
                    value = PyDict_GetItem(kwds, key_pen);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_pen);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addEllipse", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "addEllipse", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pen);
                }
                static PyObject *const key_brush = Shiboken::String::createStaticString("brush");
                if (PyDict_Contains(kwds, key_brush) != 0) {
                    value = PyDict_GetItem(kwds, key_brush);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_brush);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addEllipse", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, "addEllipse", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_brush);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "addEllipse", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QPen cppArg4_local = QPen();
            ::QPen *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4]) {
                if (pythonToCpp[4].isValue())
                    pythonToCpp[4](pyArgs[4], &cppArg4_local);
                else
                    pythonToCpp[4](pyArgs[4], &cppArg4);
                }
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QBrush cppArg5_local = QBrush();
            ::QBrush *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5]) {
                if (pythonToCpp[5].isValue())
                    pythonToCpp[5](pyArgs[5], &cppArg5_local);
                else
                    pythonToCpp[5](pyArgs[5], &cppArg5);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // addEllipse(qreal,qreal,qreal,qreal,QPen,QBrush)
                QGraphicsEllipseItem * cppResult = cppSelf->addEllipse(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4, *cppArg5);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsEllipseItem_IDX]), cppResult);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_addItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::addItem(QGraphicsItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArg)))) {
        overloadId = 0; // addItem(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addItem(QGraphicsItem*)
            cppSelf->addItem(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_addLine(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addLine", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
    if (numArgs == 3)
        return Shiboken::returnWrongArguments(args, "addLine", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:addLine", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::addLine(QLineF,const QPen&=)->QGraphicsLineItem*
    // 1: QGraphicsScene::addLine(qreal,qreal,qreal,qreal,const QPen&=)->QGraphicsLineItem*
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 1; // addLine(qreal,qreal,qreal,qreal,QPen)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[4])))) {
            overloadId = 1; // addLine(qreal,qreal,qreal,qreal,QPen)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addLine(QLineF,QPen)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[1])))) {
            overloadId = 0; // addLine(QLineF,QPen)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addLine", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addLine(const QLineF &line, const QPen &pen)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_pen = Shiboken::String::createStaticString("pen");
                if (PyDict_Contains(kwds, key_pen) != 0) {
                    value = PyDict_GetItem(kwds, key_pen);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_pen);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addLine", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "addLine", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pen);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "addLine", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QLineF cppArg0_local;
            ::QLineF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPen cppArg1_local = QPen();
            ::QPen *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // addLine(QLineF,QPen)
                QGraphicsLineItem * cppResult = cppSelf->addLine(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLineItem_IDX]), cppResult);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // addLine(qreal x1, qreal y1, qreal x2, qreal y2, const QPen &pen)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_pen = Shiboken::String::createStaticString("pen");
                if (PyDict_Contains(kwds, key_pen) != 0) {
                    value = PyDict_GetItem(kwds, key_pen);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_pen);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addLine", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "addLine", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pen);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "addLine", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QPen cppArg4_local = QPen();
            ::QPen *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4]) {
                if (pythonToCpp[4].isValue())
                    pythonToCpp[4](pyArgs[4], &cppArg4_local);
                else
                    pythonToCpp[4](pyArgs[4], &cppArg4);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // addLine(qreal,qreal,qreal,qreal,QPen)
                QGraphicsLineItem * cppResult = cppSelf->addLine(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLineItem_IDX]), cppResult);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_addPath(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addPath", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:addPath", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::addPath(QPainterPath,const QPen&=,const QBrush&=)->QGraphicsPathItem*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addPath(QPainterPath,QPen,QBrush)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // addPath(QPainterPath,QPen,QBrush)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[2])))) {
                overloadId = 0; // addPath(QPainterPath,QPen,QBrush)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addPath", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_pen = Shiboken::String::createStaticString("pen");
            if (PyDict_Contains(kwds, key_pen) != 0) {
                value = PyDict_GetItem(kwds, key_pen);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_pen);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addPath", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "addPath", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_pen);
            }
            static PyObject *const key_brush = Shiboken::String::createStaticString("brush");
            if (PyDict_Contains(kwds, key_brush) != 0) {
                value = PyDict_GetItem(kwds, key_brush);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_brush);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addPath", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "addPath", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_brush);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "addPath", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainterPath cppArg0_local;
        ::QPainterPath *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPen cppArg1_local = QPen();
        ::QPen *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QBrush cppArg2_local = QBrush();
        ::QBrush *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // addPath(QPainterPath,QPen,QBrush)
            QGraphicsPathItem * cppResult = cppSelf->addPath(*cppArg0, *cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPathItem_IDX]), cppResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_addPixmap(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::addPixmap(QPixmap)->QGraphicsPixmapItem*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPixmap_IDX]), (pyArg)))) {
        overloadId = 0; // addPixmap(QPixmap)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addPixmap", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPixmap cppArg0_local;
        ::QPixmap *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // addPixmap(QPixmap)
            QGraphicsPixmapItem * cppResult = cppSelf->addPixmap(*cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPixmapItem_IDX]), cppResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_addPolygon(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 3));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addPolygon", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OOO:addPolygon", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::addPolygon(QPolygonF,const QPen&=,const QBrush&=)->QGraphicsPolygonItem*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addPolygon(QPolygonF,QPen,QBrush)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // addPolygon(QPolygonF,QPen,QBrush)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[2])))) {
                overloadId = 0; // addPolygon(QPolygonF,QPen,QBrush)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addPolygon", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_pen = Shiboken::String::createStaticString("pen");
            if (PyDict_Contains(kwds, key_pen) != 0) {
                value = PyDict_GetItem(kwds, key_pen);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_pen);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addPolygon", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "addPolygon", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_pen);
            }
            static PyObject *const key_brush = Shiboken::String::createStaticString("brush");
            if (PyDict_Contains(kwds, key_brush) != 0) {
                value = PyDict_GetItem(kwds, key_brush);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_brush);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addPolygon", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "addPolygon", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_brush);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "addPolygon", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPolygonF cppArg0_local;
        ::QPolygonF *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QPen cppArg1_local = QPen();
        ::QPen *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QBrush cppArg2_local = QBrush();
        ::QBrush *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // addPolygon(QPolygonF,QPen,QBrush)
            QGraphicsPolygonItem * cppResult = cppSelf->addPolygon(*cppArg0, *cppArg1, *cppArg2);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]), cppResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_addRect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[6];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 6));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOO:addRect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::addRect(QRectF,const QPen&=,const QBrush&=)->QGraphicsRectItem*
    // 1: QGraphicsScene::addRect(qreal,qreal,qreal,qreal,const QPen&=,const QBrush&=)->QGraphicsRectItem*
    if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 1; // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[4])))) {
            if (numArgs == 5) {
                overloadId = 1; // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
            } else if (numArgs >= 6
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[5])))) {
                overloadId = 1; // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addRect(QRectF,QPen,QBrush)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // addRect(QRectF,QPen,QBrush)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[2])))) {
                overloadId = 0; // addRect(QRectF,QPen,QBrush)
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // addRect(const QRectF &rect, const QPen &pen, const QBrush &brush)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_pen = Shiboken::String::createStaticString("pen");
                if (PyDict_Contains(kwds, key_pen) != 0) {
                    value = PyDict_GetItem(kwds, key_pen);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_pen);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "addRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pen);
                }
                static PyObject *const key_brush = Shiboken::String::createStaticString("brush");
                if (PyDict_Contains(kwds, key_brush) != 0) {
                    value = PyDict_GetItem(kwds, key_brush);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_brush);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "addRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_brush);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "addRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPen cppArg1_local = QPen();
            ::QPen *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1]) {
                if (pythonToCpp[1].isValue())
                    pythonToCpp[1](pyArgs[1], &cppArg1_local);
                else
                    pythonToCpp[1](pyArgs[1], &cppArg1);
                }
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QBrush cppArg2_local = QBrush();
            ::QBrush *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2]) {
                if (pythonToCpp[2].isValue())
                    pythonToCpp[2](pyArgs[2], &cppArg2_local);
                else
                    pythonToCpp[2](pyArgs[2], &cppArg2);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // addRect(QRectF,QPen,QBrush)
                QGraphicsRectItem * cppResult = cppSelf->addRect(*cppArg0, *cppArg1, *cppArg2);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsRectItem_IDX]), cppResult);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
        case 1: // addRect(qreal x, qreal y, qreal w, qreal h, const QPen &pen, const QBrush &brush)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_pen = Shiboken::String::createStaticString("pen");
                if (PyDict_Contains(kwds, key_pen) != 0) {
                    value = PyDict_GetItem(kwds, key_pen);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_pen);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPen_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "addRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_pen);
                }
                static PyObject *const key_brush = Shiboken::String::createStaticString("brush");
                if (PyDict_Contains(kwds, key_brush) != 0) {
                    value = PyDict_GetItem(kwds, key_brush);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_brush);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "addRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, "addRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_brush);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "addRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QPen cppArg4_local = QPen();
            ::QPen *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4]) {
                if (pythonToCpp[4].isValue())
                    pythonToCpp[4](pyArgs[4], &cppArg4_local);
                else
                    pythonToCpp[4](pyArgs[4], &cppArg4);
                }
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QBrush cppArg5_local = QBrush();
            ::QBrush *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5]) {
                if (pythonToCpp[5].isValue())
                    pythonToCpp[5](pyArgs[5], &cppArg5_local);
                else
                    pythonToCpp[5](pyArgs[5], &cppArg5);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // addRect(qreal,qreal,qreal,qreal,QPen,QBrush)
                QGraphicsRectItem * cppResult = cppSelf->addRect(cppArg0, cppArg1, cppArg2, cppArg3, *cppArg4, *cppArg5);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsRectItem_IDX]), cppResult);
                // Ownership transferences.
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_addSimpleText(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addSimpleText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OO:addSimpleText", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::addSimpleText(QString,const QFont&=)->QGraphicsSimpleTextItem*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addSimpleText(QString,QFont)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArgs[1])))) {
            overloadId = 0; // addSimpleText(QString,QFont)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addSimpleText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_font = Shiboken::String::createStaticString("font");
            if (PyDict_Contains(kwds, key_font) != 0) {
                value = PyDict_GetItem(kwds, key_font);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_font);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addSimpleText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "addSimpleText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_font);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "addSimpleText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QFont cppArg1_local = QFont();
        ::QFont *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // addSimpleText(QString,QFont)
            QGraphicsSimpleTextItem * cppResult = cppSelf->addSimpleText(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSimpleTextItem_IDX]), cppResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_addText(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OO:addText", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::addText(QString,const QFont&=)->QGraphicsTextItem*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addText(QString,QFont)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArgs[1])))) {
            overloadId = 0; // addText(QString,QFont)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_font = Shiboken::String::createStaticString("font");
            if (PyDict_Contains(kwds, key_font) != 0) {
                value = PyDict_GetItem(kwds, key_font);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_font);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "addText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_font);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "addText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
            }
        }
        ::QString cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QFont cppArg1_local = QFont();
        ::QFont *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }

        if (Shiboken::Errors::occurred() == nullptr) {
            // addText(QString,QFont)
            QGraphicsTextItem * cppResult = cppSelf->addText(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsTextItem_IDX]), cppResult);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_addWidget(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OO:addWidget", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::addWidget(QWidget*,QFlags<Qt::WindowType>=)->QGraphicsProxyWidget*
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addWidget(QWidget*,QFlags<Qt::WindowType>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // addWidget(QWidget*,QFlags<Qt::WindowType>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_wFlags = Shiboken::String::createStaticString("wFlags");
            if (PyDict_Contains(kwds, key_wFlags) != 0) {
                value = PyDict_GetItem(kwds, key_wFlags);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_wFlags);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "addWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_WindowType_IDX])))->flagsConverter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "addWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_wFlags);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "addWidget", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QWidget *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QFlags<Qt::WindowType> cppArg1 = Qt::WindowFlags();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // addWidget(QWidget*,QFlags<Qt::WindowType>)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtwidgets.cpp (qgraphicsscene-addwidget)]
            ::QGraphicsProxyWidget * cppResult = cppSelf->addWidget(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsProxyWidget_IDX]), cppResult);
            Shiboken::Object::keepReference(reinterpret_cast<SbkObject *>(pyResult), "setWidget(QWidget*)1", pyArgs[1-1]);
            // END of custom code block [file: ../glue/qtwidgets.cpp (qgraphicsscene-addwidget)]
            // ========================================================================
            // End of code injection

            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_advance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // advance()
        cppSelf->advance();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_backgroundBrush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // backgroundBrush()const
        QBrush cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->backgroundBrush();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_bspTreeDepth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // bspTreeDepth()const
        int cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->bspTreeDepth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        // Begin code injection
        // ========================================================================
        // START of custom code block [file: ../glue/qtwidgets.cpp (qgraphicsscene-clear)]
        const QList<QGraphicsItem *> items = cppSelf->items();
        Shiboken::BindingManager &bm = Shiboken::BindingManager::instance();
        for (auto *item : items) {
            SbkObject *obj = bm.retrieveWrapper(item);
            if (obj) {
                if (Py_REFCNT(reinterpret_cast<PyObject *>(obj)) > 1) // If the refcnt is 1 the object will vannish anyway.
                    Shiboken::Object::invalidate(obj);
                Shiboken::Object::removeParent(obj);
            }
        }
        cppSelf->clear();
        // END of custom code block [file: ../glue/qtwidgets.cpp (qgraphicsscene-clear)]
        // ========================================================================
        // End of code injection

    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_clearFocus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearFocus()
        cppSelf->clearFocus();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_clearSelection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clearSelection()
        cppSelf->clearSelection();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_collidingItems(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "collidingItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OO:collidingItems", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::collidingItems(const QGraphicsItem*,Qt::ItemSelectionMode=)const->QList<QGraphicsItem*>
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // collidingItems(const QGraphicsItem*,Qt::ItemSelectionMode)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // collidingItems(const QGraphicsItem*,Qt::ItemSelectionMode)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "collidingItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "collidingItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "collidingItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "collidingItems", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QGraphicsItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::ItemSelectionMode cppArg1(Qt::IntersectsItemShape);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // collidingItems(const QGraphicsItem*,Qt::ItemSelectionMode)const
            QList<QGraphicsItem*> cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->collidingItems(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsItemPTR_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_contextMenuEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::contextMenuEvent(QGraphicsSceneContextMenuEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]), (pyArg)))) {
        overloadId = 0; // contextMenuEvent(QGraphicsSceneContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contextMenuEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneContextMenuEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contextMenuEvent(QGraphicsSceneContextMenuEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::contextMenuEvent(cppArg0)
                : cppSelf->contextMenuEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_createItemGroup(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::createItemGroup(QList<QGraphicsItem*>)->QGraphicsItemGroup*
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsItemPTR_IDX], (pyArg)))) {
        overloadId = 0; // createItemGroup(QList<QGraphicsItem*>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "createItemGroup", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        ::QList<QGraphicsItem*> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // createItemGroup(QList<QGraphicsItem*>)
            QGraphicsItemGroup * cppResult = cppSelf->createItemGroup(cppArg0);
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]), cppResult);

            // Ownership transferences.
            // Ownership transferences.
            Shiboken::Object::setParent(pyResult, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_destroyItemGroup(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::destroyItemGroup(QGraphicsItemGroup*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]), (pyArg)))) {
        overloadId = 0; // destroyItemGroup(QGraphicsItemGroup*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "destroyItemGroup", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsItemGroup *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // destroyItemGroup(QGraphicsItemGroup*)
            // Begin code injection
            // ========================================================================
            // START of custom code block [file: ../glue/qtwidgets.cpp (qgraphicsscene-destroyitemgroup)]
            QGraphicsItem *parentItem = cppArg0->parentItem();
            Shiboken::AutoDecRef parent(Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), parentItem));
            const auto &childItems = cppArg0->childItems();
            for (auto *item : childItems)
                Shiboken::Object::setParent(parent, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), item));
            cppSelf->destroyItemGroup(cppArg0);
            // the arg was destroyed by Qt.
            Shiboken::Object::invalidate(pyArg);
            // END of custom code block [file: ../glue/qtwidgets.cpp (qgraphicsscene-destroyitemgroup)]
            // ========================================================================
            // End of code injection

        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_dragEnterEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::dragEnterEvent(QGraphicsSceneDragDropEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneDragDropEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragEnterEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragEnterEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneDragDropEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragEnterEvent(QGraphicsSceneDragDropEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::dragEnterEvent(cppArg0)
                : cppSelf->dragEnterEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_dragLeaveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::dragLeaveEvent(QGraphicsSceneDragDropEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneDragDropEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragLeaveEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragLeaveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneDragDropEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragLeaveEvent(QGraphicsSceneDragDropEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::dragLeaveEvent(cppArg0)
                : cppSelf->dragLeaveEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_dragMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::dragMoveEvent(QGraphicsSceneDragDropEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneDragDropEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragMoveEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragMoveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneDragDropEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragMoveEvent(QGraphicsSceneDragDropEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::dragMoveEvent(cppArg0)
                : cppSelf->dragMoveEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_drawBackground(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawBackground", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::drawBackground(QPainter*,QRectF)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
        overloadId = 0; // drawBackground(QPainter*,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawBackground", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRectF cppArg1_local;
        ::QRectF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // drawBackground(QPainter*,QRectF)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::drawBackground(cppArg0, *cppArg1)
                : cppSelf->drawBackground(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_drawForeground(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "drawForeground", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::drawForeground(QPainter*,QRectF)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
        overloadId = 0; // drawForeground(QPainter*,QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "drawForeground", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRectF cppArg1_local;
        ::QRectF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // drawForeground(QPainter*,QRectF)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::drawForeground(cppArg0, *cppArg1)
                : cppSelf->drawForeground(cppArg0, *cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_dropEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::dropEvent(QGraphicsSceneDragDropEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneDragDropEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dropEvent(QGraphicsSceneDragDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dropEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneDragDropEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dropEvent(QGraphicsSceneDragDropEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::dropEvent(cppArg0)
                : cppSelf->dropEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_eventFilter(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "eventFilter", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QObject::eventFilter(QObject*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // eventFilter(QObject*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "eventFilter", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QObject *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // eventFilter(QObject*,QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::eventFilter(cppArg0, cppArg1)
                : cppSelf->eventFilter(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_focusInEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::focusInEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusInEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusInEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::focusInEvent(cppArg0)
                : cppSelf->focusInEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_focusItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // focusItem()const
        QGraphicsItem * cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->focusItem();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_focusNextPrevChild(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::focusNextPrevChild(bool)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusNextPrevChild", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusNextPrevChild(bool)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::focusNextPrevChild(cppArg0)
                : cppSelf->focusNextPrevChild(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_focusOnTouch(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // focusOnTouch()const
        bool cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->focusOnTouch();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_focusOutEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::focusOutEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusOutEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusOutEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::focusOutEvent(cppArg0)
                : cppSelf->focusOutEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_font(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // font()const
        QFont cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->font();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_foregroundBrush(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // foregroundBrush()const
        QBrush cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->foregroundBrush();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_hasFocus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // hasFocus()const
        bool cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->hasFocus();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_height(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // height()const
        qreal cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->height();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_helpEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::helpEvent(QGraphicsSceneHelpEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneHelpEvent_IDX]), (pyArg)))) {
        overloadId = 0; // helpEvent(QGraphicsSceneHelpEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "helpEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneHelpEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // helpEvent(QGraphicsSceneHelpEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::helpEvent(cppArg0)
                : cppSelf->helpEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_inputMethodEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::inputMethodEvent(QInputMethodEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), (pyArg)))) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "inputMethodEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QInputMethodEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inputMethodEvent(QInputMethodEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::inputMethodEvent(cppArg0)
                : cppSelf->inputMethodEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_inputMethodQuery(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::inputMethodQuery(Qt::InputMethodQuery)const->QVariant
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "inputMethodQuery", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        ::Qt::InputMethodQuery cppArg0 = static_cast< ::Qt::InputMethodQuery>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inputMethodQuery(Qt::InputMethodQuery)const
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QGraphicsScene *>(cppSelf)->::QGraphicsScene::inputMethodQuery(cppArg0)
                : const_cast<const ::QGraphicsScene *>(cppSelf)->inputMethodQuery(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_invalidate(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[5];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 5));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "invalidate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
    if (numArgs == 3)
        return Shiboken::returnWrongArguments(args, "invalidate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOO:invalidate", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::invalidate(const QRectF&=,QFlags<QGraphicsScene::SceneLayer>=)
    // 1: QGraphicsScene::invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>=)
    if (numArgs == 0) {
        overloadId = 0; // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
    } else if (numArgs >= 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        if (numArgs == 4) {
            overloadId = 1; // invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>)
        } else if (numArgs >= 5
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QGraphicsScene_SceneLayer_IDX])))->flagsConverter, (pyArgs[4])))) {
            overloadId = 1; // invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QGraphicsScene_SceneLayer_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "invalidate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // invalidate(const QRectF &rect, QFlags<QGraphicsScene::SceneLayer> layers)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_rect = Shiboken::String::createStaticString("rect");
                if (PyDict_Contains(kwds, key_rect) != 0) {
                    value = PyDict_GetItem(kwds, key_rect);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_rect);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "invalidate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "invalidate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_rect);
                }
                static PyObject *const key_layers = Shiboken::String::createStaticString("layers");
                if (PyDict_Contains(kwds, key_layers) != 0) {
                    value = PyDict_GetItem(kwds, key_layers);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_layers);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "invalidate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QGraphicsScene_SceneLayer_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "invalidate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_layers);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "invalidate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local = QRectF();
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0]) {
                if (pythonToCpp[0].isValue())
                    pythonToCpp[0](pyArgs[0], &cppArg0_local);
                else
                    pythonToCpp[0](pyArgs[0], &cppArg0);
                }
            ::QFlags<QGraphicsScene::SceneLayer> cppArg1(QGraphicsScene::SceneLayer::AllLayers);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // invalidate(QRectF,QFlags<QGraphicsScene::SceneLayer>)
                cppSelf->invalidate(*cppArg0, cppArg1);
            }
            break;
        }
        case 1: // invalidate(qreal x, qreal y, qreal w, qreal h, QFlags<QGraphicsScene::SceneLayer> layers)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_layers = Shiboken::String::createStaticString("layers");
                if (PyDict_Contains(kwds, key_layers) != 0) {
                    value = PyDict_GetItem(kwds, key_layers);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_layers);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "invalidate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QGraphicsScene_SceneLayer_IDX])))->flagsConverter, (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, "invalidate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_layers);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "invalidate", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::QFlags<QGraphicsScene::SceneLayer> cppArg4(QGraphicsScene::SceneLayer::AllLayers);
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // invalidate(qreal,qreal,qreal,qreal,QFlags<QGraphicsScene::SceneLayer>)
                cppSelf->invalidate(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_isActive(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isActive()const
        bool cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->isActive();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_itemAt(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[3];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "itemAt", 2, 3, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::itemAt(QPointF,QTransform)const->QGraphicsItem*
    // 1: QGraphicsScene::itemAt(qreal,qreal,QTransform)const->QGraphicsItem*
    if (numArgs == 3
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[2])))) {
        overloadId = 1; // itemAt(qreal,qreal,QTransform)const
    } else if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[1])))) {
        overloadId = 0; // itemAt(QPointF,QTransform)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "itemAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // itemAt(const QPointF &pos, const QTransform &deviceTransform) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTransform cppArg1_local;
            ::QTransform *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // itemAt(QPointF,QTransform)const
                QGraphicsItem * cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->itemAt(*cppArg0, *cppArg1);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), cppResult);
            }
            break;
        }
        case 1: // itemAt(qreal x, qreal y, const QTransform &deviceTransform) const
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QTransform cppArg2_local;
            ::QTransform *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);


            if (Shiboken::Errors::occurred() == nullptr) {
                // itemAt(qreal,qreal,QTransform)const
                QGraphicsItem * cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->itemAt(cppArg0, cppArg1, *cppArg2);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_itemIndexMethod(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // itemIndexMethod()const
        QGraphicsScene::ItemIndexMethod cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->itemIndexMethod();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_ItemIndexMethod_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_items(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[7];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 7));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
    if (numArgs == 5)
        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OOOOOOO:items", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::items(Qt::SortOrder=)const->QList<QGraphicsItem*>
    // 1: QGraphicsScene::items(QPainterPath,Qt::ItemSelectionMode=,Qt::SortOrder=,const QTransform&=)const->QList<QGraphicsItem*>
    // 2: QGraphicsScene::items(QPointF,Qt::ItemSelectionMode=,Qt::SortOrder=,const QTransform&=)const->QList<QGraphicsItem*>
    // 3: QGraphicsScene::items(QPolygonF,Qt::ItemSelectionMode=,Qt::SortOrder=,const QTransform&=)const->QList<QGraphicsItem*>
    // 4: QGraphicsScene::items(QRectF,Qt::ItemSelectionMode=,Qt::SortOrder=,const QTransform&=)const->QList<QGraphicsItem*>
    // 5: QGraphicsScene::items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,const QTransform&=)const->QList<QGraphicsItem*>
    if (numArgs == 0) {
        overloadId = 0; // items(Qt::SortOrder)const
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 4; // items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionMode_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 4; // items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 4; // items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[3])))) {
                    overloadId = 4; // items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPolygonF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 3; // items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionMode_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 3; // items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 3; // items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[3])))) {
                    overloadId = 3; // items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 2; // items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionMode_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 2; // items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 2; // items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[3])))) {
                    overloadId = 2; // items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionMode_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 1; // items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 1; // items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[3])))) {
                    overloadId = 1; // items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                }
            }
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // items(Qt::SortOrder)const
    } else if (numArgs >= 6
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))
        && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionMode_IDX])))->converter, (pyArgs[4])))
        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[5])))) {
        if (numArgs == 6) {
            overloadId = 5; // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
        } else if (numArgs >= 7
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[6])))) {
            overloadId = 5; // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // items(Qt::SortOrder order) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_order = Shiboken::String::createStaticString("order");
                if (PyDict_Contains(kwds, key_order) != 0) {
                    value = PyDict_GetItem(kwds, key_order);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_order);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_order);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            ::Qt::SortOrder cppArg0(Qt::DescendingOrder);
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // items(Qt::SortOrder)const
                QList<QGraphicsItem*> cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->items(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsItemPTR_IDX], &cppResult);
            }
            break;
        }
        case 1: // items(const QPainterPath &path, Qt::ItemSelectionMode mode, Qt::SortOrder order, const QTransform &deviceTransform) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionMode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                static PyObject *const key_order = Shiboken::String::createStaticString("order");
                if (PyDict_Contains(kwds, key_order) != 0) {
                    value = PyDict_GetItem(kwds, key_order);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_order);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_order);
                }
                static PyObject *const key_deviceTransform = Shiboken::String::createStaticString("deviceTransform");
                if (PyDict_Contains(kwds, key_deviceTransform) != 0) {
                    value = PyDict_GetItem(kwds, key_deviceTransform);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_deviceTransform);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_deviceTransform);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainterPath cppArg0_local;
            ::QPainterPath *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::ItemSelectionMode cppArg1(Qt::IntersectsItemShape);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::SortOrder cppArg2(Qt::DescendingOrder);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QTransform cppArg3_local = QTransform();
            ::QTransform *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3]) {
                if (pythonToCpp[3].isValue())
                    pythonToCpp[3](pyArgs[3], &cppArg3_local);
                else
                    pythonToCpp[3](pyArgs[3], &cppArg3);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // items(QPainterPath,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                QList<QGraphicsItem*> cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->items(*cppArg0, cppArg1, cppArg2, *cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsItemPTR_IDX], &cppResult);
            }
            break;
        }
        case 2: // items(const QPointF &pos, Qt::ItemSelectionMode mode, Qt::SortOrder order, const QTransform &deviceTransform) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionMode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                static PyObject *const key_order = Shiboken::String::createStaticString("order");
                if (PyDict_Contains(kwds, key_order) != 0) {
                    value = PyDict_GetItem(kwds, key_order);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_order);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_order);
                }
                static PyObject *const key_deviceTransform = Shiboken::String::createStaticString("deviceTransform");
                if (PyDict_Contains(kwds, key_deviceTransform) != 0) {
                    value = PyDict_GetItem(kwds, key_deviceTransform);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_deviceTransform);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_deviceTransform);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPointF cppArg0_local;
            ::QPointF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::ItemSelectionMode cppArg1(Qt::IntersectsItemShape);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::SortOrder cppArg2(Qt::DescendingOrder);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QTransform cppArg3_local = QTransform();
            ::QTransform *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3]) {
                if (pythonToCpp[3].isValue())
                    pythonToCpp[3](pyArgs[3], &cppArg3_local);
                else
                    pythonToCpp[3](pyArgs[3], &cppArg3);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // items(QPointF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                QList<QGraphicsItem*> cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->items(*cppArg0, cppArg1, cppArg2, *cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsItemPTR_IDX], &cppResult);
            }
            break;
        }
        case 3: // items(const QPolygonF &polygon, Qt::ItemSelectionMode mode, Qt::SortOrder order, const QTransform &deviceTransform) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionMode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                static PyObject *const key_order = Shiboken::String::createStaticString("order");
                if (PyDict_Contains(kwds, key_order) != 0) {
                    value = PyDict_GetItem(kwds, key_order);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_order);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_order);
                }
                static PyObject *const key_deviceTransform = Shiboken::String::createStaticString("deviceTransform");
                if (PyDict_Contains(kwds, key_deviceTransform) != 0) {
                    value = PyDict_GetItem(kwds, key_deviceTransform);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_deviceTransform);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_deviceTransform);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPolygonF cppArg0_local;
            ::QPolygonF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::ItemSelectionMode cppArg1(Qt::IntersectsItemShape);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::SortOrder cppArg2(Qt::DescendingOrder);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QTransform cppArg3_local = QTransform();
            ::QTransform *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3]) {
                if (pythonToCpp[3].isValue())
                    pythonToCpp[3](pyArgs[3], &cppArg3_local);
                else
                    pythonToCpp[3](pyArgs[3], &cppArg3);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // items(QPolygonF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                QList<QGraphicsItem*> cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->items(*cppArg0, cppArg1, cppArg2, *cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsItemPTR_IDX], &cppResult);
            }
            break;
        }
        case 4: // items(const QRectF &rect, Qt::ItemSelectionMode mode, Qt::SortOrder order, const QTransform &deviceTransform) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionMode_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                static PyObject *const key_order = Shiboken::String::createStaticString("order");
                if (PyDict_Contains(kwds, key_order) != 0) {
                    value = PyDict_GetItem(kwds, key_order);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_order);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_SortOrder_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_order);
                }
                static PyObject *const key_deviceTransform = Shiboken::String::createStaticString("deviceTransform");
                if (PyDict_Contains(kwds, key_deviceTransform) != 0) {
                    value = PyDict_GetItem(kwds, key_deviceTransform);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_deviceTransform);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_deviceTransform);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::ItemSelectionMode cppArg1(Qt::IntersectsItemShape);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::SortOrder cppArg2(Qt::DescendingOrder);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QTransform cppArg3_local = QTransform();
            ::QTransform *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3]) {
                if (pythonToCpp[3].isValue())
                    pythonToCpp[3](pyArgs[3], &cppArg3_local);
                else
                    pythonToCpp[3](pyArgs[3], &cppArg3);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // items(QRectF,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                QList<QGraphicsItem*> cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->items(*cppArg0, cppArg1, cppArg2, *cppArg3);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsItemPTR_IDX], &cppResult);
            }
            break;
        }
        case 5: // items(qreal x, qreal y, qreal w, qreal h, Qt::ItemSelectionMode mode, Qt::SortOrder order, const QTransform &deviceTransform) const
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_deviceTransform = Shiboken::String::createStaticString("deviceTransform");
                if (PyDict_Contains(kwds, key_deviceTransform) != 0) {
                    value = PyDict_GetItem(kwds, key_deviceTransform);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_deviceTransform);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_deviceTransform);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "items", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            ::Qt::ItemSelectionMode cppArg4{Qt::ContainsItemShape};
            pythonToCpp[4](pyArgs[4], &cppArg4);
            ::Qt::SortOrder cppArg5{Qt::AscendingOrder};
            pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QTransform cppArg6_local = QTransform();
            ::QTransform *cppArg6 = &cppArg6_local;
            if (pythonToCpp[6]) {
                if (pythonToCpp[6].isValue())
                    pythonToCpp[6](pyArgs[6], &cppArg6_local);
                else
                    pythonToCpp[6](pyArgs[6], &cppArg6);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // items(qreal,qreal,qreal,qreal,Qt::ItemSelectionMode,Qt::SortOrder,QTransform)const
                QList<QGraphicsItem*> cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->items(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, *cppArg6);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsItemPTR_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_itemsBoundingRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // itemsBoundingRect()const
        QRectF cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->itemsBoundingRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_keyPressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::keyPressEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyPressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyPressEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::keyPressEvent(cppArg0)
                : cppSelf->keyPressEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_keyReleaseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::keyReleaseEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyReleaseEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyReleaseEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::keyReleaseEvent(cppArg0)
                : cppSelf->keyReleaseEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_minimumRenderSize(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // minimumRenderSize()const
        qreal cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->minimumRenderSize();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_mouseDoubleClickEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::mouseDoubleClickEvent(QGraphicsSceneMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseDoubleClickEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseDoubleClickEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseDoubleClickEvent(QGraphicsSceneMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::mouseDoubleClickEvent(cppArg0)
                : cppSelf->mouseDoubleClickEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_mouseGrabberItem(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // mouseGrabberItem()const
        QGraphicsItem * cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->mouseGrabberItem();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_mouseMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::mouseMoveEvent(QGraphicsSceneMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseMoveEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseMoveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseMoveEvent(QGraphicsSceneMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::mouseMoveEvent(cppArg0)
                : cppSelf->mouseMoveEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_mousePressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::mousePressEvent(QGraphicsSceneMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mousePressEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mousePressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mousePressEvent(QGraphicsSceneMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::mousePressEvent(cppArg0)
                : cppSelf->mousePressEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_mouseReleaseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::mouseReleaseEvent(QGraphicsSceneMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseReleaseEvent(QGraphicsSceneMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseReleaseEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseReleaseEvent(QGraphicsSceneMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::mouseReleaseEvent(cppArg0)
                : cppSelf->mouseReleaseEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_palette(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // palette()const
        QPalette cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->palette();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_removeItem(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::removeItem(QGraphicsItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArg)))) {
        overloadId = 0; // removeItem(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // removeItem(QGraphicsItem*)
            cppSelf->removeItem(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(Py_None, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_render(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:render", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::render(QPainter*,const QRectF&=,const QRectF&=,Qt::AspectRatioMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AspectRatioMode_IDX])))->converter, (pyArgs[3])))) {
                    overloadId = 0; // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_target = Shiboken::String::createStaticString("target");
            if (PyDict_Contains(kwds, key_target) != 0) {
                value = PyDict_GetItem(kwds, key_target);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_target);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_target);
            }
            static PyObject *const key_source = Shiboken::String::createStaticString("source");
            if (PyDict_Contains(kwds, key_source) != 0) {
                value = PyDict_GetItem(kwds, key_source);
                if (value != nullptr && pyArgs[2] != nullptr ) {
                    errInfo.reset(key_source);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[2] = value;
                    if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[2]))))
                        return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_source);
            }
            static PyObject *const key_aspectRatioMode = Shiboken::String::createStaticString("aspectRatioMode");
            if (PyDict_Contains(kwds, key_aspectRatioMode) != 0) {
                value = PyDict_GetItem(kwds, key_aspectRatioMode);
                if (value != nullptr && pyArgs[3] != nullptr ) {
                    errInfo.reset(key_aspectRatioMode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[3] = value;
                    if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_AspectRatioMode_IDX])))->converter, (pyArgs[3]))))
                        return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_aspectRatioMode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "render", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QPainter *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QRectF cppArg1_local = QRectF();
        ::QRectF *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1]) {
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);
            }
        if (!Shiboken::Object::isValid(pyArgs[2]))
            return {};
        ::QRectF cppArg2_local = QRectF();
        ::QRectF *cppArg2 = &cppArg2_local;
        if (pythonToCpp[2]) {
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);
            }
        ::Qt::AspectRatioMode cppArg3(Qt::KeepAspectRatio);
        if (pythonToCpp[3])
            pythonToCpp[3](pyArgs[3], &cppArg3);

        if (Shiboken::Errors::occurred() == nullptr) {
            // render(QPainter*,QRectF,QRectF,Qt::AspectRatioMode)
            cppSelf->render(cppArg0, *cppArg1, *cppArg2, cppArg3);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_sceneRect(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // sceneRect()const
        QRectF cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->sceneRect();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_selectedItems(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectedItems()const
        QList<QGraphicsItem*> cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->selectedItems();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsItemPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_selectionArea(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectionArea()const
        QPainterPath cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->selectionArea();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_sendEvent(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "sendEvent", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::sendEvent(QGraphicsItem*,QEvent*)->bool
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArgs[1])))) {
        overloadId = 0; // sendEvent(QGraphicsItem*,QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "sendEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QGraphicsItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QEvent *cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // sendEvent(QGraphicsItem*,QEvent*)
            bool cppResult = cppSelf->sendEvent(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_setActivePanel(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::setActivePanel(QGraphicsItem*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArg)))) {
        overloadId = 0; // setActivePanel(QGraphicsItem*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActivePanel", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsItem *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActivePanel(QGraphicsItem*)
            cppSelf->setActivePanel(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setActiveWindow(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::setActiveWindow(QGraphicsWidget*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]), (pyArg)))) {
        overloadId = 0; // setActiveWindow(QGraphicsWidget*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setActiveWindow", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsWidget *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setActiveWindow(QGraphicsWidget*)
            cppSelf->setActiveWindow(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setBackgroundBrush(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::setBackgroundBrush(QBrush)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArg)))) {
        overloadId = 0; // setBackgroundBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackgroundBrush", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBrush cppArg0_local;
        ::QBrush *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackgroundBrush(QBrush)
            cppSelf->setBackgroundBrush(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setBspTreeDepth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::setBspTreeDepth(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setBspTreeDepth(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBspTreeDepth", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBspTreeDepth(int)
            cppSelf->setBspTreeDepth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setFocus(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setFocus", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|O:setFocus", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::setFocus(Qt::FocusReason=)
    if (numArgs == 0) {
        overloadId = 0; // setFocus(Qt::FocusReason)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FocusReason_IDX])))->converter, (pyArgs[0])))) {
        overloadId = 0; // setFocus(Qt::FocusReason)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFocus", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_focusReason = Shiboken::String::createStaticString("focusReason");
            if (PyDict_Contains(kwds, key_focusReason) != 0) {
                value = PyDict_GetItem(kwds, key_focusReason);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_focusReason);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setFocus", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FocusReason_IDX])))->converter, (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "setFocus", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_focusReason);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setFocus", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
            }
        }
        ::Qt::FocusReason cppArg0(Qt::OtherFocusReason);
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFocus(Qt::FocusReason)
            cppSelf->setFocus(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setFocusItem(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setFocusItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setFocusItem", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::setFocusItem(QGraphicsItem*,Qt::FocusReason=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setFocusItem(QGraphicsItem*,Qt::FocusReason)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FocusReason_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // setFocusItem(QGraphicsItem*,Qt::FocusReason)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setFocusItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_focusReason = Shiboken::String::createStaticString("focusReason");
            if (PyDict_Contains(kwds, key_focusReason) != 0) {
                value = PyDict_GetItem(kwds, key_focusReason);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_focusReason);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "setFocusItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_FocusReason_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "setFocusItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_focusReason);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "setFocusItem", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QGraphicsItem *cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::Qt::FocusReason cppArg1(Qt::OtherFocusReason);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFocusItem(QGraphicsItem*,Qt::FocusReason)
            cppSelf->setFocusItem(cppArg0, cppArg1);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArgs[0]);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setFocusOnTouch(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::setFocusOnTouch(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setFocusOnTouch(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFocusOnTouch", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setFocusOnTouch(bool)
            cppSelf->setFocusOnTouch(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setFont(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::setFont(QFont)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFont_IDX]), (pyArg)))) {
        overloadId = 0; // setFont(QFont)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFont", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFont cppArg0_local;
        ::QFont *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setFont(QFont)
            cppSelf->setFont(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setForegroundBrush(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::setForegroundBrush(QBrush)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArg)))) {
        overloadId = 0; // setForegroundBrush(QBrush)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setForegroundBrush", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QBrush cppArg0_local;
        ::QBrush *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setForegroundBrush(QBrush)
            cppSelf->setForegroundBrush(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setItemIndexMethod(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::setItemIndexMethod(QGraphicsScene::ItemIndexMethod)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_ItemIndexMethod_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setItemIndexMethod(QGraphicsScene::ItemIndexMethod)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setItemIndexMethod", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        ::QGraphicsScene::ItemIndexMethod cppArg0{QGraphicsScene::BspTreeIndex};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setItemIndexMethod(QGraphicsScene::ItemIndexMethod)
            cppSelf->setItemIndexMethod(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setMinimumRenderSize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::setMinimumRenderSize(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setMinimumRenderSize(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMinimumRenderSize", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMinimumRenderSize(qreal)
            cppSelf->setMinimumRenderSize(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setPalette(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::setPalette(QPalette)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArg)))) {
        overloadId = 0; // setPalette(QPalette)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPalette", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPalette cppArg0_local;
        ::QPalette *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setPalette(QPalette)
            cppSelf->setPalette(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setSceneRect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "setSceneRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_UnpackTuple(args, "setSceneRect", 1, 4, &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::setSceneRect(QRectF)
    // 1: QGraphicsScene::setSceneRect(qreal,qreal,qreal,qreal)
    if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 1; // setSceneRect(qreal,qreal,qreal,qreal)
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // setSceneRect(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSceneRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setSceneRect(const QRectF &rect)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local;
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setSceneRect(QRectF)
                cppSelf->setSceneRect(*cppArg0);
            }
            break;
        }
        case 1: // setSceneRect(qreal x, qreal y, qreal w, qreal h)
        {
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // setSceneRect(qreal,qreal,qreal,qreal)
                cppSelf->setSceneRect(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setSelectionArea(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setSelectionArea", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:setSelectionArea", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::setSelectionArea(QPainterPath,Qt::ItemSelectionOperation=,Qt::ItemSelectionMode=,const QTransform&=)
    // 1: QGraphicsScene::setSelectionArea(QPainterPath,QTransform)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainterPath_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setSelectionArea(QPainterPath,Qt::ItemSelectionOperation,Qt::ItemSelectionMode,QTransform)
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[1])))) {
            overloadId = 1; // setSelectionArea(QPainterPath,QTransform)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionOperation_IDX])))->converter, (pyArgs[1])))) {
            if (numArgs == 2) {
                overloadId = 0; // setSelectionArea(QPainterPath,Qt::ItemSelectionOperation,Qt::ItemSelectionMode,QTransform)
            } else if (numArgs >= 3
                && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionMode_IDX])))->converter, (pyArgs[2])))) {
                if (numArgs == 3) {
                    overloadId = 0; // setSelectionArea(QPainterPath,Qt::ItemSelectionOperation,Qt::ItemSelectionMode,QTransform)
                } else if (numArgs >= 4
                    && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[3])))) {
                    overloadId = 0; // setSelectionArea(QPainterPath,Qt::ItemSelectionOperation,Qt::ItemSelectionMode,QTransform)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setSelectionArea", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setSelectionArea(const QPainterPath &path, Qt::ItemSelectionOperation selectionOperation, Qt::ItemSelectionMode mode, const QTransform &deviceTransform)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_selectionOperation = Shiboken::String::createStaticString("selectionOperation");
                if (PyDict_Contains(kwds, key_selectionOperation) != 0) {
                    value = PyDict_GetItem(kwds, key_selectionOperation);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_selectionOperation);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setSelectionArea", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionOperation_IDX])))->converter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "setSelectionArea", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_selectionOperation);
                }
                static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
                if (PyDict_Contains(kwds, key_mode) != 0) {
                    value = PyDict_GetItem(kwds, key_mode);
                    if (value != nullptr && pyArgs[2] != nullptr ) {
                        errInfo.reset(key_mode);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setSelectionArea", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[2] = value;
                        if (!(pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_ItemSelectionMode_IDX])))->converter, (pyArgs[2]))))
                            return Shiboken::returnWrongArguments(args, "setSelectionArea", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_mode);
                }
                static PyObject *const key_deviceTransform = Shiboken::String::createStaticString("deviceTransform");
                if (PyDict_Contains(kwds, key_deviceTransform) != 0) {
                    value = PyDict_GetItem(kwds, key_deviceTransform);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_deviceTransform);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "setSelectionArea", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTransform_IDX]), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, "setSelectionArea", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_deviceTransform);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "setSelectionArea", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainterPath cppArg0_local;
            ::QPainterPath *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::Qt::ItemSelectionOperation cppArg1(Qt::ReplaceSelection);
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);
            ::Qt::ItemSelectionMode cppArg2(Qt::IntersectsItemShape);
            if (pythonToCpp[2])
                pythonToCpp[2](pyArgs[2], &cppArg2);
            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QTransform cppArg3_local = QTransform();
            ::QTransform *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3]) {
                if (pythonToCpp[3].isValue())
                    pythonToCpp[3](pyArgs[3], &cppArg3_local);
                else
                    pythonToCpp[3](pyArgs[3], &cppArg3);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // setSelectionArea(QPainterPath,Qt::ItemSelectionOperation,Qt::ItemSelectionMode,QTransform)
                cppSelf->setSelectionArea(*cppArg0, cppArg1, cppArg2, *cppArg3);
            }
            break;
        }
        case 1: // setSelectionArea(const QPainterPath &path, const QTransform &deviceTransform)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setSelectionArea", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainterPath cppArg0_local;
            ::QPainterPath *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QTransform cppArg1_local;
            ::QTransform *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);


            if (Shiboken::Errors::occurred() == nullptr) {
                // setSelectionArea(QPainterPath,QTransform)
                cppSelf->setSelectionArea(*cppArg0, *cppArg1);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setStickyFocus(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::setStickyFocus(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setStickyFocus(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStickyFocus", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStickyFocus(bool)
            cppSelf->setStickyFocus(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_setStyle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::setStyle(QStyle*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), (pyArg)))) {
        overloadId = 0; // setStyle(QStyle*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setStyle", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QStyle *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setStyle(QStyle*)
            cppSelf->setStyle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_stickyFocus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // stickyFocus()const
        bool cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->stickyFocus();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_style(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // style()const
        QStyle * cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->style();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_update(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[4];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 4));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "update", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
    if (numArgs == 2 || numArgs == 3)
        return Shiboken::returnWrongArguments(args, "update", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    if (PyArg_ParseTuple(args, "|OOOO:update", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QGraphicsScene::update(const QRectF&=)
    // 1: QGraphicsScene::update(qreal,qreal,qreal,qreal)
    if (numArgs == 0) {
        overloadId = 0; // update(QRectF)
    } else if (numArgs == 4
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[1])))
        && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
        && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))) {
        overloadId = 1; // update(qreal,qreal,qreal,qreal)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0])))) {
        overloadId = 0; // update(QRectF)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "update", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // update(const QRectF &rect)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_rect = Shiboken::String::createStaticString("rect");
                if (PyDict_Contains(kwds, key_rect) != 0) {
                    value = PyDict_GetItem(kwds, key_rect);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_rect);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "update", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments(args, "update", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_rect);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "update", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRectF cppArg0_local = QRectF();
            ::QRectF *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0]) {
                if (pythonToCpp[0].isValue())
                    pythonToCpp[0](pyArgs[0], &cppArg0_local);
                else
                    pythonToCpp[0](pyArgs[0], &cppArg0);
                }

            if (Shiboken::Errors::occurred() == nullptr) {
                // update(QRectF)
                cppSelf->update(*cppArg0);
            }
            break;
        }
        case 1: // update(qreal x, qreal y, qreal w, qreal h)
        {
            if (kwds != nullptr && PyDict_Size(kwds) > 0) {
                errInfo.reset(kwds);
                Py_INCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "update", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
            }
            qreal cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            qreal cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);

            if (Shiboken::Errors::occurred() == nullptr) {
                // update(qreal,qreal,qreal,qreal)
                cppSelf->update(cppArg0, cppArg1, cppArg2, cppArg3);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_views(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // views()const
        QList<QGraphicsView*> cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->views();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsViewPTR_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QGraphicsSceneFunc_wheelEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QGraphicsScene::wheelEvent(QGraphicsSceneWheelEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneWheelEvent_IDX]), (pyArg)))) {
        overloadId = 0; // wheelEvent(QGraphicsSceneWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "wheelEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QGraphicsSceneWheelEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wheelEvent(QGraphicsSceneWheelEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QGraphicsScene::wheelEvent(cppArg0)
                : cppSelf->wheelEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QGraphicsSceneFunc_width(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // width()const
        qreal cppResult = const_cast<const ::QGraphicsScene *>(cppSelf)->width();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}


static const char *Sbk_QGraphicsScene_PropertyStrings[] = {
    "backgroundBrush::",
    "bspTreeDepth::",
    "focusOnTouch::",
    "font::",
    "foregroundBrush::",
    "itemIndexMethod::",
    "minimumRenderSize::",
    "palette::",
    "sceneRect::",
    "stickyFocus::",
    nullptr // Sentinel
};

static const char *Sbk_QGraphicsScene_EnumFlagInfo[] = {
    "ItemIndexMethod:Enum",
    "SceneLayer:Flag:SceneLayers",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QGraphicsScene_methods[] = {
    {"activePanel", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_activePanel), METH_NOARGS, nullptr},
    {"activeWindow", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_activeWindow), METH_NOARGS, nullptr},
    {"addEllipse", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_addEllipse), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addItem", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_addItem), METH_O, nullptr},
    {"addLine", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_addLine), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addPath", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_addPath), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addPixmap", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_addPixmap), METH_O, nullptr},
    {"addPolygon", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_addPolygon), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addRect", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_addRect), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addSimpleText", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_addSimpleText), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addText", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_addText), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addWidget", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_addWidget), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"advance", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_advance), METH_NOARGS, nullptr},
    {"backgroundBrush", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_backgroundBrush), METH_NOARGS, nullptr},
    {"bspTreeDepth", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_bspTreeDepth), METH_NOARGS, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_clear), METH_NOARGS, nullptr},
    {"clearFocus", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_clearFocus), METH_NOARGS, nullptr},
    {"clearSelection", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_clearSelection), METH_NOARGS, nullptr},
    {"collidingItems", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_collidingItems), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"contextMenuEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_contextMenuEvent), METH_O, nullptr},
    {"createItemGroup", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_createItemGroup), METH_O, nullptr},
    {"destroyItemGroup", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_destroyItemGroup), METH_O, nullptr},
    {"dragEnterEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_dragEnterEvent), METH_O, nullptr},
    {"dragLeaveEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_dragLeaveEvent), METH_O, nullptr},
    {"dragMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_dragMoveEvent), METH_O, nullptr},
    {"drawBackground", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_drawBackground), METH_VARARGS, nullptr},
    {"drawForeground", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_drawForeground), METH_VARARGS, nullptr},
    {"dropEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_dropEvent), METH_O, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_event), METH_O, nullptr},
    {"eventFilter", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_eventFilter), METH_VARARGS, nullptr},
    {"focusInEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_focusInEvent), METH_O, nullptr},
    {"focusItem", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_focusItem), METH_NOARGS, nullptr},
    {"focusNextPrevChild", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_focusNextPrevChild), METH_O, nullptr},
    {"focusOnTouch", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_focusOnTouch), METH_NOARGS, nullptr},
    {"focusOutEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_focusOutEvent), METH_O, nullptr},
    {"font", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_font), METH_NOARGS, nullptr},
    {"foregroundBrush", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_foregroundBrush), METH_NOARGS, nullptr},
    {"hasFocus", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_hasFocus), METH_NOARGS, nullptr},
    {"height", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_height), METH_NOARGS, nullptr},
    {"helpEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_helpEvent), METH_O, nullptr},
    {"inputMethodEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_inputMethodEvent), METH_O, nullptr},
    {"inputMethodQuery", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_inputMethodQuery), METH_O, nullptr},
    {"invalidate", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_invalidate), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"isActive", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_isActive), METH_NOARGS, nullptr},
    {"itemAt", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_itemAt), METH_VARARGS, nullptr},
    {"itemIndexMethod", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_itemIndexMethod), METH_NOARGS, nullptr},
    {"items", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_items), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"itemsBoundingRect", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_itemsBoundingRect), METH_NOARGS, nullptr},
    {"keyPressEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_keyPressEvent), METH_O, nullptr},
    {"keyReleaseEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_keyReleaseEvent), METH_O, nullptr},
    {"minimumRenderSize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_minimumRenderSize), METH_NOARGS, nullptr},
    {"mouseDoubleClickEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_mouseDoubleClickEvent), METH_O, nullptr},
    {"mouseGrabberItem", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_mouseGrabberItem), METH_NOARGS, nullptr},
    {"mouseMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_mouseMoveEvent), METH_O, nullptr},
    {"mousePressEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_mousePressEvent), METH_O, nullptr},
    {"mouseReleaseEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_mouseReleaseEvent), METH_O, nullptr},
    {"palette", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_palette), METH_NOARGS, nullptr},
    {"removeItem", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_removeItem), METH_O, nullptr},
    {"render", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_render), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"sceneRect", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_sceneRect), METH_NOARGS, nullptr},
    {"selectedItems", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_selectedItems), METH_NOARGS, nullptr},
    {"selectionArea", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_selectionArea), METH_NOARGS, nullptr},
    {"sendEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_sendEvent), METH_VARARGS, nullptr},
    {"setActivePanel", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setActivePanel), METH_O, nullptr},
    {"setActiveWindow", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setActiveWindow), METH_O, nullptr},
    {"setBackgroundBrush", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setBackgroundBrush), METH_O, nullptr},
    {"setBspTreeDepth", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setBspTreeDepth), METH_O, nullptr},
    {"setFocus", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setFocus), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setFocusItem", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setFocusItem), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setFocusOnTouch", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setFocusOnTouch), METH_O, nullptr},
    {"setFont", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setFont), METH_O, nullptr},
    {"setForegroundBrush", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setForegroundBrush), METH_O, nullptr},
    {"setItemIndexMethod", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setItemIndexMethod), METH_O, nullptr},
    {"setMinimumRenderSize", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setMinimumRenderSize), METH_O, nullptr},
    {"setPalette", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setPalette), METH_O, nullptr},
    {"setSceneRect", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setSceneRect), METH_VARARGS, nullptr},
    {"setSelectionArea", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setSelectionArea), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setStickyFocus", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setStickyFocus), METH_O, nullptr},
    {"setStyle", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_setStyle), METH_O, nullptr},
    {"stickyFocus", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_stickyFocus), METH_NOARGS, nullptr},
    {"style", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_style), METH_NOARGS, nullptr},
    {"update", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_update), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"views", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_views), METH_NOARGS, nullptr},
    {"wheelEvent", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_wheelEvent), METH_O, nullptr},
    {"width", reinterpret_cast<PyCFunction>(Sbk_QGraphicsSceneFunc_width), METH_NOARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QGraphicsScene_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QGraphicsScene *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QGraphicsSceneWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QGraphicsScene_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QGraphicsScene_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QGraphicsScene_Type = nullptr;
static PyTypeObject *Sbk_QGraphicsScene_TypeF(void)
{
    return _Sbk_QGraphicsScene_Type;
}

static PyType_Slot Sbk_QGraphicsScene_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QGraphicsScene_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QGraphicsScene_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QGraphicsScene_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QGraphicsScene_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QGraphicsScene_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QGraphicsScene_spec = {
    "2:PySide6.QtWidgets.QGraphicsScene",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QGraphicsScene_slots
};

} //extern "C"

static void *Sbk_QGraphicsScene_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QGraphicsScene *>(reinterpret_cast< ::QObject *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QGraphicsScene_ItemIndexMethod(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGraphicsScene::ItemIndexMethod>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGraphicsScene::ItemIndexMethod *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGraphicsScene_ItemIndexMethod_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_ItemIndexMethod_IDX])))
        return Enum_PythonToCpp_QGraphicsScene_ItemIndexMethod;
    return {};
}

static PyObject *QGraphicsScene_ItemIndexMethod_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGraphicsScene::ItemIndexMethod>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGraphicsScene::ItemIndexMethod *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_ItemIndexMethod_IDX]), castCppIn);

}

static void Enum_PythonToCpp_QGraphicsScene_SceneLayer(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QGraphicsScene::SceneLayer>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QGraphicsScene::SceneLayer *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QGraphicsScene_SceneLayer_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_SceneLayer_IDX])))
        return Enum_PythonToCpp_QGraphicsScene_SceneLayer;
    return {};
}

static PyObject *QGraphicsScene_SceneLayer_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QGraphicsScene::SceneLayer>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QGraphicsScene::SceneLayer *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_SceneLayer_IDX]), castCppIn);

}

static void Flag_PythonToCpp_QGraphicsScene_SceneLayer(PyObject *pyIn, void *cppOut)
{
    const auto value = QFlags<::QGraphicsScene::SceneLayer>::fromInt(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<QFlags<::QGraphicsScene::SceneLayer> *>(cppOut) = value;

}

static PyObject *QGraphicsScene_SceneLayer_CppToPython_Flag(const void *cppIn)
{
    const auto flags = *reinterpret_cast<const QFlags<::QGraphicsScene::SceneLayer> *>(cppIn);
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_SceneLayer_IDX]), flags.toInt());

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QGraphicsScene_PythonToCpp_QGraphicsScene_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QGraphicsScene_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QGraphicsScene_PythonToCpp_QGraphicsScene_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QGraphicsScene_TypeF()))
        return QGraphicsScene_PythonToCpp_QGraphicsScene_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QGraphicsScene_PTR_CppToPython_QGraphicsScene(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QGraphicsScene *>(const_cast<void *>(cppIn)), Sbk_QGraphicsScene_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QGraphicsScene_SignatureStrings[] = {
    "2:PySide6.QtWidgets.QGraphicsScene(self,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,backgroundBrush:QBrush=None,foregroundBrush:QBrush=None,itemIndexMethod:QGraphicsScene.ItemIndexMethod=None,sceneRect:QRectF=None,bspTreeDepth:int=None,palette:QPalette=None,font:QFont=None,stickyFocus:bool=None,minimumRenderSize:qreal=None,focusOnTouch:bool=None)",
    "1:PySide6.QtWidgets.QGraphicsScene(self,sceneRect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,backgroundBrush:QBrush=None,foregroundBrush:QBrush=None,itemIndexMethod:QGraphicsScene.ItemIndexMethod=None,sceneRect:QRectF=None,bspTreeDepth:int=None,palette:QPalette=None,font:QFont=None,stickyFocus:bool=None,minimumRenderSize:qreal=None,focusOnTouch:bool=None)",
    "0:PySide6.QtWidgets.QGraphicsScene(self,x:qreal,y:qreal,width:qreal,height:qreal,parent:PySide6.QtCore.QObject=nullptr,*:KeywordOnly=None,backgroundBrush:QBrush=None,foregroundBrush:QBrush=None,itemIndexMethod:QGraphicsScene.ItemIndexMethod=None,sceneRect:QRectF=None,bspTreeDepth:int=None,palette:QPalette=None,font:QFont=None,stickyFocus:bool=None,minimumRenderSize:qreal=None,focusOnTouch:bool=None)",
    "PySide6.QtWidgets.QGraphicsScene.activePanel(self)->PySide6.QtWidgets.QGraphicsItem",
    "PySide6.QtWidgets.QGraphicsScene.activeWindow(self)->PySide6.QtWidgets.QGraphicsWidget",
    "1:PySide6.QtWidgets.QGraphicsScene.addEllipse(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor]=QPen(),brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=QBrush())->PySide6.QtWidgets.QGraphicsEllipseItem",
    "0:PySide6.QtWidgets.QGraphicsScene.addEllipse(self,x:qreal,y:qreal,w:qreal,h:qreal,pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor]=QPen(),brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=QBrush())->PySide6.QtWidgets.QGraphicsEllipseItem",
    "PySide6.QtWidgets.QGraphicsScene.addItem(self,item:PySide6.QtWidgets.QGraphicsItem)",
    "1:PySide6.QtWidgets.QGraphicsScene.addLine(self,line:typing.Union[PySide6.QtCore.QLineF, PySide6.QtCore.QLine],pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor]=QPen())->PySide6.QtWidgets.QGraphicsLineItem",
    "0:PySide6.QtWidgets.QGraphicsScene.addLine(self,x1:qreal,y1:qreal,x2:qreal,y2:qreal,pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor]=QPen())->PySide6.QtWidgets.QGraphicsLineItem",
    "PySide6.QtWidgets.QGraphicsScene.addPath(self,path:PySide6.QtGui.QPainterPath,pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor]=QPen(),brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=QBrush())->PySide6.QtWidgets.QGraphicsPathItem",
    "PySide6.QtWidgets.QGraphicsScene.addPixmap(self,pixmap:typing.Union[PySide6.QtGui.QPixmap, PySide6.QtGui.QImage])->PySide6.QtWidgets.QGraphicsPixmapItem",
    "PySide6.QtWidgets.QGraphicsScene.addPolygon(self,polygon:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF],pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor]=QPen(),brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=QBrush())->PySide6.QtWidgets.QGraphicsPolygonItem",
    "1:PySide6.QtWidgets.QGraphicsScene.addRect(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor]=QPen(),brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=QBrush())->PySide6.QtWidgets.QGraphicsRectItem",
    "0:PySide6.QtWidgets.QGraphicsScene.addRect(self,x:qreal,y:qreal,w:qreal,h:qreal,pen:typing.Union[PySide6.QtGui.QPen, PySide6.QtCore.Qt.PenStyle, PySide6.QtGui.QColor]=QPen(),brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=QBrush())->PySide6.QtWidgets.QGraphicsRectItem",
    "PySide6.QtWidgets.QGraphicsScene.addSimpleText(self,text:QString,font:typing.Union[PySide6.QtGui.QFont, QString, QStringList]=QFont())->PySide6.QtWidgets.QGraphicsSimpleTextItem",
    "PySide6.QtWidgets.QGraphicsScene.addText(self,text:QString,font:typing.Union[PySide6.QtGui.QFont, QString, QStringList]=QFont())->PySide6.QtWidgets.QGraphicsTextItem",
    "PySide6.QtWidgets.QGraphicsScene.addWidget(self,widget:PySide6.QtWidgets.QWidget,wFlags:PySide6.QtCore.Qt.WindowType=Qt.WindowFlags())->PySide6.QtWidgets.QGraphicsProxyWidget",
    "PySide6.QtWidgets.QGraphicsScene.advance(self)",
    "PySide6.QtWidgets.QGraphicsScene.backgroundBrush(self)->PySide6.QtGui.QBrush",
    "PySide6.QtWidgets.QGraphicsScene.bspTreeDepth(self)->int",
    "PySide6.QtWidgets.QGraphicsScene.clear(self)",
    "PySide6.QtWidgets.QGraphicsScene.clearFocus(self)",
    "PySide6.QtWidgets.QGraphicsScene.clearSelection(self)",
    "PySide6.QtWidgets.QGraphicsScene.collidingItems(self,item:PySide6.QtWidgets.QGraphicsItem,mode:PySide6.QtCore.Qt.ItemSelectionMode=Qt.IntersectsItemShape)->QList[PySide6.QtWidgets.QGraphicsItem]",
    "PySide6.QtWidgets.QGraphicsScene.contextMenuEvent(self,event:PySide6.QtWidgets.QGraphicsSceneContextMenuEvent)",
    "PySide6.QtWidgets.QGraphicsScene.createItemGroup(self,items:QList[PySide6.QtWidgets.QGraphicsItem])->PySide6.QtWidgets.QGraphicsItemGroup",
    "PySide6.QtWidgets.QGraphicsScene.destroyItemGroup(self,group:PySide6.QtWidgets.QGraphicsItemGroup)",
    "PySide6.QtWidgets.QGraphicsScene.dragEnterEvent(self,event:PySide6.QtWidgets.QGraphicsSceneDragDropEvent)",
    "PySide6.QtWidgets.QGraphicsScene.dragLeaveEvent(self,event:PySide6.QtWidgets.QGraphicsSceneDragDropEvent)",
    "PySide6.QtWidgets.QGraphicsScene.dragMoveEvent(self,event:PySide6.QtWidgets.QGraphicsSceneDragDropEvent)",
    "PySide6.QtWidgets.QGraphicsScene.drawBackground(self,painter:PySide6.QtGui.QPainter,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtWidgets.QGraphicsScene.drawForeground(self,painter:PySide6.QtGui.QPainter,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "PySide6.QtWidgets.QGraphicsScene.dropEvent(self,event:PySide6.QtWidgets.QGraphicsSceneDragDropEvent)",
    "PySide6.QtWidgets.QGraphicsScene.event(self,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QGraphicsScene.eventFilter(self,watched:PySide6.QtCore.QObject,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QGraphicsScene.focusInEvent(self,event:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtWidgets.QGraphicsScene.focusItem(self)->PySide6.QtWidgets.QGraphicsItem",
    "PySide6.QtWidgets.QGraphicsScene.focusNextPrevChild(self,next:bool)->bool",
    "PySide6.QtWidgets.QGraphicsScene.focusOnTouch(self)->bool",
    "PySide6.QtWidgets.QGraphicsScene.focusOutEvent(self,event:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtWidgets.QGraphicsScene.font(self)->PySide6.QtGui.QFont",
    "PySide6.QtWidgets.QGraphicsScene.foregroundBrush(self)->PySide6.QtGui.QBrush",
    "PySide6.QtWidgets.QGraphicsScene.hasFocus(self)->bool",
    "PySide6.QtWidgets.QGraphicsScene.height(self)->qreal",
    "PySide6.QtWidgets.QGraphicsScene.helpEvent(self,event:PySide6.QtWidgets.QGraphicsSceneHelpEvent)",
    "PySide6.QtWidgets.QGraphicsScene.inputMethodEvent(self,event:PySide6.QtGui.QInputMethodEvent)",
    "PySide6.QtWidgets.QGraphicsScene.inputMethodQuery(self,query:PySide6.QtCore.Qt.InputMethodQuery)->QVariant",
    "1:PySide6.QtWidgets.QGraphicsScene.invalidate(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect]=QRectF(),layers:PySide6.QtWidgets.QGraphicsScene.SceneLayer=QGraphicsScene.SceneLayer.AllLayers)",
    "0:PySide6.QtWidgets.QGraphicsScene.invalidate(self,x:qreal,y:qreal,w:qreal,h:qreal,layers:PySide6.QtWidgets.QGraphicsScene.SceneLayer=QGraphicsScene.SceneLayer.AllLayers)",
    "PySide6.QtWidgets.QGraphicsScene.isActive(self)->bool",
    "1:PySide6.QtWidgets.QGraphicsScene.itemAt(self,pos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],deviceTransform:PySide6.QtGui.QTransform)->PySide6.QtWidgets.QGraphicsItem",
    "0:PySide6.QtWidgets.QGraphicsScene.itemAt(self,x:qreal,y:qreal,deviceTransform:PySide6.QtGui.QTransform)->PySide6.QtWidgets.QGraphicsItem",
    "PySide6.QtWidgets.QGraphicsScene.itemIndexMethod(self)->PySide6.QtWidgets.QGraphicsScene.ItemIndexMethod",
    "5:PySide6.QtWidgets.QGraphicsScene.items(self,order:PySide6.QtCore.Qt.SortOrder=Qt.DescendingOrder)->QList[PySide6.QtWidgets.QGraphicsItem]",
    "4:PySide6.QtWidgets.QGraphicsScene.items(self,path:PySide6.QtGui.QPainterPath,mode:PySide6.QtCore.Qt.ItemSelectionMode=Qt.IntersectsItemShape,order:PySide6.QtCore.Qt.SortOrder=Qt.DescendingOrder,deviceTransform:PySide6.QtGui.QTransform=QTransform())->QList[PySide6.QtWidgets.QGraphicsItem]",
    "3:PySide6.QtWidgets.QGraphicsScene.items(self,pos:typing.Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element],mode:PySide6.QtCore.Qt.ItemSelectionMode=Qt.IntersectsItemShape,order:PySide6.QtCore.Qt.SortOrder=Qt.DescendingOrder,deviceTransform:PySide6.QtGui.QTransform=QTransform())->QList[PySide6.QtWidgets.QGraphicsItem]",
    "2:PySide6.QtWidgets.QGraphicsScene.items(self,polygon:typing.Union[PySide6.QtGui.QPolygonF, QList[PySide6.QtCore.QPointF], PySide6.QtGui.QPolygon, PySide6.QtCore.QRectF],mode:PySide6.QtCore.Qt.ItemSelectionMode=Qt.IntersectsItemShape,order:PySide6.QtCore.Qt.SortOrder=Qt.DescendingOrder,deviceTransform:PySide6.QtGui.QTransform=QTransform())->QList[PySide6.QtWidgets.QGraphicsItem]",
    "1:PySide6.QtWidgets.QGraphicsScene.items(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect],mode:PySide6.QtCore.Qt.ItemSelectionMode=Qt.IntersectsItemShape,order:PySide6.QtCore.Qt.SortOrder=Qt.DescendingOrder,deviceTransform:PySide6.QtGui.QTransform=QTransform())->QList[PySide6.QtWidgets.QGraphicsItem]",
    "0:PySide6.QtWidgets.QGraphicsScene.items(self,x:qreal,y:qreal,w:qreal,h:qreal,mode:PySide6.QtCore.Qt.ItemSelectionMode,order:PySide6.QtCore.Qt.SortOrder,deviceTransform:PySide6.QtGui.QTransform=QTransform())->QList[PySide6.QtWidgets.QGraphicsItem]",
    "PySide6.QtWidgets.QGraphicsScene.itemsBoundingRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtWidgets.QGraphicsScene.keyPressEvent(self,event:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtWidgets.QGraphicsScene.keyReleaseEvent(self,event:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtWidgets.QGraphicsScene.minimumRenderSize(self)->qreal",
    "PySide6.QtWidgets.QGraphicsScene.mouseDoubleClickEvent(self,event:PySide6.QtWidgets.QGraphicsSceneMouseEvent)",
    "PySide6.QtWidgets.QGraphicsScene.mouseGrabberItem(self)->PySide6.QtWidgets.QGraphicsItem",
    "PySide6.QtWidgets.QGraphicsScene.mouseMoveEvent(self,event:PySide6.QtWidgets.QGraphicsSceneMouseEvent)",
    "PySide6.QtWidgets.QGraphicsScene.mousePressEvent(self,event:PySide6.QtWidgets.QGraphicsSceneMouseEvent)",
    "PySide6.QtWidgets.QGraphicsScene.mouseReleaseEvent(self,event:PySide6.QtWidgets.QGraphicsSceneMouseEvent)",
    "PySide6.QtWidgets.QGraphicsScene.palette(self)->PySide6.QtGui.QPalette",
    "PySide6.QtWidgets.QGraphicsScene.removeItem(self,item:PySide6.QtWidgets.QGraphicsItem)",
    "PySide6.QtWidgets.QGraphicsScene.render(self,painter:PySide6.QtGui.QPainter,target:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect]=QRectF(),source:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect]=QRectF(),aspectRatioMode:PySide6.QtCore.Qt.AspectRatioMode=Qt.KeepAspectRatio)",
    "PySide6.QtWidgets.QGraphicsScene.sceneRect(self)->PySide6.QtCore.QRectF",
    "PySide6.QtWidgets.QGraphicsScene.selectedItems(self)->QList[PySide6.QtWidgets.QGraphicsItem]",
    "PySide6.QtWidgets.QGraphicsScene.selectionArea(self)->PySide6.QtGui.QPainterPath",
    "PySide6.QtWidgets.QGraphicsScene.sendEvent(self,item:PySide6.QtWidgets.QGraphicsItem,event:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QGraphicsScene.setActivePanel(self,item:PySide6.QtWidgets.QGraphicsItem)",
    "PySide6.QtWidgets.QGraphicsScene.setActiveWindow(self,widget:PySide6.QtWidgets.QGraphicsWidget)",
    "PySide6.QtWidgets.QGraphicsScene.setBackgroundBrush(self,brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "PySide6.QtWidgets.QGraphicsScene.setBspTreeDepth(self,depth:int)",
    "PySide6.QtWidgets.QGraphicsScene.setFocus(self,focusReason:PySide6.QtCore.Qt.FocusReason=Qt.OtherFocusReason)",
    "PySide6.QtWidgets.QGraphicsScene.setFocusItem(self,item:PySide6.QtWidgets.QGraphicsItem,focusReason:PySide6.QtCore.Qt.FocusReason=Qt.OtherFocusReason)",
    "PySide6.QtWidgets.QGraphicsScene.setFocusOnTouch(self,enabled:bool)",
    "PySide6.QtWidgets.QGraphicsScene.setFont(self,font:typing.Union[PySide6.QtGui.QFont, QString, QStringList])",
    "PySide6.QtWidgets.QGraphicsScene.setForegroundBrush(self,brush:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap])",
    "PySide6.QtWidgets.QGraphicsScene.setItemIndexMethod(self,method:PySide6.QtWidgets.QGraphicsScene.ItemIndexMethod)",
    "PySide6.QtWidgets.QGraphicsScene.setMinimumRenderSize(self,minSize:qreal)",
    "PySide6.QtWidgets.QGraphicsScene.setPalette(self,palette:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor])",
    "1:PySide6.QtWidgets.QGraphicsScene.setSceneRect(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect])",
    "0:PySide6.QtWidgets.QGraphicsScene.setSceneRect(self,x:qreal,y:qreal,w:qreal,h:qreal)",
    "1:PySide6.QtWidgets.QGraphicsScene.setSelectionArea(self,path:PySide6.QtGui.QPainterPath,selectionOperation:PySide6.QtCore.Qt.ItemSelectionOperation=Qt.ReplaceSelection,mode:PySide6.QtCore.Qt.ItemSelectionMode=Qt.IntersectsItemShape,deviceTransform:PySide6.QtGui.QTransform=QTransform())",
    "0:PySide6.QtWidgets.QGraphicsScene.setSelectionArea(self,path:PySide6.QtGui.QPainterPath,deviceTransform:PySide6.QtGui.QTransform)",
    "PySide6.QtWidgets.QGraphicsScene.setStickyFocus(self,enabled:bool)",
    "PySide6.QtWidgets.QGraphicsScene.setStyle(self,style:PySide6.QtWidgets.QStyle)",
    "PySide6.QtWidgets.QGraphicsScene.stickyFocus(self)->bool",
    "PySide6.QtWidgets.QGraphicsScene.style(self)->PySide6.QtWidgets.QStyle",
    "1:PySide6.QtWidgets.QGraphicsScene.update(self,rect:typing.Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect]=QRectF())",
    "0:PySide6.QtWidgets.QGraphicsScene.update(self,x:qreal,y:qreal,w:qreal,h:qreal)",
    "PySide6.QtWidgets.QGraphicsScene.views(self)->QList[PySide6.QtWidgets.QGraphicsView]",
    "PySide6.QtWidgets.QGraphicsScene.wheelEvent(self,event:PySide6.QtWidgets.QGraphicsSceneWheelEvent)",
    "PySide6.QtWidgets.QGraphicsScene.width(self)->qreal",
    nullptr}; // Sentinel
#else
static constexpr size_t QGraphicsScene_SignatureByteSize = 1788;
static constexpr uint8_t QGraphicsScene_SignatureBytes[1788] = {
    0x78, 0xda, 0xed, 0x1b, 0xc9, 0x72, 0xdb, 0x36, 0xf4, 0x9e, 0xaf, 0xe8, 0x31, 0xee, 0x28, 0x1a,
    0xc7, 0x5d, 0x0e, 0x9a, 0x71, 0x66, 0xbc, 0xc9, 0xd5, 0x24, 0x8e, 0x25, 0xcb, 0x4d, 0x0e, 0x1d,
    0x1f, 0x20, 0xf2, 0x45, 0x42, 0x0d, 0x01, 0x0c, 0x00, 0x4a, 0x62, 0xbf, 0xbe, 0x58, 0x48, 0x6a,
    0x21, 0x25, 0x3e, 0x5a, 0xb4, 0x93, 0xa6, 0xba, 0xd8, 0x10, 0x96, 0x87, 0xb7, 0xe1, 0xe1, 0x2d,
    0xe0, 0x49, 0xa7, 0x9f, 0x0c, 0x69, 0x08, 0xbf, 0xb7, 0x07, 0xfa, 0x33, 0x0d, 0xc7, 0xa0, 0x55,
    0x7b, 0x70, 0x2d, 0x49, 0x34, 0xa1, 0x81, 0x1a, 0x06, 0xc0, 0xe1, 0xb5, 0x02, 0xf6, 0xa5, 0x15,
    0x11, 0x09, 0x5c, 0xaf, 0x4c, 0xbe, 0x10, 0x12, 0xda, 0x83, 0xdb, 0xd1, 0xdf, 0x10, 0xe8, 0x53,
    0x1e, 0x33, 0x16, 0x69, 0xd9, 0xfa, 0xb9, 0xf3, 0x1e, 0x92, 0xb9, 0x90, 0xe1, 0x2d, 0x67, 0xc9,
    0xe9, 0x47, 0xc1, 0xa1, 0x35, 0x22, 0xc1, 0xe3, 0x58, 0x8a, 0x98, 0x87, 0xe7, 0x32, 0x56, 0x93,
    0xce, 0xc0, 0xfd, 0xf3, 0x63, 0x5f, 0x0c, 0x8c, 0x6d, 0x63, 0x54, 0xc3, 0xb4, 0xc7, 0x43, 0x58,
    0xdc, 0x80, 0x9e, 0x88, 0xb0, 0xb3, 0x8e, 0x54, 0xbb, 0xb7, 0x3e, 0xec, 0xd7, 0x28, 0x3b, 0x74,
    0x67, 0x10, 0xea, 0x0c, 0xec, 0xdf, 0x6e, 0x8a, 0x81, 0x8a, 0xee, 0x25, 0xc0, 0x25, 0x44, 0x7a,
    0xd2, 0xa1, 0x5c, 0xfb, 0xde, 0x88, 0x30, 0xd0, 0x1a, 0x3a, 0x83, 0xbe, 0x6f, 0x64, 0x18, 0x19,
    0x22, 0x07, 0x5d, 0x91, 0xcd, 0x52, 0x9a, 0x06, 0x8f, 0x49, 0x57, 0x04, 0xb1, 0xea, 0x8c, 0x84,
    0x60, 0xbe, 0x77, 0x4a, 0x39, 0x9d, 0xc6, 0xd3, 0x3b, 0x30, 0x08, 0xc8, 0x21, 0xfd, 0x07, 0x3a,
    0x5f, 0x25, 0x10, 0x96, 0x81, 0x30, 0x93, 0x6f, 0xf9, 0xbd, 0x88, 0x83, 0xc9, 0x72, 0xcd, 0xd1,
    0xab, 0xb7, 0x48, 0x4e, 0x2f, 0x89, 0xd0, 0x49, 0x44, 0xf9, 0xb8, 0xfd, 0x27, 0xa7, 0x82, 0xff,
    0xb5, 0xc9, 0x79, 0x47, 0x60, 0xeb, 0xa7, 0xb2, 0xee, 0x87, 0x83, 0xb4, 0xf6, 0x96, 0xd6, 0x31,
    0x52, 0x5a, 0x0b, 0x0f, 0xac, 0x95, 0xa4, 0xff, 0xe7, 0x34, 0x34, 0x78, 0xfb, 0xf6, 0x04, 0xe8,
    0x78, 0xa2, 0xd3, 0x1f, 0x07, 0x91, 0xec, 0x2b, 0x92, 0x2a, 0x81, 0xb4, 0x49, 0xa0, 0xe9, 0x0c,
    0xfa, 0x84, 0x03, 0x73, 0xc2, 0x39, 0x7a, 0xf3, 0x6e, 0xc7, 0x1a, 0xcb, 0x00, 0x2c, 0xcc, 0xcf,
    0x94, 0x87, 0x62, 0x8e, 0x00, 0xea, 0x3b, 0x10, 0x67, 0xbd, 0x4d, 0xc2, 0xf0, 0x8a, 0x31, 0x1a,
    0xa9, 0x54, 0x91, 0xe4, 0x9e, 0x27, 0x1e, 0xf8, 0xb6, 0xd5, 0xd7, 0x31, 0x6d, 0x0f, 0xfa, 0xc0,
    0x8b, 0x4b, 0x75, 0xdb, 0x74, 0x0f, 0x75, 0xc2, 0x60, 0x75, 0xcc, 0xcd, 0xbf, 0x10, 0x4c, 0xc8,
    0x87, 0x53, 0xbb, 0xee, 0xf5, 0x51, 0x6b, 0xe4, 0xb4, 0x6b, 0x17, 0x7c, 0xa7, 0x78, 0x65, 0x3b,
    0xb8, 0x81, 0xc2, 0x1e, 0xd9, 0xe8, 0x35, 0x13, 0x23, 0xc2, 0xdc, 0x66, 0xe5, 0x28, 0x14, 0x7a,
    0x0d, 0x17, 0x43, 0x6a, 0x4e, 0x52, 0x61, 0xa0, 0x37, 0x25, 0xe3, 0x22, 0x1d, 0x7d, 0xba, 0x98,
    0x92, 0xc8, 0x10, 0xe2, 0xf0, 0x78, 0x7d, 0xb4, 0x5b, 0x7c, 0xa9, 0x44, 0x9c, 0x6a, 0x1c, 0xd7,
    0x97, 0x61, 0xc1, 0x18, 0x64, 0x86, 0x20, 0xb3, 0x01, 0x07, 0x21, 0x35, 0x2c, 0x24, 0x8c, 0x88,
    0xec, 0x44, 0x2f, 0x1f, 0x6b, 0x12, 0x3b, 0x15, 0x26, 0xe1, 0x08, 0x79, 0x78, 0x3f, 0xd0, 0xec,
    0x0a, 0x60, 0xa6, 0xb5, 0xfb, 0xe4, 0xda, 0xb9, 0x25, 0x27, 0xd7, 0x76, 0x3f, 0xf3, 0xc9, 0xdd,
    0xcd, 0x49, 0x8b, 0x40, 0x0d, 0x5d, 0x5f, 0x92, 0xbc, 0x78, 0x9b, 0x69, 0x7a, 0xd6, 0x58, 0x9c,
    0x64, 0x3d, 0x27, 0x2f, 0xa1, 0xec, 0x48, 0xba, 0x30, 0x54, 0xf5, 0x89, 0x9e, 0x64, 0x3e, 0xae,
    0xb9, 0xdf, 0x36, 0xb1, 0x24, 0xe6, 0xc2, 0x03, 0x69, 0x27, 0x1d, 0x8e, 0x6f, 0x23, 0xc7, 0xd7,
    0xb2, 0x12, 0x2f, 0x1c, 0x07, 0x3a, 0x15, 0x8f, 0x6b, 0xef, 0x96, 0x80, 0x9b, 0x52, 0x8e, 0xf6,
    0x43, 0x05, 0x5a, 0x6e, 0x29, 0x1e, 0x31, 0xc1, 0x92, 0xb1, 0xe0, 0x29, 0x66, 0xfe, 0xc7, 0x6e,
    0xd4, 0xfc, 0x1c, 0x63, 0x06, 0xcc, 0xb9, 0x57, 0xba, 0x60, 0x23, 0xfa, 0xc2, 0x28, 0x5a, 0xf7,
    0xa1, 0xc8, 0x5c, 0xbf, 0xae, 0xfc, 0xde, 0xef, 0x1e, 0x2e, 0xfe, 0x86, 0x94, 0xd2, 0x73, 0xd9,
    0x89, 0x1f, 0x67, 0xff, 0x2d, 0xfb, 0x0f, 0x9e, 0xdb, 0x77, 0x23, 0x40, 0xcb, 0xcb, 0x1a, 0x57,
    0xd9, 0x52, 0x7a, 0x07, 0x9f, 0xed, 0x45, 0xc5, 0x83, 0x11, 0xce, 0x90, 0x4e, 0x23, 0x06, 0xf7,
    0xb0, 0x48, 0x45, 0xa4, 0x4d, 0xab, 0x33, 0x18, 0x6a, 0x69, 0x98, 0xe4, 0x03, 0xcc, 0x5d, 0x0c,
    0xb3, 0xb1, 0xa7, 0x31, 0xb2, 0xe9, 0xf4, 0xac, 0x61, 0x6d, 0xae, 0x41, 0xd6, 0x0e, 0x56, 0xe1,
    0xba, 0xdc, 0x1e, 0x8d, 0xf1, 0x37, 0xc3, 0xb5, 0x16, 0x96, 0x7e, 0xc4, 0xe3, 0x39, 0x77, 0xed,
    0xb2, 0xb3, 0xe2, 0x1b, 0xad, 0x79, 0x97, 0x91, 0xb1, 0xea, 0x14, 0x35, 0xcb, 0xc7, 0xc2, 0xf7,
    0x49, 0x04, 0xa7, 0xf9, 0x2f, 0x37, 0xb7, 0xd2, 0xc6, 0x4a, 0xb1, 0x48, 0xd2, 0x00, 0x19, 0x81,
    0xee, 0x8c, 0xf0, 0xc0, 0xbb, 0x9b, 0x88, 0xd0, 0x7f, 0x23, 0x49, 0x52, 0x8c, 0xd4, 0x97, 0x67,
    0x09, 0x01, 0x6c, 0x25, 0xdf, 0x91, 0x41, 0x32, 0x97, 0x73, 0xf5, 0xc2, 0x80, 0x01, 0x91, 0x58,
    0x94, 0xdd, 0x64, 0x97, 0x18, 0xa9, 0xb5, 0x62, 0x08, 0xcc, 0x9c, 0x25, 0x9a, 0xba, 0x1e, 0x98,
    0x55, 0xc2, 0xc4, 0x4b, 0xa1, 0x51, 0x2b, 0xab, 0x27, 0x0a, 0x1f, 0x08, 0xb5, 0xa6, 0x22, 0x84,
    0x12, 0xf9, 0xdb, 0xb1, 0x1c, 0x89, 0x1b, 0x33, 0xc7, 0xaa, 0x41, 0xcf, 0x3a, 0xc9, 0xca, 0xf4,
    0xb9, 0xa5, 0xc3, 0x09, 0x89, 0xc0, 0x30, 0x6d, 0xd3, 0xd3, 0x29, 0xdd, 0xe7, 0x01, 0x43, 0x02,
    0xb7, 0xe7, 0xea, 0x06, 0x78, 0x7c, 0x35, 0x33, 0x26, 0xca, 0x13, 0x01, 0xb3, 0xf5, 0x84, 0x5a,
    0xf9, 0xe2, 0x8b, 0x8d, 0xb5, 0x18, 0x8e, 0x19, 0xc3, 0xaf, 0x5d, 0x00, 0x71, 0x6d, 0x54, 0x2a,
    0x5a, 0xb2, 0x4c, 0x75, 0x70, 0x14, 0x55, 0x27, 0x9e, 0x1c, 0xe0, 0x6a, 0x4c, 0x42, 0x50, 0x5a,
    0x8a, 0x64, 0x03, 0x15, 0xab, 0xe8, 0x51, 0x07, 0xb3, 0x03, 0x82, 0xd8, 0x50, 0x92, 0xf1, 0x95,
    0x95, 0x5e, 0x6d, 0xce, 0x5e, 0x9a, 0x95, 0x97, 0x52, 0x44, 0x58, 0xb6, 0xda, 0x9d, 0x3e, 0x00,
    0x99, 0xc1, 0x8b, 0xec, 0x74, 0x23, 0x5e, 0x66, 0xa3, 0xf9, 0x79, 0x6e, 0x7a, 0xb2, 0x28, 0xd2,
    0x45, 0x8c, 0x5b, 0x02, 0xc9, 0x3d, 0xbd, 0x45, 0x24, 0x4e, 0xdd, 0x3c, 0x2f, 0xfc, 0xbd, 0xe0,
    0x94, 0xf2, 0xf4, 0x39, 0x85, 0x01, 0xdb, 0x37, 0xf0, 0xd8, 0x7a, 0x40, 0x6f, 0xde, 0xd9, 0x9c,
    0x32, 0x12, 0x5c, 0x97, 0x32, 0xc3, 0xa0, 0xf4, 0xca, 0x24, 0x3a, 0x98, 0x40, 0xb8, 0x25, 0x85,
    0xdf, 0xc8, 0x9e, 0x2e, 0xf5, 0xdd, 0xe3, 0x3b, 0x58, 0x95, 0xba, 0x0d, 0x66, 0x1a, 0x96, 0x2d,
    0x1e, 0x66, 0x96, 0x03, 0x6b, 0x22, 0x27, 0xee, 0x20, 0x7e, 0x34, 0x46, 0xb5, 0x2f, 0x61, 0x76,
    0x31, 0xa1, 0x2c, 0xd5, 0x32, 0x6e, 0x7d, 0x1f, 0x4b, 0x68, 0x3d, 0x7a, 0xd3, 0x54, 0x7f, 0x86,
    0x5e, 0x9d, 0x95, 0xb1, 0x6e, 0x98, 0x55, 0x29, 0xac, 0xa2, 0xeb, 0x60, 0x9d, 0x31, 0x0c, 0x80,
    0xb5, 0x7a, 0xcc, 0x7e, 0x6e, 0xc8, 0x84, 0xa8, 0x15, 0xf7, 0x00, 0xcb, 0x18, 0x5f, 0x74, 0xca,
    0xd6, 0xb8, 0x18, 0x06, 0xb3, 0x88, 0xd5, 0x3f, 0x9f, 0x7f, 0x64, 0x8b, 0x10, 0x9c, 0xa5, 0x3c,
    0x8a, 0xb5, 0xaf, 0x34, 0x55, 0x49, 0xac, 0xb7, 0x31, 0xb5, 0x1e, 0xf4, 0x41, 0x0c, 0x32, 0xf1,
    0xd0, 0xbf, 0xda, 0x66, 0x99, 0x03, 0xb3, 0x31, 0xdb, 0x3a, 0x2a, 0x9f, 0x88, 0xa4, 0x84, 0xa3,
    0x0a, 0x37, 0x94, 0xcf, 0x88, 0x71, 0xa8, 0x8c, 0x87, 0xd0, 0x44, 0xf8, 0x7f, 0xea, 0x47, 0x4d,
    0x28, 0xc8, 0x48, 0x62, 0x5c, 0xa8, 0xea, 0xfd, 0xdd, 0xdf, 0x0f, 0x76, 0xf2, 0xe9, 0xd6, 0x91,
    0xf6, 0x19, 0x63, 0xae, 0xa1, 0x30, 0x95, 0xcc, 0x02, 0x49, 0x55, 0x31, 0xf1, 0x73, 0xa1, 0x5a,
    0x8d, 0xa8, 0x3a, 0x73, 0xf5, 0xb8, 0xb5, 0x23, 0x81, 0x91, 0x99, 0xb1, 0x6b, 0x67, 0x3a, 0x4b,
    0xd6, 0xa9, 0xdd, 0xe2, 0xf2, 0x99, 0xb8, 0xa2, 0xbc, 0x5c, 0x7f, 0x31, 0x0e, 0x5e, 0x26, 0x88,
    0xdb, 0x57, 0x0c, 0xa6, 0x46, 0x63, 0x1f, 0x5a, 0x21, 0xcc, 0x68, 0x00, 0xf7, 0x92, 0x70, 0x65,
    0x4c, 0xc2, 0x74, 0x53, 0xc5, 0xf3, 0x01, 0x84, 0x35, 0x3e, 0xae, 0x47, 0xdd, 0xa6, 0xe8, 0x1a,
    0xc4, 0x04, 0x85, 0xc7, 0x4a, 0x49, 0x19, 0x71, 0xdf, 0x94, 0x96, 0xa2, 0x5f, 0xfd, 0x86, 0x23,
    0x39, 0x8d, 0x65, 0x84, 0x0c, 0xd7, 0x3c, 0x9b, 0xec, 0x98, 0x0f, 0x85, 0xd4, 0xb7, 0x76, 0xcc,
    0xc6, 0x27, 0x97, 0x60, 0x4b, 0xdb, 0x36, 0x0a, 0x72, 0x5d, 0xf8, 0xd8, 0xe4, 0xd7, 0x5a, 0xb8,
    0x54, 0x55, 0x10, 0xf6, 0x0c, 0xa9, 0x9e, 0x44, 0x2b, 0x5a, 0x05, 0x4e, 0x97, 0x4d, 0x17, 0xca,
    0x23, 0x39, 0xf4, 0x4b, 0x3d, 0x0e, 0xbd, 0xc0, 0xe9, 0xfb, 0x11, 0xb9, 0x7c, 0x52, 0x93, 0xcb,
    0xdf, 0xae, 0x20, 0xf1, 0x23, 0x72, 0xff, 0x6d, 0x2d, 0xee, 0xef, 0x59, 0x10, 0xf8, 0x11, 0x19,
    0x78, 0x5c, 0x8b, 0x81, 0x55, 0xfe, 0x07, 0x96, 0x43, 0xd5, 0xac, 0x78, 0x6e, 0xba, 0x71, 0x54,
    0x9f, 0xdb, 0x88, 0xc1, 0x88, 0x22, 0xaf, 0x4a, 0xac, 0xdd, 0x9a, 0x2b, 0x2a, 0x53, 0x0d, 0xef,
    0x11, 0x12, 0x13, 0x95, 0x29, 0x55, 0xe5, 0x65, 0xbf, 0x87, 0x04, 0xeb, 0x5d, 0x1b, 0x90, 0x77,
    0x86, 0xab, 0x44, 0x41, 0x83, 0x40, 0x0b, 0x2f, 0xc0, 0x6a, 0x46, 0x2c, 0x53, 0x11, 0x2b, 0xb8,
    0x14, 0xf1, 0x88, 0xc1, 0x05, 0xa3, 0xc1, 0x63, 0xed, 0xe8, 0xe5, 0xc6, 0x02, 0x40, 0x63, 0x6b,
    0x27, 0x9b, 0xae, 0xd1, 0x08, 0x64, 0xa3, 0xa1, 0xb4, 0x03, 0xfc, 0xa4, 0x54, 0x55, 0x7d, 0xfc,
    0xab, 0xf4, 0xa2, 0xa9, 0x7d, 0xaa, 0x95, 0xa5, 0x81, 0x9d, 0xd2, 0xd7, 0x87, 0x5b, 0x22, 0xec,
    0xf4, 0x49, 0x62, 0x35, 0x18, 0x09, 0x53, 0xc3, 0xfc, 0xba, 0x2f, 0x84, 0x10, 0x60, 0xad, 0x5a,
    0xa3, 0x72, 0x6f, 0x9a, 0x48, 0x5b, 0x88, 0x69, 0x20, 0x80, 0x54, 0x22, 0x96, 0x01, 0x34, 0x01,
    0x89, 0xa8, 0xc8, 0xb4, 0xee, 0x88, 0xb1, 0xa3, 0x37, 0xe5, 0xa6, 0xf6, 0x6c, 0x7d, 0x86, 0xbd,
    0x51, 0xde, 0x03, 0x44, 0x2b, 0xdd, 0x08, 0x2e, 0xe5, 0xaf, 0x4d, 0xf7, 0xb4, 0x79, 0xca, 0xd9,
    0x7c, 0x08, 0x97, 0x05, 0x8e, 0x06, 0x0d, 0xb4, 0xca, 0x2e, 0x94, 0x33, 0x63, 0x98, 0xb6, 0xaa,
    0x5b, 0xee, 0x85, 0x62, 0x00, 0xf2, 0xd5, 0x1c, 0x08, 0xaa, 0x14, 0xd3, 0x44, 0x6e, 0x51, 0x81,
    0x3e, 0xdb, 0x78, 0x20, 0xdb, 0x94, 0xba, 0xe7, 0xa0, 0x57, 0xde, 0xc9, 0xee, 0xa8, 0x30, 0xae,
    0x3f, 0x96, 0xc5, 0xc1, 0x3f, 0x2f, 0x29, 0xf0, 0xfd, 0xf7, 0xab, 0xe7, 0x48, 0xda, 0x37, 0xeb,
    0x91, 0xc6, 0x6b, 0x49, 0x9f, 0x62, 0xe3, 0x00, 0x2c, 0xd3, 0x88, 0xfe, 0x71, 0xf5, 0x9d, 0xb1,
    0xcf, 0x26, 0x3a, 0x28, 0xd2, 0xdd, 0x5d, 0x8e, 0xda, 0x23, 0x7d, 0xab, 0x27, 0x20, 0x57, 0xfa,
    0x6a, 0xec, 0x56, 0xcf, 0xa4, 0xbe, 0x18, 0x5a, 0xab, 0xb9, 0xe6, 0x16, 0x70, 0x62, 0xdc, 0x87,
    0xd0, 0xa7, 0xac, 0x91, 0x30, 0xb2, 0x63, 0xbb, 0x4f, 0x69, 0x1f, 0xbb, 0x57, 0x31, 0x97, 0xfc,
    0x7f, 0xd1, 0xf8, 0x5e, 0x49, 0x26, 0xa9, 0x35, 0xf5, 0xdf, 0x31, 0xd4, 0x4d, 0x27, 0xe1, 0x76,
    0xbc, 0x29, 0xf5, 0x47, 0xed, 0x87, 0x0a, 0xcb, 0xcf, 0x13, 0x70, 0x90, 0xfa, 0x2b, 0x9e, 0x49,
    0xfe, 0x91, 0xc4, 0xce, 0x40, 0xdc, 0xcf, 0x79, 0x92, 0x54, 0x1e, 0x50, 0xcf, 0x95, 0x0d, 0x56,
    0xc3, 0xb5, 0xbb, 0x76, 0xef, 0x8a, 0xdf, 0xf1, 0x53, 0x36, 0xad, 0x08, 0xeb, 0xd0, 0xa4, 0x14,
    0x6e, 0xe4, 0xca, 0xbc, 0x5b, 0x7e, 0x89, 0xdf, 0x46, 0x20, 0xad, 0x77, 0xc2, 0xab, 0xc2, 0xc7,
    0x7c, 0xa2, 0x35, 0x38, 0x77, 0x10, 0x31, 0x12, 0x40, 0x3e, 0xb8, 0x77, 0x88, 0xfe, 0xb4, 0xa8,
    0x13, 0xcb, 0xf5, 0xfa, 0xfc, 0x41, 0x67, 0x89, 0x51, 0x27, 0x60, 0xb8, 0xfc, 0xe6, 0xe7, 0xa9,
    0x86, 0xd6, 0xd9, 0xa9, 0xf4, 0x7b, 0x38, 0xdb, 0x2c, 0x23, 0xdc, 0xcd, 0xc1, 0x80, 0xdb, 0x40,
    0x07, 0xef, 0x31, 0xe5, 0x48, 0x94, 0x87, 0x7a, 0x0e, 0x01, 0x8c, 0xd2, 0xc6, 0x51, 0xe3, 0xe5,
    0x22, 0x94, 0x32, 0xac, 0xee, 0x5b, 0x79, 0xf8, 0x2a, 0xa1, 0xcd, 0x28, 0xcc, 0xf1, 0xee, 0xf5,
    0x27, 0x33, 0x1b, 0xe1, 0x5e, 0xcf, 0x27, 0x00, 0xac, 0x76, 0xa8, 0xf8, 0x39, 0x5f, 0x85, 0xc0,
    0xdb, 0x7d, 0x92, 0xb7, 0x9e, 0x5e, 0xf8, 0x17, 0x28, 0xc8, 0x59, 0xfb
};
#endif

PyTypeObject *init_QGraphicsScene(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX].type;

    Shiboken::AutoDecRef Sbk_QGraphicsScene_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))));

    _Sbk_QGraphicsScene_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QGraphicsScene",
        "QGraphicsScene*",
        &Sbk_QGraphicsScene_spec,
        &Shiboken::callCppDestructor< QGraphicsScene >,
        Sbk_QGraphicsScene_Type_bases.object(),
        0);
    auto *pyType = Sbk_QGraphicsScene_TypeF(); // references _Sbk_QGraphicsScene_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QGraphicsScene_SignatureStrings);
#else
    InitSignatureBytes(pyType, QGraphicsScene_SignatureBytes, QGraphicsScene_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QGraphicsScene_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QGraphicsScene_PythonToCpp_QGraphicsScene_PTR,
        is_QGraphicsScene_PythonToCpp_QGraphicsScene_PTR_Convertible,
        QGraphicsScene_PTR_CppToPython_QGraphicsScene);

    Shiboken::Conversions::registerConverterName(converter, "QGraphicsScene");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsScene*");
    Shiboken::Conversions::registerConverterName(converter, "QGraphicsScene&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QGraphicsScene).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QGraphicsSceneWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QGraphicsScene_TypeF(), &Sbk_QGraphicsScene_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QGraphicsScene_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'ItemIndexMethod'.
    const char *ItemIndexMethod_Initializer[] = {
        "BspTreeIndex",
        "NoIndex",
        nullptr};
    // "int8_t" used instead of "int"
    constexpr int8_t ItemIndexMethod_InitializerValues[] = {
        int8_t(QGraphicsScene::ItemIndexMethod::BspTreeIndex), //  0x00  0
        int8_t(QGraphicsScene::ItemIndexMethod::NoIndex)       // -0x01 -1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGraphicsScene_TypeF(),
        "2:PySide6.QtWidgets.QGraphicsScene.ItemIndexMethod",
        ItemIndexMethod_Initializer, ItemIndexMethod_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_ItemIndexMethod_IDX].type = EType;
    // Register converter for enum 'QGraphicsScene::ItemIndexMethod'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGraphicsScene_ItemIndexMethod_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGraphicsScene_ItemIndexMethod,
            is_Enum_PythonToCpp_QGraphicsScene_ItemIndexMethod_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGraphicsScene::ItemIndexMethod");
        Shiboken::Conversions::registerConverterAlias(converter, "ItemIndexMethod");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'ItemIndexMethod' enum.

    // Initialization of enum 'SceneLayer'.
    const char *SceneLayer_Initializer[] = {
        "ItemLayer",
        "BackgroundLayer",
        "ForegroundLayer",
        "AllLayers",
        nullptr};
    // "uint16_t" used instead of "unsigned int"
    constexpr uint16_t SceneLayer_InitializerValues[] = {
        uint16_t(QGraphicsScene::SceneLayer::ItemLayer),       //  0x0001  1
        uint16_t(QGraphicsScene::SceneLayer::BackgroundLayer), //  0x0002  2
        uint16_t(QGraphicsScene::SceneLayer::ForegroundLayer), //  0x0004  4
        uint16_t(QGraphicsScene::SceneLayer::AllLayers)        //  0xffff  65535
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QGraphicsScene_TypeF(),
        "2:PySide6.QtWidgets.QGraphicsScene.SceneLayer",
        SceneLayer_Initializer, SceneLayer_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_SceneLayer_IDX].type = EType;
    // PYSIDE-1735: Mapping the flags class to the same enum class.
    SbkPySide6_QtWidgetsTypeStructs[SBK_QFlags_QGraphicsScene_SceneLayer_IDX].type =
        EType;
    // Register converter for enum 'QGraphicsScene::SceneLayer'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QGraphicsScene_SceneLayer_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QGraphicsScene_SceneLayer,
            is_Enum_PythonToCpp_QGraphicsScene_SceneLayer_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QGraphicsScene::SceneLayer");
        Shiboken::Conversions::registerConverterAlias(converter, "SceneLayer");
        SbkConverter *flagsConverter = Shiboken::Conversions::createConverter(EType,
            QGraphicsScene_SceneLayer_CppToPython_Flag);
        Shiboken::Conversions::addPythonToCppValueConversion(flagsConverter,
            Flag_PythonToCpp_QGraphicsScene_SceneLayer,
            is_Enum_PythonToCpp_QGraphicsScene_SceneLayer_Convertible);
        // Register converter for flag 'QFlags<QGraphicsScene::SceneLayer>'.
        Shiboken::Conversions::registerConverterName(flagsConverter, "QFlags<QGraphicsScene::SceneLayer>");
        Shiboken::Conversions::registerConverterName(flagsConverter, "QGraphicsScene::SceneLayers");
        Shiboken::Enum::setTypeConverter(EType, converter, flagsConverter);
    }
    // End of 'SceneLayer' enum/flags.

    PySide::Signal::registerSignals(pyType, &::QGraphicsScene::staticMetaObject);
    qRegisterMetaType< ::QGraphicsScene::ItemIndexMethod >("QGraphicsScene::ItemIndexMethod");
    qRegisterMetaType< ::QGraphicsScene::SceneLayer >("QGraphicsScene::SceneLayer");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QGraphicsScene::staticMetaObject, sizeof(QGraphicsSceneWrapper));

    return pyType;
}
