// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqobject.h>
#include <pysidesignal.h>
#include <pysideproperty.h>
#include <signalmanager.h>
#include <pysidemetafunction.h>
#include <pysideqenum.h>
#include <pysideqmetatype.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "pyside6_qtwidgets_python.h"

// main header
#include "qplaintextedit_wrapper.h"

// Argument includes
#include <QAbstractTextDocumentLayout>
#include <QList>
#include <QString>
#include <QTextEdit>
#include <QtGui/qevent.h>
#include <QtGui/qpagedpaintdevice.h>
#include <QtGui/qpaintdevice.h>
#include <QtGui/qpaintengine.h>
#include <QtGui/qpainter.h>
#include <QtGui/qtextcursor.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qtextobject.h>
#include <QtGui/qtextoption.h>
#include <QtWidgets/qabstractscrollarea.h>
#include <QtWidgets/qmenu.h>
#include <QtWidgets/qplaintextedit.h>
#include <QtWidgets/qscrollbar.h>
#include <QtWidgets/qstyleoption.h>
#include <QtWidgets/qwidget.h>
#include <qbytearray.h>
#include <qcoreevent.h>
#include <qmargins.h>
#include <qmetaobject.h>
#include <qmimedata.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qpoint.h>
#include <qrect.h>
#include <qregularexpression.h>
#include <qsize.h>
#include <qurl.h>
#include <qvariant.h>

#include <algorithm>
#include <cctype>
#include <cstring>
#include <iterator>
#include <set>
#include <type_traits>
#include <typeinfo>

// Native ---------------------------------------------------------

void QPlainTextEditWrapper::resetPyMethodCache()
{
    std::fill_n(m_PyMethodCache, sizeof(m_PyMethodCache) / sizeof(m_PyMethodCache[0]), false);
}

QPlainTextEditWrapper::QPlainTextEditWrapper(::QWidget * parent) : QPlainTextEdit(parent)
{
}

QPlainTextEditWrapper::QPlainTextEditWrapper(const ::QString & text, ::QWidget * parent) : QPlainTextEdit(text, parent)
{
}

void QPlainTextEditWrapper::actionEvent(::QActionEvent * event)
{
    if (m_PyMethodCache[0]) {
        return this->::QWidget::actionEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "actionEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[0] = true;
        gil.release();
        return this->::QWidget::actionEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QActionEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QActionEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

bool QPlainTextEditWrapper::canInsertFromMimeData(const ::QMimeData * source) const
{
    if (m_PyMethodCache[1])
        return this->::QPlainTextEdit::canInsertFromMimeData(source);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "canInsertFromMimeData";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[1] = true;
        gil.release();
        return this->::QPlainTextEdit::canInsertFromMimeData(source);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), source)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), source)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPlainTextEditWrapper::changeEvent(::QEvent * e)
{
    if (m_PyMethodCache[2]) {
        return this->::QPlainTextEdit::changeEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "changeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[2] = true;
        gil.release();
        return this->::QPlainTextEdit::changeEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::childEvent(::QChildEvent * event)
{
    if (m_PyMethodCache[3]) {
        return this->::QObject::childEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "childEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[3] = true;
        gil.release();
        return this->::QObject::childEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QChildEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::closeEvent(::QCloseEvent * event)
{
    if (m_PyMethodCache[4]) {
        return this->::QWidget::closeEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "closeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[4] = true;
        gil.release();
        return this->::QWidget::closeEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCloseEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QCloseEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::connectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[5]) {
        return this->::QObject::connectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "connectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[5] = true;
        gil.release();
        return this->::QObject::connectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::contextMenuEvent(::QContextMenuEvent * e)
{
    if (m_PyMethodCache[6]) {
        return this->::QPlainTextEdit::contextMenuEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "contextMenuEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[6] = true;
        gil.release();
        return this->::QPlainTextEdit::contextMenuEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

::QMimeData * QPlainTextEditWrapper::createMimeDataFromSelection() const
{
    if (m_PyMethodCache[7])
        return this->::QPlainTextEdit::createMimeDataFromSelection();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "createMimeDataFromSelection";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[7] = true;
        gil.release();
        return this->::QPlainTextEdit::createMimeDataFromSelection();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, Shiboken::SbkType< QMimeData >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QMimeData *cppResult;
    pythonToCpp(pyResult, &cppResult);
    if (Shiboken::Object::checkType(pyResult))
        Shiboken::Object::releaseOwnership(pyResult);
    return cppResult;
}

void QPlainTextEditWrapper::customEvent(::QEvent * event)
{
    if (m_PyMethodCache[8]) {
        return this->::QObject::customEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "customEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[8] = true;
        gil.release();
        return this->::QObject::customEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

int QPlainTextEditWrapper::devType() const
{
    if (m_PyMethodCache[9])
        return this->::QWidget::devType();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "devType";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[9] = true;
        gil.release();
        return this->::QWidget::devType();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPlainTextEditWrapper::disconnectNotify(const ::QMetaMethod & signal)
{
    if (m_PyMethodCache[10]) {
        return this->::QObject::disconnectNotify(signal);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "disconnectNotify";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[10] = true;
        gil.release();
        return this->::QObject::disconnectNotify(signal);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMetaMethod_IDX]), &signal)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::doSetTextCursor(const ::QTextCursor & cursor)
{
    if (m_PyMethodCache[11]) {
        return this->::QPlainTextEdit::doSetTextCursor(cursor);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "doSetTextCursor";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[11] = true;
        gil.release();
        return this->::QPlainTextEdit::doSetTextCursor(cursor);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), &cursor)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), &cursor)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::dragEnterEvent(::QDragEnterEvent * e)
{
    if (m_PyMethodCache[12]) {
        return this->::QPlainTextEdit::dragEnterEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragEnterEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[12] = true;
        gil.release();
        return this->::QPlainTextEdit::dragEnterEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::dragLeaveEvent(::QDragLeaveEvent * e)
{
    if (m_PyMethodCache[13]) {
        return this->::QPlainTextEdit::dragLeaveEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragLeaveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[13] = true;
        gil.release();
        return this->::QPlainTextEdit::dragLeaveEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::dragMoveEvent(::QDragMoveEvent * e)
{
    if (m_PyMethodCache[14]) {
        return this->::QPlainTextEdit::dragMoveEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dragMoveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[14] = true;
        gil.release();
        return this->::QPlainTextEdit::dragMoveEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::dropEvent(::QDropEvent * e)
{
    if (m_PyMethodCache[15]) {
        return this->::QPlainTextEdit::dropEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "dropEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[15] = true;
        gil.release();
        return this->::QPlainTextEdit::dropEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::enterEvent(::QEnterEvent * event)
{
    if (m_PyMethodCache[16]) {
        return this->::QWidget::enterEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "enterEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[16] = true;
        gil.release();
        return this->::QWidget::enterEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEnterEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QEnterEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

bool QPlainTextEditWrapper::event(::QEvent * e)
{
    if (m_PyMethodCache[17])
        return this->::QPlainTextEdit::event(e);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "event";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[17] = true;
        gil.release();
        return this->::QPlainTextEdit::event(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool QPlainTextEditWrapper::eventFilter(::QObject * arg__1, ::QEvent * arg__2)
{
    if (m_PyMethodCache[18])
        return this->::QAbstractScrollArea::eventFilter(arg__1, arg__2);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "eventFilter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[18] = true;
        gil.release();
        return this->::QAbstractScrollArea::eventFilter(arg__1, arg__2);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__2)
    };

    const bool invalidateArg2 = Py_REFCNT(pyArgArray[1]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), arg__1),
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__2)
    ));
    bool invalidateArg2 = Py_REFCNT(PyTuple_GetItem(pyArgs, 1)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(pyArgArray[1]);
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg2)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 1));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPlainTextEditWrapper::focusInEvent(::QFocusEvent * e)
{
    if (m_PyMethodCache[19]) {
        return this->::QPlainTextEdit::focusInEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusInEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[19] = true;
        gil.release();
        return this->::QPlainTextEdit::focusInEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

bool QPlainTextEditWrapper::focusNextPrevChild(bool next)
{
    if (m_PyMethodCache[20])
        return this->::QPlainTextEdit::focusNextPrevChild(next);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusNextPrevChild";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[20] = true;
        gil.release();
        return this->::QPlainTextEdit::focusNextPrevChild(next);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &next)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &next)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPlainTextEditWrapper::focusOutEvent(::QFocusEvent * e)
{
    if (m_PyMethodCache[21]) {
        return this->::QPlainTextEdit::focusOutEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "focusOutEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[21] = true;
        gil.release();
        return this->::QPlainTextEdit::focusOutEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

bool QPlainTextEditWrapper::hasHeightForWidth() const
{
    if (m_PyMethodCache[22])
        return this->::QWidget::hasHeightForWidth();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hasHeightForWidth";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[22] = true;
        gil.release();
        return this->::QWidget::hasHeightForWidth();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QPlainTextEditWrapper::heightForWidth(int arg__1) const
{
    if (m_PyMethodCache[23])
        return this->::QWidget::heightForWidth(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "heightForWidth";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[23] = true;
        gil.release();
        return this->::QWidget::heightForWidth(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(i)",
        arg__1
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPlainTextEditWrapper::hideEvent(::QHideEvent * event)
{
    if (m_PyMethodCache[24]) {
        return this->::QWidget::hideEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "hideEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[24] = true;
        gil.release();
        return this->::QWidget::hideEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHideEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QHideEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::initPainter(::QPainter * painter) const
{
    if (m_PyMethodCache[25]) {
        return this->::QWidget::initPainter(painter);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "initPainter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[25] = true;
        gil.release();
        return this->::QWidget::initPainter(painter);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), painter)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::initStyleOption(::QStyleOptionFrame * option) const
{
    if (m_PyMethodCache[26]) {
        return this->::QFrame::initStyleOption(option);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "initStyleOption";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[26] = true;
        gil.release();
        return this->::QFrame::initStyleOption(option);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionFrame_IDX]), option)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionFrame_IDX]), option)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::inputMethodEvent(::QInputMethodEvent * arg__1)
{
    if (m_PyMethodCache[27]) {
        return this->::QPlainTextEdit::inputMethodEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "inputMethodEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[27] = true;
        gil.release();
        return this->::QPlainTextEdit::inputMethodEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

::QVariant QPlainTextEditWrapper::inputMethodQuery(::Qt::InputMethodQuery property) const
{
    if (m_PyMethodCache[28])
        return this->::QPlainTextEdit::inputMethodQuery(property);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "inputMethodQuery";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[28] = true;
        gil.release();
        return this->::QPlainTextEdit::inputMethodQuery(property);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, &property)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, &property)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPlainTextEditWrapper::insertFromMimeData(const ::QMimeData * source)
{
    if (m_PyMethodCache[29]) {
        return this->::QPlainTextEdit::insertFromMimeData(source);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "insertFromMimeData";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[29] = true;
        gil.release();
        return this->::QPlainTextEdit::insertFromMimeData(source);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), source)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), source)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::keyPressEvent(::QKeyEvent * e)
{
    if (m_PyMethodCache[30]) {
        return this->::QPlainTextEdit::keyPressEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "keyPressEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[30] = true;
        gil.release();
        return this->::QPlainTextEdit::keyPressEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::keyReleaseEvent(::QKeyEvent * e)
{
    if (m_PyMethodCache[31]) {
        return this->::QPlainTextEdit::keyReleaseEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "keyReleaseEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[31] = true;
        gil.release();
        return this->::QPlainTextEdit::keyReleaseEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::leaveEvent(::QEvent * event)
{
    if (m_PyMethodCache[32]) {
        return this->::QWidget::leaveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "leaveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[32] = true;
        gil.release();
        return this->::QWidget::leaveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

::QVariant QPlainTextEditWrapper::loadResource(int type, const ::QUrl & name)
{
    if (m_PyMethodCache[33])
        return this->::QPlainTextEdit::loadResource(type, name);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return ::QVariant();
    static PyObject *nameCache[2] = {};
    static const char *funcName = "loadResource";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[33] = true;
        gil.release();
        return this->::QPlainTextEdit::loadResource(type, name);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &type),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &name)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(iN)",
        type,
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &name)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return ::QVariant();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, "QVariant", Py_TYPE(pyResult)->tp_name);
        return ::QVariant();
    }
    ::QVariant cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

int QPlainTextEditWrapper::metric(::QPaintDevice::PaintDeviceMetric arg__1) const
{
    if (m_PyMethodCache[34])
        return this->::QWidget::metric(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return 0;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "metric";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[34] = true;
        gil.release();
        return this->::QWidget::metric(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &arg__1)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_PaintDeviceMetric_IDX])))->converter, &arg__1)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return 0;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, "int", Py_TYPE(pyResult)->tp_name);
        return 0;
    }
    int cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSize QPlainTextEditWrapper::minimumSizeHint() const
{
    if (m_PyMethodCache[35])
        return this->::QAbstractScrollArea::minimumSizeHint();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "minimumSizeHint";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[35] = true;
        gil.release();
        return this->::QAbstractScrollArea::minimumSizeHint();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPlainTextEditWrapper::mouseDoubleClickEvent(::QMouseEvent * e)
{
    if (m_PyMethodCache[36]) {
        return this->::QPlainTextEdit::mouseDoubleClickEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseDoubleClickEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[36] = true;
        gil.release();
        return this->::QPlainTextEdit::mouseDoubleClickEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::mouseMoveEvent(::QMouseEvent * e)
{
    if (m_PyMethodCache[37]) {
        return this->::QPlainTextEdit::mouseMoveEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseMoveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[37] = true;
        gil.release();
        return this->::QPlainTextEdit::mouseMoveEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::mousePressEvent(::QMouseEvent * e)
{
    if (m_PyMethodCache[38]) {
        return this->::QPlainTextEdit::mousePressEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mousePressEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[38] = true;
        gil.release();
        return this->::QPlainTextEdit::mousePressEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::mouseReleaseEvent(::QMouseEvent * e)
{
    if (m_PyMethodCache[39]) {
        return this->::QPlainTextEdit::mouseReleaseEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "mouseReleaseEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[39] = true;
        gil.release();
        return this->::QPlainTextEdit::mouseReleaseEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::moveEvent(::QMoveEvent * event)
{
    if (m_PyMethodCache[40]) {
        return this->::QWidget::moveEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "moveEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[40] = true;
        gil.release();
        return this->::QWidget::moveEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMoveEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMoveEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

bool QPlainTextEditWrapper::nativeEvent(const ::QByteArray & eventType, void * message, ::qintptr * result)
{
    if (m_PyMethodCache[41]) {
        return this->::QWidget::nativeEvent(eventType, message, result);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "nativeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[41] = true;
        gil.release();
        return this->::QWidget::nativeEvent(eventType, message, result);
    }

    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &eventType),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), message)
    ));

    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return false;
    }
    // Begin code injection
    // TEMPLATE - return_native_eventfilter_conversion - START
    bool cppResult = false;
    if (PySequence_Check(pyResult.object()) && (PySequence_Size(pyResult.object()) == 2)) {
        Shiboken::AutoDecRef pyItem(PySequence_GetItem(pyResult.object(), 0));
        Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyItem, &(cppResult));
        if (result) {
            Shiboken::AutoDecRef pyResultItem(PySequence_GetItem(pyResult, 1));
            Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<long>(), pyResultItem, (result));
        }
    }
    // TEMPLATE - return_native_eventfilter_conversion - END
    // End of code injection


    return cppResult;
}

::QPaintEngine * QPlainTextEditWrapper::paintEngine() const
{
    if (m_PyMethodCache[42])
        return this->::QWidget::paintEngine();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "paintEngine";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[42] = true;
        gil.release();
        return this->::QWidget::paintEngine();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEngine_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, Shiboken::SbkType< QPaintEngine >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPaintEngine *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPlainTextEditWrapper::paintEvent(::QPaintEvent * e)
{
    if (m_PyMethodCache[43]) {
        return this->::QPlainTextEdit::paintEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "paintEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[43] = true;
        gil.release();
        return this->::QPlainTextEdit::paintEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

::QPaintDevice * QPlainTextEditWrapper::redirected(::QPoint * offset) const
{
    if (m_PyMethodCache[44])
        return this->::QWidget::redirected(offset);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "redirected";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[44] = true;
        gil.release();
        return this->::QWidget::redirected(offset);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), offset)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), offset)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, Shiboken::SbkType< QPaintDevice >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPaintDevice *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPlainTextEditWrapper::resizeEvent(::QResizeEvent * e)
{
    if (m_PyMethodCache[45]) {
        return this->::QPlainTextEdit::resizeEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "resizeEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[45] = true;
        gil.release();
        return this->::QPlainTextEdit::resizeEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::scrollContentsBy(int dx, int dy)
{
    if (m_PyMethodCache[46]) {
        return this->::QPlainTextEdit::scrollContentsBy(dx, dy);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "scrollContentsBy";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[46] = true;
        gil.release();
        return this->::QPlainTextEdit::scrollContentsBy(dx, dy);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &dx),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &dy)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(ii)",
        dx,
        dy
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::setVisible(bool visible)
{
    if (m_PyMethodCache[47]) {
        return this->::QWidget::setVisible(visible);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    // This method belongs to a property.
    static const char *funcName = "2:setVisible";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[47] = true;
        gil.release();
        return this->::QWidget::setVisible(visible);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &visible)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &visible)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::setupViewport(::QWidget * viewport)
{
    if (m_PyMethodCache[48]) {
        return this->::QAbstractScrollArea::setupViewport(viewport);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "setupViewport";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[48] = true;
        gil.release();
        return this->::QAbstractScrollArea::setupViewport(viewport);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), viewport)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), viewport)
    ));
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

::QPainter * QPlainTextEditWrapper::sharedPainter() const
{
    if (m_PyMethodCache[49])
        return this->::QWidget::sharedPainter();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return nullptr;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sharedPainter";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[49] = true;
        gil.release();
        return this->::QWidget::sharedPainter();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return nullptr;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, Shiboken::SbkType< QPainter >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return nullptr;
    }
    ::QPainter *cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPlainTextEditWrapper::showEvent(::QShowEvent * arg__1)
{
    if (m_PyMethodCache[50]) {
        return this->::QPlainTextEdit::showEvent(arg__1);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "showEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[50] = true;
        gil.release();
        return this->::QPlainTextEdit::showEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

::QSize QPlainTextEditWrapper::sizeHint() const
{
    if (m_PyMethodCache[51])
        return this->::QAbstractScrollArea::sizeHint();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "sizeHint";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[51] = true;
        gil.release();
        return this->::QAbstractScrollArea::sizeHint();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPlainTextEditWrapper::tabletEvent(::QTabletEvent * event)
{
    if (m_PyMethodCache[52]) {
        return this->::QWidget::tabletEvent(event);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "tabletEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[52] = true;
        gil.release();
        return this->::QWidget::tabletEvent(event);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTabletEvent_IDX]), event)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTabletEvent_IDX]), event)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

void QPlainTextEditWrapper::timerEvent(::QTimerEvent * e)
{
    if (m_PyMethodCache[53]) {
        return this->::QPlainTextEdit::timerEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "timerEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[53] = true;
        gil.release();
        return this->::QPlainTextEdit::timerEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

bool QPlainTextEditWrapper::viewportEvent(::QEvent * arg__1)
{
    if (m_PyMethodCache[54])
        return this->::QAbstractScrollArea::viewportEvent(arg__1);
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return false;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "viewportEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[54] = true;
        gil.release();
        return this->::QAbstractScrollArea::viewportEvent(arg__1);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), arg__1)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QSize QPlainTextEditWrapper::viewportSizeHint() const
{
    if (m_PyMethodCache[55])
        return this->::QAbstractScrollArea::viewportSizeHint();
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return {};
    static PyObject *nameCache[2] = {};
    static const char *funcName = "viewportSizeHint";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[55] = true;
        gil.release();
        return this->::QAbstractScrollArea::viewportSizeHint();
    }

#if defined(PYPY_VERSION) || (defined(Py_LIMITED_API) && Py_LIMITED_API < 0x030A0000)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION) && ((defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030A0000) || !defined(Py_LIMITED_API))
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QSize_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue("QPlainTextEdit", funcName, Shiboken::SbkType< QSize >()->tp_name, Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QSize cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void QPlainTextEditWrapper::wheelEvent(::QWheelEvent * e)
{
    if (m_PyMethodCache[56]) {
        return this->::QPlainTextEdit::wheelEvent(e);
    }
    Shiboken::GilState gil;
    if (Shiboken::Errors::occurred() != nullptr)
        return;
    static PyObject *nameCache[2] = {};
    static const char *funcName = "wheelEvent";
    Shiboken::AutoDecRef pyOverride(Shiboken::BindingManager::instance().getOverride(this, nameCache, funcName));
    if (pyOverride.isNull()) {
        m_PyMethodCache[56] = true;
        gil.release();
        return this->::QPlainTextEdit::wheelEvent(e);
    }

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), e)
    };

    const bool invalidateArg1 = Py_REFCNT(pyArgArray[0]) == 1;
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), e)
    ));
    bool invalidateArg1 = Py_REFCNT(PyTuple_GetItem(pyArgs, 0)) == 1;
#endif

#if !defined(PYPY_VERSION) && !defined(Py_LIMITED_API)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(pyArgArray[0]);
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
    if (invalidateArg1)
        Shiboken::Object::invalidate(PyTuple_GetItem(pyArgs, 0));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint("QPlainTextEdit", funcName);
        return;
    }
}

const QMetaObject *QPlainTextEditWrapper::metaObject() const
{
    if (QObject::d_ptr->metaObject != nullptr)
        return QObject::d_ptr->dynamicMetaObject();
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf == nullptr)
        return QPlainTextEdit::metaObject();
    return PySide::SignalManager::retrieveMetaObject(reinterpret_cast<PyObject *>(pySelf));
}

int QPlainTextEditWrapper::qt_metacall(QMetaObject::Call call, int id, void **args)
{
    int result = QPlainTextEdit::qt_metacall(call, id, args);
    return result < 0 ? result : PySide::SignalManager::qt_metacall(this, call, id, args);
}

void *QPlainTextEditWrapper::qt_metacast(const char *_clname)
{
    if (_clname == nullptr)
        return {};
    SbkObject *pySelf = Shiboken::BindingManager::instance().retrieveWrapper(this);
    if (pySelf != nullptr && PySide::inherits(Py_TYPE(pySelf), _clname))
        return static_cast<void *>(const_cast< QPlainTextEditWrapper *>(this));
    return QPlainTextEdit::qt_metacast(_clname);
}

QPlainTextEditWrapper::~QPlainTextEditWrapper()
{
    SbkObject *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this);
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int
Sbk_QPlainTextEdit_Init(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    auto *sbkSelf = reinterpret_cast<SbkObject *>(self);
    PySide::Feature::Select(self);
    if (Shiboken::Object::isUserType(self) && !Shiboken::ObjectType::canCallConstructor(self->ob_type, Shiboken::SbkType< ::QPlainTextEdit >()))
        return -1;

    QPlainTextEditWrapper *cptr{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_ParseTuple(args, "|OO:QPlainTextEdit", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return -1;


    // Overloaded function decisor
    // 0: QPlainTextEdit::QPlainTextEdit(QWidget*=)
    // 1: QPlainTextEdit::QPlainTextEdit(QString,QWidget*=)
    if (numArgs == 0) {
        overloadId = 0; // QPlainTextEdit(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0])))) {
        overloadId = 0; // QPlainTextEdit(QWidget*)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // QPlainTextEdit(QString,QWidget*)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1])))) {
            overloadId = 1; // QPlainTextEdit(QString,QWidget*)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);


    // PyMI support
    bool usesPyMI = Shiboken::callInheritedInit(self, args, kwds, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
    if (Shiboken::Errors::occurred() != nullptr)
        return -1;

    // Call function/method
    switch (overloadId) {
        case 0: // QPlainTextEdit(QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[0] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[0] = value;
                        if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[0]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return -1;
            ::QWidget *cppArg0 = nullptr;
            if (pythonToCpp[0])
                pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlainTextEdit(QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QPlainTextEditWrapper(cppArg0);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QPlainTextEditWrapper(cppArg0);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[0], self);
            }
            break;
        }
        case 1: // QPlainTextEdit(const QString &text, QWidget *parent)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_parent = Shiboken::String::createStaticString("parent");
                if (PyDict_Contains(kwds, key_parent) != 0) {
                    value = PyDict_GetItem(kwds, key_parent);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_parent);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), (pyArgs[1]))))
                            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_parent);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    // fall through to handle extra keyword signals and properties
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return -1;
            ::QWidget *cppArg1 = nullptr;
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // QPlainTextEdit(QString,QWidget*)
                void *addr = PySide::nextQObjectMemoryAddr();
                if (addr != nullptr) {
                    cptr = new (addr) QPlainTextEditWrapper(cppArg0, cppArg1);
                    PySide::setNextQObjectMemoryAddr(nullptr);
                } else {
                    cptr = new QPlainTextEditWrapper(cppArg0, cppArg1);
                }

                // Ownership transferences (constructor heuristics).
                Shiboken::Object::setParent(pyArgs[1], self);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || !Shiboken::Object::setCppPointer(sbkSelf, Shiboken::SbkType< QPlainTextEdit >(), cptr)) {
        delete cptr;
        return -1;
    }
    if (cptr == nullptr)
        return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    Shiboken::Object::setValidCpp(sbkSelf, true);
    Shiboken::Object::setHasCppWrapper(sbkSelf, true);
    if (Shiboken::BindingManager::instance().hasWrapper(cptr)) {
        Shiboken::BindingManager::instance().releaseWrapper(Shiboken::BindingManager::instance().retrieveWrapper(cptr));
    }
    Shiboken::BindingManager::instance().registerWrapper(sbkSelf, cptr);

    // QObject setup
    PySide::Signal::updateSourceObject(self);
    const auto *metaObject = cptr->metaObject(); // <- init python qt properties
    if (!errInfo.isNull() && PyDict_Check(errInfo.object())) {
        if (!PySide::fillQtProperties(self, metaObject, errInfo, usesPyMI))
            return Shiboken::returnWrongArguments_MinusOne(args, "__init__", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
    };


    return 1;
}

static PyObject *Sbk_QPlainTextEditFunc_anchorAt(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::anchorAt(QPoint)const->QString
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // anchorAt(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "anchorAt", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // anchorAt(QPoint)const
            QString cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->anchorAt(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_appendHtml(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::appendHtml(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // appendHtml(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "appendHtml", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // appendHtml(QString)
            cppSelf->appendHtml(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_appendPlainText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::appendPlainText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // appendPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "appendPlainText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // appendPlainText(QString)
            cppSelf->appendPlainText(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_backgroundVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // backgroundVisible()const
        bool cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->backgroundVisible();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_blockBoundingGeometry(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::blockBoundingGeometry(QTextBlock)const->QRectF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), (pyArg)))) {
        overloadId = 0; // blockBoundingGeometry(QTextBlock)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "blockBoundingGeometry", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextBlock cppArg0_local;
        ::QTextBlock *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // blockBoundingGeometry(QTextBlock)const
            QRectF cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->blockBoundingGeometry(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_blockBoundingRect(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::blockBoundingRect(QTextBlock)const->QRectF
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), (pyArg)))) {
        overloadId = 0; // blockBoundingRect(QTextBlock)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "blockBoundingRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextBlock cppArg0_local;
        ::QTextBlock *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // blockBoundingRect(QTextBlock)const
            QRectF cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->blockBoundingRect(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_blockCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // blockCount()const
        int cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->blockCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_canInsertFromMimeData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::canInsertFromMimeData(const QMimeData*)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), (pyArg)))) {
        overloadId = 0; // canInsertFromMimeData(const QMimeData*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "canInsertFromMimeData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMimeData *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // canInsertFromMimeData(const QMimeData*)const
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::QPlainTextEdit *>(cppSelf)->::QPlainTextEdit::canInsertFromMimeData(cppArg0)
                : const_cast<const ::QPlainTextEdit *>(cppSelf)->canInsertFromMimeData(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_canPaste(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // canPaste()const
        bool cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->canPaste();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_centerCursor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // centerCursor()
        cppSelf->centerCursor();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_centerOnScroll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // centerOnScroll()const
        bool cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->centerOnScroll();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_changeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::changeEvent(QEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // changeEvent(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "changeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // changeEvent(QEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::changeEvent(cppArg0)
                : cppSelf->changeEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_clear(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // clear()
        cppSelf->clear();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_contentOffset(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // contentOffset()const
        QPointF cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->contentOffset();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_contextMenuEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::contextMenuEvent(QContextMenuEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QContextMenuEvent_IDX]), (pyArg)))) {
        overloadId = 0; // contextMenuEvent(QContextMenuEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "contextMenuEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QContextMenuEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // contextMenuEvent(QContextMenuEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::contextMenuEvent(cppArg0)
                : cppSelf->contextMenuEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_copy(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // copy()
        cppSelf->copy();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_createMimeDataFromSelection(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // createMimeDataFromSelection()const
        QMimeData * cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::QPlainTextEdit *>(cppSelf)->::QPlainTextEdit::createMimeDataFromSelection()
            : const_cast<const ::QPlainTextEdit *>(cppSelf)->createMimeDataFromSelection();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), cppResult);

        // Ownership transferences.
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_createStandardContextMenu(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "createStandardContextMenu", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlainTextEdit::createStandardContextMenu()->QMenu*
    // 1: QPlainTextEdit::createStandardContextMenu(QPoint)->QMenu*
    if (numArgs == 0) {
        overloadId = 0; // createStandardContextMenu()
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[0])))) {
        overloadId = 1; // createStandardContextMenu(QPoint)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "createStandardContextMenu", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // createStandardContextMenu()
        {

            // createStandardContextMenu()
            QMenu * cppResult = cppSelf->createStandardContextMenu();
            pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMenu_IDX]), cppResult);
            // Ownership transferences (return value heuristics).
            Shiboken::Object::setParent(self, pyResult);
            break;
        }
        case 1: // createStandardContextMenu(const QPoint &position)
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPoint cppArg0_local;
            ::QPoint *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // createStandardContextMenu(QPoint)
                QMenu * cppResult = cppSelf->createStandardContextMenu(*cppArg0);
                pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMenu_IDX]), cppResult);
                // Ownership transferences (return value heuristics).
                Shiboken::Object::setParent(self, pyResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_currentCharFormat(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // currentCharFormat()const
        QTextCharFormat cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->currentCharFormat();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_cursorForPosition(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::cursorForPosition(QPoint)const->QTextCursor
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg)))) {
        overloadId = 0; // cursorForPosition(QPoint)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "cursorForPosition", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPoint cppArg0_local;
        ::QPoint *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // cursorForPosition(QPoint)const
            QTextCursor cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->cursorForPosition(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_cursorRect(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "cursorRect", 0, 1, &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlainTextEdit::cursorRect()const->QRect
    // 1: QPlainTextEdit::cursorRect(QTextCursor)const->QRect
    if (numArgs == 0) {
        overloadId = 0; // cursorRect()const
    } else if (numArgs == 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArgs[0])))) {
        overloadId = 1; // cursorRect(QTextCursor)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "cursorRect", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // cursorRect() const
        {

            // cursorRect()const
            QRect cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->cursorRect();
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
            break;
        }
        case 1: // cursorRect(const QTextCursor &cursor) const
        {
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QTextCursor cppArg0_local;
            ::QTextCursor *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);


            if (Shiboken::Errors::occurred() == nullptr) {
                // cursorRect(QTextCursor)const
                QRect cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->cursorRect(*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_cursorWidth(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cursorWidth()const
        int cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->cursorWidth();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_cut(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // cut()
        cppSelf->cut();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_doSetTextCursor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::doSetTextCursor(QTextCursor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArg)))) {
        overloadId = 0; // doSetTextCursor(QTextCursor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "doSetTextCursor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextCursor cppArg0_local;
        ::QTextCursor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // doSetTextCursor(QTextCursor)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::doSetTextCursor(*cppArg0)
                : cppSelf->doSetTextCursor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_document(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // document()const
        QTextDocument * cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->document();
        pyResult = Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), cppResult);
        // Ownership transferences (return value heuristics).
        Shiboken::Object::setParent(self, pyResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_documentTitle(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // documentTitle()const
        QString cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->documentTitle();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_dragEnterEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::dragEnterEvent(QDragEnterEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragEnterEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragEnterEvent(QDragEnterEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragEnterEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDragEnterEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragEnterEvent(QDragEnterEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::dragEnterEvent(cppArg0)
                : cppSelf->dragEnterEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_dragLeaveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::dragLeaveEvent(QDragLeaveEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragLeaveEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragLeaveEvent(QDragLeaveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragLeaveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDragLeaveEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragLeaveEvent(QDragLeaveEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::dragLeaveEvent(cppArg0)
                : cppSelf->dragLeaveEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_dragMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::dragMoveEvent(QDragMoveEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDragMoveEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dragMoveEvent(QDragMoveEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dragMoveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDragMoveEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dragMoveEvent(QDragMoveEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::dragMoveEvent(cppArg0)
                : cppSelf->dragMoveEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_dropEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::dropEvent(QDropEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QDropEvent_IDX]), (pyArg)))) {
        overloadId = 0; // dropEvent(QDropEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dropEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDropEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // dropEvent(QDropEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::dropEvent(cppArg0)
                : cppSelf->dropEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_ensureCursorVisible(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // ensureCursorVisible()
        cppSelf->ensureCursorVisible();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_event(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::event(QEvent*)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX]), (pyArg)))) {
        overloadId = 0; // event(QEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "event", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // event(QEvent*)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::event(cppArg0)
                : cppSelf->event(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_extraSelections(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // extraSelections()const
        QList<QTextEdit::ExtraSelection> cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->extraSelections();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTextEdit_ExtraSelection_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_find(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    if (PyArg_ParseTuple(args, "|OO:find", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlainTextEdit::find(QRegularExpression,QFlags<QTextDocument::FindFlag>=)->bool
    // 1: QPlainTextEdit::find(QString,QFlags<QTextDocument::FindFlag>=)->bool
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 1; // find(QString,QFlags<QTextDocument::FindFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_FindFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 1; // find(QString,QFlags<QTextDocument::FindFlag>)
        }
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRegularExpression_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // find(QRegularExpression,QFlags<QTextDocument::FindFlag>)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_FindFlag_IDX])))->flagsConverter, (pyArgs[1])))) {
            overloadId = 0; // find(QRegularExpression,QFlags<QTextDocument::FindFlag>)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // find(const QRegularExpression &exp, QFlags<QTextDocument::FindFlag> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_FindFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QRegularExpression cppArg0_local;
            ::QRegularExpression *cppArg0 = &cppArg0_local;
            if (pythonToCpp[0].isValue())
                pythonToCpp[0](pyArgs[0], &cppArg0_local);
            else
                pythonToCpp[0](pyArgs[0], &cppArg0);

            ::QFlags<QTextDocument::FindFlag> cppArg1 = QTextDocument::FindFlags();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // find(QRegularExpression,QFlags<QTextDocument::FindFlag>)
                bool cppResult = cppSelf->find(*cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
        case 1: // find(const QString &exp, QFlags<QTextDocument::FindFlag> options)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_options = Shiboken::String::createStaticString("options");
                if (PyDict_Contains(kwds, key_options) != 0) {
                    value = PyDict_GetItem(kwds, key_options);
                    if (value != nullptr && pyArgs[1] != nullptr ) {
                        errInfo.reset(key_options);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                    }
                    if (value != nullptr) {
                        pyArgs[1] = value;
                        if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QTextDocument_FindFlag_IDX])))->flagsConverter, (pyArgs[1]))))
                            return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                    }
                    PyDict_DelItem(kwds_dup, key_options);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, "find", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                }
            }
            ::QString cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QFlags<QTextDocument::FindFlag> cppArg1 = QTextDocument::FindFlags();
            if (pythonToCpp[1])
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // find(QString,QFlags<QTextDocument::FindFlag>)
                bool cppResult = cppSelf->find(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_firstVisibleBlock(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // firstVisibleBlock()const
        QTextBlock cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->firstVisibleBlock();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextBlock_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_focusInEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::focusInEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusInEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusInEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusInEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::focusInEvent(cppArg0)
                : cppSelf->focusInEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_focusNextPrevChild(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::focusNextPrevChild(bool)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // focusNextPrevChild(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusNextPrevChild", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusNextPrevChild(bool)
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::focusNextPrevChild(cppArg0)
                : cppSelf->focusNextPrevChild(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_focusOutEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::focusOutEvent(QFocusEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFocusEvent_IDX]), (pyArg)))) {
        overloadId = 0; // focusOutEvent(QFocusEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "focusOutEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QFocusEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // focusOutEvent(QFocusEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::focusOutEvent(cppArg0)
                : cppSelf->focusOutEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_getPaintContext(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // getPaintContext()const
        QAbstractTextDocumentLayout::PaintContext cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->getPaintContext();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_PaintContext_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_inputMethodEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::inputMethodEvent(QInputMethodEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QInputMethodEvent_IDX]), (pyArg)))) {
        overloadId = 0; // inputMethodEvent(QInputMethodEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "inputMethodEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QInputMethodEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // inputMethodEvent(QInputMethodEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::inputMethodEvent(cppArg0)
                : cppSelf->inputMethodEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_inputMethodQuery(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "inputMethodQuery", 1, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QWidget::inputMethodQuery(Qt::InputMethodQuery)const->QVariant
    // 1: QPlainTextEdit::inputMethodQuery(Qt::InputMethodQuery,QVariant)const->QVariant
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_Qt_InputMethodQuery_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // inputMethodQuery(Qt::InputMethodQuery)const
        } else if (numArgs == 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], (pyArgs[1])))) {
            overloadId = 1; // inputMethodQuery(Qt::InputMethodQuery,QVariant)const
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "inputMethodQuery", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // inputMethodQuery(Qt::InputMethodQuery property) const
        {
            ::Qt::InputMethodQuery cppArg0 = static_cast< ::Qt::InputMethodQuery>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // inputMethodQuery(Qt::InputMethodQuery)const
                QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                    ? const_cast<const ::QPlainTextEdit *>(cppSelf)->::QPlainTextEdit::inputMethodQuery(cppArg0)
                    : const_cast<const ::QPlainTextEdit *>(cppSelf)->inputMethodQuery(cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
        case 1: // inputMethodQuery(Qt::InputMethodQuery query, QVariant argument) const
        {
            ::Qt::InputMethodQuery cppArg0 = static_cast< ::Qt::InputMethodQuery>(0);
            pythonToCpp[0](pyArgs[0], &cppArg0);
            ::QVariant cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);

            if (Shiboken::Errors::occurred() == nullptr) {
                // inputMethodQuery(Qt::InputMethodQuery,QVariant)const
                QVariant cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->inputMethodQuery(cppArg0, cppArg1);
                pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_insertFromMimeData(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::insertFromMimeData(const QMimeData*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QMimeData_IDX]), (pyArg)))) {
        overloadId = 0; // insertFromMimeData(const QMimeData*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "insertFromMimeData", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMimeData *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertFromMimeData(const QMimeData*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::insertFromMimeData(cppArg0)
                : cppSelf->insertFromMimeData(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_insertPlainText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::insertPlainText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // insertPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "insertPlainText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // insertPlainText(QString)
            cppSelf->insertPlainText(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_isReadOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isReadOnly()const
        bool cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->isReadOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_isUndoRedoEnabled(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // isUndoRedoEnabled()const
        bool cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->isUndoRedoEnabled();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_keyPressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::keyPressEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyPressEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyPressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyPressEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::keyPressEvent(cppArg0)
                : cppSelf->keyPressEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_keyReleaseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::keyReleaseEvent(QKeyEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeyEvent_IDX]), (pyArg)))) {
        overloadId = 0; // keyReleaseEvent(QKeyEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "keyReleaseEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QKeyEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // keyReleaseEvent(QKeyEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::keyReleaseEvent(cppArg0)
                : cppSelf->keyReleaseEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_lineWrapMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // lineWrapMode()const
        QPlainTextEdit::LineWrapMode cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->lineWrapMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_LineWrapMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_loadResource(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "loadResource", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlainTextEdit::loadResource(int,QUrl)->QVariant
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArgs[1])))) {
        overloadId = 0; // loadResource(int,QUrl)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "loadResource", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QUrl cppArg1_local;
        ::QUrl *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // loadResource(int,QUrl)
            QVariant cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::loadResource(cppArg0, *cppArg1)
                : cppSelf->loadResource(cppArg0, *cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppResult);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_maximumBlockCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // maximumBlockCount()const
        int cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->maximumBlockCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_mergeCurrentCharFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::mergeCurrentCharFormat(QTextCharFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArg)))) {
        overloadId = 0; // mergeCurrentCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mergeCurrentCharFormat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextCharFormat cppArg0_local;
        ::QTextCharFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // mergeCurrentCharFormat(QTextCharFormat)
            cppSelf->mergeCurrentCharFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_mouseDoubleClickEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseDoubleClickEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseDoubleClickEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseDoubleClickEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseDoubleClickEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::mouseDoubleClickEvent(cppArg0)
                : cppSelf->mouseDoubleClickEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_mouseMoveEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseMoveEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseMoveEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseMoveEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseMoveEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::mouseMoveEvent(cppArg0)
                : cppSelf->mouseMoveEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_mousePressEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mousePressEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mousePressEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mousePressEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mousePressEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::mousePressEvent(cppArg0)
                : cppSelf->mousePressEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_mouseReleaseEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::mouseReleaseEvent(QMouseEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QMouseEvent_IDX]), (pyArg)))) {
        overloadId = 0; // mouseReleaseEvent(QMouseEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "mouseReleaseEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QMouseEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // mouseReleaseEvent(QMouseEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::mouseReleaseEvent(cppArg0)
                : cppSelf->mouseReleaseEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_moveCursor(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "moveCursor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    if (PyArg_ParseTuple(args, "|OO:moveCursor", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlainTextEdit::moveCursor(QTextCursor::MoveOperation,QTextCursor::MoveMode=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveOperation_IDX])))->converter, (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // moveCursor(QTextCursor::MoveOperation,QTextCursor::MoveMode)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveMode_IDX])))->converter, (pyArgs[1])))) {
            overloadId = 0; // moveCursor(QTextCursor::MoveOperation,QTextCursor::MoveMode)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "moveCursor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_mode = Shiboken::String::createStaticString("mode");
            if (PyDict_Contains(kwds, key_mode) != 0) {
                value = PyDict_GetItem(kwds, key_mode);
                if (value != nullptr && pyArgs[1] != nullptr ) {
                    errInfo.reset(key_mode);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "moveCursor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[1] = value;
                    if (!(pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_MoveMode_IDX])))->converter, (pyArgs[1]))))
                        return Shiboken::returnWrongArguments(args, "moveCursor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_mode);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "moveCursor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
            }
        }
        ::QTextCursor::MoveOperation cppArg0{QTextCursor::NoMove};
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QTextCursor::MoveMode cppArg1(QTextCursor::MoveAnchor);
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // moveCursor(QTextCursor::MoveOperation,QTextCursor::MoveMode)
            cppSelf->moveCursor(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_overwriteMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // overwriteMode()const
        bool cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->overwriteMode();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_paintEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::paintEvent(QPaintEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintEvent_IDX]), (pyArg)))) {
        overloadId = 0; // paintEvent(QPaintEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "paintEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPaintEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // paintEvent(QPaintEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::paintEvent(cppArg0)
                : cppSelf->paintEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_paste(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // paste()
        cppSelf->paste();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_placeholderText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // placeholderText()const
        QString cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->placeholderText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_print_(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::print(QPagedPaintDevice*)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPagedPaintDevice_IDX]), (pyArg)))) {
        overloadId = 0; // print(QPagedPaintDevice*)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "print_", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QPagedPaintDevice *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // print(QPagedPaintDevice*)const
            const_cast<const ::QPlainTextEdit *>(cppSelf)->print(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_redo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // redo()
        cppSelf->redo();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_resizeEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::resizeEvent(QResizeEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QResizeEvent_IDX]), (pyArg)))) {
        overloadId = 0; // resizeEvent(QResizeEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "resizeEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QResizeEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // resizeEvent(QResizeEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::resizeEvent(cppArg0)
                : cppSelf->resizeEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_scrollContentsBy(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "scrollContentsBy", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QAbstractScrollArea::scrollContentsBy(int,int)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))) {
        overloadId = 0; // scrollContentsBy(int,int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "scrollContentsBy", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        int cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // scrollContentsBy(int,int)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::scrollContentsBy(cppArg0, cppArg1)
                : cppSelf->scrollContentsBy(cppArg0, cppArg1);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_selectAll(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // selectAll()
        cppSelf->selectAll();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setBackgroundVisible(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setBackgroundVisible(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setBackgroundVisible(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setBackgroundVisible", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setBackgroundVisible(bool)
            cppSelf->setBackgroundVisible(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setCenterOnScroll(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setCenterOnScroll(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setCenterOnScroll(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCenterOnScroll", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCenterOnScroll(bool)
            cppSelf->setCenterOnScroll(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setCurrentCharFormat(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setCurrentCharFormat(QTextCharFormat)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), (pyArg)))) {
        overloadId = 0; // setCurrentCharFormat(QTextCharFormat)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCurrentCharFormat", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextCharFormat cppArg0_local;
        ::QTextCharFormat *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setCurrentCharFormat(QTextCharFormat)
            cppSelf->setCurrentCharFormat(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setCursorWidth(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setCursorWidth(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setCursorWidth(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setCursorWidth", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setCursorWidth(int)
            cppSelf->setCursorWidth(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setDocument(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setDocument(QTextDocument*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextDocument_IDX]), (pyArg)))) {
        overloadId = 0; // setDocument(QTextDocument*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDocument", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextDocument *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDocument(QTextDocument*)
            cppSelf->setDocument(cppArg0);
            // Ownership transferences.
            Shiboken::Object::setParent(self, pyArg);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setDocumentTitle(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setDocumentTitle(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setDocumentTitle(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDocumentTitle", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setDocumentTitle(QString)
            cppSelf->setDocumentTitle(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setExtraSelections(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setExtraSelections(QList<QTextEdit::ExtraSelection>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTextEdit_ExtraSelection_IDX], (pyArg)))) {
        overloadId = 0; // setExtraSelections(QList<QTextEdit::ExtraSelection>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setExtraSelections", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        ::QList<QTextEdit::ExtraSelection> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setExtraSelections(QList<QTextEdit::ExtraSelection>)
            cppSelf->setExtraSelections(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setLineWrapMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setLineWrapMode(QPlainTextEdit::LineWrapMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_LineWrapMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setLineWrapMode(QPlainTextEdit::LineWrapMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLineWrapMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        ::QPlainTextEdit::LineWrapMode cppArg0{QPlainTextEdit::NoWrap};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setLineWrapMode(QPlainTextEdit::LineWrapMode)
            cppSelf->setLineWrapMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setMaximumBlockCount(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setMaximumBlockCount(int)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg)))) {
        overloadId = 0; // setMaximumBlockCount(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setMaximumBlockCount", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        int cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setMaximumBlockCount(int)
            cppSelf->setMaximumBlockCount(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setOverwriteMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setOverwriteMode(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setOverwriteMode(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOverwriteMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setOverwriteMode(bool)
            cppSelf->setOverwriteMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setPlaceholderText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setPlaceholderText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPlaceholderText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPlaceholderText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlaceholderText(QString)
            cppSelf->setPlaceholderText(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setPlainText(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setPlainText(QString)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // setPlainText(QString)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setPlainText", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setPlainText(QString)
            cppSelf->setPlainText(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setReadOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setReadOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setReadOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReadOnly", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setReadOnly(bool)
            cppSelf->setReadOnly(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setTabChangesFocus(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setTabChangesFocus(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setTabChangesFocus(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTabChangesFocus", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabChangesFocus(bool)
            cppSelf->setTabChangesFocus(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setTabStopDistance(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setTabStopDistance(qreal)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArg)))) {
        overloadId = 0; // setTabStopDistance(qreal)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTabStopDistance", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        qreal cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTabStopDistance(qreal)
            cppSelf->setTabStopDistance(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setTextCursor(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setTextCursor(QTextCursor)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), (pyArg)))) {
        overloadId = 0; // setTextCursor(QTextCursor)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextCursor", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTextCursor cppArg0_local;
        ::QTextCursor *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextCursor(QTextCursor)
            cppSelf->setTextCursor(*cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setTextInteractionFlags(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setTextInteractionFlags(QFlags<Qt::TextInteractionFlag>)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_TextInteractionFlag_IDX])))->flagsConverter, (pyArg)))) {
        overloadId = 0; // setTextInteractionFlags(QFlags<Qt::TextInteractionFlag>)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setTextInteractionFlags", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        ::QFlags<Qt::TextInteractionFlag> cppArg0 = QFlags<Qt::TextInteractionFlag>(0);
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setTextInteractionFlags(QFlags<Qt::TextInteractionFlag>)
            cppSelf->setTextInteractionFlags(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setUndoRedoEnabled(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setUndoRedoEnabled(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // setUndoRedoEnabled(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUndoRedoEnabled", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setUndoRedoEnabled(bool)
            cppSelf->setUndoRedoEnabled(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_setWordWrapMode(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::setWordWrapMode(QTextOption::WrapMode)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_WrapMode_IDX])))->converter, (pyArg)))) {
        overloadId = 0; // setWordWrapMode(QTextOption::WrapMode)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setWordWrapMode", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        ::QTextOption::WrapMode cppArg0{QTextOption::NoWrap};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // setWordWrapMode(QTextOption::WrapMode)
            cppSelf->setWordWrapMode(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_showEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::showEvent(QShowEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QShowEvent_IDX]), (pyArg)))) {
        overloadId = 0; // showEvent(QShowEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "showEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QShowEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // showEvent(QShowEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::showEvent(cppArg0)
                : cppSelf->showEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_tabChangesFocus(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tabChangesFocus()const
        bool cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->tabChangesFocus();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_tabStopDistance(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // tabStopDistance()const
        qreal cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->tabStopDistance();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_textCursor(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textCursor()const
        QTextCursor cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->textCursor();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCursor_IDX]), &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_textInteractionFlags(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // textInteractionFlags()const
        QFlags<Qt::TextInteractionFlag> cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->textInteractionFlags();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QFlags_Qt_TextInteractionFlag_IDX])))->flagsConverter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_timerEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QObject::timerEvent(QTimerEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimerEvent_IDX]), (pyArg)))) {
        overloadId = 0; // timerEvent(QTimerEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "timerEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QTimerEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // timerEvent(QTimerEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::timerEvent(cppArg0)
                : cppSelf->timerEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_toPlainText(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // toPlainText()const
        QString cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->toPlainText();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_undo(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // undo()
        cppSelf->undo();
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_wheelEvent(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QWidget::wheelEvent(QWheelEvent*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWheelEvent_IDX]), (pyArg)))) {
        overloadId = 0; // wheelEvent(QWheelEvent*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "wheelEvent", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QWheelEvent *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // wheelEvent(QWheelEvent*)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::QPlainTextEdit::wheelEvent(cppArg0)
                : cppSelf->wheelEvent(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_wordWrapMode(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // wordWrapMode()const
        QTextOption::WrapMode cppResult = const_cast<const ::QPlainTextEdit *>(cppSelf)->wordWrapMode();
        pyResult = Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextOption_WrapMode_IDX])))->converter, &cppResult);
    }

    if (Shiboken::Errors::occurred() != nullptr || pyResult == nullptr) {
        Py_XDECREF(pyResult);
        return {};
    }
    return pyResult;
}

static PyObject *Sbk_QPlainTextEditFunc_zoomIn(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "zoomIn", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    if (PyArg_ParseTuple(args, "|O:zoomIn", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlainTextEdit::zoomIn(int=)
    if (numArgs == 0) {
        overloadId = 0; // zoomIn(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // zoomIn(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "zoomIn", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_range = Shiboken::String::createStaticString("range");
            if (PyDict_Contains(kwds, key_range) != 0) {
                value = PyDict_GetItem(kwds, key_range);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_range);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "zoomIn", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "zoomIn", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_range);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "zoomIn", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
            }
        }
        int cppArg0 = 1;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // zoomIn(int)
            cppSelf->zoomIn(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_zoomInF(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    SBK_UNUSED(pythonToCpp)

    // Overloaded function decisor
    // 0: QPlainTextEdit::zoomInF(float)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<float>(), (pyArg)))) {
        overloadId = 0; // zoomInF(float)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "zoomInF", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        float cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // zoomInF(float)
            cppSelf->zoomInF(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *Sbk_QPlainTextEditFunc_zoomOut(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(kwds)
    if (!Shiboken::Object::isValid(self))
        return {};
    auto *cppSelf = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
    SBK_UNUSED(cppSelf)
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[1];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 0, 1));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "zoomOut", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    if (PyArg_ParseTuple(args, "|O:zoomOut", &(pyArgs[0])) == 0)
        return {};


    // Overloaded function decisor
    // 0: QPlainTextEdit::zoomOut(int=)
    if (numArgs == 0) {
        overloadId = 0; // zoomOut(int)
    } else if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0])))) {
        overloadId = 0; // zoomOut(int)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "zoomOut", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);

    // Call function/method
    {
        if (kwds && PyDict_Size(kwds) > 0) {
            PyObject *value{};
            Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
            static PyObject *const key_range = Shiboken::String::createStaticString("range");
            if (PyDict_Contains(kwds, key_range) != 0) {
                value = PyDict_GetItem(kwds, key_range);
                if (value != nullptr && pyArgs[0] != nullptr ) {
                    errInfo.reset(key_range);
                    Py_INCREF(errInfo.object());
                    return Shiboken::returnWrongArguments(args, "zoomOut", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                }
                if (value != nullptr) {
                    pyArgs[0] = value;
                    if (!(pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[0]))))
                        return Shiboken::returnWrongArguments(args, "zoomOut", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
                }
                PyDict_DelItem(kwds_dup, key_range);
            }
            if (PyDict_Size(kwds_dup) > 0) {
                errInfo.reset(kwds_dup.release());
                return Shiboken::returnWrongArguments(args, "zoomOut", errInfo, SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
            }
        }
        int cppArg0 = 1;
        if (pythonToCpp[0])
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // zoomOut(int)
            cppSelf->zoomOut(cppArg0);
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static const char *Sbk_QPlainTextEdit_PropertyStrings[] = {
    "backgroundVisible::",
    "blockCount:",
    "centerOnScroll::",
    "cursorWidth::",
    "documentTitle::",
    "lineWrapMode::",
    "maximumBlockCount::",
    "overwriteMode::",
    "placeholderText::",
    "plainText:toPlainText:",
    "readOnly:isReadOnly:",
    "tabChangesFocus::",
    "tabStopDistance::",
    "textInteractionFlags::",
    "undoRedoEnabled:isUndoRedoEnabled:",
    nullptr // Sentinel
};

static const char *Sbk_QPlainTextEdit_EnumFlagInfo[] = {
    "LineWrapMode:Enum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_QPlainTextEdit_methods[] = {
    {"anchorAt", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_anchorAt), METH_O, nullptr},
    {"appendHtml", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_appendHtml), METH_O, nullptr},
    {"appendPlainText", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_appendPlainText), METH_O, nullptr},
    {"backgroundVisible", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_backgroundVisible), METH_NOARGS, nullptr},
    {"blockBoundingGeometry", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_blockBoundingGeometry), METH_O, nullptr},
    {"blockBoundingRect", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_blockBoundingRect), METH_O, nullptr},
    {"blockCount", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_blockCount), METH_NOARGS, nullptr},
    {"canInsertFromMimeData", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_canInsertFromMimeData), METH_O, nullptr},
    {"canPaste", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_canPaste), METH_NOARGS, nullptr},
    {"centerCursor", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_centerCursor), METH_NOARGS, nullptr},
    {"centerOnScroll", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_centerOnScroll), METH_NOARGS, nullptr},
    {"changeEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_changeEvent), METH_O, nullptr},
    {"clear", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_clear), METH_NOARGS, nullptr},
    {"contentOffset", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_contentOffset), METH_NOARGS, nullptr},
    {"contextMenuEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_contextMenuEvent), METH_O, nullptr},
    {"copy", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_copy), METH_NOARGS, nullptr},
    {"createMimeDataFromSelection", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_createMimeDataFromSelection), METH_NOARGS, nullptr},
    {"createStandardContextMenu", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_createStandardContextMenu), METH_VARARGS, nullptr},
    {"currentCharFormat", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_currentCharFormat), METH_NOARGS, nullptr},
    {"cursorForPosition", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_cursorForPosition), METH_O, nullptr},
    {"cursorRect", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_cursorRect), METH_VARARGS, nullptr},
    {"cursorWidth", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_cursorWidth), METH_NOARGS, nullptr},
    {"cut", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_cut), METH_NOARGS, nullptr},
    {"doSetTextCursor", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_doSetTextCursor), METH_O, nullptr},
    {"document", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_document), METH_NOARGS, nullptr},
    {"documentTitle", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_documentTitle), METH_NOARGS, nullptr},
    {"dragEnterEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_dragEnterEvent), METH_O, nullptr},
    {"dragLeaveEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_dragLeaveEvent), METH_O, nullptr},
    {"dragMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_dragMoveEvent), METH_O, nullptr},
    {"dropEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_dropEvent), METH_O, nullptr},
    {"ensureCursorVisible", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_ensureCursorVisible), METH_NOARGS, nullptr},
    {"event", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_event), METH_O, nullptr},
    {"extraSelections", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_extraSelections), METH_NOARGS, nullptr},
    {"find", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_find), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"firstVisibleBlock", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_firstVisibleBlock), METH_NOARGS, nullptr},
    {"focusInEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_focusInEvent), METH_O, nullptr},
    {"focusNextPrevChild", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_focusNextPrevChild), METH_O, nullptr},
    {"focusOutEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_focusOutEvent), METH_O, nullptr},
    {"getPaintContext", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_getPaintContext), METH_NOARGS, nullptr},
    {"inputMethodEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_inputMethodEvent), METH_O, nullptr},
    {"inputMethodQuery", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_inputMethodQuery), METH_VARARGS, nullptr},
    {"insertFromMimeData", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_insertFromMimeData), METH_O, nullptr},
    {"insertPlainText", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_insertPlainText), METH_O, nullptr},
    {"isReadOnly", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_isReadOnly), METH_NOARGS, nullptr},
    {"isUndoRedoEnabled", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_isUndoRedoEnabled), METH_NOARGS, nullptr},
    {"keyPressEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_keyPressEvent), METH_O, nullptr},
    {"keyReleaseEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_keyReleaseEvent), METH_O, nullptr},
    {"lineWrapMode", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_lineWrapMode), METH_NOARGS, nullptr},
    {"loadResource", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_loadResource), METH_VARARGS, nullptr},
    {"maximumBlockCount", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_maximumBlockCount), METH_NOARGS, nullptr},
    {"mergeCurrentCharFormat", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_mergeCurrentCharFormat), METH_O, nullptr},
    {"mouseDoubleClickEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_mouseDoubleClickEvent), METH_O, nullptr},
    {"mouseMoveEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_mouseMoveEvent), METH_O, nullptr},
    {"mousePressEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_mousePressEvent), METH_O, nullptr},
    {"mouseReleaseEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_mouseReleaseEvent), METH_O, nullptr},
    {"moveCursor", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_moveCursor), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"overwriteMode", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_overwriteMode), METH_NOARGS, nullptr},
    {"paintEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_paintEvent), METH_O, nullptr},
    {"paste", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_paste), METH_NOARGS, nullptr},
    {"placeholderText", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_placeholderText), METH_NOARGS, nullptr},
    {"print_", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_print_), METH_O, nullptr},
    {"redo", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_redo), METH_NOARGS, nullptr},
    {"resizeEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_resizeEvent), METH_O, nullptr},
    {"scrollContentsBy", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_scrollContentsBy), METH_VARARGS, nullptr},
    {"selectAll", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_selectAll), METH_NOARGS, nullptr},
    {"setBackgroundVisible", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setBackgroundVisible), METH_O, nullptr},
    {"setCenterOnScroll", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setCenterOnScroll), METH_O, nullptr},
    {"setCurrentCharFormat", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setCurrentCharFormat), METH_O, nullptr},
    {"setCursorWidth", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setCursorWidth), METH_O, nullptr},
    {"setDocument", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setDocument), METH_O, nullptr},
    {"setDocumentTitle", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setDocumentTitle), METH_O, nullptr},
    {"setExtraSelections", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setExtraSelections), METH_O, nullptr},
    {"setLineWrapMode", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setLineWrapMode), METH_O, nullptr},
    {"setMaximumBlockCount", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setMaximumBlockCount), METH_O, nullptr},
    {"setOverwriteMode", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setOverwriteMode), METH_O, nullptr},
    {"setPlaceholderText", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setPlaceholderText), METH_O, nullptr},
    {"setPlainText", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setPlainText), METH_O, nullptr},
    {"setReadOnly", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setReadOnly), METH_O, nullptr},
    {"setTabChangesFocus", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setTabChangesFocus), METH_O, nullptr},
    {"setTabStopDistance", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setTabStopDistance), METH_O, nullptr},
    {"setTextCursor", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setTextCursor), METH_O, nullptr},
    {"setTextInteractionFlags", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setTextInteractionFlags), METH_O, nullptr},
    {"setUndoRedoEnabled", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setUndoRedoEnabled), METH_O, nullptr},
    {"setWordWrapMode", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_setWordWrapMode), METH_O, nullptr},
    {"showEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_showEvent), METH_O, nullptr},
    {"tabChangesFocus", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_tabChangesFocus), METH_NOARGS, nullptr},
    {"tabStopDistance", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_tabStopDistance), METH_NOARGS, nullptr},
    {"textCursor", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_textCursor), METH_NOARGS, nullptr},
    {"textInteractionFlags", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_textInteractionFlags), METH_NOARGS, nullptr},
    {"timerEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_timerEvent), METH_O, nullptr},
    {"toPlainText", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_toPlainText), METH_NOARGS, nullptr},
    {"undo", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_undo), METH_NOARGS, nullptr},
    {"wheelEvent", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_wheelEvent), METH_O, nullptr},
    {"wordWrapMode", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_wordWrapMode), METH_NOARGS, nullptr},
    {"zoomIn", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_zoomIn), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"zoomInF", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_zoomInF), METH_O, nullptr},
    {"zoomOut", reinterpret_cast<PyCFunction>(Sbk_QPlainTextEditFunc_zoomOut), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_QPlainTextEdit_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::QPlainTextEdit *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<QPlainTextEditWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    Shiboken::AutoDecRef pp(reinterpret_cast<PyObject *>(PySide::Property::getObject(self, name)));
    if (!pp.isNull())
        return PySide::Property::setValue(reinterpret_cast<PySideProperty *>(pp.object()), self, value);
    return PyObject_GenericSetAttr(self, name, value);
}

} // extern "C"

static int Sbk_QPlainTextEdit_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_QPlainTextEdit_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PepType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}
static void * Sbk_QPlainTextEditSpecialCastFunction(void *obj, PyTypeObject *desiredType)
{
    auto me = reinterpret_cast< ::QPlainTextEdit *>(obj);
    if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX]))
        return static_cast< ::QAbstractScrollArea *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX]))
        return static_cast< ::QFrame *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]))
        return static_cast< ::QWidget *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]))
        return static_cast< ::QObject *>(me);
    else if (desiredType == Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX]))
        return static_cast< ::QPaintDevice *>(me);
    return me;
}


// Class Definition -----------------------------------------------
extern "C" {
static PyTypeObject *_Sbk_QPlainTextEdit_Type = nullptr;
static PyTypeObject *Sbk_QPlainTextEdit_TypeF(void)
{
    return _Sbk_QPlainTextEdit_Type;
}

static PyType_Slot Sbk_QPlainTextEdit_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_QPlainTextEdit_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_QPlainTextEdit_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_QPlainTextEdit_clear)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_QPlainTextEdit_methods)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_QPlainTextEdit_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkObject_tp_new)},
    {0, nullptr}
};
static PyType_Spec Sbk_QPlainTextEdit_spec = {
    "2:PySide6.QtWidgets.QPlainTextEdit",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_QPlainTextEdit_slots
};

} //extern "C"

static void *Sbk_QPlainTextEdit_typeDiscovery(void *cptr, PyTypeObject *instanceType)
{
    SBK_UNUSED(cptr)
    SBK_UNUSED(instanceType)
    if (instanceType == Shiboken::SbkType< ::QWidget >())
        return dynamic_cast< ::QPlainTextEdit *>(reinterpret_cast< ::QWidget *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QObject >())
        return dynamic_cast< ::QPlainTextEdit *>(reinterpret_cast< ::QObject *>(cptr));
    if (instanceType == Shiboken::SbkType< ::QPaintDevice >())
        return dynamic_cast< ::QPlainTextEdit *>(reinterpret_cast< ::QPaintDevice *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_QPlainTextEdit_LineWrapMode(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::QPlainTextEdit::LineWrapMode>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::QPlainTextEdit::LineWrapMode *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_QPlainTextEdit_LineWrapMode_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_LineWrapMode_IDX])))
        return Enum_PythonToCpp_QPlainTextEdit_LineWrapMode;
    return {};
}

static PyObject *QPlainTextEdit_LineWrapMode_CppToPython_Enum(const void *cppIn)
{
    using IntType = std::underlying_type_t<::QPlainTextEdit::LineWrapMode>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::QPlainTextEdit::LineWrapMode *>(cppIn));
    return Shiboken::Enum::newItem(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_LineWrapMode_IDX]), castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void QPlainTextEdit_PythonToCpp_QPlainTextEdit_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_QPlainTextEdit_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_QPlainTextEdit_PythonToCpp_QPlainTextEdit_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_QPlainTextEdit_TypeF()))
        return QPlainTextEdit_PythonToCpp_QPlainTextEdit_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *QPlainTextEdit_PTR_CppToPython_QPlainTextEdit(const void *cppIn)
{
    return PySide::getWrapperForQObject(reinterpret_cast<::QPlainTextEdit *>(const_cast<void *>(cppIn)), Sbk_QPlainTextEdit_TypeF());

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QPlainTextEdit_SignatureStrings[] = {
    "1:PySide6.QtWidgets.QPlainTextEdit(self,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,tabChangesFocus:bool=None,documentTitle:QString=None,undoRedoEnabled:bool=None,lineWrapMode:QPlainTextEdit.LineWrapMode=None,readOnly:bool=None,plainText:QString=None,overwriteMode:bool=None,tabStopDistance:qreal=None,cursorWidth:int=None,textInteractionFlags:PySide6.QtCore.Qt.TextInteractionFlag=None,blockCount:int=None,maximumBlockCount:int=None,backgroundVisible:bool=None,centerOnScroll:bool=None,placeholderText:QString=None)",
    "0:PySide6.QtWidgets.QPlainTextEdit(self,text:QString,parent:PySide6.QtWidgets.QWidget=nullptr,*:KeywordOnly=None,tabChangesFocus:bool=None,documentTitle:QString=None,undoRedoEnabled:bool=None,lineWrapMode:QPlainTextEdit.LineWrapMode=None,readOnly:bool=None,plainText:QString=None,overwriteMode:bool=None,tabStopDistance:qreal=None,cursorWidth:int=None,textInteractionFlags:PySide6.QtCore.Qt.TextInteractionFlag=None,blockCount:int=None,maximumBlockCount:int=None,backgroundVisible:bool=None,centerOnScroll:bool=None,placeholderText:QString=None)",
    "PySide6.QtWidgets.QPlainTextEdit.anchorAt(self,pos:PySide6.QtCore.QPoint)->QString",
    "PySide6.QtWidgets.QPlainTextEdit.appendHtml(self,html:QString)",
    "PySide6.QtWidgets.QPlainTextEdit.appendPlainText(self,text:QString)",
    "PySide6.QtWidgets.QPlainTextEdit.backgroundVisible(self)->bool",
    "PySide6.QtWidgets.QPlainTextEdit.blockBoundingGeometry(self,block:PySide6.QtGui.QTextBlock)->PySide6.QtCore.QRectF",
    "PySide6.QtWidgets.QPlainTextEdit.blockBoundingRect(self,block:PySide6.QtGui.QTextBlock)->PySide6.QtCore.QRectF",
    "PySide6.QtWidgets.QPlainTextEdit.blockCount(self)->int",
    "PySide6.QtWidgets.QPlainTextEdit.canInsertFromMimeData(self,source:PySide6.QtCore.QMimeData)->bool",
    "PySide6.QtWidgets.QPlainTextEdit.canPaste(self)->bool",
    "PySide6.QtWidgets.QPlainTextEdit.centerCursor(self)",
    "PySide6.QtWidgets.QPlainTextEdit.centerOnScroll(self)->bool",
    "PySide6.QtWidgets.QPlainTextEdit.changeEvent(self,e:PySide6.QtCore.QEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.clear(self)",
    "PySide6.QtWidgets.QPlainTextEdit.contentOffset(self)->PySide6.QtCore.QPointF",
    "PySide6.QtWidgets.QPlainTextEdit.contextMenuEvent(self,e:PySide6.QtGui.QContextMenuEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.copy(self)",
    "PySide6.QtWidgets.QPlainTextEdit.createMimeDataFromSelection(self)->PySide6.QtCore.QMimeData",
    "1:PySide6.QtWidgets.QPlainTextEdit.createStandardContextMenu(self)->PySide6.QtWidgets.QMenu",
    "0:PySide6.QtWidgets.QPlainTextEdit.createStandardContextMenu(self,position:PySide6.QtCore.QPoint)->PySide6.QtWidgets.QMenu",
    "PySide6.QtWidgets.QPlainTextEdit.currentCharFormat(self)->PySide6.QtGui.QTextCharFormat",
    "PySide6.QtWidgets.QPlainTextEdit.cursorForPosition(self,pos:PySide6.QtCore.QPoint)->PySide6.QtGui.QTextCursor",
    "1:PySide6.QtWidgets.QPlainTextEdit.cursorRect(self)->PySide6.QtCore.QRect",
    "0:PySide6.QtWidgets.QPlainTextEdit.cursorRect(self,cursor:PySide6.QtGui.QTextCursor)->PySide6.QtCore.QRect",
    "PySide6.QtWidgets.QPlainTextEdit.cursorWidth(self)->int",
    "PySide6.QtWidgets.QPlainTextEdit.cut(self)",
    "PySide6.QtWidgets.QPlainTextEdit.doSetTextCursor(self,cursor:PySide6.QtGui.QTextCursor)",
    "PySide6.QtWidgets.QPlainTextEdit.document(self)->PySide6.QtGui.QTextDocument",
    "PySide6.QtWidgets.QPlainTextEdit.documentTitle(self)->QString",
    "PySide6.QtWidgets.QPlainTextEdit.dragEnterEvent(self,e:PySide6.QtGui.QDragEnterEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.dragLeaveEvent(self,e:PySide6.QtGui.QDragLeaveEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.dragMoveEvent(self,e:PySide6.QtGui.QDragMoveEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.dropEvent(self,e:PySide6.QtGui.QDropEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.ensureCursorVisible(self)",
    "PySide6.QtWidgets.QPlainTextEdit.event(self,e:PySide6.QtCore.QEvent)->bool",
    "PySide6.QtWidgets.QPlainTextEdit.extraSelections(self)->QList[PySide6.QtWidgets.QTextEdit.ExtraSelection]",
    "1:PySide6.QtWidgets.QPlainTextEdit.find(self,exp:typing.Union[PySide6.QtCore.QRegularExpression, QString],options:PySide6.QtGui.QTextDocument.FindFlag=QTextDocument.FindFlags())->bool",
    "0:PySide6.QtWidgets.QPlainTextEdit.find(self,exp:QString,options:PySide6.QtGui.QTextDocument.FindFlag=QTextDocument.FindFlags())->bool",
    "PySide6.QtWidgets.QPlainTextEdit.firstVisibleBlock(self)->PySide6.QtGui.QTextBlock",
    "PySide6.QtWidgets.QPlainTextEdit.focusInEvent(self,e:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.focusNextPrevChild(self,next:bool)->bool",
    "PySide6.QtWidgets.QPlainTextEdit.focusOutEvent(self,e:PySide6.QtGui.QFocusEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.getPaintContext(self)->PySide6.QtGui.QAbstractTextDocumentLayout.PaintContext",
    "PySide6.QtWidgets.QPlainTextEdit.inputMethodEvent(self,arg__1:PySide6.QtGui.QInputMethodEvent)",
    "1:PySide6.QtWidgets.QPlainTextEdit.inputMethodQuery(self,property:PySide6.QtCore.Qt.InputMethodQuery)->QVariant",
    "0:PySide6.QtWidgets.QPlainTextEdit.inputMethodQuery(self,query:PySide6.QtCore.Qt.InputMethodQuery,argument:QVariant)->QVariant",
    "PySide6.QtWidgets.QPlainTextEdit.insertFromMimeData(self,source:PySide6.QtCore.QMimeData)",
    "PySide6.QtWidgets.QPlainTextEdit.insertPlainText(self,text:QString)",
    "PySide6.QtWidgets.QPlainTextEdit.isReadOnly(self)->bool",
    "PySide6.QtWidgets.QPlainTextEdit.isUndoRedoEnabled(self)->bool",
    "PySide6.QtWidgets.QPlainTextEdit.keyPressEvent(self,e:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.keyReleaseEvent(self,e:PySide6.QtGui.QKeyEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.lineWrapMode(self)->PySide6.QtWidgets.QPlainTextEdit.LineWrapMode",
    "PySide6.QtWidgets.QPlainTextEdit.loadResource(self,type:int,name:typing.Union[PySide6.QtCore.QUrl, QString])->QVariant",
    "PySide6.QtWidgets.QPlainTextEdit.maximumBlockCount(self)->int",
    "PySide6.QtWidgets.QPlainTextEdit.mergeCurrentCharFormat(self,modifier:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtWidgets.QPlainTextEdit.mouseDoubleClickEvent(self,e:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.mouseMoveEvent(self,e:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.mousePressEvent(self,e:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.mouseReleaseEvent(self,e:PySide6.QtGui.QMouseEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.moveCursor(self,operation:PySide6.QtGui.QTextCursor.MoveOperation,mode:PySide6.QtGui.QTextCursor.MoveMode=QTextCursor.MoveAnchor)",
    "PySide6.QtWidgets.QPlainTextEdit.overwriteMode(self)->bool",
    "PySide6.QtWidgets.QPlainTextEdit.paintEvent(self,e:PySide6.QtGui.QPaintEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.paste(self)",
    "PySide6.QtWidgets.QPlainTextEdit.placeholderText(self)->QString",
    "PySide6.QtWidgets.QPlainTextEdit.print_(self,printer:PySide6.QtGui.QPagedPaintDevice)",
    "PySide6.QtWidgets.QPlainTextEdit.redo(self)",
    "PySide6.QtWidgets.QPlainTextEdit.resizeEvent(self,e:PySide6.QtGui.QResizeEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.scrollContentsBy(self,dx:int,dy:int)",
    "PySide6.QtWidgets.QPlainTextEdit.selectAll(self)",
    "PySide6.QtWidgets.QPlainTextEdit.setBackgroundVisible(self,visible:bool)",
    "PySide6.QtWidgets.QPlainTextEdit.setCenterOnScroll(self,enabled:bool)",
    "PySide6.QtWidgets.QPlainTextEdit.setCurrentCharFormat(self,format:PySide6.QtGui.QTextCharFormat)",
    "PySide6.QtWidgets.QPlainTextEdit.setCursorWidth(self,width:int)",
    "PySide6.QtWidgets.QPlainTextEdit.setDocument(self,document:PySide6.QtGui.QTextDocument)",
    "PySide6.QtWidgets.QPlainTextEdit.setDocumentTitle(self,title:QString)",
    "PySide6.QtWidgets.QPlainTextEdit.setExtraSelections(self,selections:QList[PySide6.QtWidgets.QTextEdit.ExtraSelection])",
    "PySide6.QtWidgets.QPlainTextEdit.setLineWrapMode(self,mode:PySide6.QtWidgets.QPlainTextEdit.LineWrapMode)",
    "PySide6.QtWidgets.QPlainTextEdit.setMaximumBlockCount(self,maximum:int)",
    "PySide6.QtWidgets.QPlainTextEdit.setOverwriteMode(self,overwrite:bool)",
    "PySide6.QtWidgets.QPlainTextEdit.setPlaceholderText(self,placeholderText:QString)",
    "PySide6.QtWidgets.QPlainTextEdit.setPlainText(self,text:QString)",
    "PySide6.QtWidgets.QPlainTextEdit.setReadOnly(self,ro:bool)",
    "PySide6.QtWidgets.QPlainTextEdit.setTabChangesFocus(self,b:bool)",
    "PySide6.QtWidgets.QPlainTextEdit.setTabStopDistance(self,distance:qreal)",
    "PySide6.QtWidgets.QPlainTextEdit.setTextCursor(self,cursor:PySide6.QtGui.QTextCursor)",
    "PySide6.QtWidgets.QPlainTextEdit.setTextInteractionFlags(self,flags:PySide6.QtCore.Qt.TextInteractionFlag)",
    "PySide6.QtWidgets.QPlainTextEdit.setUndoRedoEnabled(self,enable:bool)",
    "PySide6.QtWidgets.QPlainTextEdit.setWordWrapMode(self,policy:PySide6.QtGui.QTextOption.WrapMode)",
    "PySide6.QtWidgets.QPlainTextEdit.showEvent(self,arg__1:PySide6.QtGui.QShowEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.tabChangesFocus(self)->bool",
    "PySide6.QtWidgets.QPlainTextEdit.tabStopDistance(self)->qreal",
    "PySide6.QtWidgets.QPlainTextEdit.textCursor(self)->PySide6.QtGui.QTextCursor",
    "PySide6.QtWidgets.QPlainTextEdit.textInteractionFlags(self)->PySide6.QtCore.Qt.TextInteractionFlag",
    "PySide6.QtWidgets.QPlainTextEdit.timerEvent(self,e:PySide6.QtCore.QTimerEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.toPlainText(self)->QString",
    "PySide6.QtWidgets.QPlainTextEdit.undo(self)",
    "PySide6.QtWidgets.QPlainTextEdit.wheelEvent(self,e:PySide6.QtGui.QWheelEvent)",
    "PySide6.QtWidgets.QPlainTextEdit.wordWrapMode(self)->PySide6.QtGui.QTextOption.WrapMode",
    "PySide6.QtWidgets.QPlainTextEdit.zoomIn(self,range:int=1)",
    "PySide6.QtWidgets.QPlainTextEdit.zoomInF(self,range:float)",
    "PySide6.QtWidgets.QPlainTextEdit.zoomOut(self,range:int=1)",
    nullptr}; // Sentinel
#else
static constexpr size_t QPlainTextEdit_SignatureByteSize = 1525;
static constexpr uint8_t QPlainTextEdit_SignatureBytes[1525] = {
    0x78, 0xda, 0xed, 0x59, 0x4b, 0x6f, 0xdb, 0x38, 0x10, 0xbe, 0xf7, 0x57, 0xec, 0xb1, 0x5e, 0x68,
    0x8d, 0xe6, 0xb2, 0x07, 0x03, 0x5d, 0x20, 0xf1, 0xa3, 0x1b, 0x34, 0xa9, 0x9d, 0x38, 0x69, 0x0e,
    0x45, 0x51, 0x30, 0xd2, 0xd8, 0x26, 0x22, 0x91, 0x2a, 0x49, 0x39, 0x51, 0x7f, 0x7d, 0x87, 0xd4,
    0xc3, 0x92, 0x2c, 0x4b, 0xa3, 0x6d, 0xb0, 0x97, 0xdd, 0x93, 0x1f, 0x9c, 0xf9, 0x66, 0x38, 0x1c,
    0xce, 0x8b, 0x67, 0x93, 0x55, 0xba, 0xe6, 0x01, 0xfc, 0x39, 0xbe, 0x31, 0x0f, 0x3c, 0xd8, 0x82,
    0xd1, 0xe3, 0x9b, 0x55, 0xc8, 0xb8, 0xb8, 0x83, 0x17, 0x33, 0x0f, 0xb8, 0x79, 0xab, 0x21, 0xdc,
    0x78, 0x31, 0x53, 0x20, 0x4c, 0x1b, 0x71, 0xf6, 0xe5, 0xbd, 0x48, 0xc2, 0x30, 0x36, 0xca, 0xfb,
    0x7d, 0xf2, 0x11, 0xd2, 0x67, 0xa9, 0x82, 0xa5, 0x08, 0xd3, 0xf7, 0x9f, 0xa4, 0x00, 0xcf, 0xb0,
    0xc7, 0xe9, 0x8e, 0x89, 0x2d, 0xe8, 0x85, 0xf4, 0x13, 0x3d, 0x79, 0x94, 0x32, 0xcc, 0x56, 0x02,
    0xfc, 0x1d, 0x21, 0xee, 0x1d, 0x37, 0x21, 0x4c, 0x6e, 0xd6, 0x46, 0x71, 0xb1, 0xcd, 0x96, 0x12,
    0x11, 0xc8, 0x5b, 0x08, 0xe4, 0x5c, 0xb0, 0xc7, 0x10, 0x82, 0x0a, 0x53, 0xc8, 0x05, 0x3c, 0x28,
    0x16, 0x5f, 0xcb, 0x00, 0x79, 0x6a, 0xba, 0x8e, 0xaf, 0x2a, 0x6b, 0x19, 0xb5, 0x02, 0xe6, 0x54,
    0xa9, 0x00, 0xc4, 0x05, 0x4b, 0x5d, 0xa2, 0xdc, 0x83, 0x7a, 0x56, 0xdc, 0x80, 0x03, 0x3e, 0x90,
    0xa3, 0xfa, 0x6b, 0x23, 0xe3, 0x19, 0xd7, 0x86, 0x09, 0x1f, 0x26, 0xdf, 0x11, 0x32, 0x5f, 0xf2,
    0x13, 0xa5, 0xa5, 0x42, 0x0b, 0x98, 0xdd, 0x84, 0x0b, 0x93, 0xd3, 0x23, 0xf2, 0xa5, 0x30, 0xa0,
    0x98, 0x6f, 0xb8, 0x14, 0x8b, 0x90, 0x6d, 0x75, 0xc5, 0x70, 0x53, 0xa9, 0x00, 0x3f, 0xc6, 0x77,
    0xc7, 0x64, 0x19, 0xff, 0x63, 0x28, 0xfd, 0xa7, 0xa9, 0x4c, 0xd0, 0xdc, 0x25, 0x66, 0xc4, 0x5e,
    0x78, 0x94, 0x44, 0x17, 0x2d, 0x4b, 0x8f, 0xcc, 0x7f, 0xda, 0x2a, 0xfc, 0x2f, 0xf8, 0xcc, 0x35,
    0x47, 0x5b, 0x55, 0x54, 0xf7, 0xc1, 0x0a, 0x58, 0x8a, 0xb5, 0xaf, 0x64, 0x18, 0xd6, 0x4d, 0xe0,
    0xc3, 0x4e, 0x86, 0x01, 0xa8, 0x23, 0x43, 0x8c, 0xde, 0xbc, 0x23, 0x3a, 0x85, 0xa9, 0xb0, 0xfe,
    0xef, 0x21, 0xff, 0x25, 0x0f, 0xe9, 0xf3, 0x8f, 0x31, 0xda, 0x61, 0x27, 0xd5, 0x79, 0x11, 0x3d,
    0xe4, 0xf1, 0xfe, 0x56, 0x12, 0x15, 0x1c, 0xfd, 0xf1, 0x57, 0x0e, 0x4c, 0x80, 0x8c, 0x63, 0x10,
    0xc1, 0xdf, 0x26, 0x0a, 0x33, 0xd0, 0x1d, 0x7e, 0x2b, 0xd4, 0x1a, 0x51, 0xd9, 0xcb, 0xff, 0x8e,
    0x3d, 0x98, 0x80, 0x71, 0x64, 0x49, 0x87, 0x82, 0x9b, 0xb0, 0x76, 0x23, 0xb0, 0xdb, 0xc3, 0xb9,
    0xb0, 0xec, 0x28, 0xee, 0x03, 0xc8, 0x08, 0x8c, 0x4a, 0x33, 0x45, 0xdc, 0x52, 0xc5, 0x46, 0x1f,
    0x12, 0x3e, 0xbe, 0xb1, 0x8c, 0xee, 0x40, 0x51, 0x42, 0xd3, 0x7c, 0xb7, 0xe0, 0x9b, 0xc5, 0x40,
    0x91, 0x96, 0xe7, 0x5f, 0x10, 0xe7, 0xdc, 0xaf, 0xb0, 0x0c, 0x1e, 0x72, 0x3f, 0x9b, 0xcf, 0xc4,
    0xa5, 0xd0, 0xa0, 0xcc, 0x42, 0xc9, 0xe8, 0x9a, 0x47, 0x30, 0x63, 0x86, 0x65, 0x9a, 0x6a, 0x99,
    0x28, 0xbc, 0x52, 0x4d, 0x7d, 0x0a, 0x22, 0xb2, 0xed, 0x51, 0xc4, 0x8a, 0x69, 0x33, 0xf0, 0xc4,
    0xb2, 0xeb, 0x31, 0x75, 0x97, 0x38, 0xe3, 0xa4, 0xf2, 0x14, 0x57, 0x6a, 0xa0, 0x3c, 0x17, 0x05,
    0xe7, 0x7b, 0xc8, 0x0d, 0xe8, 0x1d, 0xef, 0xdc, 0x2d, 0x52, 0xd4, 0x08, 0x81, 0xd1, 0x75, 0x96,
    0xa8, 0xb3, 0x30, 0xcb, 0xcd, 0x46, 0x43, 0x79, 0x74, 0xad, 0x37, 0x76, 0x41, 0x04, 0x7b, 0x31,
    0xd7, 0x20, 0x92, 0x13, 0x3b, 0x71, 0xee, 0x36, 0x6d, 0x90, 0x91, 0xd4, 0x8c, 0x53, 0xf2, 0x96,
    0x30, 0x08, 0x63, 0xa4, 0xce, 0xfd, 0xc4, 0x3a, 0xd6, 0x1a, 0x42, 0x70, 0x91, 0xf4, 0xd4, 0x06,
    0x0b, 0xe2, 0x37, 0x67, 0x13, 0x22, 0xfc, 0x1a, 0x03, 0x7e, 0xc0, 0x54, 0x50, 0xd9, 0xcb, 0x31,
    0x78, 0x89, 0x60, 0x97, 0x09, 0xc9, 0xb5, 0x07, 0xdb, 0x46, 0x53, 0x6e, 0xb7, 0x71, 0x32, 0xa4,
    0x9e, 0x12, 0xdd, 0x2f, 0x38, 0x51, 0x36, 0x89, 0x63, 0x2e, 0x56, 0x0b, 0xa9, 0x22, 0xd6, 0xe2,
    0x0a, 0x65, 0xa4, 0x38, 0x10, 0x91, 0x70, 0xf1, 0x02, 0x21, 0xf5, 0x2a, 0x57, 0xbd, 0x3f, 0x2d,
    0xb4, 0x49, 0x74, 0x28, 0xa4, 0xc3, 0x71, 0x94, 0x65, 0xb8, 0x3b, 0x11, 0xcf, 0x48, 0x47, 0x51,
    0x47, 0xca, 0xf3, 0xf9, 0xe4, 0xa4, 0x76, 0xa7, 0x44, 0x11, 0x05, 0xb9, 0x42, 0x61, 0x58, 0xe8,
    0x4c, 0x0c, 0xf5, 0x46, 0x04, 0x72, 0x0d, 0xe6, 0xa0, 0x2a, 0x71, 0x43, 0x14, 0xdc, 0xac, 0x46,
    0xeb, 0x70, 0x96, 0x59, 0x4e, 0x42, 0x07, 0x73, 0x05, 0x5f, 0x81, 0x48, 0xae, 0x11, 0x02, 0xc5,
    0xb6, 0x73, 0x1b, 0x7e, 0xbb, 0x02, 0xcf, 0xac, 0x46, 0x34, 0xa2, 0xa1, 0x5e, 0x01, 0xdb, 0x43,
    0x1f, 0xea, 0x81, 0x88, 0x88, 0x7a, 0x2d, 0xfb, 0x41, 0x4b, 0x1a, 0x12, 0xa6, 0x8c, 0xbb, 0xf1,
    0xf2, 0x75, 0x02, 0x16, 0x08, 0x9d, 0x28, 0xc8, 0xbc, 0xa0, 0x56, 0xee, 0x10, 0x58, 0xfb, 0x13,
    0x18, 0x35, 0x23, 0xe2, 0xa7, 0x62, 0x65, 0xe4, 0xd6, 0xa5, 0x47, 0x5c, 0x61, 0xb1, 0xfd, 0xa5,
    0x85, 0xbb, 0x64, 0x9c, 0xd7, 0x18, 0xbf, 0x52, 0xc2, 0xc6, 0x86, 0x8b, 0x20, 0xd7, 0xfa, 0x25,
    0x9e, 0x98, 0x34, 0x46, 0x9f, 0x1b, 0xdf, 0x0b, 0x64, 0xff, 0x72, 0x7c, 0xa9, 0xb7, 0x49, 0xc8,
    0xd4, 0xfc, 0x25, 0x56, 0xa0, 0x35, 0x52, 0x78, 0xbf, 0xe5, 0x4e, 0xfa, 0xd5, 0x93, 0xb1, 0x53,
    0x75, 0xd2, 0x71, 0x0f, 0xc6, 0x0b, 0x14, 0xe5, 0x0a, 0xfa, 0xf6, 0xbf, 0xf5, 0xdb, 0x51, 0x61,
    0xa1, 0x77, 0x43, 0xf5, 0x2e, 0x1a, 0xb2, 0xd7, 0x55, 0x83, 0xa0, 0x84, 0xd2, 0x26, 0xf7, 0x13,
    0x57, 0x45, 0x76, 0x84, 0x03, 0xb7, 0x4e, 0x80, 0xb4, 0xcd, 0xe0, 0xa5, 0xe8, 0x72, 0x68, 0xd7,
    0x2f, 0x52, 0x3d, 0xda, 0xe1, 0x7d, 0xc2, 0x5f, 0x2b, 0x05, 0xfb, 0xe9, 0x8e, 0x87, 0xb9, 0xd5,
    0x84, 0xed, 0x02, 0xec, 0x2e, 0xe9, 0x9b, 0xb5, 0x48, 0xcb, 0xc4, 0xbc, 0x9a, 0x6a, 0xf8, 0xdf,
    0x0a, 0x7f, 0x9b, 0x3c, 0xd9, 0x9f, 0xb0, 0xdd, 0xf9, 0xa3, 0x36, 0xb6, 0x1b, 0xac, 0x1e, 0xd6,
    0x15, 0x4b, 0x65, 0x62, 0xc6, 0x55, 0xee, 0x7e, 0x71, 0x5c, 0xc4, 0x09, 0x56, 0x14, 0x66, 0x27,
    0x83, 0xca, 0x16, 0x98, 0xda, 0x7e, 0xfb, 0x76, 0xd6, 0xdc, 0xc7, 0x65, 0x83, 0x76, 0x44, 0xb9,
    0x4a, 0x15, 0x01, 0x37, 0x09, 0x14, 0x5d, 0x4e, 0x8c, 0xe1, 0x07, 0xab, 0xfc, 0xb4, 0xa5, 0xd9,
    0xbd, 0x6c, 0x30, 0xd8, 0x3b, 0xfe, 0x99, 0x29, 0xce, 0x04, 0x29, 0x4f, 0xb7, 0xcb, 0xfb, 0x6e,
    0xbf, 0x12, 0x84, 0xd9, 0x9d, 0x3b, 0x63, 0x4e, 0x0a, 0x99, 0x55, 0xf1, 0x04, 0xe1, 0xff, 0xac,
    0x77, 0xa1, 0x22, 0xff, 0x5a, 0xd3, 0xca, 0xf5, 0x6d, 0x3e, 0xe1, 0x18, 0xd6, 0x8b, 0x70, 0x7d,
    0x5f, 0x9f, 0xb0, 0x0c, 0x63, 0x7f, 0x82, 0x74, 0x65, 0x63, 0x63, 0xd7, 0x15, 0xf9, 0x08, 0x29,
    0xf5, 0x82, 0x20, 0xdc, 0x2d, 0x06, 0x73, 0xa6, 0xe1, 0x95, 0x00, 0xab, 0x43, 0xa2, 0x8e, 0x9a,
    0xfd, 0xf4, 0xf4, 0x88, 0x20, 0x42, 0xb2, 0xe0, 0x16, 0x32, 0x2f, 0xc8, 0x8f, 0x2e, 0x8d, 0xc1,
    0x0e, 0x66, 0x3c, 0xc1, 0x22, 0xe8, 0xce, 0x30, 0xf7, 0x2a, 0x3c, 0xe4, 0x94, 0x41, 0xee, 0x78,
    0x34, 0x0a, 0x1a, 0x54, 0x50, 0x46, 0xa0, 0xb6, 0x36, 0xeb, 0xb7, 0x34, 0x02, 0x5e, 0x24, 0x03,
    0xbe, 0xe1, 0xd0, 0x5e, 0x2e, 0x96, 0xb4, 0x04, 0xe3, 0x47, 0x32, 0xd1, 0x30, 0x93, 0x09, 0xba,
    0xd5, 0x34, 0xe4, 0xfe, 0x53, 0xd7, 0x99, 0x5e, 0x5b, 0x5a, 0xea, 0xa9, 0x3a, 0xe0, 0xbe, 0xaa,
    0x6a, 0x38, 0x62, 0xaf, 0x27, 0x0f, 0x87, 0x24, 0x78, 0xf3, 0x40, 0xd0, 0x3d, 0x54, 0x0b, 0x7b,
    0x1b, 0x69, 0x59, 0xa3, 0x4d, 0x6c, 0xd4, 0xf6, 0x63, 0x6b, 0xa8, 0x65, 0x41, 0x67, 0x4f, 0x17,
    0x7a, 0x88, 0xdd, 0xd4, 0xb4, 0xf9, 0xe7, 0xb9, 0x9b, 0xf5, 0x11, 0x54, 0xac, 0xcd, 0x4f, 0x87,
    0x45, 0x93, 0xd8, 0xa6, 0xb7, 0x2e, 0x5b, 0xad, 0x4a, 0x82, 0x11, 0x05, 0xad, 0x9c, 0x04, 0x11,
    0x88, 0xeb, 0x93, 0xd0, 0xc1, 0x3d, 0x49, 0x8c, 0x64, 0xe6, 0x5b, 0x91, 0x00, 0xb9, 0x6d, 0x3c,
    0x8e, 0x95, 0xdf, 0x42, 0xe0, 0x76, 0x30, 0x83, 0x3d, 0xf7, 0x29, 0x03, 0x56, 0x85, 0x71, 0x99,
    0xba, 0x03, 0x74, 0x5e, 0xfe, 0xa3, 0xd3, 0xd3, 0x6e, 0x0f, 0x14, 0x04, 0x3c, 0xed, 0x26, 0x5b,
    0xd3, 0x6c, 0x66, 0xa4, 0x2f, 0xf2, 0x64, 0x1b, 0xbc, 0xb8, 0xc8, 0x16, 0xa4, 0xf6, 0x83, 0x82,
    0xe2, 0x6a, 0xf3, 0xf3, 0x62, 0x44, 0x46, 0x61, 0x30, 0x17, 0xad, 0x03, 0x58, 0x6f, 0x5f, 0x99,
    0x6b, 0xd3, 0x80, 0xa6, 0xc7, 0x43, 0x3a, 0x0f, 0x2a, 0x0f, 0x09, 0x44, 0x94, 0xf6, 0x30, 0xb9,
    0x71, 0xdf, 0x7f, 0x39, 0x48, 0x66, 0x02, 0x6a, 0x53, 0x01, 0xef, 0xb9, 0x78, 0x49, 0xa0, 0xf1,
    0xcf, 0xaa, 0xad, 0x79, 0xf9, 0x98, 0xd2, 0xd5, 0x12, 0x0c, 0xc3, 0x3d, 0x74, 0xe9, 0x9e, 0xa9,
    0xbe, 0xd0, 0xd0, 0x50, 0xe6, 0x2d, 0xbd, 0x9d, 0xa7, 0xcb, 0xdf, 0x93, 0xc1, 0x4d, 0x1e, 0x4d,
    0xec, 0x55, 0x33, 0xf3, 0x37, 0x23, 0x1f, 0x21, 0xf9, 0xd3, 0x24, 0x5d, 0xb7, 0x66, 0xe2, 0xe2,
    0xad, 0x86, 0x7e, 0x8c, 0xcb, 0xa3, 0xc0, 0x79, 0x78, 0x8b, 0x1a, 0xe0, 0xae, 0xab, 0x96, 0x48,
    0x76, 0xea, 0xa1, 0x87, 0x8c, 0xf8, 0x0b, 0x95, 0x29, 0x02, 0xd4, 0x4a, 0x53, 0x4f, 0xc9, 0x01,
    0xbb, 0xb9, 0xab, 0x3f, 0x1a, 0xe6, 0x0f, 0x1b, 0xc3, 0x00, 0xaa, 0xcf, 0x76, 0xf9, 0x1d, 0xa9,
    0x3d, 0xe2, 0x11, 0x81, 0x5e, 0x7f, 0xa6, 0x96, 0xa3, 0x36, 0x5f, 0x09, 0xf3, 0xf8, 0x42, 0x7f,
    0x30, 0xa4, 0x89, 0x6a, 0x2b, 0xf4, 0xf3, 0x70, 0x38, 0xc0, 0x9e, 0x0f, 0x52, 0x05, 0xf5, 0x7b,
    0x15, 0x4b, 0x2c, 0xee, 0xd2, 0x36, 0x43, 0x2c, 0xdd, 0x70, 0x62, 0x3c, 0xe4, 0x3a, 0xed, 0xe4,
    0x73, 0x6f, 0xaf, 0xba, 0x2e, 0x88, 0x08, 0x80, 0xa6, 0xc5, 0x7f, 0xc8, 0xf5, 0x88, 0x69, 0xf1,
    0x1d, 0x64, 0x76, 0x4e, 0x43, 0xe0, 0xae, 0x3b, 0x4c, 0xe7, 0xb8, 0x9b, 0x04, 0xd6, 0xea, 0x27,
    0x2d, 0xb3, 0xe8, 0x56, 0x1f, 0x21, 0x88, 0xc0, 0x8e, 0x55, 0x75, 0xbe, 0x4a, 0xdd, 0x95, 0x14,
    0x14, 0xcb, 0xcb, 0x7a, 0xdc, 0x18, 0x52, 0x4d, 0xd9, 0x57, 0x7f, 0x6a, 0xc1, 0xf0, 0xbc, 0x03,
    0x08, 0xbb, 0xca, 0x9e, 0x87, 0x92, 0x80, 0x82, 0xd6, 0x74, 0xef, 0xf6, 0x63, 0x6b, 0x78, 0x76,
    0x3f, 0xee, 0x0f, 0x29, 0xa3, 0xcb, 0xfc, 0x45, 0x44, 0x59, 0x7f, 0x74, 0x2f, 0xf7, 0x67, 0x23,
    0x2a, 0xe7, 0xa2, 0xca, 0xba, 0xc1, 0x9e, 0xd3, 0x10, 0x59, 0x97, 0xf9, 0xd3, 0x41, 0x5d, 0xea,
    0x4f, 0x02, 0x34, 0x39, 0x67
};
#endif

PyTypeObject *init_QPlainTextEdit(PyObject *module)
{
    if (SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX].type != nullptr)
        return SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX].type;

    Shiboken::AutoDecRef Sbk_QPlainTextEdit_Type_bases(PyTuple_Pack(1,
        reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX]))));

    _Sbk_QPlainTextEdit_Type = Shiboken::ObjectType::introduceWrapperType(
        module,
        "QPlainTextEdit",
        "QPlainTextEdit*",
        &Sbk_QPlainTextEdit_spec,
        &Shiboken::callCppDestructor< QPlainTextEdit >,
        Sbk_QPlainTextEdit_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::DeleteInMainThread);
    auto *pyType = Sbk_QPlainTextEdit_TypeF(); // references _Sbk_QPlainTextEdit_Type
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, QPlainTextEdit_SignatureStrings);
#else
    InitSignatureBytes(pyType, QPlainTextEdit_SignatureBytes, QPlainTextEdit_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_QPlainTextEdit_PropertyStrings);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX].type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        QPlainTextEdit_PythonToCpp_QPlainTextEdit_PTR,
        is_QPlainTextEdit_PythonToCpp_QPlainTextEdit_PTR_Convertible,
        QPlainTextEdit_PTR_CppToPython_QPlainTextEdit);

    Shiboken::Conversions::registerConverterName(converter, "QPlainTextEdit");
    Shiboken::Conversions::registerConverterName(converter, "QPlainTextEdit*");
    Shiboken::Conversions::registerConverterName(converter, "QPlainTextEdit&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::QPlainTextEdit).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(QPlainTextEditWrapper).name());

    MultipleInheritanceInitFunction func = Shiboken::ObjectType::getMultipleInheritanceFunction(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]));
    Shiboken::ObjectType::setMultipleInheritanceFunction(Sbk_QPlainTextEdit_TypeF(), func);
    Shiboken::ObjectType::setCastFunction(Sbk_QPlainTextEdit_TypeF(), &Sbk_QPlainTextEditSpecialCastFunction);
    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(
        Sbk_QPlainTextEdit_TypeF(), &Sbk_QPlainTextEdit_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_QPlainTextEdit_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    PyTypeObject *EType{};

    // Initialization of enum 'LineWrapMode'.
    const char *LineWrapMode_Initializer[] = {
        "NoWrap",
        "WidgetWidth",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t LineWrapMode_InitializerValues[] = {
        uint8_t(QPlainTextEdit::LineWrapMode::NoWrap),     //  0x00  0
        uint8_t(QPlainTextEdit::LineWrapMode::WidgetWidth) //  0x01  1
        };
    EType = Shiboken::Enum::createPythonEnum(Sbk_QPlainTextEdit_TypeF(),
        "2:PySide6.QtWidgets.QPlainTextEdit.LineWrapMode",
        LineWrapMode_Initializer, LineWrapMode_InitializerValues);
    SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_LineWrapMode_IDX].type = EType;
    // Register converter for enum 'QPlainTextEdit::LineWrapMode'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            QPlainTextEdit_LineWrapMode_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_QPlainTextEdit_LineWrapMode,
            is_Enum_PythonToCpp_QPlainTextEdit_LineWrapMode_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "QPlainTextEdit::LineWrapMode");
        Shiboken::Conversions::registerConverterAlias(converter, "LineWrapMode");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'LineWrapMode' enum.

    PySide::Signal::registerSignals(pyType, &::QPlainTextEdit::staticMetaObject);
    qRegisterMetaType< ::QPlainTextEdit::LineWrapMode >("QPlainTextEdit::LineWrapMode");
    Shiboken::ObjectType::setSubTypeInitHook(pyType, &PySide::initQObjectSubType);
    PySide::initDynamicMetaObject(pyType, &::QPlainTextEdit::staticMetaObject, sizeof(QPlainTextEditWrapper));

    return pyType;
}
