// Copyright (C) 2022 The Qt Company Ltd.
// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only

#include <sbkpython.h>
#include <shiboken.h>
#include <algorithm>
#include <signature.h>
#include <sbkcontainer.h>
#include <sbkstaticstrings.h>

#define PYSIDE6_COMOPT_FULLNAME 1
#define PYSIDE6_COMOPT_COMPRESS 1
// TODO: #define PYSIDE6_COMOPT_FOLDING 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysidecleanup.h>
#include <pysideqenum.h>
#include <feature_select.h>
#include <pysidestaticstrings.h>
#include "pyside6_qtwidgets_python.h"

#include <QHash>
#include <QList>
#include <QMap>
#include <QString>
#include <QTextEdit>
#include <QtGui/qaccessible.h>
#include <QtGui/qaction.h>
#include <QtGui/qcolor.h>
#include <QtGui/qkeysequence.h>
#include <QtGui/qscreen.h>
#include <QtGui/qtextformat.h>
#include <QtGui/qwindow.h>
#include <QtWidgets/qabstractbutton.h>
#include <QtWidgets/qdockwidget.h>
#include <QtWidgets/qdrawutil.h>
#include <QtWidgets/qgesture.h>
#include <QtWidgets/qgraphicsitem.h>
#include <QtWidgets/qgraphicstransform.h>
#include <QtWidgets/qgraphicsview.h>
#include <QtWidgets/qlistwidget.h>
#include <QtWidgets/qmdisubwindow.h>
#include <QtWidgets/qscroller.h>
#include <QtWidgets/qtablewidget.h>
#include <QtWidgets/qtreewidget.h>
#include <QtWidgets/qwidget.h>
#include <QtWidgets/qwizard.h>
#include <qabstractitemmodel.h>
#include <qbytearray.h>
#include <qdatetime.h>
#include <qline.h>
#include <qnamespace.h>
#include <qobject.h>
#include <qpoint.h>
#include <qrect.h>
#include <qurl.h>
#include <qvariant.h>
#include <utility>


// Current module's type array.
Shiboken::Module::TypeInitStruct *SbkPySide6_QtWidgetsTypeStructs = nullptr;
// Backwards compatible structure with identical indexing.
PyTypeObject **SbkPySide6_QtWidgetsTypes = nullptr;
// Current module's PyObject pointer.
PyObject *SbkPySide6_QtWidgetsModuleObject = nullptr;
// Current module's converter array.
SbkConverter **SbkPySide6_QtWidgetsTypeConverters = nullptr;

void cleanTypesAttributes() {
    static PyObject *attrName = Shiboken::PyName::qtStaticMetaObject();
    const int imax = SBK_QtWidgets_IDX_COUNT;
    for (int i = 0; i < imax && SbkPySide6_QtWidgetsTypeStructs[i].fullName != nullptr; ++i) {
        auto *pyType = reinterpret_cast<PyObject *>(SbkPySide6_QtWidgetsTypeStructs[i].type);
        if (pyType != nullptr && PyObject_HasAttr(pyType, attrName))
            PyObject_SetAttr(pyType, attrName, Py_None);
    }
}

// Global functions ------------------------------------------------------------
static PyObject *SbkQtWidgetsModule_qDrawPlainRect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.qDrawPlainRect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 8));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOO:qDrawPlainRect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qDrawPlainRect(QPainter*,int,int,int,int,QColor,int=,const QBrush*=)
    // 1: qDrawPlainRect(QPainter*,QRect,QColor,int=,const QBrush*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // qDrawPlainRect(QPainter*,QRect,QColor,int,const QBrush*)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // qDrawPlainRect(QPainter*,QRect,QColor,int,const QBrush*)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[4])))) {
                    overloadId = 1; // qDrawPlainRect(QPainter*,QRect,QColor,int,const QBrush*)
                }
            }
        } else if (numArgs >= 6
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 0; // qDrawPlainRect(QPainter*,int,int,int,int,QColor,int,const QBrush*)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 0; // qDrawPlainRect(QPainter*,int,int,int,int,QColor,int,const QBrush*)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[7])))) {
                    overloadId = 0; // qDrawPlainRect(QPainter*,int,int,int,int,QColor,int,const QBrush*)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qDrawPlainRect(QPainter *p, int x, int y, int w, int h, const QColor &arg__6, int lineWidth, const QBrush *fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QColor cppArg5_local;
            ::QColor *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5].isValue())
                pythonToCpp[5](pyArgs[5], &cppArg5_local);
            else
                pythonToCpp[5](pyArgs[5], &cppArg5);

            int cppArg6 = 1;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QBrush *cppArg7 = nullptr;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawPlainRect(QPainter*,int,int,int,int,QColor,int,const QBrush*)
                qDrawPlainRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, *cppArg5, cppArg6, cppArg7);
            }
            break;
        }
        case 1: // qDrawPlainRect(QPainter *p, const QRect &r, const QColor &arg__3, int lineWidth, const QBrush *fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QColor cppArg2_local;
            ::QColor *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            int cppArg3 = 1;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QBrush *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawPlainRect(QPainter*,QRect,QColor,int,const QBrush*)
                qDrawPlainRect(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtWidgetsModule_qDrawPlainRoundedRect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.qDrawPlainRoundedRect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[10];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 5, 10));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOOOO:qDrawPlainRoundedRect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qDrawPlainRoundedRect(QPainter*,int,int,int,int,qreal,qreal,QColor,int=,const QBrush*=)
    // 1: qDrawPlainRoundedRect(QPainter*,QRect,qreal,qreal,QColor,int=,const QBrush*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))) {
        if (numArgs >= 5
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[4])))) {
            if (numArgs == 5) {
                overloadId = 1; // qDrawPlainRoundedRect(QPainter*,QRect,qreal,qreal,QColor,int,const QBrush*)
            } else if (numArgs >= 6
                && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
                if (numArgs == 6) {
                    overloadId = 1; // qDrawPlainRoundedRect(QPainter*,QRect,qreal,qreal,QColor,int,const QBrush*)
                } else if (numArgs >= 7
                    && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[6])))) {
                    overloadId = 1; // qDrawPlainRoundedRect(QPainter*,QRect,qreal,qreal,QColor,int,const QBrush*)
                }
            }
        } else if (numArgs >= 8
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[5])))
            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), (pyArgs[6])))
            && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), (pyArgs[7])))) {
            if (numArgs == 8) {
                overloadId = 0; // qDrawPlainRoundedRect(QPainter*,int,int,int,int,qreal,qreal,QColor,int,const QBrush*)
            } else if (numArgs >= 9
                && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8])))) {
                if (numArgs == 9) {
                    overloadId = 0; // qDrawPlainRoundedRect(QPainter*,int,int,int,int,qreal,qreal,QColor,int,const QBrush*)
                } else if (numArgs >= 10
                    && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[9])))) {
                    overloadId = 0; // qDrawPlainRoundedRect(QPainter*,int,int,int,int,qreal,qreal,QColor,int,const QBrush*)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qDrawPlainRoundedRect(QPainter *p, int x, int y, int w, int h, qreal rx, qreal ry, const QColor &arg__8, int lineWidth, const QBrush *fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            qreal cppArg5;
            pythonToCpp[5](pyArgs[5], &cppArg5);
            qreal cppArg6;
            pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QColor cppArg7_local;
            ::QColor *cppArg7 = &cppArg7_local;
            if (pythonToCpp[7].isValue())
                pythonToCpp[7](pyArgs[7], &cppArg7_local);
            else
                pythonToCpp[7](pyArgs[7], &cppArg7);

            int cppArg8 = 1;
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QBrush *cppArg9 = nullptr;
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawPlainRoundedRect(QPainter*,int,int,int,int,qreal,qreal,QColor,int,const QBrush*)
                qDrawPlainRoundedRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, cppArg5, cppArg6, *cppArg7, cppArg8, cppArg9);
            }
            break;
        }
        case 1: // qDrawPlainRoundedRect(QPainter *painter, const QRect &rect, qreal rx, qreal ry, const QColor &lineColor, int lineWidth, const QBrush *fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            qreal cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            qreal cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QColor cppArg4_local;
            ::QColor *cppArg4 = &cppArg4_local;
            if (pythonToCpp[4].isValue())
                pythonToCpp[4](pyArgs[4], &cppArg4_local);
            else
                pythonToCpp[4](pyArgs[4], &cppArg4);

            int cppArg5 = 1;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QBrush *cppArg6 = nullptr;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawPlainRoundedRect(QPainter*,QRect,qreal,qreal,QColor,int,const QBrush*)
                qDrawPlainRoundedRect(cppArg0, *cppArg1, cppArg2, cppArg3, *cppArg4, cppArg5, cppArg6);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtWidgetsModule_qDrawShadeLine(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.qDrawShadeLine";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 4, 9));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOOO:qDrawShadeLine", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qDrawShadeLine(QPainter*,int,int,int,int,QPalette,bool=,int=,int=)
    // 1: qDrawShadeLine(QPainter*,QPoint,QPoint,QPalette,bool=,int=,int=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))) {
        if (numArgs >= 4
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArgs[3])))) {
            if (numArgs == 4) {
                overloadId = 1; // qDrawShadeLine(QPainter*,QPoint,QPoint,QPalette,bool,int,int)
            } else if (numArgs >= 5
                && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[4])))) {
                if (numArgs == 5) {
                    overloadId = 1; // qDrawShadeLine(QPainter*,QPoint,QPoint,QPalette,bool,int,int)
                } else if (numArgs >= 6
                    && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
                    if (numArgs == 6) {
                        overloadId = 1; // qDrawShadeLine(QPainter*,QPoint,QPoint,QPalette,bool,int,int)
                    } else if (numArgs >= 7
                        && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6])))) {
                        overloadId = 1; // qDrawShadeLine(QPainter*,QPoint,QPoint,QPalette,bool,int,int)
                    }
                }
            }
        } else if (numArgs >= 6
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 0; // qDrawShadeLine(QPainter*,int,int,int,int,QPalette,bool,int,int)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 0; // qDrawShadeLine(QPainter*,int,int,int,int,QPalette,bool,int,int)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))) {
                    if (numArgs == 8) {
                        overloadId = 0; // qDrawShadeLine(QPainter*,int,int,int,int,QPalette,bool,int,int)
                    } else if (numArgs >= 9
                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8])))) {
                        overloadId = 0; // qDrawShadeLine(QPainter*,int,int,int,int,QPalette,bool,int,int)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qDrawShadeLine(QPainter *p, int x1, int y1, int x2, int y2, const QPalette &pal, bool sunken, int lineWidth, int midLineWidth)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_midLineWidth = Shiboken::String::createStaticString("midLineWidth");
                if (PyDict_Contains(kwds, key_midLineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_midLineWidth);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_midLineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_midLineWidth);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QPalette cppArg5_local;
            ::QPalette *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5].isValue())
                pythonToCpp[5](pyArgs[5], &cppArg5_local);
            else
                pythonToCpp[5](pyArgs[5], &cppArg5);

            bool cppArg6 = true;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            int cppArg7 = 1;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            int cppArg8 = 0;
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawShadeLine(QPainter*,int,int,int,int,QPalette,bool,int,int)
                qDrawShadeLine(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, *cppArg5, cppArg6, cppArg7, cppArg8);
            }
            break;
        }
        case 1: // qDrawShadeLine(QPainter *p, const QPoint &p1, const QPoint &p2, const QPalette &pal, bool sunken, int lineWidth, int midLineWidth)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_midLineWidth = Shiboken::String::createStaticString("midLineWidth");
                if (PyDict_Contains(kwds, key_midLineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_midLineWidth);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_midLineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_midLineWidth);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QPoint cppArg1_local;
            ::QPoint *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPoint cppArg2_local;
            ::QPoint *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            if (!Shiboken::Object::isValid(pyArgs[3]))
                return {};
            ::QPalette cppArg3_local;
            ::QPalette *cppArg3 = &cppArg3_local;
            if (pythonToCpp[3].isValue())
                pythonToCpp[3](pyArgs[3], &cppArg3_local);
            else
                pythonToCpp[3](pyArgs[3], &cppArg3);

            bool cppArg4 = true;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5 = 1;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            int cppArg6 = 0;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawShadeLine(QPainter*,QPoint,QPoint,QPalette,bool,int,int)
                qDrawShadeLine(cppArg0, *cppArg1, *cppArg2, *cppArg3, cppArg4, cppArg5, cppArg6);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtWidgetsModule_qDrawShadePanel(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.qDrawShadePanel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[9];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 9));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOOO:qDrawShadePanel", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qDrawShadePanel(QPainter*,int,int,int,int,QPalette,bool=,int=,const QBrush*=)
    // 1: qDrawShadePanel(QPainter*,QRect,QPalette,bool=,int=,const QBrush*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // qDrawShadePanel(QPainter*,QRect,QPalette,bool,int,const QBrush*)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // qDrawShadePanel(QPainter*,QRect,QPalette,bool,int,const QBrush*)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 1; // qDrawShadePanel(QPainter*,QRect,QPalette,bool,int,const QBrush*)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[5])))) {
                        overloadId = 1; // qDrawShadePanel(QPainter*,QRect,QPalette,bool,int,const QBrush*)
                    }
                }
            }
        } else if (numArgs >= 6
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 0; // qDrawShadePanel(QPainter*,int,int,int,int,QPalette,bool,int,const QBrush*)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 0; // qDrawShadePanel(QPainter*,int,int,int,int,QPalette,bool,int,const QBrush*)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))) {
                    if (numArgs == 8) {
                        overloadId = 0; // qDrawShadePanel(QPainter*,int,int,int,int,QPalette,bool,int,const QBrush*)
                    } else if (numArgs >= 9
                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[8])))) {
                        overloadId = 0; // qDrawShadePanel(QPainter*,int,int,int,int,QPalette,bool,int,const QBrush*)
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qDrawShadePanel(QPainter *p, int x, int y, int w, int h, const QPalette &pal, bool sunken, int lineWidth, const QBrush *fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QPalette cppArg5_local;
            ::QPalette *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5].isValue())
                pythonToCpp[5](pyArgs[5], &cppArg5_local);
            else
                pythonToCpp[5](pyArgs[5], &cppArg5);

            bool cppArg6 = false;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            int cppArg7 = 1;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            if (!Shiboken::Object::isValid(pyArgs[8]))
                return {};
            ::QBrush *cppArg8 = nullptr;
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawShadePanel(QPainter*,int,int,int,int,QPalette,bool,int,const QBrush*)
                qDrawShadePanel(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, *cppArg5, cppArg6, cppArg7, cppArg8);
            }
            break;
        }
        case 1: // qDrawShadePanel(QPainter *p, const QRect &r, const QPalette &pal, bool sunken, int lineWidth, const QBrush *fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPalette cppArg2_local;
            ::QPalette *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            bool cppArg3 = false;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = 1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QBrush *cppArg5 = nullptr;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawShadePanel(QPainter*,QRect,QPalette,bool,int,const QBrush*)
                qDrawShadePanel(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4, cppArg5);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtWidgetsModule_qDrawShadeRect(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.qDrawShadeRect";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[10];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 10));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOOOO:qDrawShadeRect", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7]), &(pyArgs[8]), &(pyArgs[9])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool=,int=,int=,const QBrush*=)
    // 1: qDrawShadeRect(QPainter*,QRect,QPalette,bool=,int=,int=,const QBrush*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // qDrawShadeRect(QPainter*,QRect,QPalette,bool,int,int,const QBrush*)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // qDrawShadeRect(QPainter*,QRect,QPalette,bool,int,int,const QBrush*)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))) {
                    if (numArgs == 5) {
                        overloadId = 1; // qDrawShadeRect(QPainter*,QRect,QPalette,bool,int,int,const QBrush*)
                    } else if (numArgs >= 6
                        && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5])))) {
                        if (numArgs == 6) {
                            overloadId = 1; // qDrawShadeRect(QPainter*,QRect,QPalette,bool,int,int,const QBrush*)
                        } else if (numArgs >= 7
                            && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[6])))) {
                            overloadId = 1; // qDrawShadeRect(QPainter*,QRect,QPalette,bool,int,int,const QBrush*)
                        }
                    }
                }
            }
        } else if (numArgs >= 6
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 0; // qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool,int,int,const QBrush*)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 0; // qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool,int,int,const QBrush*)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7])))) {
                    if (numArgs == 8) {
                        overloadId = 0; // qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool,int,int,const QBrush*)
                    } else if (numArgs >= 9
                        && (pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8])))) {
                        if (numArgs == 9) {
                            overloadId = 0; // qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool,int,int,const QBrush*)
                        } else if (numArgs >= 10
                            && (pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[9])))) {
                            overloadId = 0; // qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool,int,int,const QBrush*)
                        }
                    }
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qDrawShadeRect(QPainter *p, int x, int y, int w, int h, const QPalette &pal, bool sunken, int lineWidth, int midLineWidth, const QBrush *fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_midLineWidth = Shiboken::String::createStaticString("midLineWidth");
                if (PyDict_Contains(kwds, key_midLineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_midLineWidth);
                    if (value != nullptr && pyArgs[8] != nullptr ) {
                        errInfo.reset(key_midLineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[8] = value;
                        if (!(pythonToCpp[8] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[8]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_midLineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[9] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[9] = value;
                        if (!(pythonToCpp[9] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[9]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QPalette cppArg5_local;
            ::QPalette *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5].isValue())
                pythonToCpp[5](pyArgs[5], &cppArg5_local);
            else
                pythonToCpp[5](pyArgs[5], &cppArg5);

            bool cppArg6 = false;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            int cppArg7 = 1;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);
            int cppArg8 = 0;
            if (pythonToCpp[8])
                pythonToCpp[8](pyArgs[8], &cppArg8);
            if (!Shiboken::Object::isValid(pyArgs[9]))
                return {};
            ::QBrush *cppArg9 = nullptr;
            if (pythonToCpp[9])
                pythonToCpp[9](pyArgs[9], &cppArg9);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawShadeRect(QPainter*,int,int,int,int,QPalette,bool,int,int,const QBrush*)
                qDrawShadeRect(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, *cppArg5, cppArg6, cppArg7, cppArg8, cppArg9);
            }
            break;
        }
        case 1: // qDrawShadeRect(QPainter *p, const QRect &r, const QPalette &pal, bool sunken, int lineWidth, int midLineWidth, const QBrush *fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_lineWidth = Shiboken::String::createStaticString("lineWidth");
                if (PyDict_Contains(kwds, key_lineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_lineWidth);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_lineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_lineWidth);
                }
                static PyObject *const key_midLineWidth = Shiboken::String::createStaticString("midLineWidth");
                if (PyDict_Contains(kwds, key_midLineWidth) != 0) {
                    value = PyDict_GetItem(kwds, key_midLineWidth);
                    if (value != nullptr && pyArgs[5] != nullptr ) {
                        errInfo.reset(key_midLineWidth);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[5] = value;
                        if (!(pythonToCpp[5] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[5]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_midLineWidth);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPalette cppArg2_local;
            ::QPalette *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            bool cppArg3 = false;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4 = 1;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);
            int cppArg5 = 0;
            if (pythonToCpp[5])
                pythonToCpp[5](pyArgs[5], &cppArg5);
            if (!Shiboken::Object::isValid(pyArgs[6]))
                return {};
            ::QBrush *cppArg6 = nullptr;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawShadeRect(QPainter*,QRect,QPalette,bool,int,int,const QBrush*)
                qDrawShadeRect(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4, cppArg5, cppArg6);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtWidgetsModule_qDrawWinButton(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.qDrawWinButton";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 8));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOO:qDrawWinButton", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qDrawWinButton(QPainter*,int,int,int,int,QPalette,bool=,const QBrush*=)
    // 1: qDrawWinButton(QPainter*,QRect,QPalette,bool=,const QBrush*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // qDrawWinButton(QPainter*,QRect,QPalette,bool,const QBrush*)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // qDrawWinButton(QPainter*,QRect,QPalette,bool,const QBrush*)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[4])))) {
                    overloadId = 1; // qDrawWinButton(QPainter*,QRect,QPalette,bool,const QBrush*)
                }
            }
        } else if (numArgs >= 6
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 0; // qDrawWinButton(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 0; // qDrawWinButton(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[7])))) {
                    overloadId = 0; // qDrawWinButton(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qDrawWinButton(QPainter *p, int x, int y, int w, int h, const QPalette &pal, bool sunken, const QBrush *fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QPalette cppArg5_local;
            ::QPalette *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5].isValue())
                pythonToCpp[5](pyArgs[5], &cppArg5_local);
            else
                pythonToCpp[5](pyArgs[5], &cppArg5);

            bool cppArg6 = false;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QBrush *cppArg7 = nullptr;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawWinButton(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
                qDrawWinButton(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, *cppArg5, cppArg6, cppArg7);
            }
            break;
        }
        case 1: // qDrawWinButton(QPainter *p, const QRect &r, const QPalette &pal, bool sunken, const QBrush *fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPalette cppArg2_local;
            ::QPalette *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            bool cppArg3 = false;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QBrush *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawWinButton(QPainter*,QRect,QPalette,bool,const QBrush*)
                qDrawWinButton(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}

static PyObject *SbkQtWidgetsModule_qDrawWinPanel(PyObject *self, PyObject *args, PyObject *kwds)
{
    SBK_UNUSED(self)
    SBK_UNUSED(kwds)
    Shiboken::AutoDecRef errInfo{};
    static const char fullName[] = "PySide6.QtWidgets.qDrawWinPanel";
    SBK_UNUSED(fullName)
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    Shiboken::Conversions::PythonToCppConversion pythonToCpp[8];
    SBK_UNUSED(pythonToCpp)
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 3, 8));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    if (PyArg_ParseTuple(args, "|OOOOOOOO:qDrawWinPanel", &(pyArgs[0]), &(pyArgs[1]), &(pyArgs[2]), &(pyArgs[3]), &(pyArgs[4]), &(pyArgs[5]), &(pyArgs[6]), &(pyArgs[7])) == 0)
        return {};


    // Overloaded function decisor
    // 0: qDrawWinPanel(QPainter*,int,int,int,int,QPalette,bool=,const QBrush*=)
    // 1: qDrawWinPanel(QPainter*,QRect,QPalette,bool=,const QBrush*=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX]), (pyArgs[0])))) {
        if (numArgs >= 3
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArgs[2])))) {
            if (numArgs == 3) {
                overloadId = 1; // qDrawWinPanel(QPainter*,QRect,QPalette,bool,const QBrush*)
            } else if (numArgs >= 4
                && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3])))) {
                if (numArgs == 4) {
                    overloadId = 1; // qDrawWinPanel(QPainter*,QRect,QPalette,bool,const QBrush*)
                } else if (numArgs >= 5
                    && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[4])))) {
                    overloadId = 1; // qDrawWinPanel(QPainter*,QRect,QPalette,bool,const QBrush*)
                }
            }
        } else if (numArgs >= 6
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[1])))
            && (pythonToCpp[2] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[2])))
            && (pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[3])))
            && (pythonToCpp[4] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArgs[4])))
            && (pythonToCpp[5] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QPalette_IDX]), (pyArgs[5])))) {
            if (numArgs == 6) {
                overloadId = 0; // qDrawWinPanel(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
            } else if (numArgs >= 7
                && (pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6])))) {
                if (numArgs == 7) {
                    overloadId = 0; // qDrawWinPanel(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
                } else if (numArgs >= 8
                    && (pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[7])))) {
                    overloadId = 0; // qDrawWinPanel(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
                }
            }
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, fullName, errInfo);

    // Call function/method
    switch (overloadId) {
        case 0: // qDrawWinPanel(QPainter *p, int x, int y, int w, int h, const QPalette &pal, bool sunken, const QBrush *fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[6] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[6] = value;
                        if (!(pythonToCpp[6] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[6]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[7] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[7] = value;
                        if (!(pythonToCpp[7] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[7]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            int cppArg1;
            pythonToCpp[1](pyArgs[1], &cppArg1);
            int cppArg2;
            pythonToCpp[2](pyArgs[2], &cppArg2);
            int cppArg3;
            pythonToCpp[3](pyArgs[3], &cppArg3);
            int cppArg4;
            pythonToCpp[4](pyArgs[4], &cppArg4);
            if (!Shiboken::Object::isValid(pyArgs[5]))
                return {};
            ::QPalette cppArg5_local;
            ::QPalette *cppArg5 = &cppArg5_local;
            if (pythonToCpp[5].isValue())
                pythonToCpp[5](pyArgs[5], &cppArg5_local);
            else
                pythonToCpp[5](pyArgs[5], &cppArg5);

            bool cppArg6 = false;
            if (pythonToCpp[6])
                pythonToCpp[6](pyArgs[6], &cppArg6);
            if (!Shiboken::Object::isValid(pyArgs[7]))
                return {};
            ::QBrush *cppArg7 = nullptr;
            if (pythonToCpp[7])
                pythonToCpp[7](pyArgs[7], &cppArg7);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawWinPanel(QPainter*,int,int,int,int,QPalette,bool,const QBrush*)
                qDrawWinPanel(cppArg0, cppArg1, cppArg2, cppArg3, cppArg4, *cppArg5, cppArg6, cppArg7);
            }
            break;
        }
        case 1: // qDrawWinPanel(QPainter *p, const QRect &r, const QPalette &pal, bool sunken, const QBrush *fill)
        {
            if (kwds && PyDict_Size(kwds) > 0) {
                PyObject *value{};
                Shiboken::AutoDecRef kwds_dup(PyDict_Copy(kwds));
                static PyObject *const key_sunken = Shiboken::String::createStaticString("sunken");
                if (PyDict_Contains(kwds, key_sunken) != 0) {
                    value = PyDict_GetItem(kwds, key_sunken);
                    if (value != nullptr && pyArgs[3] != nullptr ) {
                        errInfo.reset(key_sunken);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[3] = value;
                        if (!(pythonToCpp[3] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[3]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_sunken);
                }
                static PyObject *const key_fill = Shiboken::String::createStaticString("fill");
                if (PyDict_Contains(kwds, key_fill) != 0) {
                    value = PyDict_GetItem(kwds, key_fill);
                    if (value != nullptr && pyArgs[4] != nullptr ) {
                        errInfo.reset(key_fill);
                        Py_INCREF(errInfo.object());
                        return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    if (value != nullptr) {
                        pyArgs[4] = value;
                        if (!(pythonToCpp[4] = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QBrush_IDX]), (pyArgs[4]))))
                            return Shiboken::returnWrongArguments(args, fullName, errInfo);
                    }
                    PyDict_DelItem(kwds_dup, key_fill);
                }
                if (PyDict_Size(kwds_dup) > 0) {
                    errInfo.reset(kwds_dup.release());
                    return Shiboken::returnWrongArguments(args, fullName, errInfo);
                }
            }
            if (!Shiboken::Object::isValid(pyArgs[0]))
                return {};
            ::QPainter *cppArg0;
            pythonToCpp[0](pyArgs[0], &cppArg0);
            if (!Shiboken::Object::isValid(pyArgs[1]))
                return {};
            ::QRect cppArg1_local;
            ::QRect *cppArg1 = &cppArg1_local;
            if (pythonToCpp[1].isValue())
                pythonToCpp[1](pyArgs[1], &cppArg1_local);
            else
                pythonToCpp[1](pyArgs[1], &cppArg1);

            if (!Shiboken::Object::isValid(pyArgs[2]))
                return {};
            ::QPalette cppArg2_local;
            ::QPalette *cppArg2 = &cppArg2_local;
            if (pythonToCpp[2].isValue())
                pythonToCpp[2](pyArgs[2], &cppArg2_local);
            else
                pythonToCpp[2](pyArgs[2], &cppArg2);

            bool cppArg3 = false;
            if (pythonToCpp[3])
                pythonToCpp[3](pyArgs[3], &cppArg3);
            if (!Shiboken::Object::isValid(pyArgs[4]))
                return {};
            ::QBrush *cppArg4 = nullptr;
            if (pythonToCpp[4])
                pythonToCpp[4](pyArgs[4], &cppArg4);

            if (Shiboken::Errors::occurred() == nullptr) {
                // qDrawWinPanel(QPainter*,QRect,QPalette,bool,const QBrush*)
                qDrawWinPanel(cppArg0, *cppArg1, *cppArg2, cppArg3, cppArg4);
            }
            break;
        }
    }

    if (Shiboken::Errors::occurred() != nullptr) {
        return {};
    }
    Py_RETURN_NONE;
}


static PyMethodDef QtWidgets_methods[] = {
    {"qDrawPlainRect", reinterpret_cast<PyCFunction>(SbkQtWidgetsModule_qDrawPlainRect), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qDrawPlainRoundedRect", reinterpret_cast<PyCFunction>(SbkQtWidgetsModule_qDrawPlainRoundedRect), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qDrawShadeLine", reinterpret_cast<PyCFunction>(SbkQtWidgetsModule_qDrawShadeLine), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qDrawShadePanel", reinterpret_cast<PyCFunction>(SbkQtWidgetsModule_qDrawShadePanel), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qDrawShadeRect", reinterpret_cast<PyCFunction>(SbkQtWidgetsModule_qDrawShadeRect), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qDrawWinButton", reinterpret_cast<PyCFunction>(SbkQtWidgetsModule_qDrawWinButton), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"qDrawWinPanel", reinterpret_cast<PyCFunction>(SbkQtWidgetsModule_qDrawWinPanel), METH_VARARGS|METH_KEYWORDS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

// Classes initialization functions ------------------------------------------------------------
PyTypeObject *init_QWhatsThis(PyObject *enclosing);
PyTypeObject *init_QTreeWidgetItemIterator(PyObject *enclosing);
PyTypeObject *init_QTreeWidgetItem(PyObject *enclosing);
PyTypeObject *init_QTableWidgetSelectionRange(PyObject *enclosing);
PyTypeObject *init_QTableWidgetItem(PyObject *enclosing);
PyTypeObject *init_QStyleHintReturn(PyObject *enclosing);
PyTypeObject *init_QStyleHintReturnVariant(PyObject *enclosing);
PyTypeObject *init_QStyleFactory(PyObject *enclosing);
PyTypeObject *init_QSizePolicy(PyObject *enclosing);
PyTypeObject *init_QScrollerProperties(PyObject *enclosing);
PyTypeObject *init_QListWidgetItem(PyObject *enclosing);
PyTypeObject *init_QLayoutItem(PyObject *enclosing);
PyTypeObject *init_QSpacerItem(PyObject *enclosing);
PyTypeObject *init_QItemEditorFactory(PyObject *enclosing);
PyTypeObject *init_QItemEditorCreatorBase(PyObject *enclosing);
PyTypeObject *init_QGestureRecognizer(PyObject *enclosing);
PyTypeObject *init_QColormap(PyObject *enclosing);
PyTypeObject *init_QStyleHintReturnMask(PyObject *enclosing);
PyTypeObject *init_QAccessibleWidget(PyObject *enclosing);
PyTypeObject *init_QFileIconProvider(PyObject *enclosing);
PyTypeObject *init_QTileRules(PyObject *enclosing);
PyTypeObject *init_QGraphicsLayoutItem(PyObject *enclosing);
PyTypeObject *init_QGraphicsLayout(PyObject *enclosing);
PyTypeObject *init_QGraphicsLinearLayout(PyObject *enclosing);
PyTypeObject *init_QGraphicsGridLayout(PyObject *enclosing);
PyTypeObject *init_QGraphicsAnchorLayout(PyObject *enclosing);
PyTypeObject *init_QGraphicsItem(PyObject *enclosing);
PyTypeObject *init_QGraphicsPixmapItem(PyObject *enclosing);
PyTypeObject *init_QGraphicsLineItem(PyObject *enclosing);
PyTypeObject *init_QGraphicsItemGroup(PyObject *enclosing);
PyTypeObject *init_QAbstractGraphicsShapeItem(PyObject *enclosing);
PyTypeObject *init_QGraphicsSimpleTextItem(PyObject *enclosing);
PyTypeObject *init_QGraphicsRectItem(PyObject *enclosing);
PyTypeObject *init_QGraphicsPolygonItem(PyObject *enclosing);
PyTypeObject *init_QGraphicsPathItem(PyObject *enclosing);
PyTypeObject *init_QGraphicsEllipseItem(PyObject *enclosing);
PyTypeObject *init_QToolTip(PyObject *enclosing);
PyTypeObject *init_QStylePainter(PyObject *enclosing);
PyTypeObject *init_QWidget(PyObject *enclosing);
PyTypeObject *init_QWizardPage(PyObject *enclosing);
PyTypeObject *init_QWidgetItem(PyObject *enclosing);
PyTypeObject *init_QToolBar(PyObject *enclosing);
PyTypeObject *init_QTabWidget(PyObject *enclosing);
PyTypeObject *init_QTabBar(PyObject *enclosing);
PyTypeObject *init_QStatusBar(PyObject *enclosing);
PyTypeObject *init_QSplitterHandle(PyObject *enclosing);
PyTypeObject *init_QSplashScreen(PyObject *enclosing);
PyTypeObject *init_QSizeGrip(PyObject *enclosing);
PyTypeObject *init_QRubberBand(PyObject *enclosing);
PyTypeObject *init_QRhiWidget(PyObject *enclosing);
PyTypeObject *init_QProgressBar(PyObject *enclosing);
PyTypeObject *init_QMenuBar(PyObject *enclosing);
PyTypeObject *init_QMenu(PyObject *enclosing);
PyTypeObject *init_QMdiSubWindow(PyObject *enclosing);
PyTypeObject *init_QMainWindow(PyObject *enclosing);
PyTypeObject *init_QLineEdit(PyObject *enclosing);
PyTypeObject *init_QKeySequenceEdit(PyObject *enclosing);
PyTypeObject *init_QGroupBox(PyObject *enclosing);
PyTypeObject *init_QFrame(PyObject *enclosing);
PyTypeObject *init_QToolBox(PyObject *enclosing);
PyTypeObject *init_QStackedWidget(PyObject *enclosing);
PyTypeObject *init_QSplitter(PyObject *enclosing);
PyTypeObject *init_QLabel(PyObject *enclosing);
PyTypeObject *init_QLCDNumber(PyObject *enclosing);
PyTypeObject *init_QAbstractScrollArea(PyObject *enclosing);
PyTypeObject *init_QTextEdit(PyObject *enclosing);
PyTypeObject *init_QTextEdit_ExtraSelection(PyObject *enclosing);
PyTypeObject *init_QTextBrowser(PyObject *enclosing);
PyTypeObject *init_QScrollArea(PyObject *enclosing);
PyTypeObject *init_QPlainTextEdit(PyObject *enclosing);
PyTypeObject *init_QMdiArea(PyObject *enclosing);
PyTypeObject *init_QGraphicsView(PyObject *enclosing);
PyTypeObject *init_QAbstractItemView(PyObject *enclosing);
PyTypeObject *init_QTreeView(PyObject *enclosing);
PyTypeObject *init_QTreeWidget(PyObject *enclosing);
PyTypeObject *init_QTableView(PyObject *enclosing);
PyTypeObject *init_QTableWidget(PyObject *enclosing);
PyTypeObject *init_QListView(PyObject *enclosing);
PyTypeObject *init_QUndoView(PyObject *enclosing);
PyTypeObject *init_QListWidget(PyObject *enclosing);
PyTypeObject *init_QHeaderView(PyObject *enclosing);
PyTypeObject *init_QColumnView(PyObject *enclosing);
PyTypeObject *init_QFocusFrame(PyObject *enclosing);
PyTypeObject *init_QDockWidget(PyObject *enclosing);
PyTypeObject *init_QDialogButtonBox(PyObject *enclosing);
PyTypeObject *init_QDialog(PyObject *enclosing);
PyTypeObject *init_QWizard(PyObject *enclosing);
PyTypeObject *init_QProgressDialog(PyObject *enclosing);
PyTypeObject *init_QMessageBox(PyObject *enclosing);
PyTypeObject *init_QInputDialog(PyObject *enclosing);
PyTypeObject *init_QFontDialog(PyObject *enclosing);
PyTypeObject *init_QErrorMessage(PyObject *enclosing);
PyTypeObject *init_QColorDialog(PyObject *enclosing);
PyTypeObject *init_QComboBox(PyObject *enclosing);
PyTypeObject *init_QFontComboBox(PyObject *enclosing);
PyTypeObject *init_QCalendarWidget(PyObject *enclosing);
PyTypeObject *init_QAbstractSpinBox(PyObject *enclosing);
PyTypeObject *init_QSpinBox(PyObject *enclosing);
PyTypeObject *init_QDoubleSpinBox(PyObject *enclosing);
PyTypeObject *init_QDateTimeEdit(PyObject *enclosing);
PyTypeObject *init_QTimeEdit(PyObject *enclosing);
PyTypeObject *init_QDateEdit(PyObject *enclosing);
PyTypeObject *init_QAbstractSlider(PyObject *enclosing);
PyTypeObject *init_QSlider(PyObject *enclosing);
PyTypeObject *init_QScrollBar(PyObject *enclosing);
PyTypeObject *init_QDial(PyObject *enclosing);
PyTypeObject *init_QAbstractButton(PyObject *enclosing);
PyTypeObject *init_QToolButton(PyObject *enclosing);
PyTypeObject *init_QRadioButton(PyObject *enclosing);
PyTypeObject *init_QPushButton(PyObject *enclosing);
PyTypeObject *init_QCommandLinkButton(PyObject *enclosing);
PyTypeObject *init_QCheckBox(PyObject *enclosing);
PyTypeObject *init_QSystemTrayIcon(PyObject *enclosing);
PyTypeObject *init_QStyleOption(PyObject *enclosing);
PyTypeObject *init_QStyleOptionViewItem(PyObject *enclosing);
PyTypeObject *init_QStyleOptionToolBox(PyObject *enclosing);
PyTypeObject *init_QStyleOptionToolBar(PyObject *enclosing);
PyTypeObject *init_QStyleOptionTabWidgetFrame(PyObject *enclosing);
PyTypeObject *init_QStyleOptionTabBarBase(PyObject *enclosing);
PyTypeObject *init_QStyleOptionTab(PyObject *enclosing);
PyTypeObject *init_QStyleOptionRubberBand(PyObject *enclosing);
PyTypeObject *init_QStyleOptionProgressBar(PyObject *enclosing);
PyTypeObject *init_QStyleOptionMenuItem(PyObject *enclosing);
PyTypeObject *init_QStyleOptionHeader(PyObject *enclosing);
PyTypeObject *init_QStyleOptionHeaderV2(PyObject *enclosing);
PyTypeObject *init_QStyleOptionGraphicsItem(PyObject *enclosing);
PyTypeObject *init_QStyleOptionFrame(PyObject *enclosing);
PyTypeObject *init_QStyleOptionFocusRect(PyObject *enclosing);
PyTypeObject *init_QStyleOptionDockWidget(PyObject *enclosing);
PyTypeObject *init_QStyleOptionComplex(PyObject *enclosing);
PyTypeObject *init_QStyleOptionToolButton(PyObject *enclosing);
PyTypeObject *init_QStyleOptionTitleBar(PyObject *enclosing);
PyTypeObject *init_QStyleOptionSpinBox(PyObject *enclosing);
PyTypeObject *init_QStyleOptionSlider(PyObject *enclosing);
PyTypeObject *init_QStyleOptionSizeGrip(PyObject *enclosing);
PyTypeObject *init_QStyleOptionGroupBox(PyObject *enclosing);
PyTypeObject *init_QStyleOptionComboBox(PyObject *enclosing);
PyTypeObject *init_QStyleOptionButton(PyObject *enclosing);
PyTypeObject *init_QStyle(PyObject *enclosing);
PyTypeObject *init_QCommonStyle(PyObject *enclosing);
PyTypeObject *init_QProxyStyle(PyObject *enclosing);
PyTypeObject *init_QScroller(PyObject *enclosing);
PyTypeObject *init_QLayout(PyObject *enclosing);
PyTypeObject *init_QStackedLayout(PyObject *enclosing);
PyTypeObject *init_QGridLayout(PyObject *enclosing);
PyTypeObject *init_QFormLayout(PyObject *enclosing);
PyTypeObject *init_QFormLayout_TakeRowResult(PyObject *enclosing);
PyTypeObject *init_QBoxLayout(PyObject *enclosing);
PyTypeObject *init_QVBoxLayout(PyObject *enclosing);
PyTypeObject *init_QHBoxLayout(PyObject *enclosing);
PyTypeObject *init_QGraphicsTransform(PyObject *enclosing);
PyTypeObject *init_QGraphicsScale(PyObject *enclosing);
PyTypeObject *init_QGraphicsRotation(PyObject *enclosing);
PyTypeObject *init_QGraphicsScene(PyObject *enclosing);
PyTypeObject *init_QGraphicsObject(PyObject *enclosing);
PyTypeObject *init_QGraphicsWidget(PyObject *enclosing);
PyTypeObject *init_QGraphicsProxyWidget(PyObject *enclosing);
PyTypeObject *init_QGraphicsTextItem(PyObject *enclosing);
PyTypeObject *init_QGraphicsItemAnimation(PyObject *enclosing);
PyTypeObject *init_QGraphicsEffect(PyObject *enclosing);
PyTypeObject *init_QGraphicsOpacityEffect(PyObject *enclosing);
PyTypeObject *init_QGraphicsDropShadowEffect(PyObject *enclosing);
PyTypeObject *init_QGraphicsColorizeEffect(PyObject *enclosing);
PyTypeObject *init_QGraphicsBlurEffect(PyObject *enclosing);
PyTypeObject *init_QGraphicsAnchor(PyObject *enclosing);
PyTypeObject *init_QGesture(PyObject *enclosing);
PyTypeObject *init_QTapGesture(PyObject *enclosing);
PyTypeObject *init_QTapAndHoldGesture(PyObject *enclosing);
PyTypeObject *init_QSwipeGesture(PyObject *enclosing);
PyTypeObject *init_QPinchGesture(PyObject *enclosing);
PyTypeObject *init_QPanGesture(PyObject *enclosing);
PyTypeObject *init_QDataWidgetMapper(PyObject *enclosing);
PyTypeObject *init_QCompleter(PyObject *enclosing);
PyTypeObject *init_QButtonGroup(PyObject *enclosing);
PyTypeObject *init_QAbstractItemDelegate(PyObject *enclosing);
PyTypeObject *init_QStyledItemDelegate(PyObject *enclosing);
PyTypeObject *init_QItemDelegate(PyObject *enclosing);
PyTypeObject *init_QWidgetAction(PyObject *enclosing);
PyTypeObject *init_QPlainTextDocumentLayout(PyObject *enclosing);
PyTypeObject *init_QGraphicsSceneEvent(PyObject *enclosing);
PyTypeObject *init_QGraphicsSceneWheelEvent(PyObject *enclosing);
PyTypeObject *init_QGraphicsSceneResizeEvent(PyObject *enclosing);
PyTypeObject *init_QGraphicsSceneMoveEvent(PyObject *enclosing);
PyTypeObject *init_QGraphicsSceneMouseEvent(PyObject *enclosing);
PyTypeObject *init_QGraphicsSceneHoverEvent(PyObject *enclosing);
PyTypeObject *init_QGraphicsSceneHelpEvent(PyObject *enclosing);
PyTypeObject *init_QGraphicsSceneDragDropEvent(PyObject *enclosing);
PyTypeObject *init_QGraphicsSceneContextMenuEvent(PyObject *enclosing);
PyTypeObject *init_QGestureEvent(PyObject *enclosing);
PyTypeObject *init_QApplication(PyObject *enclosing);
PyTypeObject *init_QFileDialog(PyObject *enclosing);
PyTypeObject *init_QFileSystemModel(PyObject *enclosing);

// Required modules' type and converter arrays.
Shiboken::Module::TypeInitStruct *SbkPySide6_QtGuiTypeStructs;
SbkConverter **SbkPySide6_QtGuiTypeConverters;
Shiboken::Module::TypeInitStruct *SbkPySide6_QtCoreTypeStructs;
SbkConverter **SbkPySide6_QtCoreTypeConverters;

// Module initialization ------------------------------------------------------------
// Container Type converters.

// C++ to Python conversion for container type 'QList<int>'.
static PyObject *_QList_int__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<int> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_int_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<int> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        int cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_int__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), pyIn))
        return PySequence_PythonToCpp__QList_int_;
    return {};
}


// Binding for QList<int>

template <>
struct ShibokenContainerValueConverter<int>
{
    static bool checkValue(PyObject *pyArg)
    {
        return PyLong_Check(pyArg);
    }

    static PyObject *convertValueToPython(int cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppArg);
    }

    static std::optional<int> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!(PyLong_Check(pyArg) && (pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<int>(), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        int cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QIntList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<int>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QIntList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QIntList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<int>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QIntList_spec = {
    "2:PySide6.QtWidgets.QIntList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QIntList_slots
};

static inline PyTypeObject *createQIntListType()
{
    auto *result = SbkType_FromSpec(&QIntList_spec);
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QIntList_TypeF()
{
    static PyTypeObject *type = createQIntListType();
    return type;
}

extern "C" PyObject *createQIntList(QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQIntList(const QList<int>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QIntList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<int>>();
    d->m_list = const_cast<QList<int> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QIntList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QIntList_TypeF();
}

extern "C" void PythonToCppQIntList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<int>>::get(pyArg);
    *reinterpret_cast<QList<int>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQIntListPythonToCppConvertible(PyObject *pyArg)
{
    if (QIntList_Check(pyArg))
        return PythonToCppQIntList;
    return {};
}

extern "C" void PythonToQVariantQIntList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<int>>::get(pyArg);
    *reinterpret_cast<QVariant *>(cppOut) = QVariant::fromValue(*d->m_list);
}

extern "C" PythonToCppFunc isQIntListPythonToQVariantConvertible(PyObject *pyArg)
{
    if (QIntList_Check(pyArg))
        return PythonToQVariantQIntList;
    return {};
}

// C++ to Python conversion for container type 'QList<QTreeWidgetItem*>'.
static PyObject *_QList_QTreeWidgetItemPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTreeWidgetItem*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTreeWidgetItemPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTreeWidgetItem*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTreeWidgetItem* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTreeWidgetItemPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidgetItem_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QTreeWidgetItemPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QColor>'.
static PyObject *_QList_QColor__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QColor> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QColor_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QColor> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QColor cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QColor__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QColor_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QColor_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>'.
static PyObject *std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SetItem(pyOut, 0, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), cppInRef.first));
    PyTuple_SetItem(pyOut, 1, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QAccessible_RelationFlag_IDX])))->flagsConverter, &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::AutoDecRef objfirst(PySequence_GetItem(pyIn, 0));
    Shiboken::AutoDecRef objsecond(PySequence_GetItem(pyIn, 1));
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX]), objfirst, &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QAccessible_RelationFlag_IDX])))->flagsConverter, objsecond, &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleInterface_IDX])))->converter, true, PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QFlags_QAccessible_RelationFlag_IDX])))->flagsConverter, false, pyIn))
        return PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag__;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>>'.
static PyObject *_QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX], pyIn))
        return PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___;
    return {};
}

// C++ to Python conversion for container type 'QList<QGraphicsItem*>'.
static PyObject *_QList_QGraphicsItemPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QGraphicsItem*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QGraphicsItemPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QGraphicsItem*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QGraphicsItem* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QGraphicsItemPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QGraphicsItemPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QGraphicsTransform*>'.
static PyObject *_QList_QGraphicsTransformPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QGraphicsTransform*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsTransform_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QGraphicsTransformPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QGraphicsTransform*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QGraphicsTransform* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsTransform_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QGraphicsTransformPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsTransform_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QGraphicsTransformPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLine>'.
static PyObject *_QList_QLine__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLine> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLine_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLine> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLine cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLine__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLine_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QLine_;
    return {};
}

// C++ to Python conversion for container type 'QList<QLineF>'.
static PyObject *_QList_QLineF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QLineF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QLineF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QLineF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QLineF cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QLineF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QLineF_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QLineF_;
    return {};
}

// C++ to Python conversion for container type 'QList<QPoint>'.
static PyObject *_QList_QPoint__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPoint> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QPoint_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPoint> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPoint cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QPoint__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QPoint_;
    return {};
}


// Binding for QList<QPoint>

template <>
struct ShibokenContainerValueConverter<QPoint>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), pyArg);
    }

    static PyObject *convertValueToPython(const QPoint &cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), &cppArg);
    }

    static std::optional<QPoint> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPoint_IDX]), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QPoint cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QPointList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPoint>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QPointList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QPointList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPoint>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QPointList_spec = {
    "2:PySide6.QtWidgets.QPointList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QPointList_slots
};

static inline PyTypeObject *createQPointListType()
{
    auto *result = SbkType_FromSpec(&QPointList_spec);
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QPointList_TypeF()
{
    static PyTypeObject *type = createQPointListType();
    return type;
}

extern "C" PyObject *createQPointList(QList<QPoint>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPoint>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQPointList(const QList<QPoint>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPoint>>();
    d->m_list = const_cast<QList<QPoint> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QPointList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QPointList_TypeF();
}

extern "C" void PythonToCppQPointList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QPoint>>::get(pyArg);
    *reinterpret_cast<QList<QPoint>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQPointListPythonToCppConvertible(PyObject *pyArg)
{
    if (QPointList_Check(pyArg))
        return PythonToCppQPointList;
    return {};
}

extern "C" void PythonToQVariantQPointList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QPoint>>::get(pyArg);
    *reinterpret_cast<QVariant *>(cppOut) = QVariant::fromValue(*d->m_list);
}

extern "C" PythonToCppFunc isQPointListPythonToQVariantConvertible(PyObject *pyArg)
{
    if (QPointList_Check(pyArg))
        return PythonToQVariantQPointList;
    return {};
}

// C++ to Python conversion for container type 'QList<QPointF>'.
static PyObject *_QList_QPointF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QPointF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QPointF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QPointF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QPointF cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QPointF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QPointF_;
    return {};
}


// Binding for QList<QPointF>

template <>
struct ShibokenContainerValueConverter<QPointF>
{
    static bool checkValue(PyObject *pyArg)
    {
        return SbkObject_TypeCheck(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), pyArg);
    }

    static PyObject *convertValueToPython(const QPointF &cppArg)
    {
        return Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppArg);
    }

    static std::optional<QPointF> convertValueToCpp(PyObject *pyArg)
    {
        Shiboken::Conversions::PythonToCppConversion pythonToCpp;
        if (!((pythonToCpp = Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), (pyArg))))) {
            Shiboken::Errors::setWrongContainerType();
            return {};
        }
        ::QPointF cppArg;
        pythonToCpp(pyArg, &cppArg);
        return cppArg;
    }
};

static PyMethodDef QPointFList_methods[] = {
    {"push_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_back), METH_O, "push_back"},
    {"append", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_back), METH_O, "append"},
    {"clear", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::clear), METH_NOARGS, "clear"},
    {"pop_back", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_back), METH_NOARGS, "pop_back"},
    {"removeLast", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_back), METH_NOARGS, "removeLast"},
    {"push_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_front), METH_O, "push_front"},
    {"prepend", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::push_front), METH_O, "prepend"},
    {"pop_front", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_front), METH_NOARGS, "pop_front"},
    {"removeFirst", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::pop_front), METH_O, "removeFirst"},
    {"reserve", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::reserve), METH_O, "reserve"},
    {"capacity", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::capacity), METH_NOARGS, "capacity"},
    {"data", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::data), METH_NOARGS, "data"},
    {"constData", reinterpret_cast<PyCFunction>(ShibokenSequenceContainerPrivate<QList<QPointF>>::constData), METH_NOARGS, "constData"},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static PyType_Slot QPointFList_slots[] = {
    {Py_tp_init, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpInit)},
    {Py_tp_new, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpNew)},
    {Py_tp_free, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::tpFree)},
    {Py_tp_dealloc, reinterpret_cast<void *>(Sbk_object_dealloc)},
    {Py_tp_methods, reinterpret_cast<void *>(QPointFList_methods)},
    {Py_sq_ass_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqSetItem)},
    {Py_sq_length, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqLen)},
    {Py_sq_item, reinterpret_cast<void *>(ShibokenSequenceContainerPrivate<QList<QPointF>>::sqGetItem)},
    {0, nullptr}
};

static PyType_Spec QPointFList_spec = {
    "2:PySide6.QtWidgets.QPointFList",
    sizeof(ShibokenContainer),
    0,
    Py_TPFLAGS_DEFAULT,
    QPointFList_slots
};

static inline PyTypeObject *createQPointFListType()
{
    auto *result = SbkType_FromSpec(&QPointFList_spec);
    Py_INCREF(Py_True);
    Shiboken::AutoDecRef tpDict(PepType_GetDict(result));
    PyDict_SetItem(tpDict.object(), Shiboken::PyMagicName::opaque_container(), Py_True);
    return result;
}

static PyTypeObject *QPointFList_TypeF()
{
    static PyTypeObject *type = createQPointFListType();
    return type;
}

extern "C" PyObject *createQPointFList(QList<QPointF>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointFList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPointF>>();
    d->m_list = ct;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" PyObject *createConstQPointFList(const QList<QPointF>* ct)
{
    auto *container = PyObject_New(ShibokenContainer, QPointFList_TypeF());
    auto *d = new ShibokenSequenceContainerPrivate<QList<QPointF>>();
    d->m_list = const_cast<QList<QPointF> *>(ct);
    d->m_const = true;
    container->d = d;
    return reinterpret_cast<PyObject *>(container);
}

extern "C" int QPointFList_Check(PyObject *pyArg)
{
    return pyArg != nullptr && pyArg != Py_None && pyArg->ob_type == QPointFList_TypeF();
}

extern "C" void PythonToCppQPointFList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QPointF>>::get(pyArg);
    *reinterpret_cast<QList<QPointF>**>(cppOut) = d->m_list;
}

extern "C" PythonToCppFunc isQPointFListPythonToCppConvertible(PyObject *pyArg)
{
    if (QPointFList_Check(pyArg))
        return PythonToCppQPointFList;
    return {};
}

extern "C" void PythonToQVariantQPointFList(PyObject *pyArg, void *cppOut)
{
    auto *d = ShibokenSequenceContainerPrivate<QList<QPointF>>::get(pyArg);
    *reinterpret_cast<QVariant *>(cppOut) = QVariant::fromValue(*d->m_list);
}

extern "C" PythonToCppFunc isQPointFListPythonToQVariantConvertible(PyObject *pyArg)
{
    if (QPointFList_Check(pyArg))
        return PythonToQVariantQPointFList;
    return {};
}

// C++ to Python conversion for container type 'QList<QRect>'.
static PyObject *_QList_QRect__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRect> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRect_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRect> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRect cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRect__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRect_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QRect_;
    return {};
}

// C++ to Python conversion for container type 'QList<QRectF>'.
static PyObject *_QList_QRectF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QRectF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QRectF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QRectF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QRectF cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QRectF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QRectF_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QRectF_;
    return {};
}

// C++ to Python conversion for container type 'QList<QAction*>'.
static PyObject *_QList_QActionPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QAction*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QActionPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QAction*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QAction* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QActionPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QActionPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QObject*>'.
static PyObject *_QList_QObjectPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QObject*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QObjectPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QObject*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QObject* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QObjectPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QByteArray>'.
static PyObject *_QList_QByteArray__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QByteArray cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<QDockWidget*>'.
static PyObject *_QList_QDockWidgetPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QDockWidget*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDockWidget_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QDockWidgetPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QDockWidget*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QDockWidget* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDockWidget_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QDockWidgetPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QDockWidget_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QDockWidgetPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QKeyCombination>'.
static PyObject *_QList_QKeyCombination__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QKeyCombination> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QKeyCombination_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QKeyCombination> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QKeyCombination cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QKeyCombination__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QKeyCombination_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QKeyCombination_;
    return {};
}

// C++ to Python conversion for container type 'QList<QWidget*>'.
static PyObject *_QList_QWidgetPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QWidget*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QWidgetPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QWidget*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QWidget* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QWidgetPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QWidgetPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTextEdit::ExtraSelection>'.
static PyObject *_QList_QTextEdit_ExtraSelection__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTextEdit::ExtraSelection> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTextEdit_ExtraSelection_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTextEdit::ExtraSelection> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTextEdit::ExtraSelection cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTextEdit_ExtraSelection__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_ExtraSelection_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QTextEdit_ExtraSelection_;
    return {};
}

// C++ to Python conversion for container type 'QList<QMdiSubWindow*>'.
static PyObject *_QList_QMdiSubWindowPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QMdiSubWindow*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiSubWindow_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QMdiSubWindowPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QMdiSubWindow*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QMdiSubWindow* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiSubWindow_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QMdiSubWindowPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiSubWindow_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QMdiSubWindowPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QModelIndex>'.
static PyObject *_QList_QModelIndex__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QModelIndex> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QModelIndex_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QModelIndex> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QModelIndex cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QModelIndex__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QModelIndex_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QModelIndex_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTableWidgetItem*>'.
static PyObject *_QList_QTableWidgetItemPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTableWidgetItem*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetItem_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTableWidgetItemPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTableWidgetItem*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTableWidgetItem* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetItem_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTableWidgetItemPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetItem_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QTableWidgetItemPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QTableWidgetSelectionRange>'.
static PyObject *_QList_QTableWidgetSelectionRange__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QTableWidgetSelectionRange> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QTableWidgetSelectionRange_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QTableWidgetSelectionRange> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QTableWidgetSelectionRange cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QTableWidgetSelectionRange__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidgetSelectionRange_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QTableWidgetSelectionRange_;
    return {};
}

// C++ to Python conversion for container type 'QList<QListWidgetItem*>'.
static PyObject *_QList_QListWidgetItemPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QListWidgetItem*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListWidgetItem_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QListWidgetItemPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QListWidgetItem*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QListWidgetItem* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListWidgetItem_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QListWidgetItemPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QListWidgetItem_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QListWidgetItemPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QAbstractButton*>'.
static PyObject *_QList_QAbstractButtonPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QAbstractButton*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QAbstractButtonPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QAbstractButton*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QAbstractButton* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QAbstractButtonPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QAbstractButtonPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QWizard::WizardButton>'.
static PyObject *_QList_QWizard_WizardButton__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QWizard::WizardButton> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardButton_IDX])))->converter, &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QWizard_WizardButton_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QWizard::WizardButton> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QWizard::WizardButton cppItem{QWizard::BackButton};
    Shiboken::Conversions::pythonToCppCopy(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardButton_IDX])))->converter, pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QWizard_WizardButton__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(PepType_SETP(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_WizardButton_IDX])))->converter, pyIn))
        return PySequence_PythonToCpp__QList_QWizard_WizardButton_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QDate,QTextCharFormat>'.
static PyObject *_QMap_QDate_QTextCharFormat__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QDate,QTextCharFormat> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_QDate_QTextCharFormat_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QDate,QTextCharFormat> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key{};
    PyObject *value{};
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QDate cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX]), key, &(cppKey));
        ::QTextCharFormat cppValue;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX]), value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_QDate_QTextCharFormat__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDate_IDX])))->converter, false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QTextCharFormat_IDX])))->converter, false, pyIn))
        return PyDict_PythonToCpp__QMap_QDate_QTextCharFormat_;
    return {};
}

// C++ to Python conversion for container type 'QList<QScroller*>'.
static PyObject *_QList_QScrollerPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QScroller*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QScrollerPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QScroller*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QScroller* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QScrollerPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QScrollerPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<qreal>'.
static PyObject *_QList_qreal__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<qreal> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_qreal_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<qreal> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        qreal cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_qreal__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), pyIn))
        return PySequence_PythonToCpp__QList_qreal_;
    return {};
}

// C++ to Python conversion for container type 'QList<QGraphicsView*>'.
static PyObject *_QList_QGraphicsViewPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QGraphicsView*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsView_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QGraphicsViewPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QGraphicsView*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QGraphicsView* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsView_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QGraphicsViewPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsView_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QGraphicsViewPTR_;
    return {};
}

// C++ to Python conversion for container type 'std::pair<qreal,QPointF>'.
static PyObject *std_pair_qreal_QPointF__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const std::pair<qreal,QPointF> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SetItem(pyOut, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppInRef.first));
    PyTuple_SetItem(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_qreal_QPointF_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<std::pair<qreal,QPointF> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::AutoDecRef objfirst(PySequence_GetItem(pyIn, 0));
    Shiboken::AutoDecRef objsecond(PySequence_GetItem(pyIn, 1));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), objfirst, &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX]), objsecond, &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_qreal_QPointF__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QPointF_IDX])))->converter, false, pyIn))
        return PySequence_PythonToCpp_std_pair_qreal_QPointF_;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair<qreal,QPointF>>'.
static PyObject *_QList_std_pair_qreal_QPointF___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair<qreal,QPointF>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_qreal_QPointF_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_std_pair_qreal_QPointF__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair<qreal,QPointF>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        std::pair<qreal,QPointF> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_qreal_QPointF_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_std_pair_qreal_QPointF___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_qreal_QPointF_IDX], pyIn))
        return PySequence_PythonToCpp__QList_std_pair_qreal_QPointF__;
    return {};
}

// C++ to Python conversion for container type 'std::pair<qreal,qreal>'.
static PyObject *std_pair_qreal_qreal__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const std::pair<qreal,qreal> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - START
    PyObject *pyOut = PyTuple_New(2);
    PyTuple_SetItem(pyOut, 0, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppInRef.first));
    PyTuple_SetItem(pyOut, 1, Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), &cppInRef.second));
    return pyOut;
    // TEMPLATE - shiboken_conversion_cpppair_to_pytuple - END

}
static void PySequence_PythonToCpp_std_pair_qreal_qreal_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<std::pair<qreal,qreal> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - START
    Shiboken::AutoDecRef objfirst(PySequence_GetItem(pyIn, 0));
    Shiboken::AutoDecRef objsecond(PySequence_GetItem(pyIn, 1));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), objfirst, &(cppOutRef.first));
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), objsecond, &(cppOutRef.second));
    // TEMPLATE - shiboken_conversion_pysequence_to_cpppair - END

}
static PythonToCppFunc is_PySequence_PythonToCpp_std_pair_qreal_qreal__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertiblePairTypes(Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), false, Shiboken::Conversions::PrimitiveTypeConverter<qreal>(), false, pyIn))
        return PySequence_PythonToCpp_std_pair_qreal_qreal_;
    return {};
}

// C++ to Python conversion for container type 'QList<std::pair<qreal,qreal>>'.
static PyObject *_QList_std_pair_qreal_qreal___CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<std::pair<qreal,qreal>> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_qreal_qreal_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_std_pair_qreal_qreal__(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<std::pair<qreal,qreal>> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        std::pair<qreal,qreal> cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_qreal_qreal_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_std_pair_qreal_qreal___Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_qreal_qreal_IDX], pyIn))
        return PySequence_PythonToCpp__QList_std_pair_qreal_qreal__;
    return {};
}

// C++ to Python conversion for container type 'QList<QKeySequence>'.
static PyObject *_QList_QKeySequence__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QKeySequence> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QKeySequence_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QKeySequence> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QKeySequence cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QKeySequence__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QKeySequence_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QKeySequence_;
    return {};
}

// C++ to Python conversion for container type 'QList<QGesture*>'.
static PyObject *_QList_QGesturePTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QGesture*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QGesturePTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QGesture*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QGesture* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QGesturePTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QGesturePTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QWindow*>'.
static PyObject *_QList_QWindowPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QWindow*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QWindowPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QWindow*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QWindow* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QWindowPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QWindow_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QWindowPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QScreen*>'.
static PyObject *_QList_QScreenPTR__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QScreen*> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::pointerToPython(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QScreenPTR_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QScreen*> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QScreen* cppItem{nullptr};
    Shiboken::Conversions::pythonToCppPointer(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QScreenPTR__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::checkSequenceTypes(Shiboken::Module::get(SbkPySide6_QtGuiTypeStructs[SBK_QScreen_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QScreenPTR_;
    return {};
}

// C++ to Python conversion for container type 'QList<QUrl>'.
static PyObject *_QList_QUrl__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QUrl> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QUrl_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QUrl> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QUrl cppItem;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QUrl__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), pyIn))
        return PySequence_PythonToCpp__QList_QUrl_;
    return {};
}

// C++ to Python conversion for container type 'QMap<int,QVariant>'.
static PyObject *_QMap_int_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<int,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_int_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<int,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key{};
    PyObject *value{};
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        int cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_int_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_int_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QHash<int,QByteArray>'.
static PyObject *_QHash_int_QByteArray__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QHash<int,QByteArray> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QHash_int_QByteArray_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QHash<int,QByteArray> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key{};
    PyObject *value{};
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        int cppKey;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Conversions::PrimitiveTypeConverter<int>(), key, &(cppKey));
        ::QByteArray cppValue;
    Shiboken::Conversions::pythonToCppCopy(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QHash_int_QByteArray__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(Shiboken::Conversions::PrimitiveTypeConverter<int>(), false, PepType_SOTP(reinterpret_cast<PyTypeObject *>(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX])))->converter, false, pyIn))
        return PyDict_PythonToCpp__QHash_int_QByteArray_;
    return {};
}

// C++ to Python conversion for container type 'QList<QVariant>'.
static PyObject *_QList_QVariant__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QVariant cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QVariant_;
    return {};
}

// C++ to Python conversion for container type 'QList<QString>'.
static PyObject *_QList_QString__CppToPython_PyList(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QList<QString> *>(cppIn);
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - START
    PyObject *pyOut = PyList_New(Py_ssize_t(cppInRef.size()));
    Py_ssize_t idx = 0;
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it, ++idx) {
        const auto &cppItem = *it;
        PyList_SET_ITEM(pyOut, idx, Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppItem));
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_cppsequence_to_pylist - END

}
static void PySequence_PythonToCpp__QList_QString_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QList<QString> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - START
    (cppOutRef).clear();
    if (PyList_Check(pyIn)) {
        const Py_ssize_t size = PySequence_Size(pyIn);
        if (size > 10)
            (cppOutRef).reserve(size);
    }

    Shiboken::AutoDecRef it(PyObject_GetIter(pyIn));
    while (true) {
        Shiboken::AutoDecRef pyItem(PyIter_Next(it.object()));
        if (pyItem.isNull()) {
            if (PyErr_Occurred() && PyErr_ExceptionMatches(PyExc_StopIteration))
                PyErr_Clear();
            break;
        }
        ::QString cppItem;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyItem, &(cppItem));
        (cppOutRef).push_back(cppItem);
    }
    // TEMPLATE - shiboken_conversion_pyiterable_to_cppsequentialcontainer_reserve - END

}
static PythonToCppFunc is_PySequence_PythonToCpp__QList_QString__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleSequenceTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], pyIn))
        return PySequence_PythonToCpp__QList_QString_;
    return {};
}

// C++ to Python conversion for container type 'QMap<QString,QVariant>'.
static PyObject *_QMap_QString_QVariant__CppToPython_PyDict(const void *cppIn)
{
    const auto &cppInRef = *reinterpret_cast<const ::QMap<QString,QVariant> *>(cppIn);
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - START
    PyObject *pyOut = PyDict_New();
    for (auto it = std::cbegin(cppInRef), end = std::cend(cppInRef); it != end; ++it) {
        const auto &key = it.key();
        const auto &value = it.value();
        PyObject *pyKey = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &key);
        PyObject *pyValue = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], &value);
        PyDict_SetItem(pyOut, pyKey, pyValue);
        Py_DECREF(pyKey);
        Py_DECREF(pyValue);
    }
    return pyOut;
    // TEMPLATE - shiboken_conversion_qmap_to_pydict - END

}
static void PyDict_PythonToCpp__QMap_QString_QVariant_(PyObject *pyIn, void *cppOut)
{
    auto &cppOutRef = *reinterpret_cast<::QMap<QString,QVariant> *>(cppOut);
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - START
    PyObject *key{};
    PyObject *value{};
    cppOutRef.clear();
    Py_ssize_t pos = 0;
    while (PyDict_Next(pyIn, &pos, &key, &value)) {
        ::QString cppKey;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], key, &(cppKey));
        ::QVariant cppValue;
    Shiboken::Conversions::pythonToCppCopy(SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], value, &(cppValue));
        cppOutRef.insert(cppKey, cppValue);
    }
    // TEMPLATE - shiboken_conversion_pydict_to_qmap - END

}
static PythonToCppFunc is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible(PyObject *pyIn)
{
    if (Shiboken::Conversions::convertibleDictTypes(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], false, SbkPySide6_QtCoreTypeConverters[SBK_QVariant_IDX], false, pyIn))
        return PyDict_PythonToCpp__QMap_QString_QVariant_;
    return {};
}


static struct PyModuleDef moduledef = {
    /* m_base     */ PyModuleDef_HEAD_INIT,
    /* m_name     */ "QtWidgets",
    /* m_doc      */ nullptr,
    /* m_size     */ -1,
    /* m_methods  */ QtWidgets_methods,
    /* m_reload   */ nullptr,
    /* m_traverse */ nullptr,
    /* m_clear    */ nullptr,
    /* m_free     */ nullptr
};

// The signatures string for the global functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *QtWidgets_SignatureStrings[] = {
    "1:PySide6.QtWidgets.qDrawPlainRect(p:PySide6.QtGui.QPainter,x:int,y:int,w:int,h:int,arg__6:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int],lineWidth:int=1,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "0:PySide6.QtWidgets.qDrawPlainRect(p:PySide6.QtGui.QPainter,r:PySide6.QtCore.QRect,arg__3:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int],lineWidth:int=1,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "1:PySide6.QtWidgets.qDrawPlainRoundedRect(p:PySide6.QtGui.QPainter,x:int,y:int,w:int,h:int,rx:qreal,ry:qreal,arg__8:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int],lineWidth:int=1,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "0:PySide6.QtWidgets.qDrawPlainRoundedRect(painter:PySide6.QtGui.QPainter,rect:PySide6.QtCore.QRect,rx:qreal,ry:qreal,lineColor:typing.Union[PySide6.QtGui.QColor, QLatin1String, PySide6.QtGui.QRgba64, QVariant, PySide6.QtCore.Qt.GlobalColor, QString, unsigned int],lineWidth:int=1,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "1:PySide6.QtWidgets.qDrawShadeLine(p:PySide6.QtGui.QPainter,x1:int,y1:int,x2:int,y2:int,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=true,lineWidth:int=1,midLineWidth:int=0)",
    "0:PySide6.QtWidgets.qDrawShadeLine(p:PySide6.QtGui.QPainter,p1:PySide6.QtCore.QPoint,p2:PySide6.QtCore.QPoint,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=true,lineWidth:int=1,midLineWidth:int=0)",
    "1:PySide6.QtWidgets.qDrawShadePanel(p:PySide6.QtGui.QPainter,x:int,y:int,w:int,h:int,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,lineWidth:int=1,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "0:PySide6.QtWidgets.qDrawShadePanel(p:PySide6.QtGui.QPainter,r:PySide6.QtCore.QRect,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,lineWidth:int=1,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "1:PySide6.QtWidgets.qDrawShadeRect(p:PySide6.QtGui.QPainter,x:int,y:int,w:int,h:int,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,lineWidth:int=1,midLineWidth:int=0,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "0:PySide6.QtWidgets.qDrawShadeRect(p:PySide6.QtGui.QPainter,r:PySide6.QtCore.QRect,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,lineWidth:int=1,midLineWidth:int=0,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "1:PySide6.QtWidgets.qDrawWinButton(p:PySide6.QtGui.QPainter,x:int,y:int,w:int,h:int,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "0:PySide6.QtWidgets.qDrawWinButton(p:PySide6.QtGui.QPainter,r:PySide6.QtCore.QRect,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "1:PySide6.QtWidgets.qDrawWinPanel(p:PySide6.QtGui.QPainter,x:int,y:int,w:int,h:int,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    "0:PySide6.QtWidgets.qDrawWinPanel(p:PySide6.QtGui.QPainter,r:PySide6.QtCore.QRect,pal:typing.Union[PySide6.QtGui.QPalette, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor],sunken:bool=false,fill:typing.Union[PySide6.QtGui.QBrush, PySide6.QtCore.Qt.BrushStyle, PySide6.QtCore.Qt.GlobalColor, PySide6.QtGui.QColor, PySide6.QtGui.QGradient, PySide6.QtGui.QImage, PySide6.QtGui.QPixmap]=nullptr)",
    nullptr}; // Sentinel
#else
static constexpr size_t QtWidgets_SignatureByteSize = 450;
static constexpr uint8_t QtWidgets_SignatureBytes[450] = {
    0x78, 0xda, 0xed, 0x97, 0x5d, 0x6b, 0xc2, 0x30, 0x14, 0x86, 0xef, 0xf7, 0x2b, 0xbc, 0xdc, 0xa0,
    0x14, 0xeb, 0x86, 0x8c, 0x82, 0x37, 0x3a, 0x90, 0x81, 0x17, 0xd5, 0xb2, 0x79, 0x31, 0x44, 0x8e,
    0xeb, 0xb1, 0x86, 0xc5, 0xa4, 0xa6, 0x29, 0xb6, 0xff, 0x7e, 0x31, 0x9d, 0xa0, 0xad, 0x76, 0xce,
    0x31, 0x3f, 0xd6, 0xde, 0x24, 0x6d, 0x72, 0x48, 0xcf, 0x9b, 0x27, 0x6f, 0x38, 0xb5, 0x6c, 0x27,
    0x71, 0x89, 0x87, 0x4d, 0xb3, 0x2f, 0x87, 0xc4, 0xf3, 0x51, 0x86, 0xe6, 0xe2, 0x49, 0xc0, 0xd2,
    0xa1, 0x40, 0xd8, 0x00, 0xdf, 0xe5, 0x6d, 0xb0, 0x11, 0xd2, 0x8d, 0x88, 0xd9, 0x77, 0xd4, 0x8c,
    0x44, 0x61, 0xc4, 0xb6, 0xea, 0x8d, 0x44, 0xb7, 0x4b, 0xdd, 0xce, 0x74, 0x0b, 0xc2, 0x1f, 0x8f,
    0x9b, 0xb6, 0x4c, 0x02, 0xc2, 0x7c, 0xf3, 0x85, 0x11, 0xce, 0xde, 0x32, 0x4b, 0x74, 0x38, 0xe5,
    0xc2, 0xa8, 0xf5, 0x7b, 0x20, 0x09, 0xb3, 0x5c, 0x29, 0x54, 0xa4, 0x51, 0xcb, 0x04, 0x0d, 0xfc,
    0x09, 0x34, 0x1f, 0x54, 0xd4, 0x2b, 0x08, 0x02, 0x6a, 0xe1, 0x8d, 0x80, 0x0e, 0x17, 0xa8, 0x3a,
    0xb3, 0x4b, 0xf9, 0x04, 0xe8, 0x7a, 0xb9, 0xf5, 0x42, 0x11, 0x0b, 0x89, 0xcf, 0xd0, 0xab, 0xa9,
    0x74, 0x46, 0x06, 0x25, 0x0c, 0x95, 0x36, 0xa9, 0xb3, 0x6b, 0x59, 0xc6, 0x94, 0x50, 0x5a, 0x98,
    0x5d, 0x5b, 0x44, 0xe1, 0x6c, 0xd7, 0xd7, 0xf4, 0x84, 0x2b, 0x13, 0x8a, 0xdf, 0xe6, 0xb2, 0x5b,
    0x70, 0x66, 0xb4, 0x2b, 0xc0, 0x23, 0xb8, 0xad, 0x4c, 0x4f, 0x3c, 0xcf, 0xc1, 0xc7, 0xdc, 0xa8,
    0x43, 0xe2, 0x39, 0x04, 0xa3, 0x16, 0x8b, 0x28, 0x0d, 0xa4, 0xb8, 0xbb, 0xa9, 0xff, 0x82, 0x9e,
    0xb0, 0xb3, 0x0a, 0x56, 0xf1, 0x29, 0xbc, 0xfb, 0x0a, 0xde, 0xdf, 0xc3, 0xb3, 0x8a, 0xe1, 0xf1,
    0x88, 0x79, 0xe8, 0x1d, 0xe7, 0x40, 0x11, 0xdb, 0x0b, 0x81, 0x40, 0x0d, 0x91, 0x7c, 0x3d, 0x68,
    0xac, 0x8f, 0x15, 0xd6, 0xb3, 0x7b, 0x72, 0x13, 0x6b, 0x4a, 0x71, 0xaf, 0x41, 0x55, 0xcc, 0x6e,
    0x8f, 0xe6, 0xf1, 0xae, 0xb6, 0x53, 0xcb, 0xa9, 0x08, 0x9f, 0xd1, 0xb8, 0xee, 0x0c, 0x3c, 0xec,
    0x29, 0xdd, 0x05, 0x8e, 0xb5, 0x52, 0xcb, 0xa6, 0x5d, 0xdc, 0x48, 0xdf, 0xd2, 0x2e, 0x80, 0xe2,
    0x0d, 0x72, 0x80, 0xa2, 0x94, 0xc7, 0x6d, 0xc2, 0xc8, 0x08, 0x23, 0xf6, 0x81, 0xcc, 0x9e, 0x70,
    0x4e, 0x5b, 0x52, 0x44, 0x98, 0x03, 0x34, 0x27, 0x5e, 0x6f, 0x6b, 0xa8, 0x5e, 0x70, 0x98, 0x0f,
    0x90, 0x1a, 0x58, 0xb9, 0xd3, 0xeb, 0x70, 0xad, 0xb3, 0xb1, 0x6f, 0xe2, 0xf2, 0x36, 0xa0, 0x98,
    0xb5, 0x03, 0x0c, 0xe9, 0xcf, 0xaf, 0xe7, 0xd3, 0xe9, 0x9c, 0x02, 0x0d, 0xb1, 0x8c, 0x97, 0xed,
    0x21, 0x78, 0xf6, 0x54, 0x40, 0x15, 0x9d, 0xd3, 0x5c, 0x94, 0xc7, 0x95, 0x36, 0xe7, 0xa6, 0x93,
    0xbf, 0x24, 0x4a, 0x63, 0xa7, 0xa3, 0xfe, 0x27, 0x2a, 0x5e, 0xe7, 0x30, 0xd8, 0x90, 0xb0, 0x76,
    0x24, 0x25, 0x67, 0x97, 0x6f, 0xb0, 0x12, 0xb8, 0xe7, 0x00, 0x1a, 0x17, 0xe2, 0x9e, 0x72, 0x58,
    0xe3, 0x4a, 0xca, 0xb6, 0x72, 0x38, 0xe3, 0x3a, 0x8a, 0xb4, 0xff, 0xc3, 0xe2, 0x13, 0x7e, 0x5c,
    0xbc, 0x21
};
#endif

static void initInheritance()
{
    auto &bm = Shiboken::BindingManager::instance();
    SBK_UNUSED(bm)
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturnVariant_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QLayoutItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QSpacerItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturn_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleHintReturnMask_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QAccessibleWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtGuiTypeStructs[SBK_QAccessibleActionInterface_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QAccessibleWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtGuiTypeStructs[SBK_QAbstractFileIconProvider_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QFileIconProvider_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLinearLayout_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsGridLayout_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayout_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchorLayout_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPixmapItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLineItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemGroup_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractGraphicsShapeItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractGraphicsShapeItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSimpleTextItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractGraphicsShapeItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsRectItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractGraphicsShapeItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPolygonItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractGraphicsShapeItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsPathItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractGraphicsShapeItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsEllipseItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtGuiTypeStructs[SBK_QPainter_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStylePainter_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtGuiTypeStructs[SBK_QPaintDevice_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QWizardPage_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QLayoutItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QWidgetItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QToolBar_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QTabWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QTabBar_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStatusBar_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QSplitterHandle_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QSplashScreen_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QSizeGrip_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QRubberBand_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QRhiWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QProgressBar_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QMenuBar_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QMenu_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiSubWindow_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QMainWindow_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QLineEdit_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QKeySequenceEdit_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGroupBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QToolBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStackedWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QSplitter_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QLabel_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QLCDNumber_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QFrame_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QTextEdit_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QTextBrowser_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollArea_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextEdit_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QMdiArea_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsView_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractScrollArea_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeView_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeView_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QTreeWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QTableView_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QTableView_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QTableWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QUndoView_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QListView_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QListWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QHeaderView_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemView_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QColumnView_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QFocusFrame_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QDockWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QDialogButtonBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QWizard_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QProgressDialog_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QMessageBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QInputDialog_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QFontDialog_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QErrorMessage_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QColorDialog_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QComboBox_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QFontComboBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QCalendarWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QSpinBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QDoubleSpinBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSpinBox_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QTimeEdit_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QDateTimeEdit_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QDateEdit_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QSlider_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QScrollBar_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractSlider_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QDial_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QToolButton_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QRadioButton_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QPushButton_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QPushButton_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QCommandLinkButton_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractButton_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QCheckBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QSystemTrayIcon_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionViewItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolBar_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionTabWidgetFrame_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionTabBarBase_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionTab_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionRubberBand_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionProgressBar_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionMenuItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionHeader_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionHeader_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionHeaderV2_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGraphicsItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionFrame_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionFocusRect_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionDockWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionToolButton_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionTitleBar_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSpinBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSlider_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionSizeGrip_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionGroupBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComplex_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionComboBox_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOption_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyleOptionButton_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QStyle_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QCommonStyle_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QCommonStyle_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QProxyStyle_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QScroller_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QLayout_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QLayoutItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QLayout_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QLayout_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStackedLayout_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QLayout_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGridLayout_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QLayout_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QFormLayout_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QLayout_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QBoxLayout_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QBoxLayout_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QVBoxLayout_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QBoxLayout_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QHBoxLayout_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsTransform_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsTransform_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScale_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsTransform_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsRotation_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsScene_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsObject_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsObject_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsLayoutItem_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsWidget_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsProxyWidget_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsTextItem_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsItemAnimation_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsEffect_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsEffect_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsOpacityEffect_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsEffect_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsDropShadowEffect_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsEffect_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsColorizeEffect_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsEffect_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsBlurEffect_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsAnchor_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QTapGesture_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QTapAndHoldGesture_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QSwipeGesture_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QPinchGesture_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGesture_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QPanGesture_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QDataWidgetMapper_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QCompleter_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QButtonGroup_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QObject_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QStyledItemDelegate_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QAbstractItemDelegate_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QItemDelegate_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtGuiTypeStructs[SBK_QAction_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QWidgetAction_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtGuiTypeStructs[SBK_QAbstractTextDocumentLayout_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QPlainTextDocumentLayout_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneEvent_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneEvent_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneWheelEvent_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneEvent_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneResizeEvent_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneEvent_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMoveEvent_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneEvent_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneMouseEvent_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneEvent_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneHoverEvent_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneEvent_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneHelpEvent_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneEvent_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneDragDropEvent_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneEvent_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGraphicsSceneContextMenuEvent_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QEvent_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QGestureEvent_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtGuiTypeStructs[SBK_QGuiApplication_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QApplication_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtWidgetsTypeStructs[SBK_QDialog_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QFileDialog_IDX]);
    bm.addClassInheritance(&SbkPySide6_QtCoreTypeStructs[SBK_QAbstractItemModel_IDX],
                           &SbkPySide6_QtWidgetsTypeStructs[SBK_QFileSystemModel_IDX]);
}

extern "C" LIBSHIBOKEN_EXPORT PyObject *PyInit_QtWidgets()
{
    if (SbkPySide6_QtWidgetsModuleObject != nullptr)
        return SbkPySide6_QtWidgetsModuleObject;
    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtGui"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtGuiTypeStructs = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtGuiTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    {
        Shiboken::AutoDecRef requiredModule(Shiboken::Module::import("PySide6.QtCore"));
        if (requiredModule.isNull())
            return nullptr;
        SbkPySide6_QtCoreTypeStructs = Shiboken::Module::getTypes(requiredModule);
        SbkPySide6_QtCoreTypeConverters = Shiboken::Module::getTypeConverters(requiredModule);
    }

    // Create an array of wrapper types/names for the current module.
    static Shiboken::Module::TypeInitStruct cppApi[] = {
        {nullptr, "PySide6.QtWidgets.QAbstractButton"},
        {nullptr, "PySide6.QtWidgets.QAbstractGraphicsShapeItem"},
        {nullptr, "PySide6.QtWidgets.QAbstractItemDelegate"},
        {nullptr, "PySide6.QtWidgets.QAbstractItemDelegate.EndEditHint"},
        {nullptr, "PySide6.QtWidgets.QAbstractItemView"},
        {nullptr, "PySide6.QtWidgets.QAbstractItemView.CursorAction"},
        {nullptr, "PySide6.QtWidgets.QAbstractItemView.DragDropMode"},
        {nullptr, "PySide6.QtWidgets.QAbstractItemView.DropIndicatorPosition"},
        {nullptr, "PySide6.QtWidgets.QAbstractItemView.EditTrigger"},
        {nullptr, "PySide6.QtWidgets.QAbstractItemView.ScrollHint"},
        {nullptr, "PySide6.QtWidgets.QAbstractItemView.ScrollMode"},
        {nullptr, "PySide6.QtWidgets.QAbstractItemView.SelectionBehavior"},
        {nullptr, "PySide6.QtWidgets.QAbstractItemView.SelectionMode"},
        {nullptr, "PySide6.QtWidgets.QAbstractItemView.State"},
        {nullptr, "PySide6.QtWidgets.QAbstractScrollArea"},
        {nullptr, "PySide6.QtWidgets.QAbstractScrollArea.SizeAdjustPolicy"},
        {nullptr, "PySide6.QtWidgets.QAbstractSlider"},
        {nullptr, "PySide6.QtWidgets.QAbstractSlider.SliderAction"},
        {nullptr, "PySide6.QtWidgets.QAbstractSlider.SliderChange"},
        {nullptr, "PySide6.QtWidgets.QAbstractSpinBox"},
        {nullptr, "PySide6.QtWidgets.QAbstractSpinBox.ButtonSymbols"},
        {nullptr, "PySide6.QtWidgets.QAbstractSpinBox.CorrectionMode"},
        {nullptr, "PySide6.QtWidgets.QAbstractSpinBox.StepEnabledFlag"},
        {nullptr, "PySide6.QtWidgets.QAbstractSpinBox.StepType"},
        {nullptr, "PySide6.QtWidgets.QAccessibleWidget"},
        {nullptr, "PySide6.QtWidgets.QApplication"},
        {nullptr, "PySide6.QtWidgets.QBoxLayout"},
        {nullptr, "PySide6.QtWidgets.QBoxLayout.Direction"},
        {nullptr, "PySide6.QtWidgets.QButtonGroup"},
        {nullptr, "PySide6.QtWidgets.QCalendarWidget"},
        {nullptr, "PySide6.QtWidgets.QCalendarWidget.HorizontalHeaderFormat"},
        {nullptr, "PySide6.QtWidgets.QCalendarWidget.SelectionMode"},
        {nullptr, "PySide6.QtWidgets.QCalendarWidget.VerticalHeaderFormat"},
        {nullptr, "PySide6.QtWidgets.QCheckBox"},
        {nullptr, "PySide6.QtWidgets.QColorDialog"},
        {nullptr, "PySide6.QtWidgets.QColorDialog.ColorDialogOption"},
        {nullptr, "PySide6.QtWidgets.QColormap"},
        {nullptr, "PySide6.QtWidgets.QColormap.Mode"},
        {nullptr, "PySide6.QtWidgets.QColumnView"},
        {nullptr, "PySide6.QtWidgets.QComboBox"},
        {nullptr, "PySide6.QtWidgets.QComboBox.InsertPolicy"},
        {nullptr, "PySide6.QtWidgets.QComboBox.SizeAdjustPolicy"},
        {nullptr, "PySide6.QtWidgets.QCommandLinkButton"},
        {nullptr, "PySide6.QtWidgets.QCommonStyle"},
        {nullptr, "PySide6.QtWidgets.QCompleter"},
        {nullptr, "PySide6.QtWidgets.QCompleter.CompletionMode"},
        {nullptr, "PySide6.QtWidgets.QCompleter.ModelSorting"},
        {nullptr, "PySide6.QtWidgets.QDataWidgetMapper"},
        {nullptr, "PySide6.QtWidgets.QDataWidgetMapper.SubmitPolicy"},
        {nullptr, "PySide6.QtWidgets.QDateEdit"},
        {nullptr, "PySide6.QtWidgets.QDateTimeEdit"},
        {nullptr, "PySide6.QtWidgets.QDateTimeEdit.Section"},
        {nullptr, "PySide6.QtWidgets.QDial"},
        {nullptr, "PySide6.QtWidgets.QDialog"},
        {nullptr, "PySide6.QtWidgets.QDialog.DialogCode"},
        {nullptr, "PySide6.QtWidgets.QDialogButtonBox"},
        {nullptr, "PySide6.QtWidgets.QDialogButtonBox.ButtonLayout"},
        {nullptr, "PySide6.QtWidgets.QDialogButtonBox.ButtonRole"},
        {nullptr, "PySide6.QtWidgets.QDialogButtonBox.StandardButton"},
        {nullptr, "PySide6.QtWidgets.QDockWidget"},
        {nullptr, "PySide6.QtWidgets.QDockWidget.DockWidgetFeature"},
        {nullptr, "PySide6.QtWidgets.QDoubleSpinBox"},
        {nullptr, "PySide6.QtWidgets.QErrorMessage"},
        {nullptr, "PySide6.QtWidgets.QFileDialog"},
        {nullptr, "PySide6.QtWidgets.QFileDialog.AcceptMode"},
        {nullptr, "PySide6.QtWidgets.QFileDialog.DialogLabel"},
        {nullptr, "PySide6.QtWidgets.QFileDialog.FileMode"},
        {nullptr, "PySide6.QtWidgets.QFileDialog.Option"},
        {nullptr, "PySide6.QtWidgets.QFileDialog.ViewMode"},
        {nullptr, "PySide6.QtWidgets.QFileIconProvider"},
        {nullptr, "PySide6.QtWidgets.QFileSystemModel"},
        {nullptr, "PySide6.QtWidgets.QFileSystemModel.Option"},
        {nullptr, "PySide6.QtWidgets.QFileSystemModel.Roles"},
        {nullptr, "PySide6.QtWidgets.QAbstractItemView.EditTriggers"},
        {nullptr, "PySide6.QtWidgets.QAbstractSpinBox.StepEnabled"},
        {nullptr, "PySide6.QtWidgets.QColorDialog.ColorDialogOptions"},
        {nullptr, "PySide6.QtWidgets.QDateTimeEdit.Sections"},
        {nullptr, "PySide6.QtWidgets.QDialogButtonBox.StandardButtons"},
        {nullptr, "PySide6.QtWidgets.QDockWidget.DockWidgetFeatures"},
        {nullptr, "PySide6.QtWidgets.QFileDialog.Options"},
        {nullptr, "PySide6.QtWidgets.QFileSystemModel.Options"},
        {nullptr, "PySide6.QtWidgets.QFontComboBox.FontFilters"},
        {nullptr, "PySide6.QtWidgets.QFontDialog.FontDialogOptions"},
        {nullptr, "PySide6.QtWidgets.QGestureRecognizer.Result"},
        {nullptr, "PySide6.QtWidgets.QGraphicsBlurEffect.BlurHints"},
        {nullptr, "PySide6.QtWidgets.QGraphicsEffect.ChangeFlags"},
        {nullptr, "PySide6.QtWidgets.QGraphicsItem.GraphicsItemFlags"},
        {nullptr, "PySide6.QtWidgets.QGraphicsScene.SceneLayers"},
        {nullptr, "PySide6.QtWidgets.QGraphicsView.CacheMode"},
        {nullptr, "PySide6.QtWidgets.QGraphicsView.OptimizationFlags"},
        {nullptr, "PySide6.QtWidgets.QMainWindow.DockOptions"},
        {nullptr, "PySide6.QtWidgets.QMdiArea.AreaOptions"},
        {nullptr, "PySide6.QtWidgets.QMdiSubWindow.SubWindowOptions"},
        {nullptr, "PySide6.QtWidgets.QMessageBox.Options"},
        {nullptr, "PySide6.QtWidgets.QMessageBox.StandardButtons"},
        {nullptr, "PySide6.QtWidgets.QPinchGesture.ChangeFlags"},
        {nullptr, "PySide6.QtWidgets.QSizePolicy.ControlTypes"},
        {nullptr, "PySide6.QtWidgets.QStyle.State"},
        {nullptr, "PySide6.QtWidgets.QStyle.SubControls"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionButton.ButtonFeatures"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionFrame.FrameFeatures"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTab.CornerWidgets"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTab.TabFeatures"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolBar.ToolBarFeatures"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolButton.ToolButtonFeatures"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionViewItem.ViewItemFeatures"},
        {nullptr, "PySide6.QtWidgets.QTextEdit.AutoFormatting"},
        {nullptr, "PySide6.QtWidgets.QTreeWidgetItemIterator.IteratorFlags"},
        {nullptr, "PySide6.QtWidgets.QWidget.RenderFlags"},
        {nullptr, "PySide6.QtWidgets.QWizard.WizardOptions"},
        {nullptr, "PySide6.QtWidgets.QFocusFrame"},
        {nullptr, "PySide6.QtWidgets.QFontComboBox"},
        {nullptr, "PySide6.QtWidgets.QFontComboBox.FontFilter"},
        {nullptr, "PySide6.QtWidgets.QFontDialog"},
        {nullptr, "PySide6.QtWidgets.QFontDialog.FontDialogOption"},
        {nullptr, "PySide6.QtWidgets.QFormLayout"},
        {nullptr, "PySide6.QtWidgets.QFormLayout.FieldGrowthPolicy"},
        {nullptr, "PySide6.QtWidgets.QFormLayout.ItemRole"},
        {nullptr, "PySide6.QtWidgets.QFormLayout.RowWrapPolicy"},
        {nullptr, "PySide6.QtWidgets.QFormLayout.TakeRowResult"},
        {nullptr, "PySide6.QtWidgets.QFrame"},
        {nullptr, "PySide6.QtWidgets.QFrame.Shadow"},
        {nullptr, "PySide6.QtWidgets.QFrame.Shape"},
        {nullptr, "PySide6.QtWidgets.QFrame.StyleMask"},
        {nullptr, "PySide6.QtWidgets.QGesture"},
        {nullptr, "PySide6.QtWidgets.QGesture.GestureCancelPolicy"},
        {nullptr, "PySide6.QtWidgets.QGestureEvent"},
        {nullptr, "PySide6.QtWidgets.QGestureRecognizer"},
        {nullptr, "PySide6.QtWidgets.QGestureRecognizer.ResultFlag"},
        {nullptr, "PySide6.QtWidgets.QGraphicsAnchor"},
        {nullptr, "PySide6.QtWidgets.QGraphicsAnchorLayout"},
        {nullptr, "PySide6.QtWidgets.QGraphicsBlurEffect"},
        {nullptr, "PySide6.QtWidgets.QGraphicsBlurEffect.BlurHint"},
        {nullptr, "PySide6.QtWidgets.QGraphicsColorizeEffect"},
        {nullptr, "PySide6.QtWidgets.QGraphicsDropShadowEffect"},
        {nullptr, "PySide6.QtWidgets.QGraphicsEffect"},
        {nullptr, "PySide6.QtWidgets.QGraphicsEffect.ChangeFlag"},
        {nullptr, "PySide6.QtWidgets.QGraphicsEffect.PixmapPadMode"},
        {nullptr, "PySide6.QtWidgets.QGraphicsEllipseItem"},
        {nullptr, "PySide6.QtWidgets.QGraphicsGridLayout"},
        {nullptr, "PySide6.QtWidgets.QGraphicsItem"},
        {nullptr, "PySide6.QtWidgets.QGraphicsItem.CacheMode"},
        {nullptr, "PySide6.QtWidgets.QGraphicsItem.Extension"},
        {nullptr, "PySide6.QtWidgets.QGraphicsItem.GraphicsItemChange"},
        {nullptr, "PySide6.QtWidgets.QGraphicsItem.GraphicsItemFlag"},
        {nullptr, "PySide6.QtWidgets.QGraphicsItem.PanelModality"},
        {nullptr, "PySide6.QtWidgets.QGraphicsItemAnimation"},
        {nullptr, "PySide6.QtWidgets.QGraphicsItemGroup"},
        {nullptr, "PySide6.QtWidgets.QGraphicsLayout"},
        {nullptr, "PySide6.QtWidgets.QGraphicsLayoutItem"},
        {nullptr, "PySide6.QtWidgets.QGraphicsLineItem"},
        {nullptr, "PySide6.QtWidgets.QGraphicsLinearLayout"},
        {nullptr, "PySide6.QtWidgets.QGraphicsObject"},
        {nullptr, "PySide6.QtWidgets.QGraphicsOpacityEffect"},
        {nullptr, "PySide6.QtWidgets.QGraphicsPathItem"},
        {nullptr, "PySide6.QtWidgets.QGraphicsPixmapItem"},
        {nullptr, "PySide6.QtWidgets.QGraphicsPixmapItem.ShapeMode"},
        {nullptr, "PySide6.QtWidgets.QGraphicsPolygonItem"},
        {nullptr, "PySide6.QtWidgets.QGraphicsProxyWidget"},
        {nullptr, "PySide6.QtWidgets.QGraphicsRectItem"},
        {nullptr, "PySide6.QtWidgets.QGraphicsRotation"},
        {nullptr, "PySide6.QtWidgets.QGraphicsScale"},
        {nullptr, "PySide6.QtWidgets.QGraphicsScene"},
        {nullptr, "PySide6.QtWidgets.QGraphicsScene.ItemIndexMethod"},
        {nullptr, "PySide6.QtWidgets.QGraphicsScene.SceneLayer"},
        {nullptr, "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent"},
        {nullptr, "PySide6.QtWidgets.QGraphicsSceneContextMenuEvent.Reason"},
        {nullptr, "PySide6.QtWidgets.QGraphicsSceneDragDropEvent"},
        {nullptr, "PySide6.QtWidgets.QGraphicsSceneEvent"},
        {nullptr, "PySide6.QtWidgets.QGraphicsSceneHelpEvent"},
        {nullptr, "PySide6.QtWidgets.QGraphicsSceneHoverEvent"},
        {nullptr, "PySide6.QtWidgets.QGraphicsSceneMouseEvent"},
        {nullptr, "PySide6.QtWidgets.QGraphicsSceneMoveEvent"},
        {nullptr, "PySide6.QtWidgets.QGraphicsSceneResizeEvent"},
        {nullptr, "PySide6.QtWidgets.QGraphicsSceneWheelEvent"},
        {nullptr, "PySide6.QtWidgets.QGraphicsSimpleTextItem"},
        {nullptr, "PySide6.QtWidgets.QGraphicsTextItem"},
        {nullptr, "PySide6.QtWidgets.QGraphicsTransform"},
        {nullptr, "PySide6.QtWidgets.QGraphicsView"},
        {nullptr, "PySide6.QtWidgets.QGraphicsView.CacheModeFlag"},
        {nullptr, "PySide6.QtWidgets.QGraphicsView.DragMode"},
        {nullptr, "PySide6.QtWidgets.QGraphicsView.OptimizationFlag"},
        {nullptr, "PySide6.QtWidgets.QGraphicsView.ViewportAnchor"},
        {nullptr, "PySide6.QtWidgets.QGraphicsView.ViewportUpdateMode"},
        {nullptr, "PySide6.QtWidgets.QGraphicsWidget"},
        {nullptr, "PySide6.QtWidgets.QGridLayout"},
        {nullptr, "PySide6.QtWidgets.QGroupBox"},
        {nullptr, "PySide6.QtWidgets.QHBoxLayout"},
        {nullptr, "PySide6.QtWidgets.QHeaderView"},
        {nullptr, "PySide6.QtWidgets.QHeaderView.ResizeMode"},
        {nullptr, "PySide6.QtWidgets.QInputDialog"},
        {nullptr, "PySide6.QtWidgets.QInputDialog.InputDialogOption"},
        {nullptr, "PySide6.QtWidgets.QInputDialog.InputMode"},
        {nullptr, "PySide6.QtWidgets.QItemDelegate"},
        {nullptr, "PySide6.QtWidgets.QItemEditorCreatorBase"},
        {nullptr, "PySide6.QtWidgets.QItemEditorFactory"},
        {nullptr, "PySide6.QtWidgets.QKeySequenceEdit"},
        {nullptr, "PySide6.QtWidgets.QLCDNumber"},
        {nullptr, "PySide6.QtWidgets.QLCDNumber.Mode"},
        {nullptr, "PySide6.QtWidgets.QLCDNumber.SegmentStyle"},
        {nullptr, "PySide6.QtWidgets.QLabel"},
        {nullptr, "PySide6.QtWidgets.QLayout"},
        {nullptr, "PySide6.QtWidgets.QLayout.SizeConstraint"},
        {nullptr, "PySide6.QtWidgets.QLayoutItem"},
        {nullptr, "PySide6.QtWidgets.QLineEdit"},
        {nullptr, "PySide6.QtWidgets.QLineEdit.ActionPosition"},
        {nullptr, "PySide6.QtWidgets.QLineEdit.EchoMode"},
        {nullptr, "PySide6.QtWidgets.QListView"},
        {nullptr, "PySide6.QtWidgets.QListView.Flow"},
        {nullptr, "PySide6.QtWidgets.QListView.LayoutMode"},
        {nullptr, "PySide6.QtWidgets.QListView.Movement"},
        {nullptr, "PySide6.QtWidgets.QListView.ResizeMode"},
        {nullptr, "PySide6.QtWidgets.QListView.ViewMode"},
        {nullptr, "PySide6.QtWidgets.QListWidget"},
        {nullptr, "PySide6.QtWidgets.QListWidgetItem"},
        {nullptr, "PySide6.QtWidgets.QListWidgetItem.ItemType"},
        {nullptr, "PySide6.QtWidgets.QMainWindow"},
        {nullptr, "PySide6.QtWidgets.QMainWindow.DockOption"},
        {nullptr, "PySide6.QtWidgets.QMdiArea"},
        {nullptr, "PySide6.QtWidgets.QMdiArea.AreaOption"},
        {nullptr, "PySide6.QtWidgets.QMdiArea.ViewMode"},
        {nullptr, "PySide6.QtWidgets.QMdiArea.WindowOrder"},
        {nullptr, "PySide6.QtWidgets.QMdiSubWindow"},
        {nullptr, "PySide6.QtWidgets.QMdiSubWindow.SubWindowOption"},
        {nullptr, "PySide6.QtWidgets.QMenu"},
        {nullptr, "PySide6.QtWidgets.QMenuBar"},
        {nullptr, "PySide6.QtWidgets.QMessageBox"},
        {nullptr, "PySide6.QtWidgets.QMessageBox.ButtonRole"},
        {nullptr, "PySide6.QtWidgets.QMessageBox.Icon"},
        {nullptr, "PySide6.QtWidgets.QMessageBox.Option"},
        {nullptr, "PySide6.QtWidgets.QMessageBox.StandardButton"},
        {nullptr, "PySide6.QtWidgets.QPanGesture"},
        {nullptr, "PySide6.QtWidgets.QPinchGesture"},
        {nullptr, "PySide6.QtWidgets.QPinchGesture.ChangeFlag"},
        {nullptr, "PySide6.QtWidgets.QPlainTextDocumentLayout"},
        {nullptr, "PySide6.QtWidgets.QPlainTextEdit"},
        {nullptr, "PySide6.QtWidgets.QPlainTextEdit.LineWrapMode"},
        {nullptr, "PySide6.QtWidgets.QProgressBar"},
        {nullptr, "PySide6.QtWidgets.QProgressBar.Direction"},
        {nullptr, "PySide6.QtWidgets.QProgressDialog"},
        {nullptr, "PySide6.QtWidgets.QProxyStyle"},
        {nullptr, "PySide6.QtWidgets.QPushButton"},
        {nullptr, "PySide6.QtWidgets.QRadioButton"},
        {nullptr, "PySide6.QtWidgets.QRhiWidget"},
        {nullptr, "PySide6.QtWidgets.QRhiWidget.Api"},
        {nullptr, "PySide6.QtWidgets.QRhiWidget.TextureFormat"},
        {nullptr, "PySide6.QtWidgets.QRubberBand"},
        {nullptr, "PySide6.QtWidgets.QRubberBand.Shape"},
        {nullptr, "PySide6.QtWidgets.QScrollArea"},
        {nullptr, "PySide6.QtWidgets.QScrollBar"},
        {nullptr, "PySide6.QtWidgets.QScroller"},
        {nullptr, "PySide6.QtWidgets.QScroller.Input"},
        {nullptr, "PySide6.QtWidgets.QScroller.ScrollerGestureType"},
        {nullptr, "PySide6.QtWidgets.QScroller.State"},
        {nullptr, "PySide6.QtWidgets.QScrollerProperties"},
        {nullptr, "PySide6.QtWidgets.QScrollerProperties.FrameRates"},
        {nullptr, "PySide6.QtWidgets.QScrollerProperties.OvershootPolicy"},
        {nullptr, "PySide6.QtWidgets.QScrollerProperties.ScrollMetric"},
        {nullptr, "PySide6.QtWidgets.QSizeGrip"},
        {nullptr, "PySide6.QtWidgets.QSizePolicy"},
        {nullptr, "PySide6.QtWidgets.QSizePolicy.ControlType"},
        {nullptr, "PySide6.QtWidgets.QSizePolicy.Policy"},
        {nullptr, "PySide6.QtWidgets.QSizePolicy.PolicyFlag"},
        {nullptr, "PySide6.QtWidgets.QSlider"},
        {nullptr, "PySide6.QtWidgets.QSlider.TickPosition"},
        {nullptr, "PySide6.QtWidgets.QSpacerItem"},
        {nullptr, "PySide6.QtWidgets.QSpinBox"},
        {nullptr, "PySide6.QtWidgets.QSplashScreen"},
        {nullptr, "PySide6.QtWidgets.QSplitter"},
        {nullptr, "PySide6.QtWidgets.QSplitterHandle"},
        {nullptr, "PySide6.QtWidgets.QStackedLayout"},
        {nullptr, "PySide6.QtWidgets.QStackedLayout.StackingMode"},
        {nullptr, "PySide6.QtWidgets.QStackedWidget"},
        {nullptr, "PySide6.QtWidgets.QStatusBar"},
        {nullptr, "PySide6.QtWidgets.QStyle"},
        {nullptr, "PySide6.QtWidgets.QStyle.ComplexControl"},
        {nullptr, "PySide6.QtWidgets.QStyle.ContentsType"},
        {nullptr, "PySide6.QtWidgets.QStyle.ControlElement"},
        {nullptr, "PySide6.QtWidgets.QStyle.PixelMetric"},
        {nullptr, "PySide6.QtWidgets.QStyle.PrimitiveElement"},
        {nullptr, "PySide6.QtWidgets.QStyle.RequestSoftwareInputPanel"},
        {nullptr, "PySide6.QtWidgets.QStyle.StandardPixmap"},
        {nullptr, "PySide6.QtWidgets.QStyle.StateFlag"},
        {nullptr, "PySide6.QtWidgets.QStyle.StyleHint"},
        {nullptr, "PySide6.QtWidgets.QStyle.SubControl"},
        {nullptr, "PySide6.QtWidgets.QStyle.SubElement"},
        {nullptr, "PySide6.QtWidgets.QStyleFactory"},
        {nullptr, "PySide6.QtWidgets.QStyleHintReturn"},
        {nullptr, "PySide6.QtWidgets.QStyleHintReturn.HintReturnType"},
        {nullptr, "PySide6.QtWidgets.QStyleHintReturn.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleHintReturn.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleHintReturnMask"},
        {nullptr, "PySide6.QtWidgets.QStyleHintReturnMask.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleHintReturnMask.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleHintReturnVariant"},
        {nullptr, "PySide6.QtWidgets.QStyleHintReturnVariant.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleHintReturnVariant.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOption"},
        {nullptr, "PySide6.QtWidgets.QStyleOption.OptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOption.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOption.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionButton"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionButton.ButtonFeature"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionButton.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionButton.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionComboBox"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionComboBox.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionComboBox.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionComplex"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionComplex.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionComplex.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionDockWidget"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionDockWidget.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionDockWidget.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionFocusRect"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionFocusRect.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionFocusRect.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionFrame"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionFrame.FrameFeature"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionFrame.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionFrame.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionGraphicsItem"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionGraphicsItem.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionGraphicsItem.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionGroupBox"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionGroupBox.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionGroupBox.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionHeader"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionHeader.SectionPosition"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionHeader.SelectedPosition"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionHeader.SortIndicator"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionHeader.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionHeader.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionHeaderV2"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionHeaderV2.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionHeaderV2.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionMenuItem"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionMenuItem.CheckType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionMenuItem.MenuItemType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionMenuItem.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionMenuItem.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionProgressBar"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionProgressBar.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionProgressBar.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionRubberBand"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionRubberBand.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionRubberBand.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionSizeGrip"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionSizeGrip.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionSizeGrip.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionSlider"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionSlider.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionSlider.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionSpinBox"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionSpinBox.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionSpinBox.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTab"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTab.CornerWidget"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTab.SelectedPosition"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTab.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTab.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTab.TabFeature"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTab.TabPosition"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTabBarBase"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTabBarBase.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTabBarBase.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTabWidgetFrame"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTabWidgetFrame.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTabWidgetFrame.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTitleBar"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTitleBar.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionTitleBar.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolBar"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolBar.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolBar.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolBar.ToolBarFeature"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolBar.ToolBarPosition"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolBox"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolBox.SelectedPosition"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolBox.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolBox.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolBox.TabPosition"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolButton"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolButton.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolButton.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionToolButton.ToolButtonFeature"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionViewItem"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionViewItem.Position"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionViewItem.StyleOptionType"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionViewItem.StyleOptionVersion"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionViewItem.ViewItemFeature"},
        {nullptr, "PySide6.QtWidgets.QStyleOptionViewItem.ViewItemPosition"},
        {nullptr, "PySide6.QtWidgets.QStylePainter"},
        {nullptr, "PySide6.QtWidgets.QStyledItemDelegate"},
        {nullptr, "PySide6.QtWidgets.QSwipeGesture"},
        {nullptr, "PySide6.QtWidgets.QSwipeGesture.SwipeDirection"},
        {nullptr, "PySide6.QtWidgets.QSystemTrayIcon"},
        {nullptr, "PySide6.QtWidgets.QSystemTrayIcon.ActivationReason"},
        {nullptr, "PySide6.QtWidgets.QSystemTrayIcon.MessageIcon"},
        {nullptr, "PySide6.QtWidgets.QTabBar"},
        {nullptr, "PySide6.QtWidgets.QTabBar.ButtonPosition"},
        {nullptr, "PySide6.QtWidgets.QTabBar.SelectionBehavior"},
        {nullptr, "PySide6.QtWidgets.QTabBar.Shape"},
        {nullptr, "PySide6.QtWidgets.QTabWidget"},
        {nullptr, "PySide6.QtWidgets.QTabWidget.TabPosition"},
        {nullptr, "PySide6.QtWidgets.QTabWidget.TabShape"},
        {nullptr, "PySide6.QtWidgets.QTableView"},
        {nullptr, "PySide6.QtWidgets.QTableWidget"},
        {nullptr, "PySide6.QtWidgets.QTableWidgetItem"},
        {nullptr, "PySide6.QtWidgets.QTableWidgetItem.ItemType"},
        {nullptr, "PySide6.QtWidgets.QTableWidgetSelectionRange"},
        {nullptr, "PySide6.QtWidgets.QTapAndHoldGesture"},
        {nullptr, "PySide6.QtWidgets.QTapGesture"},
        {nullptr, "PySide6.QtWidgets.QTextBrowser"},
        {nullptr, "PySide6.QtWidgets.QTextEdit"},
        {nullptr, "PySide6.QtWidgets.QTextEdit.AutoFormattingFlag"},
        {nullptr, "PySide6.QtWidgets.QTextEdit.ExtraSelection"},
        {nullptr, "PySide6.QtWidgets.QTextEdit.LineWrapMode"},
        {nullptr, "PySide6.QtWidgets.QTileRules"},
        {nullptr, "PySide6.QtWidgets.QTimeEdit"},
        {nullptr, "PySide6.QtWidgets.QToolBar"},
        {nullptr, "PySide6.QtWidgets.QToolBox"},
        {nullptr, "PySide6.QtWidgets.QToolButton"},
        {nullptr, "PySide6.QtWidgets.QToolButton.ToolButtonPopupMode"},
        {nullptr, "PySide6.QtWidgets.QToolTip"},
        {nullptr, "PySide6.QtWidgets.QTreeView"},
        {nullptr, "PySide6.QtWidgets.QTreeWidget"},
        {nullptr, "PySide6.QtWidgets.QTreeWidgetItem"},
        {nullptr, "PySide6.QtWidgets.QTreeWidgetItem.ChildIndicatorPolicy"},
        {nullptr, "PySide6.QtWidgets.QTreeWidgetItem.ItemType"},
        {nullptr, "PySide6.QtWidgets.QTreeWidgetItemIterator"},
        {nullptr, "PySide6.QtWidgets.QTreeWidgetItemIterator.IteratorFlag"},
        {nullptr, "PySide6.QtWidgets.QUndoView"},
        {nullptr, "PySide6.QtWidgets.QVBoxLayout"},
        {nullptr, "PySide6.QtWidgets.QWhatsThis"},
        {nullptr, "PySide6.QtWidgets.QWidget"},
        {nullptr, "PySide6.QtWidgets.QWidget.RenderFlag"},
        {nullptr, "PySide6.QtWidgets.QWidgetAction"},
        {nullptr, "PySide6.QtWidgets.QWidgetItem"},
        {nullptr, "PySide6.QtWidgets.QWizard"},
        {nullptr, "PySide6.QtWidgets.QWizard.WizardButton"},
        {nullptr, "PySide6.QtWidgets.QWizard.WizardOption"},
        {nullptr, "PySide6.QtWidgets.QWizard.WizardPixmap"},
        {nullptr, "PySide6.QtWidgets.QWizard.WizardStyle"},
        {nullptr, "PySide6.QtWidgets.QWizardPage"},
        {nullptr, nullptr}
    };
    // The new global structure consisting of (type, name) pairs.
    SbkPySide6_QtWidgetsTypeStructs = cppApi;
    QT_WARNING_PUSH
    QT_WARNING_DISABLE_DEPRECATED
    // The backward compatible alias with upper case indexes.
    SbkPySide6_QtWidgetsTypes = reinterpret_cast<PyTypeObject **>(cppApi);
    QT_WARNING_POP

    // Create an array of primitive type converters for the current module.
    static SbkConverter *sbkConverters[SBK_QtWidgets_CONVERTERS_IDX_COUNT];
    SbkPySide6_QtWidgetsTypeConverters = sbkConverters;

    PyObject *module = Shiboken::Module::create("QtWidgets", &moduledef);

    // Make module available from global scope
    SbkPySide6_QtWidgetsModuleObject = module;

    // Initialize classes in the type system
    Shiboken::Module::AddTypeCreationFunction(module, "QWhatsThis", init_QWhatsThis);
    Shiboken::Module::AddTypeCreationFunction(module, "QTreeWidgetItemIterator", init_QTreeWidgetItemIterator);
    Shiboken::Module::AddTypeCreationFunction(module, "QTreeWidgetItem", init_QTreeWidgetItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QTableWidgetSelectionRange", init_QTableWidgetSelectionRange);
    Shiboken::Module::AddTypeCreationFunction(module, "QTableWidgetItem", init_QTableWidgetItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleHintReturn", init_QStyleHintReturn);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleHintReturnVariant", init_QStyleHintReturnVariant);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleFactory", init_QStyleFactory);
    Shiboken::Module::AddTypeCreationFunction(module, "QSizePolicy", init_QSizePolicy);
    Shiboken::Module::AddTypeCreationFunction(module, "QScrollerProperties", init_QScrollerProperties);
    Shiboken::Module::AddTypeCreationFunction(module, "QListWidgetItem", init_QListWidgetItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QLayoutItem", init_QLayoutItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QSpacerItem", init_QSpacerItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QItemEditorFactory", init_QItemEditorFactory);
    Shiboken::Module::AddTypeCreationFunction(module, "QItemEditorCreatorBase", init_QItemEditorCreatorBase);
    Shiboken::Module::AddTypeCreationFunction(module, "QGestureRecognizer", init_QGestureRecognizer);
    Shiboken::Module::AddTypeCreationFunction(module, "QColormap", init_QColormap);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleHintReturnMask", init_QStyleHintReturnMask);
    Shiboken::Module::AddTypeCreationFunction(module, "QAccessibleWidget", init_QAccessibleWidget);
    Shiboken::Module::AddTypeCreationFunction(module, "QFileIconProvider", init_QFileIconProvider);
    Shiboken::Module::AddTypeCreationFunction(module, "QTileRules", init_QTileRules);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsLayoutItem", init_QGraphicsLayoutItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsLayout", init_QGraphicsLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsLinearLayout", init_QGraphicsLinearLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsGridLayout", init_QGraphicsGridLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsAnchorLayout", init_QGraphicsAnchorLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsItem", init_QGraphicsItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsPixmapItem", init_QGraphicsPixmapItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsLineItem", init_QGraphicsLineItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsItemGroup", init_QGraphicsItemGroup);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractGraphicsShapeItem", init_QAbstractGraphicsShapeItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsSimpleTextItem", init_QGraphicsSimpleTextItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsRectItem", init_QGraphicsRectItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsPolygonItem", init_QGraphicsPolygonItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsPathItem", init_QGraphicsPathItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsEllipseItem", init_QGraphicsEllipseItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QToolTip", init_QToolTip);
    Shiboken::Module::AddTypeCreationFunction(module, "QStylePainter", init_QStylePainter);
    Shiboken::Module::AddTypeCreationFunction(module, "QWidget", init_QWidget);
    Shiboken::Module::AddTypeCreationFunction(module, "QWizardPage", init_QWizardPage);
    Shiboken::Module::AddTypeCreationFunction(module, "QWidgetItem", init_QWidgetItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QToolBar", init_QToolBar);
    Shiboken::Module::AddTypeCreationFunction(module, "QTabWidget", init_QTabWidget);
    Shiboken::Module::AddTypeCreationFunction(module, "QTabBar", init_QTabBar);
    Shiboken::Module::AddTypeCreationFunction(module, "QStatusBar", init_QStatusBar);
    Shiboken::Module::AddTypeCreationFunction(module, "QSplitterHandle", init_QSplitterHandle);
    Shiboken::Module::AddTypeCreationFunction(module, "QSplashScreen", init_QSplashScreen);
    Shiboken::Module::AddTypeCreationFunction(module, "QSizeGrip", init_QSizeGrip);
    Shiboken::Module::AddTypeCreationFunction(module, "QRubberBand", init_QRubberBand);
    Shiboken::Module::AddTypeCreationFunction(module, "QRhiWidget", init_QRhiWidget);
    Shiboken::Module::AddTypeCreationFunction(module, "QProgressBar", init_QProgressBar);
    Shiboken::Module::AddTypeCreationFunction(module, "QMenuBar", init_QMenuBar);
    Shiboken::Module::AddTypeCreationFunction(module, "QMenu", init_QMenu);
    Shiboken::Module::AddTypeCreationFunction(module, "QMdiSubWindow", init_QMdiSubWindow);
    Shiboken::Module::AddTypeCreationFunction(module, "QMainWindow", init_QMainWindow);
    Shiboken::Module::AddTypeCreationFunction(module, "QLineEdit", init_QLineEdit);
    Shiboken::Module::AddTypeCreationFunction(module, "QKeySequenceEdit", init_QKeySequenceEdit);
    Shiboken::Module::AddTypeCreationFunction(module, "QGroupBox", init_QGroupBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QFrame", init_QFrame);
    Shiboken::Module::AddTypeCreationFunction(module, "QToolBox", init_QToolBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QStackedWidget", init_QStackedWidget);
    Shiboken::Module::AddTypeCreationFunction(module, "QSplitter", init_QSplitter);
    Shiboken::Module::AddTypeCreationFunction(module, "QLabel", init_QLabel);
    Shiboken::Module::AddTypeCreationFunction(module, "QLCDNumber", init_QLCDNumber);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractScrollArea", init_QAbstractScrollArea);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextEdit", init_QTextEdit);
    Shiboken::Module::AddTypeCreationFunction(module, "QTextEdit", init_QTextEdit_ExtraSelection, "QTextEdit.ExtraSelection");
    Shiboken::Module::AddTypeCreationFunction(module, "QTextBrowser", init_QTextBrowser);
    Shiboken::Module::AddTypeCreationFunction(module, "QScrollArea", init_QScrollArea);
    Shiboken::Module::AddTypeCreationFunction(module, "QPlainTextEdit", init_QPlainTextEdit);
    Shiboken::Module::AddTypeCreationFunction(module, "QMdiArea", init_QMdiArea);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsView", init_QGraphicsView);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractItemView", init_QAbstractItemView);
    Shiboken::Module::AddTypeCreationFunction(module, "QTreeView", init_QTreeView);
    Shiboken::Module::AddTypeCreationFunction(module, "QTreeWidget", init_QTreeWidget);
    Shiboken::Module::AddTypeCreationFunction(module, "QTableView", init_QTableView);
    Shiboken::Module::AddTypeCreationFunction(module, "QTableWidget", init_QTableWidget);
    Shiboken::Module::AddTypeCreationFunction(module, "QListView", init_QListView);
    Shiboken::Module::AddTypeCreationFunction(module, "QUndoView", init_QUndoView);
    Shiboken::Module::AddTypeCreationFunction(module, "QListWidget", init_QListWidget);
    Shiboken::Module::AddTypeCreationFunction(module, "QHeaderView", init_QHeaderView);
    Shiboken::Module::AddTypeCreationFunction(module, "QColumnView", init_QColumnView);
    Shiboken::Module::AddTypeCreationFunction(module, "QFocusFrame", init_QFocusFrame);
    Shiboken::Module::AddTypeCreationFunction(module, "QDockWidget", init_QDockWidget);
    Shiboken::Module::AddTypeCreationFunction(module, "QDialogButtonBox", init_QDialogButtonBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QDialog", init_QDialog);
    Shiboken::Module::AddTypeCreationFunction(module, "QWizard", init_QWizard);
    Shiboken::Module::AddTypeCreationFunction(module, "QProgressDialog", init_QProgressDialog);
    Shiboken::Module::AddTypeCreationFunction(module, "QMessageBox", init_QMessageBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QInputDialog", init_QInputDialog);
    Shiboken::Module::AddTypeCreationFunction(module, "QFontDialog", init_QFontDialog);
    Shiboken::Module::AddTypeCreationFunction(module, "QErrorMessage", init_QErrorMessage);
    Shiboken::Module::AddTypeCreationFunction(module, "QColorDialog", init_QColorDialog);
    Shiboken::Module::AddTypeCreationFunction(module, "QComboBox", init_QComboBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QFontComboBox", init_QFontComboBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QCalendarWidget", init_QCalendarWidget);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractSpinBox", init_QAbstractSpinBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QSpinBox", init_QSpinBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QDoubleSpinBox", init_QDoubleSpinBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QDateTimeEdit", init_QDateTimeEdit);
    Shiboken::Module::AddTypeCreationFunction(module, "QTimeEdit", init_QTimeEdit);
    Shiboken::Module::AddTypeCreationFunction(module, "QDateEdit", init_QDateEdit);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractSlider", init_QAbstractSlider);
    Shiboken::Module::AddTypeCreationFunction(module, "QSlider", init_QSlider);
    Shiboken::Module::AddTypeCreationFunction(module, "QScrollBar", init_QScrollBar);
    Shiboken::Module::AddTypeCreationFunction(module, "QDial", init_QDial);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractButton", init_QAbstractButton);
    Shiboken::Module::AddTypeCreationFunction(module, "QToolButton", init_QToolButton);
    Shiboken::Module::AddTypeCreationFunction(module, "QRadioButton", init_QRadioButton);
    Shiboken::Module::AddTypeCreationFunction(module, "QPushButton", init_QPushButton);
    Shiboken::Module::AddTypeCreationFunction(module, "QCommandLinkButton", init_QCommandLinkButton);
    Shiboken::Module::AddTypeCreationFunction(module, "QCheckBox", init_QCheckBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QSystemTrayIcon", init_QSystemTrayIcon);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOption", init_QStyleOption);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionViewItem", init_QStyleOptionViewItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionToolBox", init_QStyleOptionToolBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionToolBar", init_QStyleOptionToolBar);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionTabWidgetFrame", init_QStyleOptionTabWidgetFrame);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionTabBarBase", init_QStyleOptionTabBarBase);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionTab", init_QStyleOptionTab);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionRubberBand", init_QStyleOptionRubberBand);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionProgressBar", init_QStyleOptionProgressBar);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionMenuItem", init_QStyleOptionMenuItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionHeader", init_QStyleOptionHeader);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionHeaderV2", init_QStyleOptionHeaderV2);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionGraphicsItem", init_QStyleOptionGraphicsItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionFrame", init_QStyleOptionFrame);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionFocusRect", init_QStyleOptionFocusRect);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionDockWidget", init_QStyleOptionDockWidget);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionComplex", init_QStyleOptionComplex);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionToolButton", init_QStyleOptionToolButton);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionTitleBar", init_QStyleOptionTitleBar);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionSpinBox", init_QStyleOptionSpinBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionSlider", init_QStyleOptionSlider);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionSizeGrip", init_QStyleOptionSizeGrip);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionGroupBox", init_QStyleOptionGroupBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionComboBox", init_QStyleOptionComboBox);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyleOptionButton", init_QStyleOptionButton);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyle", init_QStyle);
    Shiboken::Module::AddTypeCreationFunction(module, "QCommonStyle", init_QCommonStyle);
    Shiboken::Module::AddTypeCreationFunction(module, "QProxyStyle", init_QProxyStyle);
    Shiboken::Module::AddTypeCreationFunction(module, "QScroller", init_QScroller);
    Shiboken::Module::AddTypeCreationFunction(module, "QLayout", init_QLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QStackedLayout", init_QStackedLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QGridLayout", init_QGridLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QFormLayout", init_QFormLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QFormLayout", init_QFormLayout_TakeRowResult, "QFormLayout.TakeRowResult");
    Shiboken::Module::AddTypeCreationFunction(module, "QBoxLayout", init_QBoxLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QVBoxLayout", init_QVBoxLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QHBoxLayout", init_QHBoxLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsTransform", init_QGraphicsTransform);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsScale", init_QGraphicsScale);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsRotation", init_QGraphicsRotation);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsScene", init_QGraphicsScene);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsObject", init_QGraphicsObject);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsWidget", init_QGraphicsWidget);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsProxyWidget", init_QGraphicsProxyWidget);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsTextItem", init_QGraphicsTextItem);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsItemAnimation", init_QGraphicsItemAnimation);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsEffect", init_QGraphicsEffect);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsOpacityEffect", init_QGraphicsOpacityEffect);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsDropShadowEffect", init_QGraphicsDropShadowEffect);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsColorizeEffect", init_QGraphicsColorizeEffect);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsBlurEffect", init_QGraphicsBlurEffect);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsAnchor", init_QGraphicsAnchor);
    Shiboken::Module::AddTypeCreationFunction(module, "QGesture", init_QGesture);
    Shiboken::Module::AddTypeCreationFunction(module, "QTapGesture", init_QTapGesture);
    Shiboken::Module::AddTypeCreationFunction(module, "QTapAndHoldGesture", init_QTapAndHoldGesture);
    Shiboken::Module::AddTypeCreationFunction(module, "QSwipeGesture", init_QSwipeGesture);
    Shiboken::Module::AddTypeCreationFunction(module, "QPinchGesture", init_QPinchGesture);
    Shiboken::Module::AddTypeCreationFunction(module, "QPanGesture", init_QPanGesture);
    Shiboken::Module::AddTypeCreationFunction(module, "QDataWidgetMapper", init_QDataWidgetMapper);
    Shiboken::Module::AddTypeCreationFunction(module, "QCompleter", init_QCompleter);
    Shiboken::Module::AddTypeCreationFunction(module, "QButtonGroup", init_QButtonGroup);
    Shiboken::Module::AddTypeCreationFunction(module, "QAbstractItemDelegate", init_QAbstractItemDelegate);
    Shiboken::Module::AddTypeCreationFunction(module, "QStyledItemDelegate", init_QStyledItemDelegate);
    Shiboken::Module::AddTypeCreationFunction(module, "QItemDelegate", init_QItemDelegate);
    Shiboken::Module::AddTypeCreationFunction(module, "QWidgetAction", init_QWidgetAction);
    Shiboken::Module::AddTypeCreationFunction(module, "QPlainTextDocumentLayout", init_QPlainTextDocumentLayout);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsSceneEvent", init_QGraphicsSceneEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsSceneWheelEvent", init_QGraphicsSceneWheelEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsSceneResizeEvent", init_QGraphicsSceneResizeEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsSceneMoveEvent", init_QGraphicsSceneMoveEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsSceneMouseEvent", init_QGraphicsSceneMouseEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsSceneHoverEvent", init_QGraphicsSceneHoverEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsSceneHelpEvent", init_QGraphicsSceneHelpEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsSceneDragDropEvent", init_QGraphicsSceneDragDropEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QGraphicsSceneContextMenuEvent", init_QGraphicsSceneContextMenuEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QGestureEvent", init_QGestureEvent);
    Shiboken::Module::AddTypeCreationFunction(module, "QApplication", init_QApplication);
    Shiboken::Module::AddTypeCreationFunction(module, "QFileDialog", init_QFileDialog);
    Shiboken::Module::AddTypeCreationFunction(module, "QFileSystemModel", init_QFileSystemModel);

    // Register converter for type 'QList<int>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_int_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_int__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_int_IDX], "QList<int>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_int_IDX],
        PySequence_PythonToCpp__QList_int_,
        is_PySequence_PythonToCpp__QList_int__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_int_IDX],
        PythonToCppQIntList,
        isQIntListPythonToCppConvertible);

    // Register converter for type 'QList<QTreeWidgetItem*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTreeWidgetItemPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTreeWidgetItemPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTreeWidgetItemPTR_IDX], "QList<QTreeWidgetItem*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTreeWidgetItemPTR_IDX],
        PySequence_PythonToCpp__QList_QTreeWidgetItemPTR_,
        is_PySequence_PythonToCpp__QList_QTreeWidgetItemPTR__Convertible);

    // Register converter for type 'QList<QColor>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QColor_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QColor__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QColor_IDX], "QList<QColor>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QColor_IDX],
        PySequence_PythonToCpp__QList_QColor_,
        is_PySequence_PythonToCpp__QList_QColor__Convertible);

    // Register converter for type 'std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX], "std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX],
        PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag__,
        is_PySequence_PythonToCpp_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___Convertible);

    // Register converter for type 'QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX], "QList<std::pair<QAccessibleInterface*,QFlags<QAccessible::RelationFlag>>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag_IDX],
        PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag___,
        is_PySequence_PythonToCpp__QList_std_pair_QAccessibleInterfacePTR_QFlags_QAccessible_RelationFlag____Convertible);

    // Register converter for type 'QList<QGraphicsItem*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsItemPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QGraphicsItemPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsItemPTR_IDX], "QList<QGraphicsItem*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsItemPTR_IDX],
        PySequence_PythonToCpp__QList_QGraphicsItemPTR_,
        is_PySequence_PythonToCpp__QList_QGraphicsItemPTR__Convertible);

    // Register converter for type 'QList<QGraphicsTransform*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsTransformPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QGraphicsTransformPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsTransformPTR_IDX], "QList<QGraphicsTransform*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsTransformPTR_IDX],
        PySequence_PythonToCpp__QList_QGraphicsTransformPTR_,
        is_PySequence_PythonToCpp__QList_QGraphicsTransformPTR__Convertible);

    // Register converter for type 'QList<QLine>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QLine_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLine__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QLine_IDX], "QList<QLine>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QLine_IDX],
        PySequence_PythonToCpp__QList_QLine_,
        is_PySequence_PythonToCpp__QList_QLine__Convertible);

    // Register converter for type 'QList<QLineF>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QLineF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QLineF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QLineF_IDX], "QList<QLineF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QLineF_IDX],
        PySequence_PythonToCpp__QList_QLineF_,
        is_PySequence_PythonToCpp__QList_QLineF__Convertible);

    // Register converter for type 'QList<QPoint>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QPoint_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QPoint__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QPoint_IDX], "QList<QPoint>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QPoint_IDX],
        PySequence_PythonToCpp__QList_QPoint_,
        is_PySequence_PythonToCpp__QList_QPoint__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QPoint_IDX],
        PythonToCppQPointList,
        isQPointListPythonToCppConvertible);

    // Register converter for type 'QList<QPointF>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QPointF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QPointF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QPointF_IDX], "QList<QPointF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QPointF_IDX],
        PySequence_PythonToCpp__QList_QPointF_,
        is_PySequence_PythonToCpp__QList_QPointF__Convertible);
    Shiboken::Conversions::setPythonToCppPointerFunctions(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QPointF_IDX],
        PythonToCppQPointFList,
        isQPointFListPythonToCppConvertible);

    // Register converter for type 'QList<QRect>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QRect_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRect__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QRect_IDX], "QList<QRect>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QRect_IDX],
        PySequence_PythonToCpp__QList_QRect_,
        is_PySequence_PythonToCpp__QList_QRect__Convertible);

    // Register converter for type 'QList<QRectF>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QRectF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QRectF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QRectF_IDX], "QList<QRectF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QRectF_IDX],
        PySequence_PythonToCpp__QList_QRectF_,
        is_PySequence_PythonToCpp__QList_QRectF__Convertible);

    // Register converter for type 'QList<QAction*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QActionPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QActionPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QActionPTR_IDX], "QList<QAction*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QActionPTR_IDX],
        PySequence_PythonToCpp__QList_QActionPTR_,
        is_PySequence_PythonToCpp__QList_QActionPTR__Convertible);

    // Register converter for type 'QList<QObject*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QObjectPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QObjectPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QObjectPTR_IDX], "QList<QObject*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QObjectPTR_IDX],
        PySequence_PythonToCpp__QList_QObjectPTR_,
        is_PySequence_PythonToCpp__QList_QObjectPTR__Convertible);
    // Register converters for type aliases of QList<QObject*>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QObjectPTR_IDX], "QObjectList");

    // Register converter for type 'QList<QByteArray>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QByteArray__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QByteArray_IDX], "QList<QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QByteArray_IDX],
        PySequence_PythonToCpp__QList_QByteArray_,
        is_PySequence_PythonToCpp__QList_QByteArray__Convertible);
    // Register converters for type aliases of QList<QByteArray>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QByteArray_IDX], "QByteArrayList");

    // Register converter for type 'QList<QDockWidget*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QDockWidgetPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QDockWidgetPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QDockWidgetPTR_IDX], "QList<QDockWidget*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QDockWidgetPTR_IDX],
        PySequence_PythonToCpp__QList_QDockWidgetPTR_,
        is_PySequence_PythonToCpp__QList_QDockWidgetPTR__Convertible);

    // Register converter for type 'QList<QKeyCombination>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QKeyCombination_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QKeyCombination__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QKeyCombination_IDX], "QList<QKeyCombination>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QKeyCombination_IDX],
        PySequence_PythonToCpp__QList_QKeyCombination_,
        is_PySequence_PythonToCpp__QList_QKeyCombination__Convertible);

    // Register converter for type 'QList<QWidget*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWidgetPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QWidgetPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWidgetPTR_IDX], "QList<QWidget*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWidgetPTR_IDX],
        PySequence_PythonToCpp__QList_QWidgetPTR_,
        is_PySequence_PythonToCpp__QList_QWidgetPTR__Convertible);
    // Register converters for type aliases of QList<QWidget*>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWidgetPTR_IDX], "QWidgetList");

    // Register converter for type 'QList<QTextEdit::ExtraSelection>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTextEdit_ExtraSelection_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTextEdit_ExtraSelection__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTextEdit_ExtraSelection_IDX], "QList<QTextEdit::ExtraSelection>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTextEdit_ExtraSelection_IDX],
        PySequence_PythonToCpp__QList_QTextEdit_ExtraSelection_,
        is_PySequence_PythonToCpp__QList_QTextEdit_ExtraSelection__Convertible);

    // Register converter for type 'QList<QMdiSubWindow*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QMdiSubWindowPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QMdiSubWindowPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QMdiSubWindowPTR_IDX], "QList<QMdiSubWindow*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QMdiSubWindowPTR_IDX],
        PySequence_PythonToCpp__QList_QMdiSubWindowPTR_,
        is_PySequence_PythonToCpp__QList_QMdiSubWindowPTR__Convertible);

    // Register converter for type 'QList<QModelIndex>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QModelIndex_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QModelIndex__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QModelIndex_IDX], "QList<QModelIndex>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QModelIndex_IDX],
        PySequence_PythonToCpp__QList_QModelIndex_,
        is_PySequence_PythonToCpp__QList_QModelIndex__Convertible);
    // Register converters for type aliases of QList<QModelIndex>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QModelIndex_IDX], "QModelIndexList");

    // Register converter for type 'QList<QTableWidgetItem*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTableWidgetItemPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTableWidgetItemPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTableWidgetItemPTR_IDX], "QList<QTableWidgetItem*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTableWidgetItemPTR_IDX],
        PySequence_PythonToCpp__QList_QTableWidgetItemPTR_,
        is_PySequence_PythonToCpp__QList_QTableWidgetItemPTR__Convertible);

    // Register converter for type 'QList<QTableWidgetSelectionRange>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTableWidgetSelectionRange_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QTableWidgetSelectionRange__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTableWidgetSelectionRange_IDX], "QList<QTableWidgetSelectionRange>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QTableWidgetSelectionRange_IDX],
        PySequence_PythonToCpp__QList_QTableWidgetSelectionRange_,
        is_PySequence_PythonToCpp__QList_QTableWidgetSelectionRange__Convertible);

    // Register converter for type 'QList<QListWidgetItem*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QListWidgetItemPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QListWidgetItemPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QListWidgetItemPTR_IDX], "QList<QListWidgetItem*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QListWidgetItemPTR_IDX],
        PySequence_PythonToCpp__QList_QListWidgetItemPTR_,
        is_PySequence_PythonToCpp__QList_QListWidgetItemPTR__Convertible);

    // Register converter for type 'QList<QAbstractButton*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QAbstractButtonPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QAbstractButtonPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QAbstractButtonPTR_IDX], "QList<QAbstractButton*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QAbstractButtonPTR_IDX],
        PySequence_PythonToCpp__QList_QAbstractButtonPTR_,
        is_PySequence_PythonToCpp__QList_QAbstractButtonPTR__Convertible);

    // Register converter for type 'QList<QWizard::WizardButton>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWizard_WizardButton_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QWizard_WizardButton__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWizard_WizardButton_IDX], "QList<QWizard::WizardButton>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWizard_WizardButton_IDX],
        PySequence_PythonToCpp__QList_QWizard_WizardButton_,
        is_PySequence_PythonToCpp__QList_QWizard_WizardButton__Convertible);

    // Register converter for type 'QMap<QDate,QTextCharFormat>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QMap_QDate_QTextCharFormat_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_QDate_QTextCharFormat__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QMap_QDate_QTextCharFormat_IDX], "QMap<QDate,QTextCharFormat>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QMap_QDate_QTextCharFormat_IDX],
        PyDict_PythonToCpp__QMap_QDate_QTextCharFormat_,
        is_PyDict_PythonToCpp__QMap_QDate_QTextCharFormat__Convertible);

    // Register converter for type 'QList<QScroller*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QScrollerPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QScrollerPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QScrollerPTR_IDX], "QList<QScroller*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QScrollerPTR_IDX],
        PySequence_PythonToCpp__QList_QScrollerPTR_,
        is_PySequence_PythonToCpp__QList_QScrollerPTR__Convertible);

    // Register converter for type 'QList<qreal>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_qreal_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_qreal__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_qreal_IDX], "QList<qreal>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_qreal_IDX],
        PySequence_PythonToCpp__QList_qreal_,
        is_PySequence_PythonToCpp__QList_qreal__Convertible);

    // Register converter for type 'QList<QGraphicsView*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsViewPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QGraphicsViewPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsViewPTR_IDX], "QList<QGraphicsView*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGraphicsViewPTR_IDX],
        PySequence_PythonToCpp__QList_QGraphicsViewPTR_,
        is_PySequence_PythonToCpp__QList_QGraphicsViewPTR__Convertible);

    // Register converter for type 'std::pair<qreal,QPointF>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_qreal_QPointF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_qreal_QPointF__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_qreal_QPointF_IDX], "std::pair<qreal,QPointF>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_qreal_QPointF_IDX],
        PySequence_PythonToCpp_std_pair_qreal_QPointF_,
        is_PySequence_PythonToCpp_std_pair_qreal_QPointF__Convertible);

    // Register converter for type 'QList<std::pair<qreal,QPointF>>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_std_pair_qreal_QPointF_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_std_pair_qreal_QPointF___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_std_pair_qreal_QPointF_IDX], "QList<std::pair<qreal,QPointF>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_std_pair_qreal_QPointF_IDX],
        PySequence_PythonToCpp__QList_std_pair_qreal_QPointF__,
        is_PySequence_PythonToCpp__QList_std_pair_qreal_QPointF___Convertible);

    // Register converter for type 'std::pair<qreal,qreal>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_qreal_qreal_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, std_pair_qreal_qreal__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_qreal_qreal_IDX], "std::pair<qreal,qreal>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_std_pair_qreal_qreal_IDX],
        PySequence_PythonToCpp_std_pair_qreal_qreal_,
        is_PySequence_PythonToCpp_std_pair_qreal_qreal__Convertible);

    // Register converter for type 'QList<std::pair<qreal,qreal>>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_std_pair_qreal_qreal_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_std_pair_qreal_qreal___CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_std_pair_qreal_qreal_IDX], "QList<std::pair<qreal,qreal>>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_std_pair_qreal_qreal_IDX],
        PySequence_PythonToCpp__QList_std_pair_qreal_qreal__,
        is_PySequence_PythonToCpp__QList_std_pair_qreal_qreal___Convertible);

    // Register converter for type 'QList<QKeySequence>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QKeySequence_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QKeySequence__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QKeySequence_IDX], "QList<QKeySequence>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QKeySequence_IDX],
        PySequence_PythonToCpp__QList_QKeySequence_,
        is_PySequence_PythonToCpp__QList_QKeySequence__Convertible);

    // Register converter for type 'QList<QGesture*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGesturePTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QGesturePTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGesturePTR_IDX], "QList<QGesture*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QGesturePTR_IDX],
        PySequence_PythonToCpp__QList_QGesturePTR_,
        is_PySequence_PythonToCpp__QList_QGesturePTR__Convertible);

    // Register converter for type 'QList<QWindow*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWindowPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QWindowPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWindowPTR_IDX], "QList<QWindow*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWindowPTR_IDX],
        PySequence_PythonToCpp__QList_QWindowPTR_,
        is_PySequence_PythonToCpp__QList_QWindowPTR__Convertible);
    // Register converters for type aliases of QList<QWindow*>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QWindowPTR_IDX], "QWindowList");

    // Register converter for type 'QList<QScreen*>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QScreenPTR_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QScreenPTR__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QScreenPTR_IDX], "QList<QScreen*>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QScreenPTR_IDX],
        PySequence_PythonToCpp__QList_QScreenPTR_,
        is_PySequence_PythonToCpp__QList_QScreenPTR__Convertible);

    // Register converter for type 'QList<QUrl>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QUrl_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QUrl__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QUrl_IDX], "QList<QUrl>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QUrl_IDX],
        PySequence_PythonToCpp__QList_QUrl_,
        is_PySequence_PythonToCpp__QList_QUrl__Convertible);

    // Register converter for type 'QMap<int,QVariant>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QMap_int_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_int_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QMap_int_QVariant_IDX], "QMap<int,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QMap_int_QVariant_IDX],
        PyDict_PythonToCpp__QMap_int_QVariant_,
        is_PyDict_PythonToCpp__QMap_int_QVariant__Convertible);

    // Register converter for type 'QHash<int,QByteArray>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QHash_int_QByteArray_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QHash_int_QByteArray__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QHash_int_QByteArray_IDX], "QHash<int,QByteArray>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QHash_int_QByteArray_IDX],
        PyDict_PythonToCpp__QHash_int_QByteArray_,
        is_PyDict_PythonToCpp__QHash_int_QByteArray__Convertible);

    // Register converter for type 'QList<QVariant>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QVariant__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QVariant_IDX], "QList<QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QVariant_IDX],
        PySequence_PythonToCpp__QList_QVariant_,
        is_PySequence_PythonToCpp__QList_QVariant__Convertible);
    // Register converters for type aliases of QList<QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QVariant_IDX], "QVariantList");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QVariant_IDX], "QVariantList");

    // Register converter for type 'QList<QString>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QString_IDX] = Shiboken::Conversions::createConverter(&PyList_Type, _QList_QString__CppToPython_PyList);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QString_IDX], "QList<QString>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QList_QString_IDX],
        PySequence_PythonToCpp__QList_QString_,
        is_PySequence_PythonToCpp__QList_QString__Convertible);
    // Register converters for type aliases of QList<QString>'.

    // Register converter for type 'QMap<QString,QVariant>'.
    SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QMap_QString_QVariant_IDX] = Shiboken::Conversions::createConverter(&PyDict_Type, _QMap_QString_QVariant__CppToPython_PyDict);
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QMap_QString_QVariant_IDX], "QMap<QString,QVariant>");
    Shiboken::Conversions::addPythonToCppValueConversion(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QMap_QString_QVariant_IDX],
        PyDict_PythonToCpp__QMap_QString_QVariant_,
        is_PyDict_PythonToCpp__QMap_QString_QVariant__Convertible);
    // Register converters for type aliases of QMap<QString,QVariant>'.
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QMap_QString_QVariant_IDX], "QVariantMap");
    Shiboken::Conversions::registerConverterName(SbkPySide6_QtWidgetsTypeConverters[SBK_QtWidgets_QMap_QString_QVariant_IDX], "QSettings::SettingsMap");


    // Opaque container type registration
    PyObject *ob_type{};
    auto *qVariantConverter = Shiboken::Conversions::getConverter("QVariant");
    Q_ASSERT(qVariantConverter != nullptr);
    ob_type = reinterpret_cast<PyObject *>(QIntList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QIntList", ob_type);
    if constexpr (QMetaTypeId2<int>::Defined) {
        Shiboken::Conversions::prependPythonToCppValueConversion(qVariantConverter,
            PythonToQVariantQIntList, isQIntListPythonToQVariantConvertible);
    }
    ob_type = reinterpret_cast<PyObject *>(QPointList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QPointList", ob_type);
    if constexpr (QMetaTypeId2<QPoint>::Defined) {
        Shiboken::Conversions::prependPythonToCppValueConversion(qVariantConverter,
            PythonToQVariantQPointList, isQPointListPythonToQVariantConvertible);
    }
    ob_type = reinterpret_cast<PyObject *>(QPointFList_TypeF());
    Py_XINCREF(ob_type);
    PyModule_AddObject(module, "QPointFList", ob_type);
    if constexpr (QMetaTypeId2<QPointF>::Defined) {
        Shiboken::Conversions::prependPythonToCppValueConversion(qVariantConverter,
            PythonToQVariantQPointFList, isQPointFListPythonToQVariantConvertible);
    }

    // Register primitive types converters.
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLbitfield");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "GLboolean");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "GLbyte");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "GLchar");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "GLcharARB");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<double>(), "GLclampd");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "GLclampf");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<double>(), "GLdouble");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLenum");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLfixed");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "GLfloat");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalf");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalfARB");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLhalfNV");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLhandleARB");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLint");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLint64");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLint64EXT");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLintptr");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<ptrdiff_t>(), "GLintptrARB");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "GLshort");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "GLsizei");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLsizeiptr");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<ptrdiff_t>(), "GLsizeiptrARB");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "GLubyte");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "GLuint");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "GLuint64");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "GLuint64EXT");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "GLushort");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "GLvdpauSurfaceNV");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLACQUIREKEYEDMUTEXWIN32EXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLAREPROGRAMSRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLARETEXTURESRESIDENTEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDLIGHTPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDMATERIALPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDTEXGENPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLBINDTEXTUREUNITPARAMETEREXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKFRAMEBUFFERSTATUSEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKFRAMEBUFFERSTATUSPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKNAMEDFRAMEBUFFERSTATUSEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCHECKNAMEDFRAMEBUFFERSTATUSPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCLIENTWAITSYNCPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATEPROGRAMOBJECTARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATEPROGRAMPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADEROBJECTARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROGRAMEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLCREATESHADERPROGRAMVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLFINISHASYNCSGIXPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENASYNCMARKERSSGIXPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENFRAGMENTSHADERSATIPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENPATHSNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENSYMBOLSEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGENVERTEXSHADERSEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETATTRIBLOCATIONARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETATTRIBLOCATIONPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETCOMMANDHEADERNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGAMDPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETDEBUGMESSAGELOGPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATAINDEXPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATALOCATIONEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETFRAGDATALOCATIONPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETGRAPHICSRESETSTATUSARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETGRAPHICSRESETSTATUSPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETHANDLEARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETIMAGEHANDLEARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETIMAGEHANDLENVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETINSTRUMENTSSGIXPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<float>(), "PFNGLGETPATHLENGTHNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETPROGRAMRESOURCEINDEXPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETPROGRAMRESOURCELOCATIONINDEXPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETPROGRAMRESOURCELOCATIONPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "PFNGLGETSTAGEINDEXNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLGETSTRINGIPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETSUBROUTINEINDEXPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETSUBROUTINEUNIFORMLOCATIONPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTUREHANDLEARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTUREHANDLENVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTURESAMPLERHANDLEARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "PFNGLGETTEXTURESAMPLERHANDLENVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLGETUNIFORMBLOCKINDEXPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMBUFFERSIZEEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMLOCATIONARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETUNIFORMLOCATIONPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLGETUNIFORMOFFSETEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLGETVARYINGLOCATIONNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISASYNCMARKERSGIXPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISBUFFERRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISCOMMANDLISTNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISENABLEDINDEXEDEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISENABLEDIPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFENCEAPPLEPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFENCENVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFRAMEBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISFRAMEBUFFERPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISIMAGEHANDLERESIDENTARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISIMAGEHANDLERESIDENTNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISMEMORYOBJECTEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEAMDPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEDBUFFERRESIDENTNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISNAMEDSTRINGARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISOBJECTBUFFERATIPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISOCCLUSIONQUERYNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPATHNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPOINTINFILLPATHNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPOINTINSTROKEPATHNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMPIPELINEPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISPROGRAMPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISQUERYARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISQUERYPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISRENDERBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISRENDERBUFFERPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSAMPLERPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSEMAPHOREEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSHADERPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSTATENVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISSYNCPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREHANDLERESIDENTARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTEXTUREHANDLERESIDENTNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTRANSFORMFEEDBACKNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISTRANSFORMFEEDBACKPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVARIANTENABLEDEXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXARRAYAPPLEPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXARRAYPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLISVERTEXATTRIBENABLEDAPPLEPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLNEWOBJECTBUFFERATIPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLOBJECTPURGEABLEAPPLEPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLOBJECTUNPURGEABLEAPPLEPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHGLYPHINDEXARRAYNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHGLYPHINDEXRANGENVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLPATHMEMORYGLYPHINDEXARRAYNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLPOINTALONGPATHNVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLPOLLASYNCSGIXPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLPOLLINSTRUMENTSSGIXPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLQUERYMATRIXXOESPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "PFNGLQUERYRESOURCENVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLRELEASEKEYEDMUTEXWIN32EXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTFENCEAPPLEPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTFENCENVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLTESTOBJECTAPPLEPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPBUFFERARBPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPBUFFERPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPNAMEDBUFFEREXTPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLUNMAPNAMEDBUFFERPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "PFNGLVDPAUISSURFACENVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTEROUTPUTSURFACENVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTERVIDEOSURFACENVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "PFNGLVDPAUREGISTERVIDEOSURFACEWITHPICTURESTRUCTURENVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "PFNGLVIDEOCAPTURENVPROC");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "QRgb");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blkcnt_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__blksize_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "__caddr_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__clock_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__clockid_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_d_fn_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__compar_fn_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__daddr_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__dev_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsblkcnt_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__fsfilcnt_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__fsword_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__gid_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__id_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__ino_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int16_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int32_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int8_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<short>(), "__int_least16_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__int_least32_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__int_least64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "__int_least8_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intmax_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__intptr_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__key_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__loff_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__mode_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__nlink_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__off_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__pid_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__poll_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__quad_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__rlim_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "__sig_atomic_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__socklen_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__ssize_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__suseconds_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__syscall_slong_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__syscall_ulong_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "__time_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__u_char");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__u_int");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_long");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__u_quad_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__u_short");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uid_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint16_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint32_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint8_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "__uint_least16_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__uint_least32_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uint_least64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "__uint_least8_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "__uintmax_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "__useconds_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blkcnt_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "blksize_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<char>(), "caddr_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "comparison_fn_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "daddr_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "dev_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsblkcnt_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "fsfilcnt_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "gid_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "id_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "ino_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast16_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast32_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "int_fast64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<signed char>(), "int_fast8_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "intmax_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "key_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "loff_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "mode_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "nlink_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "off_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<int>(), "pid_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), "qInternalCallback");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<ptrdiff_t>(), "qopengl_GLintptr");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<ptrdiff_t>(), "qopengl_GLsizeiptr");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "quad_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "register_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "ssize_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<long>(), "suseconds_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_char");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_int16_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "u_int32_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_int64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "u_int8_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_long");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "u_quad_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned short>(), "u_short");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "uid_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast16_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast32_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uint_fast64_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned char>(), "uint_fast8_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned long>(), "uintmax_t");
    Shiboken::Conversions::registerConverterAlias(Shiboken::Conversions::PrimitiveTypeConverter<unsigned int>(), "useconds_t");

    Shiboken::Module::registerTypes(module, SbkPySide6_QtWidgetsTypeStructs);
    Shiboken::Module::registerTypeConverters(module, SbkPySide6_QtWidgetsTypeConverters);

    initInheritance();

    if (Shiboken::Errors::occurred() != nullptr) {
        PyErr_Print();
        Py_FatalError("can't initialize module QtWidgets");
    }
    PySide::registerCleanupFunction(cleanTypesAttributes);

#if PYSIDE6_COMOPT_COMPRESS == 0
    FinishSignatureInitialization(module, QtWidgets_SignatureStrings);
#else
    if (FinishSignatureInitBytes(module, QtWidgets_SignatureBytes, QtWidgets_SignatureByteSize) < 0)
        return {};
#endif

    return module;
}
